{
 "cells": [
  {
   "cell_type": "code",
   "execution_count": 1,
   "metadata": {
    "tags": [
     "hide-input"
    ]
   },
   "outputs": [],
   "source": [
    "import numpy as np\n",
    "import matplotlib.pyplot as plt\n",
    "%matplotlib inline\n",
    "import matplotlib_inline\n",
    "matplotlib_inline.backend_inline.set_matplotlib_formats('svg')\n",
    "import seaborn as sns\n",
    "sns.set_context(\"paper\")\n",
    "sns.set_style(\"ticks\")\n",
    "\n",
    "import torch\n",
    "import gpytorch\n",
    "from gpytorch.kernels import RBFKernel, ScaleKernel\n",
    "\n",
    "\n",
    "class ExactGP(gpytorch.models.ExactGP):\n",
    "    def __init__(self,\n",
    "                 train_x,\n",
    "                 train_y,\n",
    "                 likelihood=gpytorch.likelihoods.GaussianLikelihood(\n",
    "                     noise_constraint=gpytorch.constraints.GreaterThan(0.0)\n",
    "                ),\n",
    "                mean_module=gpytorch.means.ConstantMean(),\n",
    "                covar_module=ScaleKernel(RBFKernel())\n",
    "        ):\n",
    "        super().__init__(train_x, train_y, likelihood)\n",
    "        self.mean_module = mean_module\n",
    "        self.covar_module = covar_module\n",
    "\n",
    "    def forward(self, x):\n",
    "        mean_x = self.mean_module(x)\n",
    "        covar_x = self.covar_module(x)\n",
    "        return gpytorch.distributions.MultivariateNormal(mean_x, covar_x)\n",
    "\n",
    "\n",
    "def plot_1d_regression(\n",
    "    x_star,\n",
    "    model,\n",
    "    ax=None,\n",
    "    f_true=None,\n",
    "    num_samples=10\n",
    "):\n",
    "    \"\"\"Plot the posterior predictive.\n",
    "    \n",
    "    Arguments\n",
    "    x_start  --  The test points on which to evaluate.\n",
    "    model    --  The trained model.\n",
    "    \n",
    "    Keyword Arguments\n",
    "    ax          --  An axes object to write on.\n",
    "    f_true      --  The true function.\n",
    "    num_samples --  The number of samples.\n",
    "    \"\"\"\n",
    "    f_star = model(x_star)\n",
    "    m_star = f_star.mean\n",
    "    v_star = f_star.variance\n",
    "    y_star = model.likelihood(f_star)\n",
    "    yv_star = y_star.variance\n",
    "\n",
    "    f_lower = (\n",
    "        m_star - 2.0 * torch.sqrt(v_star)\n",
    "    )\n",
    "    f_upper = (\n",
    "        m_star + 2.0 * torch.sqrt(v_star)\n",
    "    )\n",
    "    \n",
    "    y_lower = m_star - 2.0 * torch.sqrt(yv_star)\n",
    "    y_upper = m_star + 2.0 * torch.sqrt(yv_star)\n",
    "\n",
    "    if ax is None:\n",
    "        fig, ax = plt.subplots()\n",
    "    \n",
    "    ax.plot(model.train_inputs[0].flatten().detach(),\n",
    "            model.train_targets.detach(),\n",
    "            'kx',\n",
    "            markersize=10,\n",
    "            markeredgewidth=2,\n",
    "            label='Observations'\n",
    "    )\n",
    "\n",
    "    ax.plot(\n",
    "        x_star,\n",
    "        m_star.detach(),\n",
    "        lw=2,\n",
    "        label='$m_n(x)$',\n",
    "        color=sns.color_palette()[0]\n",
    "    )\n",
    "    \n",
    "    ax.fill_between(\n",
    "        x_star.flatten().detach(),\n",
    "        f_lower.flatten().detach(),\n",
    "        f_upper.flatten().detach(),\n",
    "        alpha=0.5,\n",
    "        label='$f(\\mathbf{x}^*)$ 95% pred.',\n",
    "        color=sns.color_palette()[0]\n",
    "    )\n",
    "\n",
    "    ax.fill_between(\n",
    "        x_star.detach().flatten(),\n",
    "        y_lower.detach().flatten(),\n",
    "        f_lower.detach().flatten(),\n",
    "        color=sns.color_palette()[1],\n",
    "        alpha=0.5,\n",
    "        label='$y^*$ 95% pred.'\n",
    "    )\n",
    "    ax.fill_between(\n",
    "        x_star.detach().flatten(),\n",
    "        f_upper.detach().flatten(),\n",
    "        y_upper.detach().flatten(),\n",
    "        color=sns.color_palette()[1],\n",
    "        alpha=0.5,\n",
    "        label=None\n",
    "    )\n",
    "\n",
    "    \n",
    "    if f_true is not None:\n",
    "        ax.plot(\n",
    "            x_star,\n",
    "            f_true(x_star),\n",
    "            'm-.',\n",
    "            label='True function'\n",
    "        )\n",
    "        \n",
    "    if num_samples > 0:\n",
    "        f_post_samples = f_star.sample(\n",
    "            sample_shape=torch.Size([10])\n",
    "        )\n",
    "        ax.plot(\n",
    "            x_star.numpy(),\n",
    "            f_post_samples.T.detach().numpy(),\n",
    "            color=\"red\",\n",
    "            lw=0.5\n",
    "        )\n",
    "        # This is just to add the legend entry\n",
    "        ax.plot(\n",
    "            [],\n",
    "            [],\n",
    "            color=\"red\",\n",
    "            lw=0.5,\n",
    "            label=\"Posterior samples\"\n",
    "        )\n",
    "        \n",
    "    ax.set_xlabel('$x$')\n",
    "    ax.set_ylabel('$y$')\n",
    "\n",
    "    plt.legend(loc='best', frameon=False)\n",
    "    sns.despine(trim=True)\n",
    "    \n",
    "    return m_star, v_star\n",
    "\n",
    "\n",
    "def train(model, train_x, train_y, n_iter=10, lr=0.1):\n",
    "    \"\"\"Train the model.\n",
    "\n",
    "    Arguments\n",
    "    model   --  The model to train.\n",
    "    train_x --  The training inputs.\n",
    "    train_y --  The training labels.\n",
    "    n_iter  --  The number of iterations.\n",
    "    \"\"\"\n",
    "    model.train()\n",
    "    optimizer = torch.optim.LBFGS(model.parameters(), line_search_fn='strong_wolfe')\n",
    "    likelihood = model.likelihood\n",
    "    mll = gpytorch.mlls.ExactMarginalLogLikelihood(likelihood, model)\n",
    "    def closure():\n",
    "        optimizer.zero_grad()\n",
    "        output = model(train_x)\n",
    "        loss = -mll(output, train_y)\n",
    "        loss.backward()\n",
    "        return loss\n",
    "    for i in range(n_iter):\n",
    "        loss = optimizer.step(closure)\n",
    "        if (i + 1) % 1 == 0:\n",
    "            print(f'Iter {i + 1:3d}/{n_iter} - Loss: {loss.item():.3f}')\n",
    "    model.eval()\n",
    "\n",
    "\n",
    "def plot_iaf(\n",
    "    x_star,\n",
    "    gpr,\n",
    "    alpha,\n",
    "    alpha_params={},\n",
    "    ax=None,\n",
    "    f_true=None,\n",
    "    iaf_label=\"Information Acquisition Function\"\n",
    "):\n",
    "    \"\"\"Plot the information acquisition function.\n",
    "    \n",
    "    Arguments\n",
    "    x_star       -- A set of points to plot on.\n",
    "    gpr          -- A rained Gaussian process regression\n",
    "                    object.\n",
    "    alpha        -- The information acquisition function.\n",
    "                    This assumed to be a function of the\n",
    "                    posterior mean and standard deviation.\n",
    "              \n",
    "    Keyword Arguments\n",
    "    ax           -- An axes object to plot on.\n",
    "    f_true       -- The true function - if available.\n",
    "    alpha_params -- Extra parameters to the information\n",
    "                    acquisition function.\n",
    "    ax           -- An axes object to plot on.\n",
    "    f_true       -- The true function - if available.\n",
    "    iaf_label    -- The label for the information acquisition\n",
    "                    function. Default is \"Information Acquisition\".\n",
    "    \n",
    "    The evaluation of the information acquisition function\n",
    "    is as follows:\n",
    "    \n",
    "        af_values = alpha(mu, sigma, y_max, **alpha_params)\n",
    "\n",
    "    \"\"\"\n",
    "    if ax is None:\n",
    "        fig, ax = plt.subplots()\n",
    "    \n",
    "    ax.set_title(\n",
    "        \", \".join(\n",
    "            f\"{n}={k:.2f}\"\n",
    "            for n, k in alpha_params.items()\n",
    "            )\n",
    "    )\n",
    "    \n",
    "    m, v = plot_1d_regression(\n",
    "        x_star,\n",
    "        gpr,\n",
    "        ax=ax,\n",
    "        f_true=f_true,\n",
    "        num_samples=0\n",
    "    )\n",
    "    \n",
    "    sigma = torch.sqrt(v)\n",
    "    af_values = alpha(m, sigma, gpr.train_targets.numpy().max(), **alpha_params)\n",
    "    next_id = torch.argmax(af_values)\n",
    "    next_x = x_star[next_id]\n",
    "    af_max = af_values[next_id]\n",
    "    \n",
    "    ax2 = ax.twinx()\n",
    "    ax2.plot(x_star, af_values.detach(), color=sns.color_palette()[1])\n",
    "    ax2.set_ylabel(\n",
    "        iaf_label,\n",
    "        color=sns.color_palette()[1]\n",
    "    )\n",
    "    plt.setp(\n",
    "        ax2.get_yticklabels(),\n",
    "        color=sns.color_palette()[1]\n",
    "    )\n",
    "    ax2.plot(\n",
    "        next_x * np.ones(100),\n",
    "        torch.linspace(0, af_max.item(), 100),\n",
    "        color=sns.color_palette()[1],\n",
    "        linewidth=1\n",
    "    )\n",
    "\n",
    "\n",
    "def maximize(\n",
    "    f,\n",
    "    model,\n",
    "    X_design,\n",
    "    alpha,\n",
    "    alpha_params={},\n",
    "    max_it=10,\n",
    "    optimize=False,\n",
    "    plot=False,\n",
    "    **kwargs\n",
    "):\n",
    "    \"\"\"Optimize a function using a limited number of evaluations.\n",
    "    \n",
    "    Arguments\n",
    "    f            -- The function to optimize.\n",
    "    gpr          -- A Gaussian process model to use for representing\n",
    "                    our state of knowledge.\n",
    "    X_design     -- The set of candidate points for identifying the\n",
    "                    maximum.\n",
    "    alpha        -- The information acquisition function.\n",
    "                    This assumed to be a function of the\n",
    "                    posterior mean and standard deviation.\n",
    "    \n",
    "    Keyword Arguments\n",
    "    alpha_params -- Extra parameters to the information\n",
    "                    acquisition function.\n",
    "    max_it       -- The maximum number of iterations.\n",
    "    optimize     -- Whether or not to optimize the hyper-parameters.\n",
    "    plot         -- Determines how often to plot. Make it one\n",
    "                    to plot at each iteration. Make it max_it\n",
    "                    to plot at the last iteration.\n",
    "                    \n",
    "    The rest of the keyword arguments are passed to plot_iaf().\n",
    "    \"\"\"\n",
    "    af_all = []\n",
    "    for count in range(max_it):\n",
    "        # Predict\n",
    "        f_design = model(X_design)\n",
    "        m = f_design.mean\n",
    "        sigma2 = f_design.variance\n",
    "        sigma = torch.sqrt(sigma2)\n",
    "        \n",
    "        # Evaluate information acquisition function\n",
    "        y_train = model.train_targets.numpy()\n",
    "        af_values = alpha(\n",
    "            m,\n",
    "            sigma,\n",
    "            y_train.max(),\n",
    "            **alpha_params\n",
    "        )\n",
    "        \n",
    "        # Find best point to include\n",
    "        i = torch.argmax(af_values)\n",
    "        af_all.append(af_values[i])\n",
    "        \n",
    "        new_x = X_design[i:(i+1)].float()\n",
    "        new_y = f(new_x)\n",
    "        train_x = torch.cat([model.train_inputs[0], new_x[:, None]])\n",
    "        train_y = torch.cat([model.train_targets, new_y])\n",
    "        model.set_train_data(train_x, train_y, strict=False)\n",
    "        \n",
    "        if optimize:\n",
    "            train(model, train_x, train_y, n_iter=100, lr=0.1)\n",
    "        else:\n",
    "            model.train()\n",
    "            model.eval()\n",
    "        \n",
    "        # Plot if required\n",
    "        if count % plot == 0:\n",
    "            if \"ax\" in kwargs:\n",
    "                ax = kwargs[ax]\n",
    "            else:\n",
    "                fig, ax = plt.subplots()\n",
    "            plot_iaf(\n",
    "                X_design,\n",
    "                model,\n",
    "                alpha,\n",
    "                alpha_params=alpha_params,\n",
    "                f_true=f,\n",
    "                ax=ax,\n",
    "                **kwargs\n",
    "            )\n",
    "            ax.set_title(\n",
    "                f\"N={count}, \" + ax.get_title()\n",
    "            )\n",
    "    return af_all"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": null,
   "metadata": {
    "tags": [
     "hide-input"
    ]
   },
   "outputs": [],
   "source": [
    "!pip install gpytorch"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "# Probability of Improvement\n",
    "\n",
    "We develop intuition about an information acquisition function using the probability of improvement.\n",
    "Let's reintroduce the same running example as the previous hands-on activity."
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 2,
   "metadata": {
    "tags": [
     "hide-input"
    ]
   },
   "outputs": [
    {
     "data": {
      "image/svg+xml": [
       "<?xml version=\"1.0\" encoding=\"utf-8\" standalone=\"no\"?>\n",
       "<!DOCTYPE svg PUBLIC \"-//W3C//DTD SVG 1.1//EN\"\n",
       "  \"http://www.w3.org/Graphics/SVG/1.1/DTD/svg11.dtd\">\n",
       "<svg xmlns:xlink=\"http://www.w3.org/1999/xlink\" width=\"414.864875pt\" height=\"309.639375pt\" viewBox=\"0 0 414.864875 309.639375\" xmlns=\"http://www.w3.org/2000/svg\" version=\"1.1\">\n",
       " <metadata>\n",
       "  <rdf:RDF xmlns:dc=\"http://purl.org/dc/elements/1.1/\" xmlns:cc=\"http://creativecommons.org/ns#\" xmlns:rdf=\"http://www.w3.org/1999/02/22-rdf-syntax-ns#\">\n",
       "   <cc:Work>\n",
       "    <dc:type rdf:resource=\"http://purl.org/dc/dcmitype/StillImage\"/>\n",
       "    <dc:date>2023-10-23T15:18:32.938758</dc:date>\n",
       "    <dc:format>image/svg+xml</dc:format>\n",
       "    <dc:creator>\n",
       "     <cc:Agent>\n",
       "      <dc:title>Matplotlib v3.8.0, https://matplotlib.org/</dc:title>\n",
       "     </cc:Agent>\n",
       "    </dc:creator>\n",
       "   </cc:Work>\n",
       "  </rdf:RDF>\n",
       " </metadata>\n",
       " <defs>\n",
       "  <style type=\"text/css\">*{stroke-linejoin: round; stroke-linecap: butt}</style>\n",
       " </defs>\n",
       " <g id=\"figure_1\">\n",
       "  <g id=\"patch_1\">\n",
       "   <path d=\"M 0 309.639375 \n",
       "L 414.864875 309.639375 \n",
       "L 414.864875 0 \n",
       "L 0 0 \n",
       "z\n",
       "\" style=\"fill: #ffffff\"/>\n",
       "  </g>\n",
       "  <g id=\"axes_1\">\n",
       "   <g id=\"patch_2\">\n",
       "    <path d=\"M 50.544875 273.312 \n",
       "L 407.664875 273.312 \n",
       "L 407.664875 7.2 \n",
       "L 50.544875 7.2 \n",
       "z\n",
       "\" style=\"fill: #ffffff\"/>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_1\">\n",
       "    <g id=\"xtick_1\">\n",
       "     <g id=\"line2d_1\">\n",
       "      <defs>\n",
       "       <path id=\"ma8ee733b78\" d=\"M 0 0 \n",
       "L 0 4.8 \n",
       "\" style=\"stroke: #262626\"/>\n",
       "      </defs>\n",
       "      <g>\n",
       "       <use xlink:href=\"#ma8ee733b78\" x=\"73.778876\" y=\"273.312\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_1\">\n",
       "      <!-- 0.2 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(67.662876 287.910875) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-30\" d=\"M 266 2259 \n",
       "Q 266 3072 433 3567 \n",
       "Q 600 4063 929 4331 \n",
       "Q 1259 4600 1759 4600 \n",
       "Q 2128 4600 2406 4451 \n",
       "Q 2684 4303 2865 4023 \n",
       "Q 3047 3744 3150 3342 \n",
       "Q 3253 2941 3253 2259 \n",
       "Q 3253 1453 3087 958 \n",
       "Q 2922 463 2592 192 \n",
       "Q 2263 -78 1759 -78 \n",
       "Q 1097 -78 719 397 \n",
       "Q 266 969 266 2259 \n",
       "z\n",
       "M 844 2259 \n",
       "Q 844 1131 1108 757 \n",
       "Q 1372 384 1759 384 \n",
       "Q 2147 384 2411 759 \n",
       "Q 2675 1134 2675 2259 \n",
       "Q 2675 3391 2411 3762 \n",
       "Q 2147 4134 1753 4134 \n",
       "Q 1366 4134 1134 3806 \n",
       "Q 844 3388 844 2259 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "        <path id=\"ArialMT-2e\" d=\"M 581 0 \n",
       "L 581 641 \n",
       "L 1222 641 \n",
       "L 1222 0 \n",
       "L 581 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "        <path id=\"ArialMT-32\" d=\"M 3222 541 \n",
       "L 3222 0 \n",
       "L 194 0 \n",
       "Q 188 203 259 391 \n",
       "Q 375 700 629 1000 \n",
       "Q 884 1300 1366 1694 \n",
       "Q 2113 2306 2375 2664 \n",
       "Q 2638 3022 2638 3341 \n",
       "Q 2638 3675 2398 3904 \n",
       "Q 2159 4134 1775 4134 \n",
       "Q 1369 4134 1125 3890 \n",
       "Q 881 3647 878 3216 \n",
       "L 300 3275 \n",
       "Q 359 3922 746 4261 \n",
       "Q 1134 4600 1788 4600 \n",
       "Q 2447 4600 2831 4234 \n",
       "Q 3216 3869 3216 3328 \n",
       "Q 3216 3053 3103 2787 \n",
       "Q 2991 2522 2730 2228 \n",
       "Q 2469 1934 1863 1422 \n",
       "Q 1356 997 1212 845 \n",
       "Q 1069 694 975 541 \n",
       "L 3222 541 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-32\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_2\">\n",
       "     <g id=\"line2d_2\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#ma8ee733b78\" x=\"117.315919\" y=\"273.312\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_2\">\n",
       "      <!-- 0.3 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(111.199919 287.910875) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-33\" d=\"M 269 1209 \n",
       "L 831 1284 \n",
       "Q 928 806 1161 595 \n",
       "Q 1394 384 1728 384 \n",
       "Q 2125 384 2398 659 \n",
       "Q 2672 934 2672 1341 \n",
       "Q 2672 1728 2419 1979 \n",
       "Q 2166 2231 1775 2231 \n",
       "Q 1616 2231 1378 2169 \n",
       "L 1441 2663 \n",
       "Q 1497 2656 1531 2656 \n",
       "Q 1891 2656 2178 2843 \n",
       "Q 2466 3031 2466 3422 \n",
       "Q 2466 3731 2256 3934 \n",
       "Q 2047 4138 1716 4138 \n",
       "Q 1388 4138 1169 3931 \n",
       "Q 950 3725 888 3313 \n",
       "L 325 3413 \n",
       "Q 428 3978 793 4289 \n",
       "Q 1159 4600 1703 4600 \n",
       "Q 2078 4600 2393 4439 \n",
       "Q 2709 4278 2876 4000 \n",
       "Q 3044 3722 3044 3409 \n",
       "Q 3044 3113 2884 2869 \n",
       "Q 2725 2625 2413 2481 \n",
       "Q 2819 2388 3044 2092 \n",
       "Q 3269 1797 3269 1353 \n",
       "Q 3269 753 2831 336 \n",
       "Q 2394 -81 1725 -81 \n",
       "Q 1122 -81 723 278 \n",
       "Q 325 638 269 1209 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-33\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_3\">\n",
       "     <g id=\"line2d_3\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#ma8ee733b78\" x=\"160.852962\" y=\"273.312\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_3\">\n",
       "      <!-- 0.4 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(154.736962 287.910875) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-34\" d=\"M 2069 0 \n",
       "L 2069 1097 \n",
       "L 81 1097 \n",
       "L 81 1613 \n",
       "L 2172 4581 \n",
       "L 2631 4581 \n",
       "L 2631 1613 \n",
       "L 3250 1613 \n",
       "L 3250 1097 \n",
       "L 2631 1097 \n",
       "L 2631 0 \n",
       "L 2069 0 \n",
       "z\n",
       "M 2069 1613 \n",
       "L 2069 3678 \n",
       "L 634 1613 \n",
       "L 2069 1613 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-34\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_4\">\n",
       "     <g id=\"line2d_4\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#ma8ee733b78\" x=\"204.390005\" y=\"273.312\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_4\">\n",
       "      <!-- 0.5 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(198.274005 287.910875) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-35\" d=\"M 266 1200 \n",
       "L 856 1250 \n",
       "Q 922 819 1161 601 \n",
       "Q 1400 384 1738 384 \n",
       "Q 2144 384 2425 690 \n",
       "Q 2706 997 2706 1503 \n",
       "Q 2706 1984 2436 2262 \n",
       "Q 2166 2541 1728 2541 \n",
       "Q 1456 2541 1237 2417 \n",
       "Q 1019 2294 894 2097 \n",
       "L 366 2166 \n",
       "L 809 4519 \n",
       "L 3088 4519 \n",
       "L 3088 3981 \n",
       "L 1259 3981 \n",
       "L 1013 2750 \n",
       "Q 1425 3038 1878 3038 \n",
       "Q 2478 3038 2890 2622 \n",
       "Q 3303 2206 3303 1553 \n",
       "Q 3303 931 2941 478 \n",
       "Q 2500 -78 1738 -78 \n",
       "Q 1113 -78 717 272 \n",
       "Q 322 622 266 1200 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-35\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_5\">\n",
       "     <g id=\"line2d_5\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#ma8ee733b78\" x=\"247.927048\" y=\"273.312\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_5\">\n",
       "      <!-- 0.6 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(241.811048 287.910875) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-36\" d=\"M 3184 3459 \n",
       "L 2625 3416 \n",
       "Q 2550 3747 2413 3897 \n",
       "Q 2184 4138 1850 4138 \n",
       "Q 1581 4138 1378 3988 \n",
       "Q 1113 3794 959 3422 \n",
       "Q 806 3050 800 2363 \n",
       "Q 1003 2672 1297 2822 \n",
       "Q 1591 2972 1913 2972 \n",
       "Q 2475 2972 2870 2558 \n",
       "Q 3266 2144 3266 1488 \n",
       "Q 3266 1056 3080 686 \n",
       "Q 2894 316 2569 119 \n",
       "Q 2244 -78 1831 -78 \n",
       "Q 1128 -78 684 439 \n",
       "Q 241 956 241 2144 \n",
       "Q 241 3472 731 4075 \n",
       "Q 1159 4600 1884 4600 \n",
       "Q 2425 4600 2770 4297 \n",
       "Q 3116 3994 3184 3459 \n",
       "z\n",
       "M 888 1484 \n",
       "Q 888 1194 1011 928 \n",
       "Q 1134 663 1356 523 \n",
       "Q 1578 384 1822 384 \n",
       "Q 2178 384 2434 671 \n",
       "Q 2691 959 2691 1453 \n",
       "Q 2691 1928 2437 2201 \n",
       "Q 2184 2475 1800 2475 \n",
       "Q 1419 2475 1153 2201 \n",
       "Q 888 1928 888 1484 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-36\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_6\">\n",
       "     <g id=\"line2d_6\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#ma8ee733b78\" x=\"291.464091\" y=\"273.312\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_6\">\n",
       "      <!-- 0.7 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(285.348091 287.910875) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-37\" d=\"M 303 3981 \n",
       "L 303 4522 \n",
       "L 3269 4522 \n",
       "L 3269 4084 \n",
       "Q 2831 3619 2401 2847 \n",
       "Q 1972 2075 1738 1259 \n",
       "Q 1569 684 1522 0 \n",
       "L 944 0 \n",
       "Q 953 541 1156 1306 \n",
       "Q 1359 2072 1739 2783 \n",
       "Q 2119 3494 2547 3981 \n",
       "L 303 3981 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-37\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_7\">\n",
       "     <g id=\"line2d_7\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#ma8ee733b78\" x=\"335.001134\" y=\"273.312\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_7\">\n",
       "      <!-- 0.8 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(328.885134 287.910875) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-38\" d=\"M 1131 2484 \n",
       "Q 781 2613 612 2850 \n",
       "Q 444 3088 444 3419 \n",
       "Q 444 3919 803 4259 \n",
       "Q 1163 4600 1759 4600 \n",
       "Q 2359 4600 2725 4251 \n",
       "Q 3091 3903 3091 3403 \n",
       "Q 3091 3084 2923 2848 \n",
       "Q 2756 2613 2416 2484 \n",
       "Q 2838 2347 3058 2040 \n",
       "Q 3278 1734 3278 1309 \n",
       "Q 3278 722 2862 322 \n",
       "Q 2447 -78 1769 -78 \n",
       "Q 1091 -78 675 323 \n",
       "Q 259 725 259 1325 \n",
       "Q 259 1772 486 2073 \n",
       "Q 713 2375 1131 2484 \n",
       "z\n",
       "M 1019 3438 \n",
       "Q 1019 3113 1228 2906 \n",
       "Q 1438 2700 1772 2700 \n",
       "Q 2097 2700 2305 2904 \n",
       "Q 2513 3109 2513 3406 \n",
       "Q 2513 3716 2298 3927 \n",
       "Q 2084 4138 1766 4138 \n",
       "Q 1444 4138 1231 3931 \n",
       "Q 1019 3725 1019 3438 \n",
       "z\n",
       "M 838 1322 \n",
       "Q 838 1081 952 856 \n",
       "Q 1066 631 1291 507 \n",
       "Q 1516 384 1775 384 \n",
       "Q 2178 384 2440 643 \n",
       "Q 2703 903 2703 1303 \n",
       "Q 2703 1709 2433 1975 \n",
       "Q 2163 2241 1756 2241 \n",
       "Q 1359 2241 1098 1978 \n",
       "Q 838 1716 838 1322 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-38\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_8\">\n",
       "     <g id=\"line2d_8\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#ma8ee733b78\" x=\"378.538177\" y=\"273.312\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_8\">\n",
       "      <!-- 0.9 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(372.422177 287.910875) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-39\" d=\"M 350 1059 \n",
       "L 891 1109 \n",
       "Q 959 728 1153 556 \n",
       "Q 1347 384 1650 384 \n",
       "Q 1909 384 2104 503 \n",
       "Q 2300 622 2425 820 \n",
       "Q 2550 1019 2634 1356 \n",
       "Q 2719 1694 2719 2044 \n",
       "Q 2719 2081 2716 2156 \n",
       "Q 2547 1888 2255 1720 \n",
       "Q 1963 1553 1622 1553 \n",
       "Q 1053 1553 659 1965 \n",
       "Q 266 2378 266 3053 \n",
       "Q 266 3750 677 4175 \n",
       "Q 1088 4600 1706 4600 \n",
       "Q 2153 4600 2523 4359 \n",
       "Q 2894 4119 3086 3673 \n",
       "Q 3278 3228 3278 2384 \n",
       "Q 3278 1506 3087 986 \n",
       "Q 2897 466 2520 194 \n",
       "Q 2144 -78 1638 -78 \n",
       "Q 1100 -78 759 220 \n",
       "Q 419 519 350 1059 \n",
       "z\n",
       "M 2653 3081 \n",
       "Q 2653 3566 2395 3850 \n",
       "Q 2138 4134 1775 4134 \n",
       "Q 1400 4134 1122 3828 \n",
       "Q 844 3522 844 3034 \n",
       "Q 844 2597 1108 2323 \n",
       "Q 1372 2050 1759 2050 \n",
       "Q 2150 2050 2401 2323 \n",
       "Q 2653 2597 2653 3081 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-39\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"text_9\">\n",
       "     <!-- $x$ -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(226.224875 300.531375) scale(0.096 -0.096)\">\n",
       "      <defs>\n",
       "       <path id=\"DejaVuSans-Oblique-78\" d=\"M 3841 3500 \n",
       "L 2234 1784 \n",
       "L 3219 0 \n",
       "L 2559 0 \n",
       "L 1819 1388 \n",
       "L 531 0 \n",
       "L -166 0 \n",
       "L 1556 1844 \n",
       "L 641 3500 \n",
       "L 1300 3500 \n",
       "L 1972 2234 \n",
       "L 3144 3500 \n",
       "L 3841 3500 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-78\" transform=\"translate(0 0.3125)\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_2\">\n",
       "    <g id=\"ytick_1\">\n",
       "     <g id=\"line2d_9\">\n",
       "      <defs>\n",
       "       <path id=\"m972828e0dd\" d=\"M 0 0 \n",
       "L -4.8 0 \n",
       "\" style=\"stroke: #262626\"/>\n",
       "      </defs>\n",
       "      <g>\n",
       "       <use xlink:href=\"#m972828e0dd\" x=\"50.544875\" y=\"245.1672\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_10\">\n",
       "      <!-- −0.38 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(19.9795 248.316637) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-2212\" d=\"M 3381 1997 \n",
       "L 356 1997 \n",
       "L 356 2522 \n",
       "L 3381 2522 \n",
       "L 3381 1997 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"58.398438\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"114.013672\"/>\n",
       "       <use xlink:href=\"#ArialMT-33\" x=\"141.796875\"/>\n",
       "       <use xlink:href=\"#ArialMT-38\" x=\"197.412109\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_2\">\n",
       "     <g id=\"line2d_10\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m972828e0dd\" x=\"50.544875\" y=\"213.255195\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_11\">\n",
       "      <!-- −0.36 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(19.9795 216.404633) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"58.398438\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"114.013672\"/>\n",
       "       <use xlink:href=\"#ArialMT-33\" x=\"141.796875\"/>\n",
       "       <use xlink:href=\"#ArialMT-36\" x=\"197.412109\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_3\">\n",
       "     <g id=\"line2d_11\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m972828e0dd\" x=\"50.544875\" y=\"181.343191\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_12\">\n",
       "      <!-- −0.34 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(19.9795 184.492628) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"58.398438\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"114.013672\"/>\n",
       "       <use xlink:href=\"#ArialMT-33\" x=\"141.796875\"/>\n",
       "       <use xlink:href=\"#ArialMT-34\" x=\"197.412109\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_4\">\n",
       "     <g id=\"line2d_12\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m972828e0dd\" x=\"50.544875\" y=\"149.431186\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_13\">\n",
       "      <!-- −0.32 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(19.9795 152.580624) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"58.398438\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"114.013672\"/>\n",
       "       <use xlink:href=\"#ArialMT-33\" x=\"141.796875\"/>\n",
       "       <use xlink:href=\"#ArialMT-32\" x=\"197.412109\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_5\">\n",
       "     <g id=\"line2d_13\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m972828e0dd\" x=\"50.544875\" y=\"117.519182\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_14\">\n",
       "      <!-- −0.30 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(19.9795 120.668619) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"58.398438\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"114.013672\"/>\n",
       "       <use xlink:href=\"#ArialMT-33\" x=\"141.796875\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"197.412109\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_6\">\n",
       "     <g id=\"line2d_14\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m972828e0dd\" x=\"50.544875\" y=\"85.607177\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_15\">\n",
       "      <!-- −0.28 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(19.9795 88.756615) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"58.398438\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"114.013672\"/>\n",
       "       <use xlink:href=\"#ArialMT-32\" x=\"141.796875\"/>\n",
       "       <use xlink:href=\"#ArialMT-38\" x=\"197.412109\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_7\">\n",
       "     <g id=\"line2d_15\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m972828e0dd\" x=\"50.544875\" y=\"53.695173\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_16\">\n",
       "      <!-- −0.26 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(19.9795 56.84461) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"58.398438\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"114.013672\"/>\n",
       "       <use xlink:href=\"#ArialMT-32\" x=\"141.796875\"/>\n",
       "       <use xlink:href=\"#ArialMT-36\" x=\"197.412109\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_8\">\n",
       "     <g id=\"line2d_16\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m972828e0dd\" x=\"50.544875\" y=\"21.783168\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_17\">\n",
       "      <!-- −0.24 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(19.9795 24.932606) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"58.398438\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"114.013672\"/>\n",
       "       <use xlink:href=\"#ArialMT-32\" x=\"141.796875\"/>\n",
       "       <use xlink:href=\"#ArialMT-34\" x=\"197.412109\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"text_18\">\n",
       "     <!-- $y$ -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(13.9635 143.136) rotate(-90) scale(0.096 -0.096)\">\n",
       "      <defs>\n",
       "       <path id=\"DejaVuSans-Oblique-79\" d=\"M 1588 -325 \n",
       "Q 1188 -997 936 -1164 \n",
       "Q 684 -1331 294 -1331 \n",
       "L -159 -1331 \n",
       "L -63 -850 \n",
       "L 269 -850 \n",
       "Q 509 -850 678 -719 \n",
       "Q 847 -588 1056 -206 \n",
       "L 1234 128 \n",
       "L 459 3500 \n",
       "L 1069 3500 \n",
       "L 1650 819 \n",
       "L 3256 3500 \n",
       "L 3859 3500 \n",
       "L 1588 -325 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-79\" transform=\"translate(0 0.3125)\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"line2d_17\">\n",
       "    <defs>\n",
       "     <path id=\"m36b5e05b86\" d=\"M -5 5 \n",
       "L 5 -5 \n",
       "M -5 -5 \n",
       "L 5 5 \n",
       "\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "    </defs>\n",
       "    <g clip-path=\"url(#p76517a0a32)\">\n",
       "     <use xlink:href=\"#m36b5e05b86\" x=\"391.432148\" y=\"19.296\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     <use xlink:href=\"#m36b5e05b86\" x=\"124.445351\" y=\"85.049893\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     <use xlink:href=\"#m36b5e05b86\" x=\"66.777602\" y=\"261.216\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"patch_3\">\n",
       "    <path d=\"M 50.544875 245.1672 \n",
       "L 50.544875 21.783168 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_4\">\n",
       "    <path d=\"M 73.778876 273.312 \n",
       "L 378.538177 273.312 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "  </g>\n",
       " </g>\n",
       " <defs>\n",
       "  <clipPath id=\"p76517a0a32\">\n",
       "   <rect x=\"50.544875\" y=\"7.2\" width=\"357.12\" height=\"266.112\"/>\n",
       "  </clipPath>\n",
       " </defs>\n",
       "</svg>\n"
      ],
      "text/plain": [
       "<Figure size 640x480 with 1 Axes>"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    }
   ],
   "source": [
    "def f(x):\n",
    "    \"\"\"A function to optimize.\"\"\"\n",
    "    return -4 * (1. - np.sin(6 * x + 8 * np.exp(6 * x - 7.))) \n",
    "\n",
    "np.random.seed(12345)\n",
    "\n",
    "n_init = 3\n",
    "\n",
    "X = np.random.rand(n_init)\n",
    "Y = f(X)\n",
    "\n",
    "plt.plot(X, Y, 'kx', markersize=10, markeredgewidth=2)\n",
    "plt.xlabel('$x$')\n",
    "plt.ylabel('$y$')\n",
    "sns.despine(trim=True);"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "Just like in the previous hands-on activity, assume that we have made some observations and that we have used them to do Gaussian process regression, resulting in the point-predictive distribution:\n",
    "\n",
    "$$\n",
    "p(y|\\mathbf{x},\\mathcal{D}_{n}) = \\mathcal{N}\\left(y|m_{n}(\\mathbf{x}), \\sigma^2_{n}(\\mathbf{x})\\right),\n",
    "$$\n",
    "\n",
    "where $m_{n}(\\mathbf{x})$ and $\\sigma^2_{n}(\\mathbf{x})$ are the predictive mean and variance respectively.\n",
    "Here is the code for this:"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 3,
   "metadata": {},
   "outputs": [
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "/Users/ibilion/.pyenv/versions/3.11.6/lib/python3.11/site-packages/linear_operator/utils/cholesky.py:40: NumericalWarning: A not p.d., added jitter of 1.0e-06 to the diagonal\n",
      "  warnings.warn(\n",
      "/Users/ibilion/.pyenv/versions/3.11.6/lib/python3.11/site-packages/linear_operator/utils/cholesky.py:40: NumericalWarning: A not p.d., added jitter of 1.0e-05 to the diagonal\n",
      "  warnings.warn(\n",
      "/Users/ibilion/.pyenv/versions/3.11.6/lib/python3.11/site-packages/linear_operator/utils/cholesky.py:40: NumericalWarning: A not p.d., added jitter of 1.0e-04 to the diagonal\n",
      "  warnings.warn(\n"
     ]
    },
    {
     "data": {
      "image/svg+xml": [
       "<?xml version=\"1.0\" encoding=\"utf-8\" standalone=\"no\"?>\n",
       "<!DOCTYPE svg PUBLIC \"-//W3C//DTD SVG 1.1//EN\"\n",
       "  \"http://www.w3.org/Graphics/SVG/1.1/DTD/svg11.dtd\">\n",
       "<svg xmlns:xlink=\"http://www.w3.org/1999/xlink\" width=\"402.632875pt\" height=\"309.639375pt\" viewBox=\"0 0 402.632875 309.639375\" xmlns=\"http://www.w3.org/2000/svg\" version=\"1.1\">\n",
       " <metadata>\n",
       "  <rdf:RDF xmlns:dc=\"http://purl.org/dc/elements/1.1/\" xmlns:cc=\"http://creativecommons.org/ns#\" xmlns:rdf=\"http://www.w3.org/1999/02/22-rdf-syntax-ns#\">\n",
       "   <cc:Work>\n",
       "    <dc:type rdf:resource=\"http://purl.org/dc/dcmitype/StillImage\"/>\n",
       "    <dc:date>2023-10-23T15:18:33.100847</dc:date>\n",
       "    <dc:format>image/svg+xml</dc:format>\n",
       "    <dc:creator>\n",
       "     <cc:Agent>\n",
       "      <dc:title>Matplotlib v3.8.0, https://matplotlib.org/</dc:title>\n",
       "     </cc:Agent>\n",
       "    </dc:creator>\n",
       "   </cc:Work>\n",
       "  </rdf:RDF>\n",
       " </metadata>\n",
       " <defs>\n",
       "  <style type=\"text/css\">*{stroke-linejoin: round; stroke-linecap: butt}</style>\n",
       " </defs>\n",
       " <g id=\"figure_1\">\n",
       "  <g id=\"patch_1\">\n",
       "   <path d=\"M 0 309.639375 \n",
       "L 402.632875 309.639375 \n",
       "L 402.632875 0 \n",
       "L 0 0 \n",
       "z\n",
       "\" style=\"fill: #ffffff\"/>\n",
       "  </g>\n",
       "  <g id=\"axes_1\">\n",
       "   <g id=\"patch_2\">\n",
       "    <path d=\"M 38.312875 273.312 \n",
       "L 395.432875 273.312 \n",
       "L 395.432875 7.2 \n",
       "L 38.312875 7.2 \n",
       "z\n",
       "\" style=\"fill: #ffffff\"/>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_1\">\n",
       "    <g id=\"xtick_1\">\n",
       "     <g id=\"line2d_1\">\n",
       "      <defs>\n",
       "       <path id=\"m90cf945d8b\" d=\"M 0 0 \n",
       "L 0 4.8 \n",
       "\" style=\"stroke: #262626\"/>\n",
       "      </defs>\n",
       "      <g>\n",
       "       <use xlink:href=\"#m90cf945d8b\" x=\"54.545602\" y=\"273.312\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_1\">\n",
       "      <!-- 0.0 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(48.429602 287.910875) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-30\" d=\"M 266 2259 \n",
       "Q 266 3072 433 3567 \n",
       "Q 600 4063 929 4331 \n",
       "Q 1259 4600 1759 4600 \n",
       "Q 2128 4600 2406 4451 \n",
       "Q 2684 4303 2865 4023 \n",
       "Q 3047 3744 3150 3342 \n",
       "Q 3253 2941 3253 2259 \n",
       "Q 3253 1453 3087 958 \n",
       "Q 2922 463 2592 192 \n",
       "Q 2263 -78 1759 -78 \n",
       "Q 1097 -78 719 397 \n",
       "Q 266 969 266 2259 \n",
       "z\n",
       "M 844 2259 \n",
       "Q 844 1131 1108 757 \n",
       "Q 1372 384 1759 384 \n",
       "Q 2147 384 2411 759 \n",
       "Q 2675 1134 2675 2259 \n",
       "Q 2675 3391 2411 3762 \n",
       "Q 2147 4134 1753 4134 \n",
       "Q 1366 4134 1134 3806 \n",
       "Q 844 3388 844 2259 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "        <path id=\"ArialMT-2e\" d=\"M 581 0 \n",
       "L 581 641 \n",
       "L 1222 641 \n",
       "L 1222 0 \n",
       "L 581 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_2\">\n",
       "     <g id=\"line2d_2\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m90cf945d8b\" x=\"119.476511\" y=\"273.312\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_2\">\n",
       "      <!-- 0.2 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(113.360511 287.910875) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-32\" d=\"M 3222 541 \n",
       "L 3222 0 \n",
       "L 194 0 \n",
       "Q 188 203 259 391 \n",
       "Q 375 700 629 1000 \n",
       "Q 884 1300 1366 1694 \n",
       "Q 2113 2306 2375 2664 \n",
       "Q 2638 3022 2638 3341 \n",
       "Q 2638 3675 2398 3904 \n",
       "Q 2159 4134 1775 4134 \n",
       "Q 1369 4134 1125 3890 \n",
       "Q 881 3647 878 3216 \n",
       "L 300 3275 \n",
       "Q 359 3922 746 4261 \n",
       "Q 1134 4600 1788 4600 \n",
       "Q 2447 4600 2831 4234 \n",
       "Q 3216 3869 3216 3328 \n",
       "Q 3216 3053 3103 2787 \n",
       "Q 2991 2522 2730 2228 \n",
       "Q 2469 1934 1863 1422 \n",
       "Q 1356 997 1212 845 \n",
       "Q 1069 694 975 541 \n",
       "L 3222 541 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-32\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_3\">\n",
       "     <g id=\"line2d_3\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m90cf945d8b\" x=\"184.40742\" y=\"273.312\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_3\">\n",
       "      <!-- 0.4 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(178.29142 287.910875) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-34\" d=\"M 2069 0 \n",
       "L 2069 1097 \n",
       "L 81 1097 \n",
       "L 81 1613 \n",
       "L 2172 4581 \n",
       "L 2631 4581 \n",
       "L 2631 1613 \n",
       "L 3250 1613 \n",
       "L 3250 1097 \n",
       "L 2631 1097 \n",
       "L 2631 0 \n",
       "L 2069 0 \n",
       "z\n",
       "M 2069 1613 \n",
       "L 2069 3678 \n",
       "L 634 1613 \n",
       "L 2069 1613 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-34\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_4\">\n",
       "     <g id=\"line2d_4\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m90cf945d8b\" x=\"249.33833\" y=\"273.312\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_4\">\n",
       "      <!-- 0.6 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(243.22233 287.910875) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-36\" d=\"M 3184 3459 \n",
       "L 2625 3416 \n",
       "Q 2550 3747 2413 3897 \n",
       "Q 2184 4138 1850 4138 \n",
       "Q 1581 4138 1378 3988 \n",
       "Q 1113 3794 959 3422 \n",
       "Q 806 3050 800 2363 \n",
       "Q 1003 2672 1297 2822 \n",
       "Q 1591 2972 1913 2972 \n",
       "Q 2475 2972 2870 2558 \n",
       "Q 3266 2144 3266 1488 \n",
       "Q 3266 1056 3080 686 \n",
       "Q 2894 316 2569 119 \n",
       "Q 2244 -78 1831 -78 \n",
       "Q 1128 -78 684 439 \n",
       "Q 241 956 241 2144 \n",
       "Q 241 3472 731 4075 \n",
       "Q 1159 4600 1884 4600 \n",
       "Q 2425 4600 2770 4297 \n",
       "Q 3116 3994 3184 3459 \n",
       "z\n",
       "M 888 1484 \n",
       "Q 888 1194 1011 928 \n",
       "Q 1134 663 1356 523 \n",
       "Q 1578 384 1822 384 \n",
       "Q 2178 384 2434 671 \n",
       "Q 2691 959 2691 1453 \n",
       "Q 2691 1928 2437 2201 \n",
       "Q 2184 2475 1800 2475 \n",
       "Q 1419 2475 1153 2201 \n",
       "Q 888 1928 888 1484 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-36\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_5\">\n",
       "     <g id=\"line2d_5\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m90cf945d8b\" x=\"314.269239\" y=\"273.312\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_5\">\n",
       "      <!-- 0.8 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(308.153239 287.910875) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-38\" d=\"M 1131 2484 \n",
       "Q 781 2613 612 2850 \n",
       "Q 444 3088 444 3419 \n",
       "Q 444 3919 803 4259 \n",
       "Q 1163 4600 1759 4600 \n",
       "Q 2359 4600 2725 4251 \n",
       "Q 3091 3903 3091 3403 \n",
       "Q 3091 3084 2923 2848 \n",
       "Q 2756 2613 2416 2484 \n",
       "Q 2838 2347 3058 2040 \n",
       "Q 3278 1734 3278 1309 \n",
       "Q 3278 722 2862 322 \n",
       "Q 2447 -78 1769 -78 \n",
       "Q 1091 -78 675 323 \n",
       "Q 259 725 259 1325 \n",
       "Q 259 1772 486 2073 \n",
       "Q 713 2375 1131 2484 \n",
       "z\n",
       "M 1019 3438 \n",
       "Q 1019 3113 1228 2906 \n",
       "Q 1438 2700 1772 2700 \n",
       "Q 2097 2700 2305 2904 \n",
       "Q 2513 3109 2513 3406 \n",
       "Q 2513 3716 2298 3927 \n",
       "Q 2084 4138 1766 4138 \n",
       "Q 1444 4138 1231 3931 \n",
       "Q 1019 3725 1019 3438 \n",
       "z\n",
       "M 838 1322 \n",
       "Q 838 1081 952 856 \n",
       "Q 1066 631 1291 507 \n",
       "Q 1516 384 1775 384 \n",
       "Q 2178 384 2440 643 \n",
       "Q 2703 903 2703 1303 \n",
       "Q 2703 1709 2433 1975 \n",
       "Q 2163 2241 1756 2241 \n",
       "Q 1359 2241 1098 1978 \n",
       "Q 838 1716 838 1322 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-38\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_6\">\n",
       "     <g id=\"line2d_6\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m90cf945d8b\" x=\"379.200148\" y=\"273.312\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_6\">\n",
       "      <!-- 1.0 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(373.084148 287.910875) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-31\" d=\"M 2384 0 \n",
       "L 1822 0 \n",
       "L 1822 3584 \n",
       "Q 1619 3391 1289 3197 \n",
       "Q 959 3003 697 2906 \n",
       "L 697 3450 \n",
       "Q 1169 3672 1522 3987 \n",
       "Q 1875 4303 2022 4600 \n",
       "L 2384 4600 \n",
       "L 2384 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-31\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"text_7\">\n",
       "     <!-- $x$ -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(213.992875 300.531375) scale(0.096 -0.096)\">\n",
       "      <defs>\n",
       "       <path id=\"DejaVuSans-Oblique-78\" d=\"M 3841 3500 \n",
       "L 2234 1784 \n",
       "L 3219 0 \n",
       "L 2559 0 \n",
       "L 1819 1388 \n",
       "L 531 0 \n",
       "L -166 0 \n",
       "L 1556 1844 \n",
       "L 641 3500 \n",
       "L 1300 3500 \n",
       "L 1972 2234 \n",
       "L 3144 3500 \n",
       "L 3841 3500 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-78\" transform=\"translate(0 0.3125)\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_2\">\n",
       "    <g id=\"ytick_1\">\n",
       "     <g id=\"line2d_7\">\n",
       "      <defs>\n",
       "       <path id=\"me6af22c570\" d=\"M 0 0 \n",
       "L -4.8 0 \n",
       "\" style=\"stroke: #262626\"/>\n",
       "      </defs>\n",
       "      <g>\n",
       "       <use xlink:href=\"#me6af22c570\" x=\"38.312875\" y=\"261.273566\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_8\">\n",
       "      <!-- −8 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(19.9795 264.423003) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-2212\" d=\"M 3381 1997 \n",
       "L 356 1997 \n",
       "L 356 2522 \n",
       "L 3381 2522 \n",
       "L 3381 1997 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-38\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_2\">\n",
       "     <g id=\"line2d_8\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#me6af22c570\" x=\"38.312875\" y=\"220.543566\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_9\">\n",
       "      <!-- −6 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(19.9795 223.693004) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-36\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_3\">\n",
       "     <g id=\"line2d_9\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#me6af22c570\" x=\"38.312875\" y=\"179.813567\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_10\">\n",
       "      <!-- −4 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(19.9795 182.963005) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-34\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_4\">\n",
       "     <g id=\"line2d_10\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#me6af22c570\" x=\"38.312875\" y=\"139.083568\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_11\">\n",
       "      <!-- −2 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(19.9795 142.233005) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-32\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_5\">\n",
       "     <g id=\"line2d_11\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#me6af22c570\" x=\"38.312875\" y=\"98.353569\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_12\">\n",
       "      <!-- 0 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(25.11925 101.503006) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_6\">\n",
       "     <g id=\"line2d_12\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#me6af22c570\" x=\"38.312875\" y=\"57.62357\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_13\">\n",
       "      <!-- 2 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(25.11925 60.773007) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-32\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_7\">\n",
       "     <g id=\"line2d_13\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#me6af22c570\" x=\"38.312875\" y=\"16.89357\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_14\">\n",
       "      <!-- 4 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(25.11925 20.043008) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-34\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"text_15\">\n",
       "     <!-- $y$ -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(13.9635 143.136) rotate(-90) scale(0.096 -0.096)\">\n",
       "      <defs>\n",
       "       <path id=\"DejaVuSans-Oblique-79\" d=\"M 1588 -325 \n",
       "Q 1188 -997 936 -1164 \n",
       "Q 684 -1331 294 -1331 \n",
       "L -159 -1331 \n",
       "L -63 -850 \n",
       "L 269 -850 \n",
       "Q 509 -850 678 -719 \n",
       "Q 847 -588 1056 -206 \n",
       "L 1234 128 \n",
       "L 459 3500 \n",
       "L 1069 3500 \n",
       "L 1650 819 \n",
       "L 3256 3500 \n",
       "L 3859 3500 \n",
       "L 1588 -325 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-79\" transform=\"translate(0 0.3125)\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"PolyCollection_1\">\n",
       "    <defs>\n",
       "     <path id=\"mf3a0a56486\" d=\"M 54.545602 -275.586429 \n",
       "L 54.545602 -139.739149 \n",
       "L 57.824941 -141.773884 \n",
       "L 61.10428 -144.062902 \n",
       "L 64.383619 -146.610838 \n",
       "L 67.662958 -149.417649 \n",
       "L 70.942296 -152.478053 \n",
       "L 74.221636 -155.7811 \n",
       "L 77.500973 -159.309947 \n",
       "L 80.780313 -163.04156 \n",
       "L 84.059653 -166.94703 \n",
       "L 87.33899 -170.991411 \n",
       "L 90.61833 -175.13431 \n",
       "L 93.89767 -179.330388 \n",
       "L 97.177007 -183.529867 \n",
       "L 100.456344 -187.680185 \n",
       "L 103.735686 -191.726054 \n",
       "L 107.015024 -195.611041 \n",
       "L 110.294361 -199.279301 \n",
       "L 113.573703 -202.673183 \n",
       "L 116.853041 -200.922203 \n",
       "L 120.132378 -198.265433 \n",
       "L 123.41172 -196.092809 \n",
       "L 126.691057 -194.439612 \n",
       "L 129.970395 -193.333729 \n",
       "L 133.249737 -192.79343 \n",
       "L 136.529069 -192.828627 \n",
       "L 139.808412 -193.439273 \n",
       "L 143.087754 -194.616015 \n",
       "L 146.367086 -196.340346 \n",
       "L 149.646428 -198.585042 \n",
       "L 152.92577 -201.314285 \n",
       "L 156.205103 -204.486126 \n",
       "L 159.484445 -203.545524 \n",
       "L 162.763787 -200.261499 \n",
       "L 166.04312 -196.699932 \n",
       "L 169.322462 -192.915284 \n",
       "L 172.601804 -188.962784 \n",
       "L 175.881137 -184.8981 \n",
       "L 179.160479 -180.775548 \n",
       "L 182.439821 -176.647176 \n",
       "L 185.719153 -172.561918 \n",
       "L 188.998496 -168.564411 \n",
       "L 192.277838 -164.694545 \n",
       "L 195.55717 -160.986757 \n",
       "L 198.836512 -157.469762 \n",
       "L 202.115855 -154.166336 \n",
       "L 205.395187 -151.093348 \n",
       "L 208.674529 -148.261876 \n",
       "L 211.953871 -145.677568 \n",
       "L 215.233204 -143.341041 \n",
       "L 218.512556 -141.248429 \n",
       "L 221.791879 -139.392085 \n",
       "L 225.071221 -137.761139 \n",
       "L 228.350563 -136.342364 \n",
       "L 231.629886 -135.120824 \n",
       "L 234.909247 -134.080624 \n",
       "L 238.18857 -133.205633 \n",
       "L 241.467912 -132.480087 \n",
       "L 244.747254 -131.889234 \n",
       "L 248.026597 -131.419795 \n",
       "L 251.305939 -131.060476 \n",
       "L 254.585262 -130.802262 \n",
       "L 257.864623 -130.638737 \n",
       "L 261.143946 -130.566251 \n",
       "L 264.423288 -130.584036 \n",
       "L 267.70263 -130.694224 \n",
       "L 270.981953 -130.901787 \n",
       "L 274.261315 -131.214426 \n",
       "L 277.540637 -131.642323 \n",
       "L 280.81998 -132.197901 \n",
       "L 284.099322 -132.895505 \n",
       "L 287.378664 -133.750938 \n",
       "L 290.658006 -134.781092 \n",
       "L 293.937329 -136.003379 \n",
       "L 297.21669 -137.435308 \n",
       "L 300.496013 -139.093765 \n",
       "L 303.775355 -140.994696 \n",
       "L 307.054697 -143.152277 \n",
       "L 310.33402 -145.578591 \n",
       "L 313.613382 -148.283016 \n",
       "L 316.892705 -151.271759 \n",
       "L 320.172047 -154.547519 \n",
       "L 323.451389 -158.10914 \n",
       "L 326.730731 -161.951291 \n",
       "L 330.010073 -166.064441 \n",
       "L 333.289396 -170.434801 \n",
       "L 336.568738 -175.044347 \n",
       "L 339.84808 -179.871197 \n",
       "L 343.127423 -184.889273 \n",
       "L 346.406765 -190.069554 \n",
       "L 349.686088 -195.380581 \n",
       "L 352.96543 -200.788012 \n",
       "L 356.244772 -206.252096 \n",
       "L 359.524114 -201.136253 \n",
       "L 362.803456 -195.723942 \n",
       "L 366.082798 -190.406208 \n",
       "L 369.362141 -185.216626 \n",
       "L 372.641463 -180.187249 \n",
       "L 375.920806 -175.347722 \n",
       "L 379.200148 -170.723609 \n",
       "L 379.200148 -243.148938 \n",
       "L 379.200148 -243.148938 \n",
       "L 375.920806 -238.265878 \n",
       "L 372.641463 -233.201444 \n",
       "L 369.362141 -227.984084 \n",
       "L 366.082798 -222.645935 \n",
       "L 362.803456 -217.221017 \n",
       "L 359.524114 -211.744339 \n",
       "L 356.244772 -206.607825 \n",
       "L 352.96543 -212.095191 \n",
       "L 349.686088 -217.56955 \n",
       "L 346.406765 -222.990222 \n",
       "L 343.127423 -228.321369 \n",
       "L 339.84808 -233.529518 \n",
       "L 336.568738 -238.583119 \n",
       "L 333.289396 -243.453133 \n",
       "L 330.010073 -248.114321 \n",
       "L 326.730731 -252.545014 \n",
       "L 323.451389 -256.727529 \n",
       "L 320.172047 -260.648284 \n",
       "L 316.892705 -264.297792 \n",
       "L 313.613382 -267.670752 \n",
       "L 310.33402 -270.765765 \n",
       "L 307.054697 -273.585045 \n",
       "L 303.775355 -276.134175 \n",
       "L 300.496013 -278.421644 \n",
       "L 297.21669 -280.458317 \n",
       "L 293.937329 -282.257099 \n",
       "L 290.658006 -283.83215 \n",
       "L 287.378664 -285.19859 \n",
       "L 284.099322 -286.37174 \n",
       "L 280.81998 -287.366708 \n",
       "L 277.540637 -288.19783 \n",
       "L 274.261315 -288.878226 \n",
       "L 270.981953 -289.41935 \n",
       "L 267.70263 -289.830626 \n",
       "L 264.423288 -290.119172 \n",
       "L 261.143946 -290.289495 \n",
       "L 257.864623 -290.343375 \n",
       "L 254.585262 -290.279755 \n",
       "L 251.305939 -290.09474 \n",
       "L 248.026597 -289.781635 \n",
       "L 244.747254 -289.331161 \n",
       "L 241.467912 -288.731705 \n",
       "L 238.18857 -287.969597 \n",
       "L 234.909247 -287.029661 \n",
       "L 231.629886 -285.895625 \n",
       "L 228.350563 -284.550807 \n",
       "L 225.071221 -282.978708 \n",
       "L 221.791879 -281.163791 \n",
       "L 218.512556 -279.092217 \n",
       "L 215.233204 -276.752563 \n",
       "L 211.953871 -274.136705 \n",
       "L 208.674529 -271.240438 \n",
       "L 205.395187 -268.064204 \n",
       "L 202.115855 -264.613709 \n",
       "L 198.836512 -260.900352 \n",
       "L 195.55717 -256.941681 \n",
       "L 192.277838 -252.761482 \n",
       "L 188.998496 -248.389918 \n",
       "L 185.719153 -243.863329 \n",
       "L 182.439821 -239.223983 \n",
       "L 179.160479 -234.519392 \n",
       "L 175.881137 -229.80188 \n",
       "L 172.601804 -225.127394 \n",
       "L 169.322462 -220.554636 \n",
       "L 166.04312 -216.144121 \n",
       "L 162.763787 -211.956346 \n",
       "L 159.484445 -208.051399 \n",
       "L 156.205103 -206.501072 \n",
       "L 152.92577 -209.080513 \n",
       "L 149.646428 -211.240908 \n",
       "L 146.367086 -212.94655 \n",
       "L 143.087754 -214.167767 \n",
       "L 139.808412 -214.883262 \n",
       "L 136.529069 -215.080134 \n",
       "L 133.249737 -214.754195 \n",
       "L 129.970395 -213.910016 \n",
       "L 126.691057 -212.561503 \n",
       "L 123.41172 -210.730165 \n",
       "L 120.132378 -208.446358 \n",
       "L 116.853041 -205.746958 \n",
       "L 113.573703 -204.02261 \n",
       "L 110.294361 -207.512173 \n",
       "L 107.015024 -211.34407 \n",
       "L 103.735686 -215.458636 \n",
       "L 100.456344 -219.797185 \n",
       "L 97.177007 -224.299655 \n",
       "L 93.89767 -228.906405 \n",
       "L 90.61833 -233.55992 \n",
       "L 87.33899 -238.20494 \n",
       "L 84.059653 -242.790231 \n",
       "L 80.780313 -247.269228 \n",
       "L 77.500973 -251.600611 \n",
       "L 74.221636 -255.749084 \n",
       "L 70.942296 -259.685255 \n",
       "L 67.662958 -263.386076 \n",
       "L 64.383619 -266.834692 \n",
       "L 61.10428 -270.020219 \n",
       "L 57.824941 -272.937476 \n",
       "L 54.545602 -275.586429 \n",
       "z\n",
       "\" style=\"stroke: #1f77b4; stroke-opacity: 0.5; stroke-width: 0.8\"/>\n",
       "    </defs>\n",
       "    <g clip-path=\"url(#pfa75df92ef)\">\n",
       "     <use xlink:href=\"#mf3a0a56486\" x=\"0\" y=\"309.639375\" style=\"fill: #1f77b4; fill-opacity: 0.5; stroke: #1f77b4; stroke-opacity: 0.5; stroke-width: 0.8\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"PolyCollection_2\">\n",
       "    <defs>\n",
       "     <path id=\"m94951a1a7e\" d=\"M 54.545602 -139.739149 \n",
       "L 54.545602 -139.739149 \n",
       "L 57.824941 -141.773884 \n",
       "L 61.10428 -144.062902 \n",
       "L 64.383619 -146.610838 \n",
       "L 67.662958 -149.417649 \n",
       "L 70.942296 -152.478053 \n",
       "L 74.221636 -155.7811 \n",
       "L 77.500973 -159.309947 \n",
       "L 80.780313 -163.04156 \n",
       "L 84.059653 -166.94703 \n",
       "L 87.33899 -170.991411 \n",
       "L 90.61833 -175.13431 \n",
       "L 93.89767 -179.330388 \n",
       "L 97.177007 -183.529867 \n",
       "L 100.456344 -187.680185 \n",
       "L 103.735686 -191.726054 \n",
       "L 107.015024 -195.611041 \n",
       "L 110.294361 -199.279301 \n",
       "L 113.573703 -202.673183 \n",
       "L 116.853041 -200.922203 \n",
       "L 120.132378 -198.265433 \n",
       "L 123.41172 -196.092809 \n",
       "L 126.691057 -194.439612 \n",
       "L 129.970395 -193.333729 \n",
       "L 133.249737 -192.79343 \n",
       "L 136.529069 -192.828627 \n",
       "L 139.808412 -193.439273 \n",
       "L 143.087754 -194.616015 \n",
       "L 146.367086 -196.340346 \n",
       "L 149.646428 -198.585042 \n",
       "L 152.92577 -201.314285 \n",
       "L 156.205103 -204.486126 \n",
       "L 159.484445 -203.545524 \n",
       "L 162.763787 -200.261499 \n",
       "L 166.04312 -196.699932 \n",
       "L 169.322462 -192.915284 \n",
       "L 172.601804 -188.962784 \n",
       "L 175.881137 -184.8981 \n",
       "L 179.160479 -180.775548 \n",
       "L 182.439821 -176.647176 \n",
       "L 185.719153 -172.561918 \n",
       "L 188.998496 -168.564411 \n",
       "L 192.277838 -164.694545 \n",
       "L 195.55717 -160.986757 \n",
       "L 198.836512 -157.469762 \n",
       "L 202.115855 -154.166336 \n",
       "L 205.395187 -151.093348 \n",
       "L 208.674529 -148.261876 \n",
       "L 211.953871 -145.677568 \n",
       "L 215.233204 -143.341041 \n",
       "L 218.512556 -141.248429 \n",
       "L 221.791879 -139.392085 \n",
       "L 225.071221 -137.761139 \n",
       "L 228.350563 -136.342364 \n",
       "L 231.629886 -135.120824 \n",
       "L 234.909247 -134.080624 \n",
       "L 238.18857 -133.205633 \n",
       "L 241.467912 -132.480087 \n",
       "L 244.747254 -131.889234 \n",
       "L 248.026597 -131.419795 \n",
       "L 251.305939 -131.060476 \n",
       "L 254.585262 -130.802262 \n",
       "L 257.864623 -130.638737 \n",
       "L 261.143946 -130.566251 \n",
       "L 264.423288 -130.584036 \n",
       "L 267.70263 -130.694224 \n",
       "L 270.981953 -130.901787 \n",
       "L 274.261315 -131.214426 \n",
       "L 277.540637 -131.642323 \n",
       "L 280.81998 -132.197901 \n",
       "L 284.099322 -132.895505 \n",
       "L 287.378664 -133.750938 \n",
       "L 290.658006 -134.781092 \n",
       "L 293.937329 -136.003379 \n",
       "L 297.21669 -137.435308 \n",
       "L 300.496013 -139.093765 \n",
       "L 303.775355 -140.994696 \n",
       "L 307.054697 -143.152277 \n",
       "L 310.33402 -145.578591 \n",
       "L 313.613382 -148.283016 \n",
       "L 316.892705 -151.271759 \n",
       "L 320.172047 -154.547519 \n",
       "L 323.451389 -158.10914 \n",
       "L 326.730731 -161.951291 \n",
       "L 330.010073 -166.064441 \n",
       "L 333.289396 -170.434801 \n",
       "L 336.568738 -175.044347 \n",
       "L 339.84808 -179.871197 \n",
       "L 343.127423 -184.889273 \n",
       "L 346.406765 -190.069554 \n",
       "L 349.686088 -195.380581 \n",
       "L 352.96543 -200.788012 \n",
       "L 356.244772 -206.252096 \n",
       "L 359.524114 -201.136253 \n",
       "L 362.803456 -195.723942 \n",
       "L 366.082798 -190.406208 \n",
       "L 369.362141 -185.216626 \n",
       "L 372.641463 -180.187249 \n",
       "L 375.920806 -175.347722 \n",
       "L 379.200148 -170.723609 \n",
       "L 379.200148 -170.723609 \n",
       "L 379.200148 -170.723609 \n",
       "L 375.920806 -175.347722 \n",
       "L 372.641463 -180.187249 \n",
       "L 369.362141 -185.216626 \n",
       "L 366.082798 -190.406208 \n",
       "L 362.803456 -195.723942 \n",
       "L 359.524114 -201.136253 \n",
       "L 356.244772 -206.252096 \n",
       "L 352.96543 -200.788012 \n",
       "L 349.686088 -195.380581 \n",
       "L 346.406765 -190.069554 \n",
       "L 343.127423 -184.889273 \n",
       "L 339.84808 -179.871197 \n",
       "L 336.568738 -175.044347 \n",
       "L 333.289396 -170.434801 \n",
       "L 330.010073 -166.064441 \n",
       "L 326.730731 -161.951291 \n",
       "L 323.451389 -158.10914 \n",
       "L 320.172047 -154.547519 \n",
       "L 316.892705 -151.271759 \n",
       "L 313.613382 -148.283016 \n",
       "L 310.33402 -145.578591 \n",
       "L 307.054697 -143.152277 \n",
       "L 303.775355 -140.994696 \n",
       "L 300.496013 -139.093765 \n",
       "L 297.21669 -137.435308 \n",
       "L 293.937329 -136.003379 \n",
       "L 290.658006 -134.781092 \n",
       "L 287.378664 -133.750938 \n",
       "L 284.099322 -132.895505 \n",
       "L 280.81998 -132.197901 \n",
       "L 277.540637 -131.642323 \n",
       "L 274.261315 -131.214426 \n",
       "L 270.981953 -130.901787 \n",
       "L 267.70263 -130.694224 \n",
       "L 264.423288 -130.584036 \n",
       "L 261.143946 -130.566251 \n",
       "L 257.864623 -130.638737 \n",
       "L 254.585262 -130.802262 \n",
       "L 251.305939 -131.060476 \n",
       "L 248.026597 -131.419795 \n",
       "L 244.747254 -131.889234 \n",
       "L 241.467912 -132.480087 \n",
       "L 238.18857 -133.205633 \n",
       "L 234.909247 -134.080624 \n",
       "L 231.629886 -135.120824 \n",
       "L 228.350563 -136.342364 \n",
       "L 225.071221 -137.761139 \n",
       "L 221.791879 -139.392085 \n",
       "L 218.512556 -141.248429 \n",
       "L 215.233204 -143.341041 \n",
       "L 211.953871 -145.677568 \n",
       "L 208.674529 -148.261876 \n",
       "L 205.395187 -151.093348 \n",
       "L 202.115855 -154.166336 \n",
       "L 198.836512 -157.469762 \n",
       "L 195.55717 -160.986757 \n",
       "L 192.277838 -164.694545 \n",
       "L 188.998496 -168.564411 \n",
       "L 185.719153 -172.561918 \n",
       "L 182.439821 -176.647176 \n",
       "L 179.160479 -180.775548 \n",
       "L 175.881137 -184.8981 \n",
       "L 172.601804 -188.962784 \n",
       "L 169.322462 -192.915284 \n",
       "L 166.04312 -196.699932 \n",
       "L 162.763787 -200.261499 \n",
       "L 159.484445 -203.545524 \n",
       "L 156.205103 -204.486126 \n",
       "L 152.92577 -201.314285 \n",
       "L 149.646428 -198.585042 \n",
       "L 146.367086 -196.340346 \n",
       "L 143.087754 -194.616015 \n",
       "L 139.808412 -193.439273 \n",
       "L 136.529069 -192.828627 \n",
       "L 133.249737 -192.79343 \n",
       "L 129.970395 -193.333729 \n",
       "L 126.691057 -194.439612 \n",
       "L 123.41172 -196.092809 \n",
       "L 120.132378 -198.265433 \n",
       "L 116.853041 -200.922203 \n",
       "L 113.573703 -202.673183 \n",
       "L 110.294361 -199.279301 \n",
       "L 107.015024 -195.611041 \n",
       "L 103.735686 -191.726054 \n",
       "L 100.456344 -187.680185 \n",
       "L 97.177007 -183.529867 \n",
       "L 93.89767 -179.330388 \n",
       "L 90.61833 -175.13431 \n",
       "L 87.33899 -170.991411 \n",
       "L 84.059653 -166.94703 \n",
       "L 80.780313 -163.04156 \n",
       "L 77.500973 -159.309947 \n",
       "L 74.221636 -155.7811 \n",
       "L 70.942296 -152.478053 \n",
       "L 67.662958 -149.417649 \n",
       "L 64.383619 -146.610838 \n",
       "L 61.10428 -144.062902 \n",
       "L 57.824941 -141.773884 \n",
       "L 54.545602 -139.739149 \n",
       "z\n",
       "\" style=\"stroke: #ff7f0e; stroke-opacity: 0.5; stroke-width: 0.8\"/>\n",
       "    </defs>\n",
       "    <g clip-path=\"url(#pfa75df92ef)\">\n",
       "     <use xlink:href=\"#m94951a1a7e\" x=\"0\" y=\"309.639375\" style=\"fill: #ff7f0e; fill-opacity: 0.5; stroke: #ff7f0e; stroke-opacity: 0.5; stroke-width: 0.8\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"PolyCollection_3\">\n",
       "    <defs>\n",
       "     <path id=\"m672158ccef\" d=\"M 54.545602 -275.586429 \n",
       "L 54.545602 -275.586429 \n",
       "L 57.824941 -272.937476 \n",
       "L 61.10428 -270.020219 \n",
       "L 64.383619 -266.834692 \n",
       "L 67.662958 -263.386076 \n",
       "L 70.942296 -259.685255 \n",
       "L 74.221636 -255.749084 \n",
       "L 77.500973 -251.600611 \n",
       "L 80.780313 -247.269228 \n",
       "L 84.059653 -242.790231 \n",
       "L 87.33899 -238.20494 \n",
       "L 90.61833 -233.55992 \n",
       "L 93.89767 -228.906405 \n",
       "L 97.177007 -224.299655 \n",
       "L 100.456344 -219.797185 \n",
       "L 103.735686 -215.458636 \n",
       "L 107.015024 -211.34407 \n",
       "L 110.294361 -207.512173 \n",
       "L 113.573703 -204.02261 \n",
       "L 116.853041 -205.746958 \n",
       "L 120.132378 -208.446358 \n",
       "L 123.41172 -210.730165 \n",
       "L 126.691057 -212.561503 \n",
       "L 129.970395 -213.910016 \n",
       "L 133.249737 -214.754195 \n",
       "L 136.529069 -215.080134 \n",
       "L 139.808412 -214.883262 \n",
       "L 143.087754 -214.167767 \n",
       "L 146.367086 -212.94655 \n",
       "L 149.646428 -211.240908 \n",
       "L 152.92577 -209.080513 \n",
       "L 156.205103 -206.501072 \n",
       "L 159.484445 -208.051399 \n",
       "L 162.763787 -211.956346 \n",
       "L 166.04312 -216.144121 \n",
       "L 169.322462 -220.554636 \n",
       "L 172.601804 -225.127394 \n",
       "L 175.881137 -229.80188 \n",
       "L 179.160479 -234.519392 \n",
       "L 182.439821 -239.223983 \n",
       "L 185.719153 -243.863329 \n",
       "L 188.998496 -248.389918 \n",
       "L 192.277838 -252.761482 \n",
       "L 195.55717 -256.941681 \n",
       "L 198.836512 -260.900352 \n",
       "L 202.115855 -264.613709 \n",
       "L 205.395187 -268.064204 \n",
       "L 208.674529 -271.240438 \n",
       "L 211.953871 -274.136705 \n",
       "L 215.233204 -276.752563 \n",
       "L 218.512556 -279.092217 \n",
       "L 221.791879 -281.163791 \n",
       "L 225.071221 -282.978708 \n",
       "L 228.350563 -284.550807 \n",
       "L 231.629886 -285.895625 \n",
       "L 234.909247 -287.029661 \n",
       "L 238.18857 -287.969597 \n",
       "L 241.467912 -288.731705 \n",
       "L 244.747254 -289.331161 \n",
       "L 248.026597 -289.781635 \n",
       "L 251.305939 -290.09474 \n",
       "L 254.585262 -290.279755 \n",
       "L 257.864623 -290.343375 \n",
       "L 261.143946 -290.289495 \n",
       "L 264.423288 -290.119172 \n",
       "L 267.70263 -289.830626 \n",
       "L 270.981953 -289.41935 \n",
       "L 274.261315 -288.878226 \n",
       "L 277.540637 -288.19783 \n",
       "L 280.81998 -287.366708 \n",
       "L 284.099322 -286.37174 \n",
       "L 287.378664 -285.19859 \n",
       "L 290.658006 -283.83215 \n",
       "L 293.937329 -282.257099 \n",
       "L 297.21669 -280.458317 \n",
       "L 300.496013 -278.421644 \n",
       "L 303.775355 -276.134175 \n",
       "L 307.054697 -273.585045 \n",
       "L 310.33402 -270.765765 \n",
       "L 313.613382 -267.670752 \n",
       "L 316.892705 -264.297792 \n",
       "L 320.172047 -260.648284 \n",
       "L 323.451389 -256.727529 \n",
       "L 326.730731 -252.545014 \n",
       "L 330.010073 -248.114321 \n",
       "L 333.289396 -243.453133 \n",
       "L 336.568738 -238.583119 \n",
       "L 339.84808 -233.529518 \n",
       "L 343.127423 -228.321369 \n",
       "L 346.406765 -222.990222 \n",
       "L 349.686088 -217.56955 \n",
       "L 352.96543 -212.095191 \n",
       "L 356.244772 -206.607825 \n",
       "L 359.524114 -211.744339 \n",
       "L 362.803456 -217.221017 \n",
       "L 366.082798 -222.645935 \n",
       "L 369.362141 -227.984084 \n",
       "L 372.641463 -233.201444 \n",
       "L 375.920806 -238.265878 \n",
       "L 379.200148 -243.148938 \n",
       "L 379.200148 -243.148938 \n",
       "L 379.200148 -243.148938 \n",
       "L 375.920806 -238.265878 \n",
       "L 372.641463 -233.201444 \n",
       "L 369.362141 -227.984084 \n",
       "L 366.082798 -222.645935 \n",
       "L 362.803456 -217.221017 \n",
       "L 359.524114 -211.744339 \n",
       "L 356.244772 -206.607825 \n",
       "L 352.96543 -212.095191 \n",
       "L 349.686088 -217.56955 \n",
       "L 346.406765 -222.990222 \n",
       "L 343.127423 -228.321369 \n",
       "L 339.84808 -233.529518 \n",
       "L 336.568738 -238.583119 \n",
       "L 333.289396 -243.453133 \n",
       "L 330.010073 -248.114321 \n",
       "L 326.730731 -252.545014 \n",
       "L 323.451389 -256.727529 \n",
       "L 320.172047 -260.648284 \n",
       "L 316.892705 -264.297792 \n",
       "L 313.613382 -267.670752 \n",
       "L 310.33402 -270.765765 \n",
       "L 307.054697 -273.585045 \n",
       "L 303.775355 -276.134175 \n",
       "L 300.496013 -278.421644 \n",
       "L 297.21669 -280.458317 \n",
       "L 293.937329 -282.257099 \n",
       "L 290.658006 -283.83215 \n",
       "L 287.378664 -285.19859 \n",
       "L 284.099322 -286.37174 \n",
       "L 280.81998 -287.366708 \n",
       "L 277.540637 -288.19783 \n",
       "L 274.261315 -288.878226 \n",
       "L 270.981953 -289.41935 \n",
       "L 267.70263 -289.830626 \n",
       "L 264.423288 -290.119172 \n",
       "L 261.143946 -290.289495 \n",
       "L 257.864623 -290.343375 \n",
       "L 254.585262 -290.279755 \n",
       "L 251.305939 -290.09474 \n",
       "L 248.026597 -289.781635 \n",
       "L 244.747254 -289.331161 \n",
       "L 241.467912 -288.731705 \n",
       "L 238.18857 -287.969597 \n",
       "L 234.909247 -287.029661 \n",
       "L 231.629886 -285.895625 \n",
       "L 228.350563 -284.550807 \n",
       "L 225.071221 -282.978708 \n",
       "L 221.791879 -281.163791 \n",
       "L 218.512556 -279.092217 \n",
       "L 215.233204 -276.752563 \n",
       "L 211.953871 -274.136705 \n",
       "L 208.674529 -271.240438 \n",
       "L 205.395187 -268.064204 \n",
       "L 202.115855 -264.613709 \n",
       "L 198.836512 -260.900352 \n",
       "L 195.55717 -256.941681 \n",
       "L 192.277838 -252.761482 \n",
       "L 188.998496 -248.389918 \n",
       "L 185.719153 -243.863329 \n",
       "L 182.439821 -239.223983 \n",
       "L 179.160479 -234.519392 \n",
       "L 175.881137 -229.80188 \n",
       "L 172.601804 -225.127394 \n",
       "L 169.322462 -220.554636 \n",
       "L 166.04312 -216.144121 \n",
       "L 162.763787 -211.956346 \n",
       "L 159.484445 -208.051399 \n",
       "L 156.205103 -206.501072 \n",
       "L 152.92577 -209.080513 \n",
       "L 149.646428 -211.240908 \n",
       "L 146.367086 -212.94655 \n",
       "L 143.087754 -214.167767 \n",
       "L 139.808412 -214.883262 \n",
       "L 136.529069 -215.080134 \n",
       "L 133.249737 -214.754195 \n",
       "L 129.970395 -213.910016 \n",
       "L 126.691057 -212.561503 \n",
       "L 123.41172 -210.730165 \n",
       "L 120.132378 -208.446358 \n",
       "L 116.853041 -205.746958 \n",
       "L 113.573703 -204.02261 \n",
       "L 110.294361 -207.512173 \n",
       "L 107.015024 -211.34407 \n",
       "L 103.735686 -215.458636 \n",
       "L 100.456344 -219.797185 \n",
       "L 97.177007 -224.299655 \n",
       "L 93.89767 -228.906405 \n",
       "L 90.61833 -233.55992 \n",
       "L 87.33899 -238.20494 \n",
       "L 84.059653 -242.790231 \n",
       "L 80.780313 -247.269228 \n",
       "L 77.500973 -251.600611 \n",
       "L 74.221636 -255.749084 \n",
       "L 70.942296 -259.685255 \n",
       "L 67.662958 -263.386076 \n",
       "L 64.383619 -266.834692 \n",
       "L 61.10428 -270.020219 \n",
       "L 57.824941 -272.937476 \n",
       "L 54.545602 -275.586429 \n",
       "z\n",
       "\" style=\"stroke: #ff7f0e; stroke-opacity: 0.5; stroke-width: 0.8\"/>\n",
       "    </defs>\n",
       "    <g clip-path=\"url(#pfa75df92ef)\">\n",
       "     <use xlink:href=\"#m672158ccef\" x=\"0\" y=\"309.639375\" style=\"fill: #ff7f0e; fill-opacity: 0.5; stroke: #ff7f0e; stroke-opacity: 0.5; stroke-width: 0.8\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"line2d_14\">\n",
       "    <defs>\n",
       "     <path id=\"mb6c7ad4a3f\" d=\"M -5 5 \n",
       "L 5 -5 \n",
       "M -5 -5 \n",
       "L 5 5 \n",
       "\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "    </defs>\n",
       "    <g clip-path=\"url(#pfa75df92ef)\">\n",
       "     <use xlink:href=\"#mb6c7ad4a3f\" x=\"356.349693\" y=\"103.209424\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     <use xlink:href=\"#mb6c7ad4a3f\" x=\"157.258364\" y=\"104.048656\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     <use xlink:href=\"#mb6c7ad4a3f\" x=\"114.255683\" y=\"106.297103\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"line2d_15\">\n",
       "    <path d=\"M 54.545602 101.976586 \n",
       "L 57.824941 102.283694 \n",
       "L 61.10428 102.597814 \n",
       "L 64.383619 102.916612 \n",
       "L 67.662958 103.237512 \n",
       "L 70.942296 103.557723 \n",
       "L 74.221636 103.874282 \n",
       "L 77.500973 104.184095 \n",
       "L 80.780313 104.483982 \n",
       "L 84.059653 104.770743 \n",
       "L 87.33899 105.041199 \n",
       "L 90.61833 105.29226 \n",
       "L 93.89767 105.520979 \n",
       "L 97.177007 105.724614 \n",
       "L 100.456344 105.900689 \n",
       "L 103.735686 106.04703 \n",
       "L 107.015024 106.16182 \n",
       "L 110.294361 106.243638 \n",
       "L 113.573703 106.291479 \n",
       "L 116.853041 106.304795 \n",
       "L 120.132378 106.283479 \n",
       "L 123.41172 106.227888 \n",
       "L 126.691057 106.138818 \n",
       "L 129.970395 106.017502 \n",
       "L 133.249737 105.865562 \n",
       "L 136.529069 105.684995 \n",
       "L 139.808412 105.478108 \n",
       "L 143.087754 105.247484 \n",
       "L 146.367086 104.995927 \n",
       "L 149.646428 104.726401 \n",
       "L 152.92577 104.441976 \n",
       "L 156.205103 104.145776 \n",
       "L 159.484445 103.840914 \n",
       "L 162.763787 103.530453 \n",
       "L 166.04312 103.217348 \n",
       "L 169.322462 102.904415 \n",
       "L 172.601804 102.594286 \n",
       "L 175.881137 102.289384 \n",
       "L 179.160479 101.991905 \n",
       "L 182.439821 101.703795 \n",
       "L 185.719153 101.426751 \n",
       "L 188.998496 101.16221 \n",
       "L 192.277838 100.911363 \n",
       "L 195.55717 100.675158 \n",
       "L 198.836512 100.454316 \n",
       "L 202.115855 100.249353 \n",
       "L 205.395187 100.060599 \n",
       "L 208.674529 99.888217 \n",
       "L 211.953871 99.732236 \n",
       "L 215.233204 99.592573 \n",
       "L 218.512556 99.469051 \n",
       "L 221.791879 99.361438 \n",
       "L 225.071221 99.269452 \n",
       "L 228.350563 99.192791 \n",
       "L 231.629886 99.13115 \n",
       "L 234.909247 99.084232 \n",
       "L 238.18857 99.051759 \n",
       "L 241.467912 99.03348 \n",
       "L 244.747254 99.029176 \n",
       "L 248.026597 99.03866 \n",
       "L 251.305939 99.061769 \n",
       "L 254.585262 99.098365 \n",
       "L 257.864623 99.14832 \n",
       "L 261.143946 99.211503 \n",
       "L 264.423288 99.287771 \n",
       "L 267.70263 99.376948 \n",
       "L 270.981953 99.478806 \n",
       "L 274.261315 99.593051 \n",
       "L 277.540637 99.719301 \n",
       "L 280.81998 99.85707 \n",
       "L 284.099322 100.005755 \n",
       "L 287.378664 100.164611 \n",
       "L 290.658006 100.332754 \n",
       "L 293.937329 100.509137 \n",
       "L 297.21669 100.692565 \n",
       "L 300.496013 100.881669 \n",
       "L 303.775355 101.07494 \n",
       "L 307.054697 101.270713 \n",
       "L 310.33402 101.467198 \n",
       "L 313.613382 101.66249 \n",
       "L 316.892705 101.854598 \n",
       "L 320.172047 102.041474 \n",
       "L 323.451389 102.221039 \n",
       "L 326.730731 102.391221 \n",
       "L 330.010073 102.549994 \n",
       "L 333.289396 102.695409 \n",
       "L 336.568738 102.825641 \n",
       "L 339.84808 102.939019 \n",
       "L 343.127423 103.034054 \n",
       "L 346.406765 103.109487 \n",
       "L 349.686088 103.16431 \n",
       "L 352.96543 103.197774 \n",
       "L 356.244772 103.209414 \n",
       "L 359.524114 103.199079 \n",
       "L 362.803456 103.166895 \n",
       "L 366.082798 103.113304 \n",
       "L 369.362141 103.039021 \n",
       "L 372.641463 102.94503 \n",
       "L 375.920806 102.832574 \n",
       "L 379.200148 102.703101 \n",
       "\" clip-path=\"url(#pfa75df92ef)\" style=\"fill: none; stroke: #1f77b4; stroke-width: 2; stroke-linecap: round\"/>\n",
       "   </g>\n",
       "   <g id=\"line2d_16\">\n",
       "    <path d=\"M 54.545602 179.219315 \n",
       "L 57.824941 174.249548 \n",
       "L 61.10428 169.29822 \n",
       "L 64.383619 164.383697 \n",
       "L 67.662958 159.524273 \n",
       "L 70.942296 154.738039 \n",
       "L 74.221636 150.042911 \n",
       "L 77.500973 145.456491 \n",
       "L 80.780313 140.99603 \n",
       "L 84.059653 136.6784 \n",
       "L 87.33899 132.519983 \n",
       "L 90.61833 128.536651 \n",
       "L 93.89767 124.7437 \n",
       "L 97.177007 121.155797 \n",
       "L 100.456344 117.786915 \n",
       "L 103.735686 114.650331 \n",
       "L 107.015024 111.758526 \n",
       "L 110.294361 109.123173 \n",
       "L 113.573703 106.755076 \n",
       "L 116.853041 104.664159 \n",
       "L 120.132378 102.859418 \n",
       "L 123.41172 101.348876 \n",
       "L 126.691057 100.139572 \n",
       "L 129.970395 99.237532 \n",
       "L 133.249737 98.647733 \n",
       "L 136.529069 98.374097 \n",
       "L 139.808412 98.419476 \n",
       "L 143.087754 98.785611 \n",
       "L 146.367086 99.47315 \n",
       "L 149.646428 100.48163 \n",
       "L 152.92577 101.809459 \n",
       "L 156.205103 103.453908 \n",
       "L 159.484445 105.411151 \n",
       "L 162.763787 107.676193 \n",
       "L 166.04312 110.242939 \n",
       "L 169.322462 113.104155 \n",
       "L 172.601804 116.251484 \n",
       "L 175.881137 119.675455 \n",
       "L 179.160479 123.365467 \n",
       "L 182.439821 127.309858 \n",
       "L 185.719153 131.495801 \n",
       "L 188.998496 135.909432 \n",
       "L 192.277838 140.535748 \n",
       "L 195.55717 145.358728 \n",
       "L 198.836512 150.361221 \n",
       "L 202.115855 155.524996 \n",
       "L 205.395187 160.830762 \n",
       "L 208.674529 166.258171 \n",
       "L 211.953871 171.785746 \n",
       "L 215.233204 177.390973 \n",
       "L 218.512556 183.050241 \n",
       "L 221.791879 188.738792 \n",
       "L 225.071221 194.430838 \n",
       "L 228.350563 200.099453 \n",
       "L 231.629886 205.716445 \n",
       "L 234.909247 211.252731 \n",
       "L 238.18857 216.67776 \n",
       "L 241.467912 221.96006 \n",
       "L 244.747254 227.066827 \n",
       "L 248.026597 231.964114 \n",
       "L 251.305939 236.616834 \n",
       "L 254.585262 240.988641 \n",
       "L 257.864623 245.042148 \n",
       "L 261.143946 248.738812 \n",
       "L 264.423288 252.03913 \n",
       "L 267.70263 254.902667 \n",
       "L 270.981953 257.288306 \n",
       "L 274.261315 259.154332 \n",
       "L 277.540637 260.458792 \n",
       "L 280.81998 261.159804 \n",
       "L 284.099322 261.216 \n",
       "L 287.378664 260.587071 \n",
       "L 290.658006 259.234494 \n",
       "L 293.937329 257.12233 \n",
       "L 297.21669 254.218153 \n",
       "L 300.496013 250.494649 \n",
       "L 303.775355 245.930481 \n",
       "L 307.054697 240.512541 \n",
       "L 310.33402 234.237837 \n",
       "L 313.613382 227.115556 \n",
       "L 316.892705 219.170179 \n",
       "L 320.172047 210.444094 \n",
       "L 323.451389 201.001051 \n",
       "L 326.730731 190.929779 \n",
       "L 330.010073 180.347602 \n",
       "L 333.289396 169.404277 \n",
       "L 336.568738 158.285662 \n",
       "L 339.84808 147.216645 \n",
       "L 343.127423 136.463583 \n",
       "L 346.406765 126.33522 \n",
       "L 349.686088 117.181069 \n",
       "L 352.96543 109.387103 \n",
       "L 356.244772 103.367919 \n",
       "L 359.524114 99.55256 \n",
       "L 362.803456 98.364858 \n",
       "L 366.082798 100.195569 \n",
       "L 369.362141 105.365914 \n",
       "L 372.641463 114.082133 \n",
       "L 375.920806 126.381332 \n",
       "L 379.200148 142.071165 \n",
       "\" clip-path=\"url(#pfa75df92ef)\" style=\"fill: none; stroke-dasharray: 7.68,1.92,1.2,1.92; stroke-dashoffset: 0; stroke: #bf00bf; stroke-width: 1.2\"/>\n",
       "   </g>\n",
       "   <g id=\"line2d_17\">\n",
       "    <path d=\"M 54.545602 118.728556 \n",
       "L 57.824941 119.452461 \n",
       "L 61.10428 120.112889 \n",
       "L 64.383619 120.202221 \n",
       "L 67.662958 120.340826 \n",
       "L 70.942296 120.689167 \n",
       "L 74.221636 120.52847 \n",
       "L 77.500973 120.32616 \n",
       "L 80.780313 120.093009 \n",
       "L 84.059653 119.608543 \n",
       "L 87.33899 118.633774 \n",
       "L 90.61833 117.717499 \n",
       "L 93.89767 117.225001 \n",
       "L 97.177007 115.168635 \n",
       "L 100.456344 113.952127 \n",
       "L 103.735686 112.060625 \n",
       "L 107.015024 110.845493 \n",
       "L 110.294361 108.392258 \n",
       "L 113.573703 106.385379 \n",
       "L 116.853041 104.859639 \n",
       "L 120.132378 103.367439 \n",
       "L 123.41172 101.545128 \n",
       "L 126.691057 100.000697 \n",
       "L 129.970395 98.904705 \n",
       "L 133.249737 98.008057 \n",
       "L 136.529069 97.866863 \n",
       "L 139.808412 97.632133 \n",
       "L 143.087754 98.173673 \n",
       "L 146.367086 98.805344 \n",
       "L 149.646428 99.570063 \n",
       "L 152.92577 101.465256 \n",
       "L 156.205103 103.427506 \n",
       "L 159.484445 105.697474 \n",
       "L 162.763787 108.238608 \n",
       "L 166.04312 110.987564 \n",
       "L 169.322462 113.946233 \n",
       "L 172.601804 117.268845 \n",
       "L 175.881137 120.108221 \n",
       "L 179.160479 122.502702 \n",
       "L 182.439821 125.212338 \n",
       "L 185.719153 127.256294 \n",
       "L 188.998496 129.355795 \n",
       "L 192.277838 130.993418 \n",
       "L 195.55717 131.613347 \n",
       "L 198.836512 132.893627 \n",
       "L 202.115855 133.172494 \n",
       "L 205.395187 132.584863 \n",
       "L 208.674529 132.149676 \n",
       "L 211.953871 130.803492 \n",
       "L 215.233204 128.934374 \n",
       "L 218.512556 127.111331 \n",
       "L 221.791879 125.144083 \n",
       "L 225.071221 123.202598 \n",
       "L 228.350563 120.774578 \n",
       "L 231.629886 118.170684 \n",
       "L 234.909247 115.549403 \n",
       "L 238.18857 112.969166 \n",
       "L 241.467912 110.530786 \n",
       "L 244.747254 108.384097 \n",
       "L 248.026597 106.302474 \n",
       "L 251.305939 104.455255 \n",
       "L 254.585262 102.755897 \n",
       "L 257.864623 101.655799 \n",
       "L 261.143946 99.991259 \n",
       "L 264.423288 99.014239 \n",
       "L 267.70263 98.21125 \n",
       "L 270.981953 98.239301 \n",
       "L 274.261315 97.166724 \n",
       "L 277.540637 96.998721 \n",
       "L 280.81998 96.814501 \n",
       "L 284.099322 95.953071 \n",
       "L 287.378664 95.743279 \n",
       "L 290.658006 96.038039 \n",
       "L 293.937329 96.302409 \n",
       "L 297.21669 95.848652 \n",
       "L 300.496013 95.197301 \n",
       "L 303.775355 94.791169 \n",
       "L 307.054697 94.524681 \n",
       "L 310.33402 94.823335 \n",
       "L 313.613382 94.288725 \n",
       "L 316.892705 93.832714 \n",
       "L 320.172047 93.749663 \n",
       "L 323.451389 93.992112 \n",
       "L 326.730731 94.449872 \n",
       "L 330.010073 94.922706 \n",
       "L 333.289396 94.91597 \n",
       "L 336.568738 95.511716 \n",
       "L 339.84808 96.282614 \n",
       "L 343.127423 97.209199 \n",
       "L 346.406765 98.645706 \n",
       "L 349.686088 100.082136 \n",
       "L 352.96543 101.64395 \n",
       "L 356.244772 103.39882 \n",
       "L 359.524114 104.708385 \n",
       "L 362.803456 106.796529 \n",
       "L 366.082798 109.390989 \n",
       "L 369.362141 110.892399 \n",
       "L 372.641463 112.156095 \n",
       "L 375.920806 114.547765 \n",
       "L 379.200148 116.038025 \n",
       "\" clip-path=\"url(#pfa75df92ef)\" style=\"fill: none; stroke: #ff0000; stroke-width: 0.5; stroke-linecap: round\"/>\n",
       "   </g>\n",
       "   <g id=\"line2d_18\">\n",
       "    <path d=\"M 54.545602 144.194157 \n",
       "L 57.824941 144.046538 \n",
       "L 61.10428 144.095738 \n",
       "L 64.383619 143.015204 \n",
       "L 67.662958 142.606137 \n",
       "L 70.942296 141.47602 \n",
       "L 74.221636 140.192438 \n",
       "L 77.500973 138.410834 \n",
       "L 80.780313 136.384027 \n",
       "L 84.059653 134.497279 \n",
       "L 87.33899 131.783589 \n",
       "L 90.61833 128.830638 \n",
       "L 93.89767 125.697362 \n",
       "L 97.177007 122.716583 \n",
       "L 100.456344 119.402752 \n",
       "L 103.735686 115.752844 \n",
       "L 107.015024 112.840669 \n",
       "L 110.294361 109.718362 \n",
       "L 113.573703 106.494646 \n",
       "L 116.853041 104.322318 \n",
       "L 120.132378 102.082789 \n",
       "L 123.41172 100.302152 \n",
       "L 126.691057 98.1814 \n",
       "L 129.970395 97.556619 \n",
       "L 133.249737 96.894139 \n",
       "L 136.529069 96.793241 \n",
       "L 139.808412 97.289142 \n",
       "L 143.087754 97.635362 \n",
       "L 146.367086 98.721376 \n",
       "L 149.646428 100.616727 \n",
       "L 152.92577 101.687477 \n",
       "L 156.205103 103.897542 \n",
       "L 159.484445 105.612522 \n",
       "L 162.763787 107.097925 \n",
       "L 166.04312 108.463365 \n",
       "L 169.322462 109.860994 \n",
       "L 172.601804 111.202166 \n",
       "L 175.881137 112.656843 \n",
       "L 179.160479 113.922768 \n",
       "L 182.439821 114.040508 \n",
       "L 185.719153 114.499561 \n",
       "L 188.998496 114.683372 \n",
       "L 192.277838 114.271305 \n",
       "L 195.55717 113.828324 \n",
       "L 198.836512 112.920522 \n",
       "L 202.115855 112.26498 \n",
       "L 205.395187 110.536805 \n",
       "L 208.674529 109.22599 \n",
       "L 211.953871 107.489388 \n",
       "L 215.233204 106.2818 \n",
       "L 218.512556 103.474352 \n",
       "L 221.791879 101.468738 \n",
       "L 225.071221 99.008901 \n",
       "L 228.350563 96.889796 \n",
       "L 231.629886 94.204125 \n",
       "L 234.909247 91.743675 \n",
       "L 238.18857 88.704557 \n",
       "L 241.467912 85.733207 \n",
       "L 244.747254 82.984973 \n",
       "L 248.026597 80.154616 \n",
       "L 251.305939 76.924692 \n",
       "L 254.585262 74.275669 \n",
       "L 257.864623 71.400695 \n",
       "L 261.143946 68.991169 \n",
       "L 264.423288 66.030071 \n",
       "L 267.70263 64.114304 \n",
       "L 270.981953 61.61725 \n",
       "L 274.261315 60.202566 \n",
       "L 277.540637 57.976142 \n",
       "L 280.81998 57.17027 \n",
       "L 284.099322 56.306617 \n",
       "L 287.378664 55.614077 \n",
       "L 290.658006 55.834425 \n",
       "L 293.937329 56.297974 \n",
       "L 297.21669 56.757105 \n",
       "L 300.496013 58.300229 \n",
       "L 303.775355 60.025873 \n",
       "L 307.054697 62.220931 \n",
       "L 310.33402 64.727451 \n",
       "L 313.613382 67.186878 \n",
       "L 316.892705 70.500398 \n",
       "L 320.172047 73.560867 \n",
       "L 323.451389 77.040109 \n",
       "L 326.730731 80.44177 \n",
       "L 330.010073 83.503093 \n",
       "L 333.289396 86.657809 \n",
       "L 336.568738 90.275436 \n",
       "L 339.84808 92.906925 \n",
       "L 343.127423 95.691309 \n",
       "L 346.406765 98.06941 \n",
       "L 349.686088 100.363311 \n",
       "L 352.96543 101.633449 \n",
       "L 356.244772 103.327107 \n",
       "L 359.524114 104.11326 \n",
       "L 362.803456 104.411085 \n",
       "L 366.082798 104.778501 \n",
       "L 369.362141 104.777337 \n",
       "L 372.641463 103.973358 \n",
       "L 375.920806 103.261287 \n",
       "L 379.200148 102.758879 \n",
       "\" clip-path=\"url(#pfa75df92ef)\" style=\"fill: none; stroke: #ff0000; stroke-width: 0.5; stroke-linecap: round\"/>\n",
       "   </g>\n",
       "   <g id=\"line2d_19\">\n",
       "    <path d=\"M 54.545602 148.472055 \n",
       "L 57.824941 144.72942 \n",
       "L 61.10428 141.927911 \n",
       "L 64.383619 137.82161 \n",
       "L 67.662958 134.638916 \n",
       "L 70.942296 131.341693 \n",
       "L 74.221636 128.051093 \n",
       "L 77.500973 124.864089 \n",
       "L 80.780313 121.974037 \n",
       "L 84.059653 119.078081 \n",
       "L 87.33899 116.657507 \n",
       "L 90.61833 114.574029 \n",
       "L 93.89767 112.630625 \n",
       "L 97.177007 111.303115 \n",
       "L 100.456344 110.094529 \n",
       "L 103.735686 108.742452 \n",
       "L 107.015024 107.64919 \n",
       "L 110.294361 106.860717 \n",
       "L 113.573703 106.515314 \n",
       "L 116.853041 106.313796 \n",
       "L 120.132378 106.004877 \n",
       "L 123.41172 105.629523 \n",
       "L 126.691057 105.45715 \n",
       "L 129.970395 105.468659 \n",
       "L 133.249737 105.101882 \n",
       "L 136.529069 105.411622 \n",
       "L 139.808412 105.343198 \n",
       "L 143.087754 105.452821 \n",
       "L 146.367086 105.064321 \n",
       "L 149.646428 104.95715 \n",
       "L 152.92577 104.593566 \n",
       "L 156.205103 104.588176 \n",
       "L 159.484445 103.807172 \n",
       "L 162.763787 103.340199 \n",
       "L 166.04312 101.941287 \n",
       "L 169.322462 101.331828 \n",
       "L 172.601804 100.241534 \n",
       "L 175.881137 99.14935 \n",
       "L 179.160479 97.876552 \n",
       "L 182.439821 96.237316 \n",
       "L 185.719153 95.392902 \n",
       "L 188.998496 93.56736 \n",
       "L 192.277838 92.080229 \n",
       "L 195.55717 90.43745 \n",
       "L 198.836512 89.307279 \n",
       "L 202.115855 87.55087 \n",
       "L 205.395187 86.025209 \n",
       "L 208.674529 85.03753 \n",
       "L 211.953871 83.526451 \n",
       "L 215.233204 82.748715 \n",
       "L 218.512556 81.944816 \n",
       "L 221.791879 81.004536 \n",
       "L 225.071221 80.201124 \n",
       "L 228.350563 80.080659 \n",
       "L 231.629886 80.016035 \n",
       "L 234.909247 80.430158 \n",
       "L 238.18857 80.635707 \n",
       "L 241.467912 81.193557 \n",
       "L 244.747254 82.540416 \n",
       "L 248.026597 83.835278 \n",
       "L 251.305939 85.762132 \n",
       "L 254.585262 86.720361 \n",
       "L 257.864623 88.578261 \n",
       "L 261.143946 90.992012 \n",
       "L 264.423288 92.682078 \n",
       "L 267.70263 94.951546 \n",
       "L 270.981953 97.168779 \n",
       "L 274.261315 99.40299 \n",
       "L 277.540637 101.356204 \n",
       "L 280.81998 103.751559 \n",
       "L 284.099322 105.350333 \n",
       "L 287.378664 106.845991 \n",
       "L 290.658006 108.144794 \n",
       "L 293.937329 110.079509 \n",
       "L 297.21669 110.928036 \n",
       "L 300.496013 111.999824 \n",
       "L 303.775355 112.413114 \n",
       "L 307.054697 112.474126 \n",
       "L 310.33402 112.601607 \n",
       "L 313.613382 112.44198 \n",
       "L 316.892705 111.68814 \n",
       "L 320.172047 111.199319 \n",
       "L 323.451389 110.566171 \n",
       "L 326.730731 109.233041 \n",
       "L 330.010073 108.266113 \n",
       "L 333.289396 107.430064 \n",
       "L 336.568738 106.171175 \n",
       "L 339.84808 105.712926 \n",
       "L 343.127423 104.896813 \n",
       "L 346.406765 103.616955 \n",
       "L 349.686088 103.629827 \n",
       "L 352.96543 103.159828 \n",
       "L 356.244772 103.102319 \n",
       "L 359.524114 103.782832 \n",
       "L 362.803456 104.056368 \n",
       "L 366.082798 104.954751 \n",
       "L 369.362141 106.529565 \n",
       "L 372.641463 108.281399 \n",
       "L 375.920806 109.918266 \n",
       "L 379.200148 112.46701 \n",
       "\" clip-path=\"url(#pfa75df92ef)\" style=\"fill: none; stroke: #ff0000; stroke-width: 0.5; stroke-linecap: round\"/>\n",
       "   </g>\n",
       "   <g id=\"line2d_20\">\n",
       "    <path d=\"M 54.545602 97.821917 \n",
       "L 57.824941 97.7134 \n",
       "L 61.10428 96.562049 \n",
       "L 64.383619 96.002247 \n",
       "L 67.662958 95.029611 \n",
       "L 70.942296 94.361175 \n",
       "L 74.221636 93.686422 \n",
       "L 77.500973 93.550891 \n",
       "L 80.780313 93.370519 \n",
       "L 84.059653 93.037224 \n",
       "L 87.33899 93.842248 \n",
       "L 90.61833 94.942518 \n",
       "L 93.89767 96.101252 \n",
       "L 97.177007 97.466996 \n",
       "L 100.456344 98.503977 \n",
       "L 103.735686 100.307585 \n",
       "L 107.015024 101.760187 \n",
       "L 110.294361 104.114991 \n",
       "L 113.573703 105.8417 \n",
       "L 116.853041 108.029344 \n",
       "L 120.132378 109.414812 \n",
       "L 123.41172 111.033597 \n",
       "L 126.691057 112.082936 \n",
       "L 129.970395 112.605265 \n",
       "L 133.249737 113.235225 \n",
       "L 136.529069 113.599694 \n",
       "L 139.808412 112.635216 \n",
       "L 143.087754 112.255378 \n",
       "L 146.367086 110.803318 \n",
       "L 149.646428 109.366351 \n",
       "L 152.92577 107.177433 \n",
       "L 156.205103 104.919781 \n",
       "L 159.484445 102.253905 \n",
       "L 162.763787 99.20578 \n",
       "L 166.04312 96.490832 \n",
       "L 169.322462 93.752535 \n",
       "L 172.601804 90.579525 \n",
       "L 175.881137 87.410777 \n",
       "L 179.160479 84.97252 \n",
       "L 182.439821 82.507708 \n",
       "L 185.719153 80.295755 \n",
       "L 188.998496 78.227066 \n",
       "L 192.277838 76.978968 \n",
       "L 195.55717 75.79479 \n",
       "L 198.836512 75.375437 \n",
       "L 202.115855 74.89454 \n",
       "L 205.395187 74.587164 \n",
       "L 208.674529 75.12242 \n",
       "L 211.953871 75.66881 \n",
       "L 215.233204 76.370999 \n",
       "L 218.512556 77.251608 \n",
       "L 221.791879 78.481143 \n",
       "L 225.071221 79.955355 \n",
       "L 228.350563 80.977237 \n",
       "L 231.629886 82.464626 \n",
       "L 234.909247 83.683914 \n",
       "L 238.18857 85.02956 \n",
       "L 241.467912 86.168458 \n",
       "L 244.747254 87.047973 \n",
       "L 248.026597 87.95992 \n",
       "L 251.305939 88.946443 \n",
       "L 254.585262 89.904423 \n",
       "L 257.864623 90.678044 \n",
       "L 261.143946 91.281626 \n",
       "L 264.423288 92.044675 \n",
       "L 267.70263 92.144531 \n",
       "L 270.981953 92.938172 \n",
       "L 274.261315 93.699702 \n",
       "L 277.540637 94.424568 \n",
       "L 280.81998 95.593153 \n",
       "L 284.099322 96.703753 \n",
       "L 287.378664 97.184697 \n",
       "L 290.658006 98.245115 \n",
       "L 293.937329 98.868402 \n",
       "L 297.21669 100.391663 \n",
       "L 300.496013 101.436242 \n",
       "L 303.775355 102.113066 \n",
       "L 307.054697 103.665644 \n",
       "L 310.33402 104.486974 \n",
       "L 313.613382 105.519172 \n",
       "L 316.892705 106.154828 \n",
       "L 320.172047 106.796347 \n",
       "L 323.451389 107.775255 \n",
       "L 326.730731 108.126137 \n",
       "L 330.010073 108.195749 \n",
       "L 333.289396 108.495206 \n",
       "L 336.568738 108.403876 \n",
       "L 339.84808 108.309625 \n",
       "L 343.127423 107.71986 \n",
       "L 346.406765 107.379921 \n",
       "L 349.686088 106.111464 \n",
       "L 352.96543 105.478144 \n",
       "L 356.244772 103.107357 \n",
       "L 359.524114 101.362123 \n",
       "L 362.803456 99.57176 \n",
       "L 366.082798 97.206813 \n",
       "L 369.362141 95.230792 \n",
       "L 372.641463 92.740692 \n",
       "L 375.920806 89.786913 \n",
       "L 379.200148 87.52312 \n",
       "\" clip-path=\"url(#pfa75df92ef)\" style=\"fill: none; stroke: #ff0000; stroke-width: 0.5; stroke-linecap: round\"/>\n",
       "   </g>\n",
       "   <g id=\"line2d_21\">\n",
       "    <path d=\"M 54.545602 131.647512 \n",
       "L 57.824941 130.665824 \n",
       "L 61.10428 128.813445 \n",
       "L 64.383619 127.018748 \n",
       "L 67.662958 124.969306 \n",
       "L 70.942296 122.72079 \n",
       "L 74.221636 120.370354 \n",
       "L 77.500973 118.062931 \n",
       "L 80.780313 116.151308 \n",
       "L 84.059653 113.799967 \n",
       "L 87.33899 111.710838 \n",
       "L 90.61833 110.03064 \n",
       "L 93.89767 109.095093 \n",
       "L 97.177007 108.018667 \n",
       "L 100.456344 107.360125 \n",
       "L 103.735686 106.372569 \n",
       "L 107.015024 106.086476 \n",
       "L 110.294361 106.083413 \n",
       "L 113.573703 106.260462 \n",
       "L 116.853041 106.422853 \n",
       "L 120.132378 106.843737 \n",
       "L 123.41172 107.562357 \n",
       "L 126.691057 107.649488 \n",
       "L 129.970395 108.016105 \n",
       "L 133.249737 108.585686 \n",
       "L 136.529069 108.395476 \n",
       "L 139.808412 108.267282 \n",
       "L 143.087754 108.248454 \n",
       "L 146.367086 107.240092 \n",
       "L 149.646428 106.900502 \n",
       "L 152.92577 105.695789 \n",
       "L 156.205103 104.236346 \n",
       "L 159.484445 102.936127 \n",
       "L 162.763787 101.053266 \n",
       "L 166.04312 99.452484 \n",
       "L 169.322462 96.708916 \n",
       "L 172.601804 94.1489 \n",
       "L 175.881137 91.449607 \n",
       "L 179.160479 88.573529 \n",
       "L 182.439821 85.105747 \n",
       "L 185.719153 82.104907 \n",
       "L 188.998496 78.25473 \n",
       "L 192.277838 74.757057 \n",
       "L 195.55717 71.131114 \n",
       "L 198.836512 67.459503 \n",
       "L 202.115855 63.639027 \n",
       "L 205.395187 60.43023 \n",
       "L 208.674529 57.299545 \n",
       "L 211.953871 54.407303 \n",
       "L 215.233204 50.972641 \n",
       "L 218.512556 49.082717 \n",
       "L 221.791879 46.771074 \n",
       "L 225.071221 45.429558 \n",
       "L 228.350563 44.568046 \n",
       "L 231.629886 44.193175 \n",
       "L 234.909247 44.502546 \n",
       "L 238.18857 45.074492 \n",
       "L 241.467912 47.077406 \n",
       "L 244.747254 49.195843 \n",
       "L 248.026597 52.381817 \n",
       "L 251.305939 55.880274 \n",
       "L 254.585262 59.932072 \n",
       "L 257.864623 64.726582 \n",
       "L 261.143946 70.153776 \n",
       "L 264.423288 75.294575 \n",
       "L 267.70263 81.257167 \n",
       "L 270.981953 86.788549 \n",
       "L 274.261315 92.939056 \n",
       "L 277.540637 98.683241 \n",
       "L 280.81998 104.169988 \n",
       "L 284.099322 109.491057 \n",
       "L 287.378664 114.678258 \n",
       "L 290.658006 118.944587 \n",
       "L 293.937329 123.039143 \n",
       "L 297.21669 126.625498 \n",
       "L 300.496013 129.025514 \n",
       "L 303.775355 131.739704 \n",
       "L 307.054697 133.095286 \n",
       "L 310.33402 133.975856 \n",
       "L 313.613382 134.495262 \n",
       "L 316.892705 134.165364 \n",
       "L 320.172047 133.102912 \n",
       "L 323.451389 131.85452 \n",
       "L 326.730731 130.021921 \n",
       "L 330.010073 128.419095 \n",
       "L 333.289396 125.414711 \n",
       "L 336.568738 122.928428 \n",
       "L 339.84808 119.976225 \n",
       "L 343.127423 117.001058 \n",
       "L 346.406765 113.51007 \n",
       "L 349.686088 109.965335 \n",
       "L 352.96543 106.702859 \n",
       "L 356.244772 103.175203 \n",
       "L 359.524114 99.57445 \n",
       "L 362.803456 96.716883 \n",
       "L 366.082798 93.19623 \n",
       "L 369.362141 90.121312 \n",
       "L 372.641463 87.154314 \n",
       "L 375.920806 85.014446 \n",
       "L 379.200148 81.716111 \n",
       "\" clip-path=\"url(#pfa75df92ef)\" style=\"fill: none; stroke: #ff0000; stroke-width: 0.5; stroke-linecap: round\"/>\n",
       "   </g>\n",
       "   <g id=\"line2d_22\">\n",
       "    <path d=\"M 54.545602 96.042619 \n",
       "L 57.824941 96.180549 \n",
       "L 61.10428 96.579662 \n",
       "L 64.383619 97.007417 \n",
       "L 67.662958 97.912138 \n",
       "L 70.942296 98.579516 \n",
       "L 74.221636 99.851899 \n",
       "L 77.500973 100.487601 \n",
       "L 80.780313 101.378716 \n",
       "L 84.059653 102.432086 \n",
       "L 87.33899 103.243584 \n",
       "L 90.61833 103.719221 \n",
       "L 93.89767 104.099218 \n",
       "L 97.177007 105.221089 \n",
       "L 100.456344 105.635259 \n",
       "L 103.735686 105.731332 \n",
       "L 107.015024 105.951723 \n",
       "L 110.294361 105.895582 \n",
       "L 113.573703 106.27409 \n",
       "L 116.853041 106.441751 \n",
       "L 120.132378 106.684825 \n",
       "L 123.41172 106.145028 \n",
       "L 126.691057 106.333956 \n",
       "L 129.970395 106.066126 \n",
       "L 133.249737 106.464865 \n",
       "L 136.529069 106.482772 \n",
       "L 139.808412 105.735931 \n",
       "L 143.087754 105.883844 \n",
       "L 146.367086 105.299023 \n",
       "L 149.646428 105.095898 \n",
       "L 152.92577 104.352612 \n",
       "L 156.205103 104.398269 \n",
       "L 159.484445 103.799362 \n",
       "L 162.763787 102.853438 \n",
       "L 166.04312 102.404777 \n",
       "L 169.322462 100.956846 \n",
       "L 172.601804 99.979454 \n",
       "L 175.881137 98.676835 \n",
       "L 179.160479 96.901298 \n",
       "L 182.439821 95.655458 \n",
       "L 185.719153 93.66989 \n",
       "L 188.998496 91.758888 \n",
       "L 192.277838 89.774063 \n",
       "L 195.55717 87.642486 \n",
       "L 198.836512 85.485935 \n",
       "L 202.115855 83.152707 \n",
       "L 205.395187 81.108943 \n",
       "L 208.674529 78.978813 \n",
       "L 211.953871 77.27569 \n",
       "L 215.233204 75.023606 \n",
       "L 218.512556 73.342136 \n",
       "L 221.791879 71.170673 \n",
       "L 225.071221 69.430881 \n",
       "L 228.350563 67.677285 \n",
       "L 231.629886 66.525522 \n",
       "L 234.909247 64.709396 \n",
       "L 238.18857 63.764459 \n",
       "L 241.467912 61.876174 \n",
       "L 244.747254 60.943856 \n",
       "L 248.026597 60.118036 \n",
       "L 251.305939 58.739308 \n",
       "L 254.585262 58.336446 \n",
       "L 257.864623 57.785944 \n",
       "L 261.143946 57.07894 \n",
       "L 264.423288 57.536415 \n",
       "L 267.70263 57.065253 \n",
       "L 270.981953 57.439502 \n",
       "L 274.261315 58.352012 \n",
       "L 277.540637 59.534813 \n",
       "L 280.81998 60.641731 \n",
       "L 284.099322 62.435598 \n",
       "L 287.378664 64.311943 \n",
       "L 290.658006 66.573503 \n",
       "L 293.937329 69.164776 \n",
       "L 297.21669 72.292767 \n",
       "L 300.496013 75.324002 \n",
       "L 303.775355 78.564953 \n",
       "L 307.054697 81.597339 \n",
       "L 310.33402 84.943579 \n",
       "L 313.613382 88.188763 \n",
       "L 316.892705 90.96394 \n",
       "L 320.172047 94.072745 \n",
       "L 323.451389 96.433157 \n",
       "L 326.730731 98.821228 \n",
       "L 330.010073 100.83024 \n",
       "L 333.289396 102.199597 \n",
       "L 336.568738 103.634478 \n",
       "L 339.84808 104.193647 \n",
       "L 343.127423 104.363087 \n",
       "L 346.406765 104.46204 \n",
       "L 349.686088 104.59446 \n",
       "L 352.96543 104.11416 \n",
       "L 356.244772 103.12291 \n",
       "L 359.524114 102.725519 \n",
       "L 362.803456 101.625965 \n",
       "L 366.082798 100.6756 \n",
       "L 369.362141 99.952552 \n",
       "L 372.641463 99.463438 \n",
       "L 375.920806 98.935521 \n",
       "L 379.200148 98.873665 \n",
       "\" clip-path=\"url(#pfa75df92ef)\" style=\"fill: none; stroke: #ff0000; stroke-width: 0.5; stroke-linecap: round\"/>\n",
       "   </g>\n",
       "   <g id=\"line2d_23\">\n",
       "    <path d=\"M 54.545602 59.759768 \n",
       "L 57.824941 59.45769 \n",
       "L 61.10428 59.387996 \n",
       "L 64.383619 61.154546 \n",
       "L 67.662958 62.115761 \n",
       "L 70.942296 64.487395 \n",
       "L 74.221636 66.737645 \n",
       "L 77.500973 69.530764 \n",
       "L 80.780313 72.701977 \n",
       "L 84.059653 76.205047 \n",
       "L 87.33899 79.138814 \n",
       "L 90.61833 82.877101 \n",
       "L 93.89767 86.109019 \n",
       "L 97.177007 90.349527 \n",
       "L 100.456344 93.488408 \n",
       "L 103.735686 96.758975 \n",
       "L 107.015024 99.647646 \n",
       "L 110.294361 103.294296 \n",
       "L 113.573703 105.766225 \n",
       "L 116.853041 108.550823 \n",
       "L 120.132378 110.209904 \n",
       "L 123.41172 111.920676 \n",
       "L 126.691057 113.660204 \n",
       "L 129.970395 114.483723 \n",
       "L 133.249737 114.881525 \n",
       "L 136.529069 114.839436 \n",
       "L 139.808412 114.069193 \n",
       "L 143.087754 113.444546 \n",
       "L 146.367086 111.578663 \n",
       "L 149.646428 109.894751 \n",
       "L 152.92577 107.184491 \n",
       "L 156.205103 104.764129 \n",
       "L 159.484445 101.913029 \n",
       "L 162.763787 99.424478 \n",
       "L 166.04312 96.04254 \n",
       "L 169.322462 92.780371 \n",
       "L 172.601804 89.889757 \n",
       "L 175.881137 87.013838 \n",
       "L 179.160479 84.650221 \n",
       "L 182.439821 82.251287 \n",
       "L 185.719153 80.348288 \n",
       "L 188.998496 79.01894 \n",
       "L 192.277838 77.870306 \n",
       "L 195.55717 76.826542 \n",
       "L 198.836512 76.760288 \n",
       "L 202.115855 76.875383 \n",
       "L 205.395187 77.071766 \n",
       "L 208.674529 78.71477 \n",
       "L 211.953871 79.253397 \n",
       "L 215.233204 81.3534 \n",
       "L 218.512556 82.672811 \n",
       "L 221.791879 84.446502 \n",
       "L 225.071221 87.05417 \n",
       "L 228.350563 88.892244 \n",
       "L 231.629886 91.041604 \n",
       "L 234.909247 93.512796 \n",
       "L 238.18857 95.609694 \n",
       "L 241.467912 97.416589 \n",
       "L 244.747254 99.478329 \n",
       "L 248.026597 100.728274 \n",
       "L 251.305939 102.238783 \n",
       "L 254.585262 103.666602 \n",
       "L 257.864623 105.213459 \n",
       "L 261.143946 106.18641 \n",
       "L 264.423288 107.050008 \n",
       "L 267.70263 108.344258 \n",
       "L 270.981953 108.633127 \n",
       "L 274.261315 108.697098 \n",
       "L 277.540637 109.371934 \n",
       "L 280.81998 109.911154 \n",
       "L 284.099322 110.384494 \n",
       "L 287.378664 111.076277 \n",
       "L 290.658006 111.270079 \n",
       "L 293.937329 111.782655 \n",
       "L 297.21669 112.438317 \n",
       "L 300.496013 113.813512 \n",
       "L 303.775355 114.126213 \n",
       "L 307.054697 115.114412 \n",
       "L 310.33402 116.83402 \n",
       "L 313.613382 117.414811 \n",
       "L 316.892705 118.642771 \n",
       "L 320.172047 119.665161 \n",
       "L 323.451389 120.649394 \n",
       "L 326.730731 121.664348 \n",
       "L 330.010073 122.023378 \n",
       "L 333.289396 122.132736 \n",
       "L 336.568738 120.993869 \n",
       "L 339.84808 120.044712 \n",
       "L 343.127423 117.942563 \n",
       "L 346.406765 115.765571 \n",
       "L 349.686088 112.714809 \n",
       "L 352.96543 108.264139 \n",
       "L 356.244772 103.422404 \n",
       "L 359.524114 97.949586 \n",
       "L 362.803456 91.481171 \n",
       "L 366.082798 84.614144 \n",
       "L 369.362141 77.311951 \n",
       "L 372.641463 68.54222 \n",
       "L 375.920806 60.67677 \n",
       "L 379.200148 52.406696 \n",
       "\" clip-path=\"url(#pfa75df92ef)\" style=\"fill: none; stroke: #ff0000; stroke-width: 0.5; stroke-linecap: round\"/>\n",
       "   </g>\n",
       "   <g id=\"line2d_24\">\n",
       "    <path d=\"M 54.545602 80.283913 \n",
       "L 57.824941 77.240479 \n",
       "L 61.10428 75.914002 \n",
       "L 64.383619 74.827933 \n",
       "L 67.662958 74.650228 \n",
       "L 70.942296 75.031255 \n",
       "L 74.221636 75.262319 \n",
       "L 77.500973 76.940396 \n",
       "L 80.780313 78.398612 \n",
       "L 84.059653 80.944704 \n",
       "L 87.33899 83.777357 \n",
       "L 90.61833 86.009758 \n",
       "L 93.89767 89.275589 \n",
       "L 97.177007 92.130058 \n",
       "L 100.456344 95.419431 \n",
       "L 103.735686 98.381035 \n",
       "L 107.015024 100.637376 \n",
       "L 110.294361 103.485304 \n",
       "L 113.573703 106.076645 \n",
       "L 116.853041 107.797387 \n",
       "L 120.132378 109.759522 \n",
       "L 123.41172 111.134492 \n",
       "L 126.691057 111.96777 \n",
       "L 129.970395 112.561627 \n",
       "L 133.249737 112.96127 \n",
       "L 136.529069 112.872557 \n",
       "L 139.808412 112.462604 \n",
       "L 143.087754 111.01945 \n",
       "L 146.367086 110.065325 \n",
       "L 149.646428 108.240183 \n",
       "L 152.92577 106.877766 \n",
       "L 156.205103 104.594987 \n",
       "L 159.484445 102.629827 \n",
       "L 162.763787 100.161723 \n",
       "L 166.04312 97.662779 \n",
       "L 169.322462 94.833972 \n",
       "L 172.601804 93.178775 \n",
       "L 175.881137 90.159834 \n",
       "L 179.160479 87.313571 \n",
       "L 182.439821 85.327816 \n",
       "L 185.719153 83.29777 \n",
       "L 188.998496 81.211953 \n",
       "L 192.277838 79.573485 \n",
       "L 195.55717 77.835712 \n",
       "L 198.836512 77.270124 \n",
       "L 202.115855 76.258556 \n",
       "L 205.395187 75.746535 \n",
       "L 208.674529 76.114227 \n",
       "L 211.953871 76.323018 \n",
       "L 215.233204 77.380162 \n",
       "L 218.512556 78.583304 \n",
       "L 221.791879 80.126581 \n",
       "L 225.071221 81.937392 \n",
       "L 228.350563 84.385876 \n",
       "L 231.629886 86.741545 \n",
       "L 234.909247 89.59422 \n",
       "L 238.18857 92.177981 \n",
       "L 241.467912 95.064258 \n",
       "L 244.747254 97.837203 \n",
       "L 248.026597 100.452589 \n",
       "L 251.305939 103.181184 \n",
       "L 254.585262 106.004447 \n",
       "L 257.864623 108.050396 \n",
       "L 261.143946 110.268203 \n",
       "L 264.423288 111.986341 \n",
       "L 267.70263 114.105333 \n",
       "L 270.981953 115.328375 \n",
       "L 274.261315 116.420199 \n",
       "L 277.540637 117.222956 \n",
       "L 280.81998 117.893847 \n",
       "L 284.099322 118.060829 \n",
       "L 287.378664 118.524121 \n",
       "L 290.658006 118.99108 \n",
       "L 293.937329 119.437805 \n",
       "L 297.21669 119.891967 \n",
       "L 300.496013 119.867102 \n",
       "L 303.775355 120.134214 \n",
       "L 307.054697 120.573557 \n",
       "L 310.33402 120.649564 \n",
       "L 313.613382 120.834554 \n",
       "L 316.892705 121.022883 \n",
       "L 320.172047 120.352251 \n",
       "L 323.451389 119.918615 \n",
       "L 326.730731 119.278779 \n",
       "L 330.010073 118.671348 \n",
       "L 333.289396 117.608517 \n",
       "L 336.568738 116.484242 \n",
       "L 339.84808 114.593901 \n",
       "L 343.127423 113.312989 \n",
       "L 346.406765 110.989849 \n",
       "L 349.686088 108.5292 \n",
       "L 352.96543 106.489446 \n",
       "L 356.244772 103.588323 \n",
       "L 359.524114 100.110034 \n",
       "L 362.803456 97.165571 \n",
       "L 366.082798 93.974396 \n",
       "L 369.362141 90.719374 \n",
       "L 372.641463 87.656204 \n",
       "L 375.920806 84.258065 \n",
       "L 379.200148 81.39254 \n",
       "\" clip-path=\"url(#pfa75df92ef)\" style=\"fill: none; stroke: #ff0000; stroke-width: 0.5; stroke-linecap: round\"/>\n",
       "   </g>\n",
       "   <g id=\"line2d_25\">\n",
       "    <path d=\"M 54.545602 87.04627 \n",
       "L 57.824941 89.815397 \n",
       "L 61.10428 92.386018 \n",
       "L 64.383619 94.776774 \n",
       "L 67.662958 96.908029 \n",
       "L 70.942296 98.555255 \n",
       "L 74.221636 101.097631 \n",
       "L 77.500973 102.275799 \n",
       "L 80.780313 103.381335 \n",
       "L 84.059653 104.827237 \n",
       "L 87.33899 105.756616 \n",
       "L 90.61833 105.949915 \n",
       "L 93.89767 106.591379 \n",
       "L 97.177007 107.150623 \n",
       "L 100.456344 106.893786 \n",
       "L 103.735686 107.138536 \n",
       "L 107.015024 106.597597 \n",
       "L 110.294361 106.38623 \n",
       "L 113.573703 106.348934 \n",
       "L 116.853041 106.042603 \n",
       "L 120.132378 105.613125 \n",
       "L 123.41172 105.356974 \n",
       "L 126.691057 104.377169 \n",
       "L 129.970395 104.362621 \n",
       "L 133.249737 103.825773 \n",
       "L 136.529069 103.728033 \n",
       "L 139.808412 103.514699 \n",
       "L 143.087754 103.421908 \n",
       "L 146.367086 103.238132 \n",
       "L 149.646428 103.504207 \n",
       "L 152.92577 103.576224 \n",
       "L 156.205103 104.042608 \n",
       "L 159.484445 104.63107 \n",
       "L 162.763787 105.153024 \n",
       "L 166.04312 105.955771 \n",
       "L 169.322462 106.559894 \n",
       "L 172.601804 107.537392 \n",
       "L 175.881137 108.708901 \n",
       "L 179.160479 109.814999 \n",
       "L 182.439821 110.939282 \n",
       "L 185.719153 111.764843 \n",
       "L 188.998496 113.064173 \n",
       "L 192.277838 113.224888 \n",
       "L 195.55717 114.036604 \n",
       "L 198.836512 114.149536 \n",
       "L 202.115855 114.202436 \n",
       "L 205.395187 114.037903 \n",
       "L 208.674529 113.975262 \n",
       "L 211.953871 113.598374 \n",
       "L 215.233204 112.427029 \n",
       "L 218.512556 111.638367 \n",
       "L 221.791879 110.349295 \n",
       "L 225.071221 108.650042 \n",
       "L 228.350563 106.954339 \n",
       "L 231.629886 104.913727 \n",
       "L 234.909247 102.883925 \n",
       "L 238.18857 100.628602 \n",
       "L 241.467912 98.603462 \n",
       "L 244.747254 96.933514 \n",
       "L 248.026597 94.691222 \n",
       "L 251.305939 92.977414 \n",
       "L 254.585262 92.090577 \n",
       "L 257.864623 90.497761 \n",
       "L 261.143946 89.660778 \n",
       "L 264.423288 89.453809 \n",
       "L 267.70263 89.433804 \n",
       "L 270.981953 90.117907 \n",
       "L 274.261315 91.3805 \n",
       "L 277.540637 92.174621 \n",
       "L 280.81998 93.918118 \n",
       "L 284.099322 95.741725 \n",
       "L 287.378664 98.103617 \n",
       "L 290.658006 100.572912 \n",
       "L 293.937329 103.287953 \n",
       "L 297.21669 105.048948 \n",
       "L 300.496013 107.54176 \n",
       "L 303.775355 109.744643 \n",
       "L 307.054697 111.413724 \n",
       "L 310.33402 113.360048 \n",
       "L 313.613382 114.19063 \n",
       "L 316.892705 114.96299 \n",
       "L 320.172047 115.285298 \n",
       "L 323.451389 115.170624 \n",
       "L 326.730731 115.622038 \n",
       "L 330.010073 114.231349 \n",
       "L 333.289396 113.734859 \n",
       "L 336.568738 112.395034 \n",
       "L 339.84808 111.418637 \n",
       "L 343.127423 109.42548 \n",
       "L 346.406765 108.111776 \n",
       "L 349.686088 106.448968 \n",
       "L 352.96543 104.812163 \n",
       "L 356.244772 103.208613 \n",
       "L 359.524114 101.698975 \n",
       "L 362.803456 100.896993 \n",
       "L 366.082798 99.489743 \n",
       "L 369.362141 98.512169 \n",
       "L 372.641463 97.292008 \n",
       "L 375.920806 96.887258 \n",
       "L 379.200148 96.048492 \n",
       "\" clip-path=\"url(#pfa75df92ef)\" style=\"fill: none; stroke: #ff0000; stroke-width: 0.5; stroke-linecap: round\"/>\n",
       "   </g>\n",
       "   <g id=\"line2d_26\">\n",
       "    <path d=\"M 54.545602 96.791073 \n",
       "L 57.824941 94.23665 \n",
       "L 61.10428 90.643635 \n",
       "L 64.383619 87.9553 \n",
       "L 67.662958 86.170736 \n",
       "L 70.942296 84.604032 \n",
       "L 74.221636 84.011727 \n",
       "L 77.500973 83.578149 \n",
       "L 80.780313 84.19723 \n",
       "L 84.059653 85.270904 \n",
       "L 87.33899 86.400785 \n",
       "L 90.61833 87.917656 \n",
       "L 93.89767 90.027389 \n",
       "L 97.177007 92.627775 \n",
       "L 100.456344 95.149136 \n",
       "L 103.735686 97.614893 \n",
       "L 107.015024 100.601715 \n",
       "L 110.294361 103.154201 \n",
       "L 113.573703 105.50629 \n",
       "L 116.853041 108.226188 \n",
       "L 120.132378 110.398294 \n",
       "L 123.41172 112.411429 \n",
       "L 126.691057 113.646694 \n",
       "L 129.970395 114.820476 \n",
       "L 133.249737 115.312203 \n",
       "L 136.529069 115.674944 \n",
       "L 139.808412 115.143406 \n",
       "L 143.087754 114.149654 \n",
       "L 146.367086 112.816186 \n",
       "L 149.646428 110.89728 \n",
       "L 152.92577 108.067019 \n",
       "L 156.205103 105.320217 \n",
       "L 159.484445 101.734686 \n",
       "L 162.763787 97.75706 \n",
       "L 166.04312 93.633405 \n",
       "L 169.322462 89.182051 \n",
       "L 172.601804 84.274366 \n",
       "L 175.881137 79.652783 \n",
       "L 179.160479 75.765512 \n",
       "L 182.439821 70.917831 \n",
       "L 185.719153 66.470545 \n",
       "L 188.998496 62.652015 \n",
       "L 192.277838 58.630326 \n",
       "L 195.55717 55.767906 \n",
       "L 198.836512 52.727215 \n",
       "L 202.115855 50.92885 \n",
       "L 205.395187 49.127052 \n",
       "L 208.674529 47.381329 \n",
       "L 211.953871 46.662949 \n",
       "L 215.233204 46.19839 \n",
       "L 218.512556 45.992613 \n",
       "L 221.791879 45.984612 \n",
       "L 225.071221 46.21099 \n",
       "L 228.350563 47.130344 \n",
       "L 231.629886 48.253678 \n",
       "L 234.909247 49.266946 \n",
       "L 238.18857 50.318702 \n",
       "L 241.467912 51.748275 \n",
       "L 244.747254 53.353177 \n",
       "L 248.026597 54.939658 \n",
       "L 251.305939 56.693616 \n",
       "L 254.585262 58.433311 \n",
       "L 257.864623 60.251736 \n",
       "L 261.143946 62.142286 \n",
       "L 264.423288 64.190876 \n",
       "L 267.70263 66.548347 \n",
       "L 270.981953 68.921196 \n",
       "L 274.261315 71.944077 \n",
       "L 277.540637 74.381587 \n",
       "L 280.81998 77.50386 \n",
       "L 284.099322 80.637837 \n",
       "L 287.378664 83.648405 \n",
       "L 290.658006 87.396499 \n",
       "L 293.937329 90.272268 \n",
       "L 297.21669 93.664762 \n",
       "L 300.496013 97.303283 \n",
       "L 303.775355 99.95106 \n",
       "L 307.054697 102.971188 \n",
       "L 310.33402 105.893101 \n",
       "L 313.613382 108.125164 \n",
       "L 316.892705 109.8813 \n",
       "L 320.172047 111.273936 \n",
       "L 323.451389 112.274572 \n",
       "L 326.730731 113.433428 \n",
       "L 330.010073 113.477385 \n",
       "L 333.289396 113.421502 \n",
       "L 336.568738 113.017568 \n",
       "L 339.84808 111.857399 \n",
       "L 343.127423 110.54975 \n",
       "L 346.406765 109.204617 \n",
       "L 349.686088 107.301748 \n",
       "L 352.96543 105.547494 \n",
       "L 356.244772 103.27819 \n",
       "L 359.524114 101.418797 \n",
       "L 362.803456 99.475155 \n",
       "L 366.082798 97.339787 \n",
       "L 369.362141 95.986253 \n",
       "L 372.641463 94.268835 \n",
       "L 375.920806 93.021909 \n",
       "L 379.200148 91.800536 \n",
       "\" clip-path=\"url(#pfa75df92ef)\" style=\"fill: none; stroke: #ff0000; stroke-width: 0.5; stroke-linecap: round\"/>\n",
       "   </g>\n",
       "   <g id=\"line2d_27\"/>\n",
       "   <g id=\"patch_3\">\n",
       "    <path d=\"M 38.312875 261.273566 \n",
       "L 38.312875 16.89357 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_4\">\n",
       "    <path d=\"M 54.545602 273.312 \n",
       "L 379.200148 273.312 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"legend_1\">\n",
       "    <g id=\"line2d_28\">\n",
       "     <g>\n",
       "      <use xlink:href=\"#mb6c7ad4a3f\" x=\"55.032875\" y=\"194.65925\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"text_16\">\n",
       "     <!-- Observations -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(70.872875 197.73925) scale(0.088 -0.088)\">\n",
       "      <defs>\n",
       "       <path id=\"ArialMT-4f\" d=\"M 309 2231 \n",
       "Q 309 3372 921 4017 \n",
       "Q 1534 4663 2503 4663 \n",
       "Q 3138 4663 3647 4359 \n",
       "Q 4156 4056 4423 3514 \n",
       "Q 4691 2972 4691 2284 \n",
       "Q 4691 1588 4409 1038 \n",
       "Q 4128 488 3612 205 \n",
       "Q 3097 -78 2500 -78 \n",
       "Q 1853 -78 1343 234 \n",
       "Q 834 547 571 1087 \n",
       "Q 309 1628 309 2231 \n",
       "z\n",
       "M 934 2222 \n",
       "Q 934 1394 1379 917 \n",
       "Q 1825 441 2497 441 \n",
       "Q 3181 441 3623 922 \n",
       "Q 4066 1403 4066 2288 \n",
       "Q 4066 2847 3877 3264 \n",
       "Q 3688 3681 3323 3911 \n",
       "Q 2959 4141 2506 4141 \n",
       "Q 1863 4141 1398 3698 \n",
       "Q 934 3256 934 2222 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-62\" d=\"M 941 0 \n",
       "L 419 0 \n",
       "L 419 4581 \n",
       "L 981 4581 \n",
       "L 981 2947 \n",
       "Q 1338 3394 1891 3394 \n",
       "Q 2197 3394 2470 3270 \n",
       "Q 2744 3147 2920 2923 \n",
       "Q 3097 2700 3197 2384 \n",
       "Q 3297 2069 3297 1709 \n",
       "Q 3297 856 2875 390 \n",
       "Q 2453 -75 1863 -75 \n",
       "Q 1275 -75 941 416 \n",
       "L 941 0 \n",
       "z\n",
       "M 934 1684 \n",
       "Q 934 1088 1097 822 \n",
       "Q 1363 388 1816 388 \n",
       "Q 2184 388 2453 708 \n",
       "Q 2722 1028 2722 1663 \n",
       "Q 2722 2313 2464 2622 \n",
       "Q 2206 2931 1841 2931 \n",
       "Q 1472 2931 1203 2611 \n",
       "Q 934 2291 934 1684 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-73\" d=\"M 197 991 \n",
       "L 753 1078 \n",
       "Q 800 744 1014 566 \n",
       "Q 1228 388 1613 388 \n",
       "Q 2000 388 2187 545 \n",
       "Q 2375 703 2375 916 \n",
       "Q 2375 1106 2209 1216 \n",
       "Q 2094 1291 1634 1406 \n",
       "Q 1016 1563 777 1677 \n",
       "Q 538 1791 414 1992 \n",
       "Q 291 2194 291 2438 \n",
       "Q 291 2659 392 2848 \n",
       "Q 494 3038 669 3163 \n",
       "Q 800 3259 1026 3326 \n",
       "Q 1253 3394 1513 3394 \n",
       "Q 1903 3394 2198 3281 \n",
       "Q 2494 3169 2634 2976 \n",
       "Q 2775 2784 2828 2463 \n",
       "L 2278 2388 \n",
       "Q 2241 2644 2061 2787 \n",
       "Q 1881 2931 1553 2931 \n",
       "Q 1166 2931 1000 2803 \n",
       "Q 834 2675 834 2503 \n",
       "Q 834 2394 903 2306 \n",
       "Q 972 2216 1119 2156 \n",
       "Q 1203 2125 1616 2013 \n",
       "Q 2213 1853 2448 1751 \n",
       "Q 2684 1650 2818 1456 \n",
       "Q 2953 1263 2953 975 \n",
       "Q 2953 694 2789 445 \n",
       "Q 2625 197 2315 61 \n",
       "Q 2006 -75 1616 -75 \n",
       "Q 969 -75 630 194 \n",
       "Q 291 463 197 991 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-65\" d=\"M 2694 1069 \n",
       "L 3275 997 \n",
       "Q 3138 488 2766 206 \n",
       "Q 2394 -75 1816 -75 \n",
       "Q 1088 -75 661 373 \n",
       "Q 234 822 234 1631 \n",
       "Q 234 2469 665 2931 \n",
       "Q 1097 3394 1784 3394 \n",
       "Q 2450 3394 2872 2941 \n",
       "Q 3294 2488 3294 1666 \n",
       "Q 3294 1616 3291 1516 \n",
       "L 816 1516 \n",
       "Q 847 969 1125 678 \n",
       "Q 1403 388 1819 388 \n",
       "Q 2128 388 2347 550 \n",
       "Q 2566 713 2694 1069 \n",
       "z\n",
       "M 847 1978 \n",
       "L 2700 1978 \n",
       "Q 2663 2397 2488 2606 \n",
       "Q 2219 2931 1791 2931 \n",
       "Q 1403 2931 1139 2672 \n",
       "Q 875 2413 847 1978 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-72\" d=\"M 416 0 \n",
       "L 416 3319 \n",
       "L 922 3319 \n",
       "L 922 2816 \n",
       "Q 1116 3169 1280 3281 \n",
       "Q 1444 3394 1641 3394 \n",
       "Q 1925 3394 2219 3213 \n",
       "L 2025 2691 \n",
       "Q 1819 2813 1613 2813 \n",
       "Q 1428 2813 1281 2702 \n",
       "Q 1134 2591 1072 2394 \n",
       "Q 978 2094 978 1738 \n",
       "L 978 0 \n",
       "L 416 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-76\" d=\"M 1344 0 \n",
       "L 81 3319 \n",
       "L 675 3319 \n",
       "L 1388 1331 \n",
       "Q 1503 1009 1600 663 \n",
       "Q 1675 925 1809 1294 \n",
       "L 2547 3319 \n",
       "L 3125 3319 \n",
       "L 1869 0 \n",
       "L 1344 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-61\" d=\"M 2588 409 \n",
       "Q 2275 144 1986 34 \n",
       "Q 1697 -75 1366 -75 \n",
       "Q 819 -75 525 192 \n",
       "Q 231 459 231 875 \n",
       "Q 231 1119 342 1320 \n",
       "Q 453 1522 633 1644 \n",
       "Q 813 1766 1038 1828 \n",
       "Q 1203 1872 1538 1913 \n",
       "Q 2219 1994 2541 2106 \n",
       "Q 2544 2222 2544 2253 \n",
       "Q 2544 2597 2384 2738 \n",
       "Q 2169 2928 1744 2928 \n",
       "Q 1347 2928 1158 2789 \n",
       "Q 969 2650 878 2297 \n",
       "L 328 2372 \n",
       "Q 403 2725 575 2942 \n",
       "Q 747 3159 1072 3276 \n",
       "Q 1397 3394 1825 3394 \n",
       "Q 2250 3394 2515 3294 \n",
       "Q 2781 3194 2906 3042 \n",
       "Q 3031 2891 3081 2659 \n",
       "Q 3109 2516 3109 2141 \n",
       "L 3109 1391 \n",
       "Q 3109 606 3145 398 \n",
       "Q 3181 191 3288 0 \n",
       "L 2700 0 \n",
       "Q 2613 175 2588 409 \n",
       "z\n",
       "M 2541 1666 \n",
       "Q 2234 1541 1622 1453 \n",
       "Q 1275 1403 1131 1340 \n",
       "Q 988 1278 909 1158 \n",
       "Q 831 1038 831 891 \n",
       "Q 831 666 1001 516 \n",
       "Q 1172 366 1500 366 \n",
       "Q 1825 366 2078 508 \n",
       "Q 2331 650 2450 897 \n",
       "Q 2541 1088 2541 1459 \n",
       "L 2541 1666 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-74\" d=\"M 1650 503 \n",
       "L 1731 6 \n",
       "Q 1494 -44 1306 -44 \n",
       "Q 1000 -44 831 53 \n",
       "Q 663 150 594 308 \n",
       "Q 525 466 525 972 \n",
       "L 525 2881 \n",
       "L 113 2881 \n",
       "L 113 3319 \n",
       "L 525 3319 \n",
       "L 525 4141 \n",
       "L 1084 4478 \n",
       "L 1084 3319 \n",
       "L 1650 3319 \n",
       "L 1650 2881 \n",
       "L 1084 2881 \n",
       "L 1084 941 \n",
       "Q 1084 700 1114 631 \n",
       "Q 1144 563 1211 522 \n",
       "Q 1278 481 1403 481 \n",
       "Q 1497 481 1650 503 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-69\" d=\"M 425 3934 \n",
       "L 425 4581 \n",
       "L 988 4581 \n",
       "L 988 3934 \n",
       "L 425 3934 \n",
       "z\n",
       "M 425 0 \n",
       "L 425 3319 \n",
       "L 988 3319 \n",
       "L 988 0 \n",
       "L 425 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-6f\" d=\"M 213 1659 \n",
       "Q 213 2581 725 3025 \n",
       "Q 1153 3394 1769 3394 \n",
       "Q 2453 3394 2887 2945 \n",
       "Q 3322 2497 3322 1706 \n",
       "Q 3322 1066 3130 698 \n",
       "Q 2938 331 2570 128 \n",
       "Q 2203 -75 1769 -75 \n",
       "Q 1072 -75 642 372 \n",
       "Q 213 819 213 1659 \n",
       "z\n",
       "M 791 1659 \n",
       "Q 791 1022 1069 705 \n",
       "Q 1347 388 1769 388 \n",
       "Q 2188 388 2466 706 \n",
       "Q 2744 1025 2744 1678 \n",
       "Q 2744 2294 2464 2611 \n",
       "Q 2184 2928 1769 2928 \n",
       "Q 1347 2928 1069 2612 \n",
       "Q 791 2297 791 1659 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-6e\" d=\"M 422 0 \n",
       "L 422 3319 \n",
       "L 928 3319 \n",
       "L 928 2847 \n",
       "Q 1294 3394 1984 3394 \n",
       "Q 2284 3394 2536 3286 \n",
       "Q 2788 3178 2913 3003 \n",
       "Q 3038 2828 3088 2588 \n",
       "Q 3119 2431 3119 2041 \n",
       "L 3119 0 \n",
       "L 2556 0 \n",
       "L 2556 2019 \n",
       "Q 2556 2363 2490 2533 \n",
       "Q 2425 2703 2258 2804 \n",
       "Q 2091 2906 1866 2906 \n",
       "Q 1506 2906 1245 2678 \n",
       "Q 984 2450 984 1813 \n",
       "L 984 0 \n",
       "L 422 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#ArialMT-4f\"/>\n",
       "      <use xlink:href=\"#ArialMT-62\" x=\"77.783203\"/>\n",
       "      <use xlink:href=\"#ArialMT-73\" x=\"133.398438\"/>\n",
       "      <use xlink:href=\"#ArialMT-65\" x=\"183.398438\"/>\n",
       "      <use xlink:href=\"#ArialMT-72\" x=\"239.013672\"/>\n",
       "      <use xlink:href=\"#ArialMT-76\" x=\"272.314453\"/>\n",
       "      <use xlink:href=\"#ArialMT-61\" x=\"322.314453\"/>\n",
       "      <use xlink:href=\"#ArialMT-74\" x=\"377.929688\"/>\n",
       "      <use xlink:href=\"#ArialMT-69\" x=\"405.712891\"/>\n",
       "      <use xlink:href=\"#ArialMT-6f\" x=\"427.929688\"/>\n",
       "      <use xlink:href=\"#ArialMT-6e\" x=\"483.544922\"/>\n",
       "      <use xlink:href=\"#ArialMT-73\" x=\"539.160156\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"line2d_29\">\n",
       "     <path d=\"M 46.232875 207.24325 \n",
       "L 55.032875 207.24325 \n",
       "L 63.832875 207.24325 \n",
       "\" style=\"fill: none; stroke: #1f77b4; stroke-width: 2; stroke-linecap: round\"/>\n",
       "    </g>\n",
       "    <g id=\"text_17\">\n",
       "     <!-- $m_n(x)$ -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(70.872875 210.32325) scale(0.088 -0.088)\">\n",
       "      <defs>\n",
       "       <path id=\"DejaVuSans-Oblique-6d\" d=\"M 5747 2113 \n",
       "L 5338 0 \n",
       "L 4763 0 \n",
       "L 5166 2094 \n",
       "Q 5191 2228 5203 2325 \n",
       "Q 5216 2422 5216 2491 \n",
       "Q 5216 2772 5059 2928 \n",
       "Q 4903 3084 4622 3084 \n",
       "Q 4203 3084 3875 2770 \n",
       "Q 3547 2456 3450 1953 \n",
       "L 3066 0 \n",
       "L 2491 0 \n",
       "L 2900 2094 \n",
       "Q 2925 2209 2937 2307 \n",
       "Q 2950 2406 2950 2484 \n",
       "Q 2950 2769 2794 2926 \n",
       "Q 2638 3084 2363 3084 \n",
       "Q 1938 3084 1609 2770 \n",
       "Q 1281 2456 1184 1953 \n",
       "L 800 0 \n",
       "L 225 0 \n",
       "L 909 3500 \n",
       "L 1484 3500 \n",
       "L 1375 2956 \n",
       "Q 1609 3263 1923 3423 \n",
       "Q 2238 3584 2597 3584 \n",
       "Q 2978 3584 3223 3384 \n",
       "Q 3469 3184 3519 2828 \n",
       "Q 3781 3197 4126 3390 \n",
       "Q 4472 3584 4856 3584 \n",
       "Q 5306 3584 5551 3325 \n",
       "Q 5797 3066 5797 2591 \n",
       "Q 5797 2488 5784 2364 \n",
       "Q 5772 2241 5747 2113 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-Oblique-6e\" d=\"M 3566 2113 \n",
       "L 3156 0 \n",
       "L 2578 0 \n",
       "L 2988 2091 \n",
       "Q 3016 2238 3031 2350 \n",
       "Q 3047 2463 3047 2528 \n",
       "Q 3047 2791 2881 2937 \n",
       "Q 2716 3084 2419 3084 \n",
       "Q 1956 3084 1622 2776 \n",
       "Q 1288 2469 1184 1941 \n",
       "L 800 0 \n",
       "L 225 0 \n",
       "L 903 3500 \n",
       "L 1478 3500 \n",
       "L 1363 2950 \n",
       "Q 1603 3253 1940 3418 \n",
       "Q 2278 3584 2650 3584 \n",
       "Q 3113 3584 3367 3334 \n",
       "Q 3622 3084 3622 2631 \n",
       "Q 3622 2519 3608 2391 \n",
       "Q 3594 2263 3566 2113 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-28\" d=\"M 1984 4856 \n",
       "Q 1566 4138 1362 3434 \n",
       "Q 1159 2731 1159 2009 \n",
       "Q 1159 1288 1364 580 \n",
       "Q 1569 -128 1984 -844 \n",
       "L 1484 -844 \n",
       "Q 1016 -109 783 600 \n",
       "Q 550 1309 550 2009 \n",
       "Q 550 2706 781 3412 \n",
       "Q 1013 4119 1484 4856 \n",
       "L 1984 4856 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-29\" d=\"M 513 4856 \n",
       "L 1013 4856 \n",
       "Q 1481 4119 1714 3412 \n",
       "Q 1947 2706 1947 2009 \n",
       "Q 1947 1309 1714 600 \n",
       "Q 1481 -109 1013 -844 \n",
       "L 513 -844 \n",
       "Q 928 -128 1133 580 \n",
       "Q 1338 1288 1338 2009 \n",
       "Q 1338 2731 1133 3434 \n",
       "Q 928 4138 513 4856 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-6d\" transform=\"translate(0 0.125)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-6e\" transform=\"translate(97.412109 -16.28125) scale(0.7)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-28\" transform=\"translate(144.511719 0.125)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-78\" transform=\"translate(183.525391 0.125)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-29\" transform=\"translate(242.705078 0.125)\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"patch_5\">\n",
       "     <path d=\"M 46.232875 224.48025 \n",
       "L 63.832875 224.48025 \n",
       "L 63.832875 218.32025 \n",
       "L 46.232875 218.32025 \n",
       "z\n",
       "\" style=\"fill: #1f77b4; fill-opacity: 0.5; stroke: #1f77b4; stroke-opacity: 0.5; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "    </g>\n",
       "    <g id=\"text_18\">\n",
       "     <!-- $f(\\mathbf{x}^*)$ 95% pred. -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(70.872875 224.48025) scale(0.088 -0.088)\">\n",
       "      <defs>\n",
       "       <path id=\"DejaVuSans-Oblique-66\" d=\"M 3059 4863 \n",
       "L 2969 4384 \n",
       "L 2419 4384 \n",
       "Q 2106 4384 1964 4261 \n",
       "Q 1822 4138 1753 3809 \n",
       "L 1691 3500 \n",
       "L 2638 3500 \n",
       "L 2553 3053 \n",
       "L 1606 3053 \n",
       "L 1013 0 \n",
       "L 434 0 \n",
       "L 1031 3053 \n",
       "L 481 3053 \n",
       "L 563 3500 \n",
       "L 1113 3500 \n",
       "L 1159 3744 \n",
       "Q 1278 4363 1576 4613 \n",
       "Q 1875 4863 2516 4863 \n",
       "L 3059 4863 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-Bold-78\" d=\"M 1422 1791 \n",
       "L 159 3500 \n",
       "L 1344 3500 \n",
       "L 2059 2463 \n",
       "L 2784 3500 \n",
       "L 3969 3500 \n",
       "L 2706 1797 \n",
       "L 4031 0 \n",
       "L 2847 0 \n",
       "L 2059 1106 \n",
       "L 1281 0 \n",
       "L 97 0 \n",
       "L 1422 1791 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-2a\" d=\"M 3009 3897 \n",
       "L 1888 3291 \n",
       "L 3009 2681 \n",
       "L 2828 2375 \n",
       "L 1778 3009 \n",
       "L 1778 1831 \n",
       "L 1422 1831 \n",
       "L 1422 3009 \n",
       "L 372 2375 \n",
       "L 191 2681 \n",
       "L 1313 3291 \n",
       "L 191 3897 \n",
       "L 372 4206 \n",
       "L 1422 3572 \n",
       "L 1422 4750 \n",
       "L 1778 4750 \n",
       "L 1778 3572 \n",
       "L 2828 4206 \n",
       "L 3009 3897 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-20\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-39\" d=\"M 350 1059 \n",
       "L 891 1109 \n",
       "Q 959 728 1153 556 \n",
       "Q 1347 384 1650 384 \n",
       "Q 1909 384 2104 503 \n",
       "Q 2300 622 2425 820 \n",
       "Q 2550 1019 2634 1356 \n",
       "Q 2719 1694 2719 2044 \n",
       "Q 2719 2081 2716 2156 \n",
       "Q 2547 1888 2255 1720 \n",
       "Q 1963 1553 1622 1553 \n",
       "Q 1053 1553 659 1965 \n",
       "Q 266 2378 266 3053 \n",
       "Q 266 3750 677 4175 \n",
       "Q 1088 4600 1706 4600 \n",
       "Q 2153 4600 2523 4359 \n",
       "Q 2894 4119 3086 3673 \n",
       "Q 3278 3228 3278 2384 \n",
       "Q 3278 1506 3087 986 \n",
       "Q 2897 466 2520 194 \n",
       "Q 2144 -78 1638 -78 \n",
       "Q 1100 -78 759 220 \n",
       "Q 419 519 350 1059 \n",
       "z\n",
       "M 2653 3081 \n",
       "Q 2653 3566 2395 3850 \n",
       "Q 2138 4134 1775 4134 \n",
       "Q 1400 4134 1122 3828 \n",
       "Q 844 3522 844 3034 \n",
       "Q 844 2597 1108 2323 \n",
       "Q 1372 2050 1759 2050 \n",
       "Q 2150 2050 2401 2323 \n",
       "Q 2653 2597 2653 3081 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-35\" d=\"M 266 1200 \n",
       "L 856 1250 \n",
       "Q 922 819 1161 601 \n",
       "Q 1400 384 1738 384 \n",
       "Q 2144 384 2425 690 \n",
       "Q 2706 997 2706 1503 \n",
       "Q 2706 1984 2436 2262 \n",
       "Q 2166 2541 1728 2541 \n",
       "Q 1456 2541 1237 2417 \n",
       "Q 1019 2294 894 2097 \n",
       "L 366 2166 \n",
       "L 809 4519 \n",
       "L 3088 4519 \n",
       "L 3088 3981 \n",
       "L 1259 3981 \n",
       "L 1013 2750 \n",
       "Q 1425 3038 1878 3038 \n",
       "Q 2478 3038 2890 2622 \n",
       "Q 3303 2206 3303 1553 \n",
       "Q 3303 931 2941 478 \n",
       "Q 2500 -78 1738 -78 \n",
       "Q 1113 -78 717 272 \n",
       "Q 322 622 266 1200 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-25\" d=\"M 372 3481 \n",
       "Q 372 3972 619 4315 \n",
       "Q 866 4659 1334 4659 \n",
       "Q 1766 4659 2048 4351 \n",
       "Q 2331 4044 2331 3447 \n",
       "Q 2331 2866 2045 2552 \n",
       "Q 1759 2238 1341 2238 \n",
       "Q 925 2238 648 2547 \n",
       "Q 372 2856 372 3481 \n",
       "z\n",
       "M 1350 4272 \n",
       "Q 1141 4272 1002 4090 \n",
       "Q 863 3909 863 3425 \n",
       "Q 863 2984 1003 2804 \n",
       "Q 1144 2625 1350 2625 \n",
       "Q 1563 2625 1702 2806 \n",
       "Q 1841 2988 1841 3469 \n",
       "Q 1841 3913 1700 4092 \n",
       "Q 1559 4272 1350 4272 \n",
       "z\n",
       "M 1353 -169 \n",
       "L 3859 4659 \n",
       "L 4316 4659 \n",
       "L 1819 -169 \n",
       "L 1353 -169 \n",
       "z\n",
       "M 3334 1075 \n",
       "Q 3334 1569 3581 1911 \n",
       "Q 3828 2253 4300 2253 \n",
       "Q 4731 2253 5014 1945 \n",
       "Q 5297 1638 5297 1041 \n",
       "Q 5297 459 5011 145 \n",
       "Q 4725 -169 4303 -169 \n",
       "Q 3888 -169 3611 142 \n",
       "Q 3334 453 3334 1075 \n",
       "z\n",
       "M 4316 1866 \n",
       "Q 4103 1866 3964 1684 \n",
       "Q 3825 1503 3825 1019 \n",
       "Q 3825 581 3965 400 \n",
       "Q 4106 219 4313 219 \n",
       "Q 4528 219 4667 400 \n",
       "Q 4806 581 4806 1063 \n",
       "Q 4806 1506 4665 1686 \n",
       "Q 4525 1866 4316 1866 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-70\" d=\"M 422 -1272 \n",
       "L 422 3319 \n",
       "L 934 3319 \n",
       "L 934 2888 \n",
       "Q 1116 3141 1344 3267 \n",
       "Q 1572 3394 1897 3394 \n",
       "Q 2322 3394 2647 3175 \n",
       "Q 2972 2956 3137 2557 \n",
       "Q 3303 2159 3303 1684 \n",
       "Q 3303 1175 3120 767 \n",
       "Q 2938 359 2589 142 \n",
       "Q 2241 -75 1856 -75 \n",
       "Q 1575 -75 1351 44 \n",
       "Q 1128 163 984 344 \n",
       "L 984 -1272 \n",
       "L 422 -1272 \n",
       "z\n",
       "M 931 1641 \n",
       "Q 931 1000 1190 694 \n",
       "Q 1450 388 1819 388 \n",
       "Q 2194 388 2461 705 \n",
       "Q 2728 1022 2728 1688 \n",
       "Q 2728 2322 2467 2637 \n",
       "Q 2206 2953 1844 2953 \n",
       "Q 1484 2953 1207 2617 \n",
       "Q 931 2281 931 1641 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-64\" d=\"M 2575 0 \n",
       "L 2575 419 \n",
       "Q 2259 -75 1647 -75 \n",
       "Q 1250 -75 917 144 \n",
       "Q 584 363 401 755 \n",
       "Q 219 1147 219 1656 \n",
       "Q 219 2153 384 2558 \n",
       "Q 550 2963 881 3178 \n",
       "Q 1213 3394 1622 3394 \n",
       "Q 1922 3394 2156 3267 \n",
       "Q 2391 3141 2538 2938 \n",
       "L 2538 4581 \n",
       "L 3097 4581 \n",
       "L 3097 0 \n",
       "L 2575 0 \n",
       "z\n",
       "M 797 1656 \n",
       "Q 797 1019 1065 703 \n",
       "Q 1334 388 1700 388 \n",
       "Q 2069 388 2326 689 \n",
       "Q 2584 991 2584 1609 \n",
       "Q 2584 2291 2321 2609 \n",
       "Q 2059 2928 1675 2928 \n",
       "Q 1300 2928 1048 2622 \n",
       "Q 797 2316 797 1656 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-66\" transform=\"translate(0 0.765625)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-28\" transform=\"translate(35.205078 0.765625)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-Bold-78\" transform=\"translate(74.21875 0.765625)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-2a\" transform=\"translate(153.31543 39.046875) scale(0.7)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-29\" transform=\"translate(204.6875 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" transform=\"translate(243.701172 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-39\" transform=\"translate(271.484375 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-35\" transform=\"translate(327.099609 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-25\" transform=\"translate(382.714844 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" transform=\"translate(471.630859 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-70\" transform=\"translate(499.414062 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-72\" transform=\"translate(555.029297 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-65\" transform=\"translate(588.330078 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-64\" transform=\"translate(643.945312 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-2e\" transform=\"translate(699.560547 0.765625)\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"patch_6\">\n",
       "     <path d=\"M 46.232875 238.64825 \n",
       "L 63.832875 238.64825 \n",
       "L 63.832875 232.48825 \n",
       "L 46.232875 232.48825 \n",
       "z\n",
       "\" style=\"fill: #ff7f0e; fill-opacity: 0.5; stroke: #ff7f0e; stroke-opacity: 0.5; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "    </g>\n",
       "    <g id=\"text_19\">\n",
       "     <!-- $y^*$ 95% pred. -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(70.872875 238.64825) scale(0.088 -0.088)\">\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-79\" transform=\"translate(0 0.765625)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-2a\" transform=\"translate(77.283529 39.046875) scale(0.7)\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" transform=\"translate(128.655599 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-39\" transform=\"translate(156.438802 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-35\" transform=\"translate(212.054036 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-25\" transform=\"translate(267.669271 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" transform=\"translate(356.585286 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-70\" transform=\"translate(384.36849 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-72\" transform=\"translate(439.983724 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-65\" transform=\"translate(473.284505 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-64\" transform=\"translate(528.89974 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-2e\" transform=\"translate(584.514974 0.765625)\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"line2d_30\">\n",
       "     <path d=\"M 46.232875 248.115125 \n",
       "L 55.032875 248.115125 \n",
       "L 63.832875 248.115125 \n",
       "\" style=\"fill: none; stroke-dasharray: 7.68,1.92,1.2,1.92; stroke-dashoffset: 0; stroke: #bf00bf; stroke-width: 1.2\"/>\n",
       "    </g>\n",
       "    <g id=\"text_20\">\n",
       "     <!-- True function -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(70.872875 251.195125) scale(0.088 -0.088)\">\n",
       "      <defs>\n",
       "       <path id=\"ArialMT-54\" d=\"M 1659 0 \n",
       "L 1659 4041 \n",
       "L 150 4041 \n",
       "L 150 4581 \n",
       "L 3781 4581 \n",
       "L 3781 4041 \n",
       "L 2266 4041 \n",
       "L 2266 0 \n",
       "L 1659 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-75\" d=\"M 2597 0 \n",
       "L 2597 488 \n",
       "Q 2209 -75 1544 -75 \n",
       "Q 1250 -75 995 37 \n",
       "Q 741 150 617 320 \n",
       "Q 494 491 444 738 \n",
       "Q 409 903 409 1263 \n",
       "L 409 3319 \n",
       "L 972 3319 \n",
       "L 972 1478 \n",
       "Q 972 1038 1006 884 \n",
       "Q 1059 663 1231 536 \n",
       "Q 1403 409 1656 409 \n",
       "Q 1909 409 2131 539 \n",
       "Q 2353 669 2445 892 \n",
       "Q 2538 1116 2538 1541 \n",
       "L 2538 3319 \n",
       "L 3100 3319 \n",
       "L 3100 0 \n",
       "L 2597 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-66\" d=\"M 556 0 \n",
       "L 556 2881 \n",
       "L 59 2881 \n",
       "L 59 3319 \n",
       "L 556 3319 \n",
       "L 556 3672 \n",
       "Q 556 4006 616 4169 \n",
       "Q 697 4388 901 4523 \n",
       "Q 1106 4659 1475 4659 \n",
       "Q 1713 4659 2000 4603 \n",
       "L 1916 4113 \n",
       "Q 1741 4144 1584 4144 \n",
       "Q 1328 4144 1222 4034 \n",
       "Q 1116 3925 1116 3625 \n",
       "L 1116 3319 \n",
       "L 1763 3319 \n",
       "L 1763 2881 \n",
       "L 1116 2881 \n",
       "L 1116 0 \n",
       "L 556 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-63\" d=\"M 2588 1216 \n",
       "L 3141 1144 \n",
       "Q 3050 572 2676 248 \n",
       "Q 2303 -75 1759 -75 \n",
       "Q 1078 -75 664 370 \n",
       "Q 250 816 250 1647 \n",
       "Q 250 2184 428 2587 \n",
       "Q 606 2991 970 3192 \n",
       "Q 1334 3394 1763 3394 \n",
       "Q 2303 3394 2647 3120 \n",
       "Q 2991 2847 3088 2344 \n",
       "L 2541 2259 \n",
       "Q 2463 2594 2264 2762 \n",
       "Q 2066 2931 1784 2931 \n",
       "Q 1359 2931 1093 2626 \n",
       "Q 828 2322 828 1663 \n",
       "Q 828 994 1084 691 \n",
       "Q 1341 388 1753 388 \n",
       "Q 2084 388 2306 591 \n",
       "Q 2528 794 2588 1216 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#ArialMT-54\"/>\n",
       "      <use xlink:href=\"#ArialMT-72\" x=\"57.333984\"/>\n",
       "      <use xlink:href=\"#ArialMT-75\" x=\"90.634766\"/>\n",
       "      <use xlink:href=\"#ArialMT-65\" x=\"146.25\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" x=\"201.865234\"/>\n",
       "      <use xlink:href=\"#ArialMT-66\" x=\"229.648438\"/>\n",
       "      <use xlink:href=\"#ArialMT-75\" x=\"257.431641\"/>\n",
       "      <use xlink:href=\"#ArialMT-6e\" x=\"313.046875\"/>\n",
       "      <use xlink:href=\"#ArialMT-63\" x=\"368.662109\"/>\n",
       "      <use xlink:href=\"#ArialMT-74\" x=\"418.662109\"/>\n",
       "      <use xlink:href=\"#ArialMT-69\" x=\"446.445312\"/>\n",
       "      <use xlink:href=\"#ArialMT-6f\" x=\"468.662109\"/>\n",
       "      <use xlink:href=\"#ArialMT-6e\" x=\"524.277344\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"line2d_31\">\n",
       "     <path d=\"M 46.232875 260.563 \n",
       "L 55.032875 260.563 \n",
       "L 63.832875 260.563 \n",
       "\" style=\"fill: none; stroke: #ff0000; stroke-width: 0.5; stroke-linecap: round\"/>\n",
       "    </g>\n",
       "    <g id=\"text_21\">\n",
       "     <!-- Posterior samples -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(70.872875 263.643) scale(0.088 -0.088)\">\n",
       "      <defs>\n",
       "       <path id=\"ArialMT-50\" d=\"M 494 0 \n",
       "L 494 4581 \n",
       "L 2222 4581 \n",
       "Q 2678 4581 2919 4538 \n",
       "Q 3256 4481 3484 4323 \n",
       "Q 3713 4166 3852 3881 \n",
       "Q 3991 3597 3991 3256 \n",
       "Q 3991 2672 3619 2267 \n",
       "Q 3247 1863 2275 1863 \n",
       "L 1100 1863 \n",
       "L 1100 0 \n",
       "L 494 0 \n",
       "z\n",
       "M 1100 2403 \n",
       "L 2284 2403 \n",
       "Q 2872 2403 3119 2622 \n",
       "Q 3366 2841 3366 3238 \n",
       "Q 3366 3525 3220 3729 \n",
       "Q 3075 3934 2838 4000 \n",
       "Q 2684 4041 2272 4041 \n",
       "L 1100 4041 \n",
       "L 1100 2403 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-6d\" d=\"M 422 0 \n",
       "L 422 3319 \n",
       "L 925 3319 \n",
       "L 925 2853 \n",
       "Q 1081 3097 1340 3245 \n",
       "Q 1600 3394 1931 3394 \n",
       "Q 2300 3394 2536 3241 \n",
       "Q 2772 3088 2869 2813 \n",
       "Q 3263 3394 3894 3394 \n",
       "Q 4388 3394 4653 3120 \n",
       "Q 4919 2847 4919 2278 \n",
       "L 4919 0 \n",
       "L 4359 0 \n",
       "L 4359 2091 \n",
       "Q 4359 2428 4304 2576 \n",
       "Q 4250 2725 4106 2815 \n",
       "Q 3963 2906 3769 2906 \n",
       "Q 3419 2906 3187 2673 \n",
       "Q 2956 2441 2956 1928 \n",
       "L 2956 0 \n",
       "L 2394 0 \n",
       "L 2394 2156 \n",
       "Q 2394 2531 2256 2718 \n",
       "Q 2119 2906 1806 2906 \n",
       "Q 1569 2906 1367 2781 \n",
       "Q 1166 2656 1075 2415 \n",
       "Q 984 2175 984 1722 \n",
       "L 984 0 \n",
       "L 422 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-6c\" d=\"M 409 0 \n",
       "L 409 4581 \n",
       "L 972 4581 \n",
       "L 972 0 \n",
       "L 409 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#ArialMT-50\"/>\n",
       "      <use xlink:href=\"#ArialMT-6f\" x=\"66.699219\"/>\n",
       "      <use xlink:href=\"#ArialMT-73\" x=\"122.314453\"/>\n",
       "      <use xlink:href=\"#ArialMT-74\" x=\"172.314453\"/>\n",
       "      <use xlink:href=\"#ArialMT-65\" x=\"200.097656\"/>\n",
       "      <use xlink:href=\"#ArialMT-72\" x=\"255.712891\"/>\n",
       "      <use xlink:href=\"#ArialMT-69\" x=\"289.013672\"/>\n",
       "      <use xlink:href=\"#ArialMT-6f\" x=\"311.230469\"/>\n",
       "      <use xlink:href=\"#ArialMT-72\" x=\"366.845703\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" x=\"400.146484\"/>\n",
       "      <use xlink:href=\"#ArialMT-73\" x=\"427.929688\"/>\n",
       "      <use xlink:href=\"#ArialMT-61\" x=\"477.929688\"/>\n",
       "      <use xlink:href=\"#ArialMT-6d\" x=\"533.544922\"/>\n",
       "      <use xlink:href=\"#ArialMT-70\" x=\"616.845703\"/>\n",
       "      <use xlink:href=\"#ArialMT-6c\" x=\"672.460938\"/>\n",
       "      <use xlink:href=\"#ArialMT-65\" x=\"694.677734\"/>\n",
       "      <use xlink:href=\"#ArialMT-73\" x=\"750.292969\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "  </g>\n",
       " </g>\n",
       " <defs>\n",
       "  <clipPath id=\"pfa75df92ef\">\n",
       "   <rect x=\"38.312875\" y=\"7.2\" width=\"357.12\" height=\"266.112\"/>\n",
       "  </clipPath>\n",
       " </defs>\n",
       "</svg>\n"
      ],
      "text/plain": [
       "<Figure size 640x480 with 1 Axes>"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    }
   ],
   "source": [
    "train_x = torch.from_numpy(X).float()\n",
    "train_y = torch.from_numpy(Y).float()\n",
    "model = ExactGP(train_x, train_y)\n",
    "\n",
    "# It is not a good idea to train the model when we don't have enough data\n",
    "# So we fix the hyperparameters to something reasonable\n",
    "model.covar_module.base_kernel.lengthscale = 0.15\n",
    "model.covar_module.outputscale = 4.0\n",
    "model.likelihood.noise = 0.0\n",
    "model.eval()\n",
    "\n",
    "x = torch.linspace(0, 1, 100)\n",
    "plot_1d_regression(\n",
    "    x,\n",
    "    model,\n",
    "    f_true=f\n",
    ");"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "What if you try to find the point that maximizes the probability of getting an observation greater than the ones you have so far?\n",
    "Let's derive this.\n",
    "First, let's call $y_n^*$ the current maximum in your dataset, i.e.,\n",
    "\n",
    "$$\n",
    "y_n^* = \\max_{1\\le i\\le n}y_i.\n",
    "$$\n",
    "\n",
    "We define the following acquisition function:\n",
    "\n",
    "$$\n",
    "a_n(\\mathbf{x}) = \\mathbb{P}[y > y_n^* + \\psi | \\mathbf{x}, \\mathcal{D}_n].\n",
    "$$\n",
    "\n",
    "We read that \"$a_n(\\mathbf{x})$\" is the probability that we observe at $x$ a $y$ that is greater than the currently observed maximum $y_n^*$ by at least $\\psi>0$.\n",
    "The good thing is that it is possible to get an analytical answer because our point predictive distribution is Gaussian.\n",
    "In particular, we get:\n",
    "\n",
    "$$\n",
    "\\begin{align}\n",
    "a_n(\\mathbf{x}) &=& \\mathbb{P}[y > y_n^* + \\psi | x, \\mathcal{D}_n]\\\\\n",
    "&=& \\mathbb{P}\\left[\\frac{y - \\mu_n(\\mathbf{x})}{\\sigma_n(\\mathbf{x})} > \\frac{y_n^* + \\psi - \\mu_n(\\mathbf{x})}{\\sigma_n(\\mathbf{x})} \\Big| \\mathbf{x}, \\mathcal{D}_n\\right]\\\\\n",
    "&=& 1 - \\mathbb{P}\\left[\\frac{y - \\mu_n(\\mathbf{x})}{\\sigma_n(\\mathbf{x})} \\le \\frac{y_n^* + \\psi - \\mu_n(\\mathbf{x})}{\\sigma_n(\\mathbf{x})} \\Big| \\mathbf{x}, \\mathcal{D}_n\\right]\\\\\n",
    "&=& 1 - \\Phi\\left(\\frac{y_n^* + \\psi - \\mu_n(\\mathbf{x})}{\\sigma_n(\\mathbf{x})} \\right)\\\\\n",
    "&=& \\Phi\\left(\\frac{\\mu_n(\\mathbf{x}) - y_n^* - \\psi}{\\sigma_n(\\mathbf{x})} \\right),\n",
    "\\end{align}\n",
    "$$\n",
    "\n",
    "where we used that since $y_n | \\mathbf{x}_n, \\mathcal{D}_n$ is Gaussian with mean $\\mu_n(\\mathbf{x})$ and variance $\\sigma_n^2(\\mathbf{x})$, then $\\frac{y_n-\\mu_n(\\mathbf{x})}{\\sigma_n(\\mathbf{x})}$ is a standard normal, and we also used that the CDF of the standard normal satisfies this property:\n",
    "\n",
    "$$\n",
    "\\Phi(-z) = 1 - \\Phi(z).\n",
    "$$\n",
    "\n",
    "Here is the code for this activation function:"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 4,
   "metadata": {},
   "outputs": [],
   "source": [
    "def poi(m, sigma, ymax, psi=0.):\n",
    "    \"\"\"Return the probability of improvement.\n",
    "    \n",
    "    Arguments\n",
    "    m     -- The predictive mean at the test points.\n",
    "    sigma -- The predictive standard deviation at\n",
    "             the test points.\n",
    "    ymax  -- The maximum observed value (so far).\n",
    "    psi   -- A parameter that controls exploration.\n",
    "    \"\"\"\n",
    "    return torch.distributions.Normal(0, 1).cdf((m - ymax - psi) / sigma)"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "Let's visualize this:"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 5,
   "metadata": {},
   "outputs": [
    {
     "data": {
      "image/svg+xml": [
       "<?xml version=\"1.0\" encoding=\"utf-8\" standalone=\"no\"?>\n",
       "<!DOCTYPE svg PUBLIC \"-//W3C//DTD SVG 1.1//EN\"\n",
       "  \"http://www.w3.org/Graphics/SVG/1.1/DTD/svg11.dtd\">\n",
       "<svg xmlns:xlink=\"http://www.w3.org/1999/xlink\" width=\"445.848625pt\" height=\"322.539375pt\" viewBox=\"0 0 445.848625 322.539375\" xmlns=\"http://www.w3.org/2000/svg\" version=\"1.1\">\n",
       " <metadata>\n",
       "  <rdf:RDF xmlns:dc=\"http://purl.org/dc/elements/1.1/\" xmlns:cc=\"http://creativecommons.org/ns#\" xmlns:rdf=\"http://www.w3.org/1999/02/22-rdf-syntax-ns#\">\n",
       "   <cc:Work>\n",
       "    <dc:type rdf:resource=\"http://purl.org/dc/dcmitype/StillImage\"/>\n",
       "    <dc:date>2023-10-23T15:18:33.241845</dc:date>\n",
       "    <dc:format>image/svg+xml</dc:format>\n",
       "    <dc:creator>\n",
       "     <cc:Agent>\n",
       "      <dc:title>Matplotlib v3.8.0, https://matplotlib.org/</dc:title>\n",
       "     </cc:Agent>\n",
       "    </dc:creator>\n",
       "   </cc:Work>\n",
       "  </rdf:RDF>\n",
       " </metadata>\n",
       " <defs>\n",
       "  <style type=\"text/css\">*{stroke-linejoin: round; stroke-linecap: butt}</style>\n",
       " </defs>\n",
       " <g id=\"figure_1\">\n",
       "  <g id=\"patch_1\">\n",
       "   <path d=\"M 0 322.539375 \n",
       "L 445.848625 322.539375 \n",
       "L 445.848625 0 \n",
       "L 0 0 \n",
       "z\n",
       "\" style=\"fill: #ffffff\"/>\n",
       "  </g>\n",
       "  <g id=\"axes_1\">\n",
       "   <g id=\"patch_2\">\n",
       "    <path d=\"M 38.312875 286.212 \n",
       "L 395.432875 286.212 \n",
       "L 395.432875 20.1 \n",
       "L 38.312875 20.1 \n",
       "z\n",
       "\" style=\"fill: #ffffff\"/>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_1\">\n",
       "    <g id=\"xtick_1\">\n",
       "     <g id=\"line2d_1\">\n",
       "      <defs>\n",
       "       <path id=\"m0109f681a3\" d=\"M 0 0 \n",
       "L 0 4.8 \n",
       "\" style=\"stroke: #262626\"/>\n",
       "      </defs>\n",
       "      <g>\n",
       "       <use xlink:href=\"#m0109f681a3\" x=\"54.545602\" y=\"286.212\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_1\">\n",
       "      <!-- 0.0 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(48.429602 300.810875) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-30\" d=\"M 266 2259 \n",
       "Q 266 3072 433 3567 \n",
       "Q 600 4063 929 4331 \n",
       "Q 1259 4600 1759 4600 \n",
       "Q 2128 4600 2406 4451 \n",
       "Q 2684 4303 2865 4023 \n",
       "Q 3047 3744 3150 3342 \n",
       "Q 3253 2941 3253 2259 \n",
       "Q 3253 1453 3087 958 \n",
       "Q 2922 463 2592 192 \n",
       "Q 2263 -78 1759 -78 \n",
       "Q 1097 -78 719 397 \n",
       "Q 266 969 266 2259 \n",
       "z\n",
       "M 844 2259 \n",
       "Q 844 1131 1108 757 \n",
       "Q 1372 384 1759 384 \n",
       "Q 2147 384 2411 759 \n",
       "Q 2675 1134 2675 2259 \n",
       "Q 2675 3391 2411 3762 \n",
       "Q 2147 4134 1753 4134 \n",
       "Q 1366 4134 1134 3806 \n",
       "Q 844 3388 844 2259 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "        <path id=\"ArialMT-2e\" d=\"M 581 0 \n",
       "L 581 641 \n",
       "L 1222 641 \n",
       "L 1222 0 \n",
       "L 581 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_2\">\n",
       "     <g id=\"line2d_2\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m0109f681a3\" x=\"119.476511\" y=\"286.212\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_2\">\n",
       "      <!-- 0.2 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(113.360511 300.810875) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-32\" d=\"M 3222 541 \n",
       "L 3222 0 \n",
       "L 194 0 \n",
       "Q 188 203 259 391 \n",
       "Q 375 700 629 1000 \n",
       "Q 884 1300 1366 1694 \n",
       "Q 2113 2306 2375 2664 \n",
       "Q 2638 3022 2638 3341 \n",
       "Q 2638 3675 2398 3904 \n",
       "Q 2159 4134 1775 4134 \n",
       "Q 1369 4134 1125 3890 \n",
       "Q 881 3647 878 3216 \n",
       "L 300 3275 \n",
       "Q 359 3922 746 4261 \n",
       "Q 1134 4600 1788 4600 \n",
       "Q 2447 4600 2831 4234 \n",
       "Q 3216 3869 3216 3328 \n",
       "Q 3216 3053 3103 2787 \n",
       "Q 2991 2522 2730 2228 \n",
       "Q 2469 1934 1863 1422 \n",
       "Q 1356 997 1212 845 \n",
       "Q 1069 694 975 541 \n",
       "L 3222 541 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-32\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_3\">\n",
       "     <g id=\"line2d_3\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m0109f681a3\" x=\"184.40742\" y=\"286.212\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_3\">\n",
       "      <!-- 0.4 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(178.29142 300.810875) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-34\" d=\"M 2069 0 \n",
       "L 2069 1097 \n",
       "L 81 1097 \n",
       "L 81 1613 \n",
       "L 2172 4581 \n",
       "L 2631 4581 \n",
       "L 2631 1613 \n",
       "L 3250 1613 \n",
       "L 3250 1097 \n",
       "L 2631 1097 \n",
       "L 2631 0 \n",
       "L 2069 0 \n",
       "z\n",
       "M 2069 1613 \n",
       "L 2069 3678 \n",
       "L 634 1613 \n",
       "L 2069 1613 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-34\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_4\">\n",
       "     <g id=\"line2d_4\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m0109f681a3\" x=\"249.33833\" y=\"286.212\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_4\">\n",
       "      <!-- 0.6 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(243.22233 300.810875) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-36\" d=\"M 3184 3459 \n",
       "L 2625 3416 \n",
       "Q 2550 3747 2413 3897 \n",
       "Q 2184 4138 1850 4138 \n",
       "Q 1581 4138 1378 3988 \n",
       "Q 1113 3794 959 3422 \n",
       "Q 806 3050 800 2363 \n",
       "Q 1003 2672 1297 2822 \n",
       "Q 1591 2972 1913 2972 \n",
       "Q 2475 2972 2870 2558 \n",
       "Q 3266 2144 3266 1488 \n",
       "Q 3266 1056 3080 686 \n",
       "Q 2894 316 2569 119 \n",
       "Q 2244 -78 1831 -78 \n",
       "Q 1128 -78 684 439 \n",
       "Q 241 956 241 2144 \n",
       "Q 241 3472 731 4075 \n",
       "Q 1159 4600 1884 4600 \n",
       "Q 2425 4600 2770 4297 \n",
       "Q 3116 3994 3184 3459 \n",
       "z\n",
       "M 888 1484 \n",
       "Q 888 1194 1011 928 \n",
       "Q 1134 663 1356 523 \n",
       "Q 1578 384 1822 384 \n",
       "Q 2178 384 2434 671 \n",
       "Q 2691 959 2691 1453 \n",
       "Q 2691 1928 2437 2201 \n",
       "Q 2184 2475 1800 2475 \n",
       "Q 1419 2475 1153 2201 \n",
       "Q 888 1928 888 1484 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-36\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_5\">\n",
       "     <g id=\"line2d_5\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m0109f681a3\" x=\"314.269239\" y=\"286.212\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_5\">\n",
       "      <!-- 0.8 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(308.153239 300.810875) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-38\" d=\"M 1131 2484 \n",
       "Q 781 2613 612 2850 \n",
       "Q 444 3088 444 3419 \n",
       "Q 444 3919 803 4259 \n",
       "Q 1163 4600 1759 4600 \n",
       "Q 2359 4600 2725 4251 \n",
       "Q 3091 3903 3091 3403 \n",
       "Q 3091 3084 2923 2848 \n",
       "Q 2756 2613 2416 2484 \n",
       "Q 2838 2347 3058 2040 \n",
       "Q 3278 1734 3278 1309 \n",
       "Q 3278 722 2862 322 \n",
       "Q 2447 -78 1769 -78 \n",
       "Q 1091 -78 675 323 \n",
       "Q 259 725 259 1325 \n",
       "Q 259 1772 486 2073 \n",
       "Q 713 2375 1131 2484 \n",
       "z\n",
       "M 1019 3438 \n",
       "Q 1019 3113 1228 2906 \n",
       "Q 1438 2700 1772 2700 \n",
       "Q 2097 2700 2305 2904 \n",
       "Q 2513 3109 2513 3406 \n",
       "Q 2513 3716 2298 3927 \n",
       "Q 2084 4138 1766 4138 \n",
       "Q 1444 4138 1231 3931 \n",
       "Q 1019 3725 1019 3438 \n",
       "z\n",
       "M 838 1322 \n",
       "Q 838 1081 952 856 \n",
       "Q 1066 631 1291 507 \n",
       "Q 1516 384 1775 384 \n",
       "Q 2178 384 2440 643 \n",
       "Q 2703 903 2703 1303 \n",
       "Q 2703 1709 2433 1975 \n",
       "Q 2163 2241 1756 2241 \n",
       "Q 1359 2241 1098 1978 \n",
       "Q 838 1716 838 1322 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-38\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_6\">\n",
       "     <g id=\"line2d_6\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m0109f681a3\" x=\"379.200148\" y=\"286.212\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_6\">\n",
       "      <!-- 1.0 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(373.084148 300.810875) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-31\" d=\"M 2384 0 \n",
       "L 1822 0 \n",
       "L 1822 3584 \n",
       "Q 1619 3391 1289 3197 \n",
       "Q 959 3003 697 2906 \n",
       "L 697 3450 \n",
       "Q 1169 3672 1522 3987 \n",
       "Q 1875 4303 2022 4600 \n",
       "L 2384 4600 \n",
       "L 2384 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-31\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"text_7\">\n",
       "     <!-- $x$ -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(213.992875 313.431375) scale(0.096 -0.096)\">\n",
       "      <defs>\n",
       "       <path id=\"DejaVuSans-Oblique-78\" d=\"M 3841 3500 \n",
       "L 2234 1784 \n",
       "L 3219 0 \n",
       "L 2559 0 \n",
       "L 1819 1388 \n",
       "L 531 0 \n",
       "L -166 0 \n",
       "L 1556 1844 \n",
       "L 641 3500 \n",
       "L 1300 3500 \n",
       "L 1972 2234 \n",
       "L 3144 3500 \n",
       "L 3841 3500 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-78\" transform=\"translate(0 0.3125)\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_2\">\n",
       "    <g id=\"ytick_1\">\n",
       "     <g id=\"line2d_7\">\n",
       "      <defs>\n",
       "       <path id=\"mb5e751a0fa\" d=\"M 0 0 \n",
       "L -4.8 0 \n",
       "\" style=\"stroke: #262626\"/>\n",
       "      </defs>\n",
       "      <g>\n",
       "       <use xlink:href=\"#mb5e751a0fa\" x=\"38.312875\" y=\"275.237111\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_8\">\n",
       "      <!-- −4 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(19.9795 278.386549) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-2212\" d=\"M 3381 1997 \n",
       "L 356 1997 \n",
       "L 356 2522 \n",
       "L 3381 2522 \n",
       "L 3381 1997 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-34\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_2\">\n",
       "     <g id=\"line2d_8\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mb5e751a0fa\" x=\"38.312875\" y=\"244.40228\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_9\">\n",
       "      <!-- −3 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(19.9795 247.551717) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-33\" d=\"M 269 1209 \n",
       "L 831 1284 \n",
       "Q 928 806 1161 595 \n",
       "Q 1394 384 1728 384 \n",
       "Q 2125 384 2398 659 \n",
       "Q 2672 934 2672 1341 \n",
       "Q 2672 1728 2419 1979 \n",
       "Q 2166 2231 1775 2231 \n",
       "Q 1616 2231 1378 2169 \n",
       "L 1441 2663 \n",
       "Q 1497 2656 1531 2656 \n",
       "Q 1891 2656 2178 2843 \n",
       "Q 2466 3031 2466 3422 \n",
       "Q 2466 3731 2256 3934 \n",
       "Q 2047 4138 1716 4138 \n",
       "Q 1388 4138 1169 3931 \n",
       "Q 950 3725 888 3313 \n",
       "L 325 3413 \n",
       "Q 428 3978 793 4289 \n",
       "Q 1159 4600 1703 4600 \n",
       "Q 2078 4600 2393 4439 \n",
       "Q 2709 4278 2876 4000 \n",
       "Q 3044 3722 3044 3409 \n",
       "Q 3044 3113 2884 2869 \n",
       "Q 2725 2625 2413 2481 \n",
       "Q 2819 2388 3044 2092 \n",
       "Q 3269 1797 3269 1353 \n",
       "Q 3269 753 2831 336 \n",
       "Q 2394 -81 1725 -81 \n",
       "Q 1122 -81 723 278 \n",
       "Q 325 638 269 1209 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-33\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_3\">\n",
       "     <g id=\"line2d_9\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mb5e751a0fa\" x=\"38.312875\" y=\"213.567448\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_10\">\n",
       "      <!-- −2 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(19.9795 216.716886) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-32\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_4\">\n",
       "     <g id=\"line2d_10\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mb5e751a0fa\" x=\"38.312875\" y=\"182.732617\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_11\">\n",
       "      <!-- −1 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(19.9795 185.882054) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-31\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_5\">\n",
       "     <g id=\"line2d_11\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mb5e751a0fa\" x=\"38.312875\" y=\"151.897785\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_12\">\n",
       "      <!-- 0 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(25.11925 155.047223) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_6\">\n",
       "     <g id=\"line2d_12\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mb5e751a0fa\" x=\"38.312875\" y=\"121.062954\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_13\">\n",
       "      <!-- 1 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(25.11925 124.212391) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-31\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_7\">\n",
       "     <g id=\"line2d_13\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mb5e751a0fa\" x=\"38.312875\" y=\"90.228122\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_14\">\n",
       "      <!-- 2 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(25.11925 93.37756) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-32\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_8\">\n",
       "     <g id=\"line2d_14\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mb5e751a0fa\" x=\"38.312875\" y=\"59.393291\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_15\">\n",
       "      <!-- 3 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(25.11925 62.542728) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-33\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_9\">\n",
       "     <g id=\"line2d_15\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mb5e751a0fa\" x=\"38.312875\" y=\"28.558459\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_16\">\n",
       "      <!-- 4 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(25.11925 31.707897) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-34\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"text_17\">\n",
       "     <!-- $y$ -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(13.9635 156.036) rotate(-90) scale(0.096 -0.096)\">\n",
       "      <defs>\n",
       "       <path id=\"DejaVuSans-Oblique-79\" d=\"M 1588 -325 \n",
       "Q 1188 -997 936 -1164 \n",
       "Q 684 -1331 294 -1331 \n",
       "L -159 -1331 \n",
       "L -63 -850 \n",
       "L 269 -850 \n",
       "Q 509 -850 678 -719 \n",
       "Q 847 -588 1056 -206 \n",
       "L 1234 128 \n",
       "L 459 3500 \n",
       "L 1069 3500 \n",
       "L 1650 819 \n",
       "L 3256 3500 \n",
       "L 3859 3500 \n",
       "L 1588 -325 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-79\" transform=\"translate(0 0.3125)\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"PolyCollection_1\">\n",
       "    <defs>\n",
       "     <path id=\"m52f9d0ed66\" d=\"M 54.545602 -267.999748 \n",
       "L 54.545602 -62.312144 \n",
       "L 57.824941 -65.392955 \n",
       "L 61.10428 -68.858777 \n",
       "L 64.383619 -72.716631 \n",
       "L 67.662958 -76.966449 \n",
       "L 70.942296 -81.600234 \n",
       "L 74.221636 -86.601408 \n",
       "L 77.500973 -91.944467 \n",
       "L 80.780313 -97.594537 \n",
       "L 84.059653 -103.507845 \n",
       "L 87.33899 -109.631479 \n",
       "L 90.61833 -115.90428 \n",
       "L 93.89767 -122.2576 \n",
       "L 97.177007 -128.61607 \n",
       "L 100.456344 -134.900104 \n",
       "L 103.735686 -141.025991 \n",
       "L 107.015024 -146.908285 \n",
       "L 110.294361 -152.462431 \n",
       "L 113.573703 -157.601138 \n",
       "L 116.853041 -154.949963 \n",
       "L 120.132378 -150.927324 \n",
       "L 123.41172 -147.637734 \n",
       "L 126.691057 -145.134613 \n",
       "L 129.970395 -143.460186 \n",
       "L 133.249737 -142.642115 \n",
       "L 136.529069 -142.695406 \n",
       "L 139.808412 -143.619991 \n",
       "L 143.087754 -145.401707 \n",
       "L 146.367086 -148.012531 \n",
       "L 149.646428 -151.411246 \n",
       "L 152.92577 -155.543619 \n",
       "L 156.205103 -160.346132 \n",
       "L 159.484445 -158.921957 \n",
       "L 162.763787 -153.949585 \n",
       "L 166.04312 -148.556985 \n",
       "L 169.322462 -142.826614 \n",
       "L 172.601804 -136.842098 \n",
       "L 175.881137 -130.687724 \n",
       "L 179.160479 -124.445729 \n",
       "L 182.439821 -118.194924 \n",
       "L 185.719153 -112.009397 \n",
       "L 188.998496 -105.956736 \n",
       "L 192.277838 -100.097337 \n",
       "L 195.55717 -94.483341 \n",
       "L 198.836512 -89.158227 \n",
       "L 202.115855 -84.15648 \n",
       "L 205.395187 -79.50364 \n",
       "L 208.674529 -75.216482 \n",
       "L 211.953871 -71.303558 \n",
       "L 215.233204 -67.765801 \n",
       "L 218.512556 -64.597358 \n",
       "L 221.791879 -61.786652 \n",
       "L 225.071221 -59.317221 \n",
       "L 228.350563 -57.16904 \n",
       "L 231.629886 -55.319496 \n",
       "L 234.909247 -53.74452 \n",
       "L 238.18857 -52.419688 \n",
       "L 241.467912 -51.321132 \n",
       "L 244.747254 -50.426516 \n",
       "L 248.026597 -49.715734 \n",
       "L 251.305939 -49.171687 \n",
       "L 254.585262 -48.780721 \n",
       "L 257.864623 -48.533127 \n",
       "L 261.143946 -48.423375 \n",
       "L 264.423288 -48.450304 \n",
       "L 267.70263 -48.617141 \n",
       "L 270.981953 -48.931414 \n",
       "L 274.261315 -49.404784 \n",
       "L 277.540637 -50.052665 \n",
       "L 280.81998 -50.893872 \n",
       "L 284.099322 -51.95012 \n",
       "L 287.378664 -53.245339 \n",
       "L 290.658006 -54.805105 \n",
       "L 293.937329 -56.655781 \n",
       "L 297.21669 -58.823877 \n",
       "L 300.496013 -61.334962 \n",
       "L 303.775355 -64.213179 \n",
       "L 307.054697 -67.479993 \n",
       "L 310.33402 -71.153696 \n",
       "L 313.613382 -75.248491 \n",
       "L 316.892705 -79.773774 \n",
       "L 320.172047 -84.733632 \n",
       "L 323.451389 -90.126314 \n",
       "L 326.730731 -95.943751 \n",
       "L 330.010073 -102.171509 \n",
       "L 333.289396 -108.78871 \n",
       "L 336.568738 -115.768066 \n",
       "L 339.84808 -123.076443 \n",
       "L 343.127423 -130.674359 \n",
       "L 346.406765 -138.517869 \n",
       "L 349.686088 -146.559343 \n",
       "L 352.96543 -154.746783 \n",
       "L 356.244772 -163.020004 \n",
       "L 359.524114 -155.274058 \n",
       "L 362.803456 -147.07923 \n",
       "L 366.082798 -139.027599 \n",
       "L 369.362141 -131.170007 \n",
       "L 372.641463 -123.55498 \n",
       "L 375.920806 -116.227409 \n",
       "L 379.200148 -109.225998 \n",
       "L 379.200148 -218.885848 \n",
       "L 379.200148 -218.885848 \n",
       "L 375.920806 -211.492362 \n",
       "L 372.641463 -203.824257 \n",
       "L 369.362141 -195.924604 \n",
       "L 366.082798 -187.842064 \n",
       "L 362.803456 -179.628146 \n",
       "L 359.524114 -171.335858 \n",
       "L 356.244772 -163.558616 \n",
       "L 352.96543 -171.867087 \n",
       "L 349.686088 -180.155864 \n",
       "L 346.406765 -188.363352 \n",
       "L 343.127423 -196.43529 \n",
       "L 339.84808 -204.320997 \n",
       "L 336.568738 -211.9727 \n",
       "L 333.289396 -219.346433 \n",
       "L 330.010073 -226.40398 \n",
       "L 326.730731 -233.112533 \n",
       "L 323.451389 -239.445316 \n",
       "L 320.172047 -245.381767 \n",
       "L 316.892705 -250.907521 \n",
       "L 313.613382 -256.01455 \n",
       "L 310.33402 -260.700737 \n",
       "L 307.054697 -264.969435 \n",
       "L 303.775355 -268.829096 \n",
       "L 300.496013 -272.292573 \n",
       "L 297.21669 -275.376318 \n",
       "L 293.937329 -278.099871 \n",
       "L 290.658006 -280.484671 \n",
       "L 287.378664 -282.553608 \n",
       "L 284.099322 -284.329887 \n",
       "L 280.81998 -285.836376 \n",
       "L 277.540637 -287.094785 \n",
       "L 274.261315 -288.124979 \n",
       "L 270.981953 -288.9443 \n",
       "L 267.70263 -289.567017 \n",
       "L 264.423288 -290.003908 \n",
       "L 261.143946 -290.261794 \n",
       "L 257.864623 -290.343375 \n",
       "L 254.585262 -290.247047 \n",
       "L 251.305939 -289.966914 \n",
       "L 248.026597 -289.492839 \n",
       "L 244.747254 -288.810773 \n",
       "L 241.467912 -287.90313 \n",
       "L 238.18857 -286.749216 \n",
       "L 234.909247 -285.32605 \n",
       "L 231.629886 -283.608996 \n",
       "L 228.350563 -281.572795 \n",
       "L 225.071221 -279.192466 \n",
       "L 221.791879 -276.444483 \n",
       "L 218.512556 -273.307895 \n",
       "L 215.233204 -269.765403 \n",
       "L 211.953871 -265.804708 \n",
       "L 208.674529 -261.419444 \n",
       "L 205.395187 -256.610279 \n",
       "L 202.115855 -251.385853 \n",
       "L 198.836512 -245.763425 \n",
       "L 195.55717 -239.769565 \n",
       "L 192.277838 -233.440289 \n",
       "L 188.998496 -226.821264 \n",
       "L 185.719153 -219.967514 \n",
       "L 182.439821 -212.943037 \n",
       "L 179.160479 -205.819774 \n",
       "L 175.881137 -198.676946 \n",
       "L 172.601804 -191.599264 \n",
       "L 169.322462 -184.675609 \n",
       "L 166.04312 -177.997609 \n",
       "L 162.763787 -171.65686 \n",
       "L 159.484445 -165.744344 \n",
       "L 156.205103 -163.39698 \n",
       "L 152.92577 -167.302535 \n",
       "L 149.646428 -170.573609 \n",
       "L 146.367086 -173.156137 \n",
       "L 143.087754 -175.005192 \n",
       "L 139.808412 -176.08853 \n",
       "L 136.529069 -176.386615 \n",
       "L 133.249737 -175.893108 \n",
       "L 129.970395 -174.61493 \n",
       "L 126.691057 -172.573134 \n",
       "L 123.41172 -169.800289 \n",
       "L 120.132378 -166.342356 \n",
       "L 116.853041 -162.255169 \n",
       "L 113.573703 -159.644318 \n",
       "L 110.294361 -164.927898 \n",
       "L 107.015024 -170.729807 \n",
       "L 103.735686 -176.959709 \n",
       "L 100.456344 -183.528746 \n",
       "L 97.177007 -190.345977 \n",
       "L 93.89767 -197.321098 \n",
       "L 90.61833 -204.367029 \n",
       "L 87.33899 -211.400095 \n",
       "L 84.059653 -218.342726 \n",
       "L 80.780313 -225.124416 \n",
       "L 77.500973 -231.682603 \n",
       "L 74.221636 -237.963844 \n",
       "L 70.942296 -243.923636 \n",
       "L 67.662958 -249.527082 \n",
       "L 64.383619 -254.748664 \n",
       "L 61.10428 -259.5719 \n",
       "L 57.824941 -263.988945 \n",
       "L 54.545602 -267.999748 \n",
       "z\n",
       "\" style=\"stroke: #1f77b4; stroke-opacity: 0.5; stroke-width: 0.8\"/>\n",
       "    </defs>\n",
       "    <g clip-path=\"url(#p60fa01c9f4)\">\n",
       "     <use xlink:href=\"#m52f9d0ed66\" x=\"0\" y=\"322.539375\" style=\"fill: #1f77b4; fill-opacity: 0.5; stroke: #1f77b4; stroke-opacity: 0.5; stroke-width: 0.8\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"PolyCollection_2\">\n",
       "    <defs>\n",
       "     <path id=\"m6fd2096b00\" d=\"M 54.545602 -62.312144 \n",
       "L 54.545602 -62.312144 \n",
       "L 57.824941 -65.392955 \n",
       "L 61.10428 -68.858777 \n",
       "L 64.383619 -72.716631 \n",
       "L 67.662958 -76.966449 \n",
       "L 70.942296 -81.600234 \n",
       "L 74.221636 -86.601408 \n",
       "L 77.500973 -91.944467 \n",
       "L 80.780313 -97.594537 \n",
       "L 84.059653 -103.507845 \n",
       "L 87.33899 -109.631479 \n",
       "L 90.61833 -115.90428 \n",
       "L 93.89767 -122.2576 \n",
       "L 97.177007 -128.61607 \n",
       "L 100.456344 -134.900104 \n",
       "L 103.735686 -141.025991 \n",
       "L 107.015024 -146.908285 \n",
       "L 110.294361 -152.462431 \n",
       "L 113.573703 -157.601138 \n",
       "L 116.853041 -154.949963 \n",
       "L 120.132378 -150.927324 \n",
       "L 123.41172 -147.637734 \n",
       "L 126.691057 -145.134613 \n",
       "L 129.970395 -143.460186 \n",
       "L 133.249737 -142.642115 \n",
       "L 136.529069 -142.695406 \n",
       "L 139.808412 -143.619991 \n",
       "L 143.087754 -145.401707 \n",
       "L 146.367086 -148.012531 \n",
       "L 149.646428 -151.411246 \n",
       "L 152.92577 -155.543619 \n",
       "L 156.205103 -160.346132 \n",
       "L 159.484445 -158.921957 \n",
       "L 162.763787 -153.949585 \n",
       "L 166.04312 -148.556985 \n",
       "L 169.322462 -142.826614 \n",
       "L 172.601804 -136.842098 \n",
       "L 175.881137 -130.687724 \n",
       "L 179.160479 -124.445729 \n",
       "L 182.439821 -118.194924 \n",
       "L 185.719153 -112.009397 \n",
       "L 188.998496 -105.956736 \n",
       "L 192.277838 -100.097337 \n",
       "L 195.55717 -94.483341 \n",
       "L 198.836512 -89.158227 \n",
       "L 202.115855 -84.15648 \n",
       "L 205.395187 -79.50364 \n",
       "L 208.674529 -75.216482 \n",
       "L 211.953871 -71.303558 \n",
       "L 215.233204 -67.765801 \n",
       "L 218.512556 -64.597358 \n",
       "L 221.791879 -61.786652 \n",
       "L 225.071221 -59.317221 \n",
       "L 228.350563 -57.16904 \n",
       "L 231.629886 -55.319496 \n",
       "L 234.909247 -53.74452 \n",
       "L 238.18857 -52.419688 \n",
       "L 241.467912 -51.321132 \n",
       "L 244.747254 -50.426516 \n",
       "L 248.026597 -49.715734 \n",
       "L 251.305939 -49.171687 \n",
       "L 254.585262 -48.780721 \n",
       "L 257.864623 -48.533127 \n",
       "L 261.143946 -48.423375 \n",
       "L 264.423288 -48.450304 \n",
       "L 267.70263 -48.617141 \n",
       "L 270.981953 -48.931414 \n",
       "L 274.261315 -49.404784 \n",
       "L 277.540637 -50.052665 \n",
       "L 280.81998 -50.893872 \n",
       "L 284.099322 -51.95012 \n",
       "L 287.378664 -53.245339 \n",
       "L 290.658006 -54.805105 \n",
       "L 293.937329 -56.655781 \n",
       "L 297.21669 -58.823877 \n",
       "L 300.496013 -61.334962 \n",
       "L 303.775355 -64.213179 \n",
       "L 307.054697 -67.479993 \n",
       "L 310.33402 -71.153696 \n",
       "L 313.613382 -75.248491 \n",
       "L 316.892705 -79.773774 \n",
       "L 320.172047 -84.733632 \n",
       "L 323.451389 -90.126314 \n",
       "L 326.730731 -95.943751 \n",
       "L 330.010073 -102.171509 \n",
       "L 333.289396 -108.78871 \n",
       "L 336.568738 -115.768066 \n",
       "L 339.84808 -123.076443 \n",
       "L 343.127423 -130.674359 \n",
       "L 346.406765 -138.517869 \n",
       "L 349.686088 -146.559343 \n",
       "L 352.96543 -154.746783 \n",
       "L 356.244772 -163.020004 \n",
       "L 359.524114 -155.274058 \n",
       "L 362.803456 -147.07923 \n",
       "L 366.082798 -139.027599 \n",
       "L 369.362141 -131.170007 \n",
       "L 372.641463 -123.55498 \n",
       "L 375.920806 -116.227409 \n",
       "L 379.200148 -109.225998 \n",
       "L 379.200148 -109.225998 \n",
       "L 379.200148 -109.225998 \n",
       "L 375.920806 -116.227409 \n",
       "L 372.641463 -123.55498 \n",
       "L 369.362141 -131.170007 \n",
       "L 366.082798 -139.027599 \n",
       "L 362.803456 -147.07923 \n",
       "L 359.524114 -155.274058 \n",
       "L 356.244772 -163.020004 \n",
       "L 352.96543 -154.746783 \n",
       "L 349.686088 -146.559343 \n",
       "L 346.406765 -138.517869 \n",
       "L 343.127423 -130.674359 \n",
       "L 339.84808 -123.076443 \n",
       "L 336.568738 -115.768066 \n",
       "L 333.289396 -108.78871 \n",
       "L 330.010073 -102.171509 \n",
       "L 326.730731 -95.943751 \n",
       "L 323.451389 -90.126314 \n",
       "L 320.172047 -84.733632 \n",
       "L 316.892705 -79.773774 \n",
       "L 313.613382 -75.248491 \n",
       "L 310.33402 -71.153696 \n",
       "L 307.054697 -67.479993 \n",
       "L 303.775355 -64.213179 \n",
       "L 300.496013 -61.334962 \n",
       "L 297.21669 -58.823877 \n",
       "L 293.937329 -56.655781 \n",
       "L 290.658006 -54.805105 \n",
       "L 287.378664 -53.245339 \n",
       "L 284.099322 -51.95012 \n",
       "L 280.81998 -50.893872 \n",
       "L 277.540637 -50.052665 \n",
       "L 274.261315 -49.404784 \n",
       "L 270.981953 -48.931414 \n",
       "L 267.70263 -48.617141 \n",
       "L 264.423288 -48.450304 \n",
       "L 261.143946 -48.423375 \n",
       "L 257.864623 -48.533127 \n",
       "L 254.585262 -48.780721 \n",
       "L 251.305939 -49.171687 \n",
       "L 248.026597 -49.715734 \n",
       "L 244.747254 -50.426516 \n",
       "L 241.467912 -51.321132 \n",
       "L 238.18857 -52.419688 \n",
       "L 234.909247 -53.74452 \n",
       "L 231.629886 -55.319496 \n",
       "L 228.350563 -57.16904 \n",
       "L 225.071221 -59.317221 \n",
       "L 221.791879 -61.786652 \n",
       "L 218.512556 -64.597358 \n",
       "L 215.233204 -67.765801 \n",
       "L 211.953871 -71.303558 \n",
       "L 208.674529 -75.216482 \n",
       "L 205.395187 -79.50364 \n",
       "L 202.115855 -84.15648 \n",
       "L 198.836512 -89.158227 \n",
       "L 195.55717 -94.483341 \n",
       "L 192.277838 -100.097337 \n",
       "L 188.998496 -105.956736 \n",
       "L 185.719153 -112.009397 \n",
       "L 182.439821 -118.194924 \n",
       "L 179.160479 -124.445729 \n",
       "L 175.881137 -130.687724 \n",
       "L 172.601804 -136.842098 \n",
       "L 169.322462 -142.826614 \n",
       "L 166.04312 -148.556985 \n",
       "L 162.763787 -153.949585 \n",
       "L 159.484445 -158.921957 \n",
       "L 156.205103 -160.346132 \n",
       "L 152.92577 -155.543619 \n",
       "L 149.646428 -151.411246 \n",
       "L 146.367086 -148.012531 \n",
       "L 143.087754 -145.401707 \n",
       "L 139.808412 -143.619991 \n",
       "L 136.529069 -142.695406 \n",
       "L 133.249737 -142.642115 \n",
       "L 129.970395 -143.460186 \n",
       "L 126.691057 -145.134613 \n",
       "L 123.41172 -147.637734 \n",
       "L 120.132378 -150.927324 \n",
       "L 116.853041 -154.949963 \n",
       "L 113.573703 -157.601138 \n",
       "L 110.294361 -152.462431 \n",
       "L 107.015024 -146.908285 \n",
       "L 103.735686 -141.025991 \n",
       "L 100.456344 -134.900104 \n",
       "L 97.177007 -128.61607 \n",
       "L 93.89767 -122.2576 \n",
       "L 90.61833 -115.90428 \n",
       "L 87.33899 -109.631479 \n",
       "L 84.059653 -103.507845 \n",
       "L 80.780313 -97.594537 \n",
       "L 77.500973 -91.944467 \n",
       "L 74.221636 -86.601408 \n",
       "L 70.942296 -81.600234 \n",
       "L 67.662958 -76.966449 \n",
       "L 64.383619 -72.716631 \n",
       "L 61.10428 -68.858777 \n",
       "L 57.824941 -65.392955 \n",
       "L 54.545602 -62.312144 \n",
       "z\n",
       "\" style=\"stroke: #ff7f0e; stroke-opacity: 0.5; stroke-width: 0.8\"/>\n",
       "    </defs>\n",
       "    <g clip-path=\"url(#p60fa01c9f4)\">\n",
       "     <use xlink:href=\"#m6fd2096b00\" x=\"0\" y=\"322.539375\" style=\"fill: #ff7f0e; fill-opacity: 0.5; stroke: #ff7f0e; stroke-opacity: 0.5; stroke-width: 0.8\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"PolyCollection_3\">\n",
       "    <defs>\n",
       "     <path id=\"mc2fbb6acc2\" d=\"M 54.545602 -267.999748 \n",
       "L 54.545602 -267.999748 \n",
       "L 57.824941 -263.988945 \n",
       "L 61.10428 -259.5719 \n",
       "L 64.383619 -254.748664 \n",
       "L 67.662958 -249.527082 \n",
       "L 70.942296 -243.923636 \n",
       "L 74.221636 -237.963844 \n",
       "L 77.500973 -231.682603 \n",
       "L 80.780313 -225.124416 \n",
       "L 84.059653 -218.342726 \n",
       "L 87.33899 -211.400095 \n",
       "L 90.61833 -204.367029 \n",
       "L 93.89767 -197.321098 \n",
       "L 97.177007 -190.345977 \n",
       "L 100.456344 -183.528746 \n",
       "L 103.735686 -176.959709 \n",
       "L 107.015024 -170.729807 \n",
       "L 110.294361 -164.927898 \n",
       "L 113.573703 -159.644318 \n",
       "L 116.853041 -162.255169 \n",
       "L 120.132378 -166.342356 \n",
       "L 123.41172 -169.800289 \n",
       "L 126.691057 -172.573134 \n",
       "L 129.970395 -174.61493 \n",
       "L 133.249737 -175.893108 \n",
       "L 136.529069 -176.386615 \n",
       "L 139.808412 -176.08853 \n",
       "L 143.087754 -175.005192 \n",
       "L 146.367086 -173.156137 \n",
       "L 149.646428 -170.573609 \n",
       "L 152.92577 -167.302535 \n",
       "L 156.205103 -163.39698 \n",
       "L 159.484445 -165.744344 \n",
       "L 162.763787 -171.65686 \n",
       "L 166.04312 -177.997609 \n",
       "L 169.322462 -184.675609 \n",
       "L 172.601804 -191.599264 \n",
       "L 175.881137 -198.676946 \n",
       "L 179.160479 -205.819774 \n",
       "L 182.439821 -212.943037 \n",
       "L 185.719153 -219.967514 \n",
       "L 188.998496 -226.821264 \n",
       "L 192.277838 -233.440289 \n",
       "L 195.55717 -239.769565 \n",
       "L 198.836512 -245.763425 \n",
       "L 202.115855 -251.385853 \n",
       "L 205.395187 -256.610279 \n",
       "L 208.674529 -261.419444 \n",
       "L 211.953871 -265.804708 \n",
       "L 215.233204 -269.765403 \n",
       "L 218.512556 -273.307895 \n",
       "L 221.791879 -276.444483 \n",
       "L 225.071221 -279.192466 \n",
       "L 228.350563 -281.572795 \n",
       "L 231.629886 -283.608996 \n",
       "L 234.909247 -285.32605 \n",
       "L 238.18857 -286.749216 \n",
       "L 241.467912 -287.90313 \n",
       "L 244.747254 -288.810773 \n",
       "L 248.026597 -289.492839 \n",
       "L 251.305939 -289.966914 \n",
       "L 254.585262 -290.247047 \n",
       "L 257.864623 -290.343375 \n",
       "L 261.143946 -290.261794 \n",
       "L 264.423288 -290.003908 \n",
       "L 267.70263 -289.567017 \n",
       "L 270.981953 -288.9443 \n",
       "L 274.261315 -288.124979 \n",
       "L 277.540637 -287.094785 \n",
       "L 280.81998 -285.836376 \n",
       "L 284.099322 -284.329887 \n",
       "L 287.378664 -282.553608 \n",
       "L 290.658006 -280.484671 \n",
       "L 293.937329 -278.099871 \n",
       "L 297.21669 -275.376318 \n",
       "L 300.496013 -272.292573 \n",
       "L 303.775355 -268.829096 \n",
       "L 307.054697 -264.969435 \n",
       "L 310.33402 -260.700737 \n",
       "L 313.613382 -256.01455 \n",
       "L 316.892705 -250.907521 \n",
       "L 320.172047 -245.381767 \n",
       "L 323.451389 -239.445316 \n",
       "L 326.730731 -233.112533 \n",
       "L 330.010073 -226.40398 \n",
       "L 333.289396 -219.346433 \n",
       "L 336.568738 -211.9727 \n",
       "L 339.84808 -204.320997 \n",
       "L 343.127423 -196.43529 \n",
       "L 346.406765 -188.363352 \n",
       "L 349.686088 -180.155864 \n",
       "L 352.96543 -171.867087 \n",
       "L 356.244772 -163.558616 \n",
       "L 359.524114 -171.335858 \n",
       "L 362.803456 -179.628146 \n",
       "L 366.082798 -187.842064 \n",
       "L 369.362141 -195.924604 \n",
       "L 372.641463 -203.824257 \n",
       "L 375.920806 -211.492362 \n",
       "L 379.200148 -218.885848 \n",
       "L 379.200148 -218.885848 \n",
       "L 379.200148 -218.885848 \n",
       "L 375.920806 -211.492362 \n",
       "L 372.641463 -203.824257 \n",
       "L 369.362141 -195.924604 \n",
       "L 366.082798 -187.842064 \n",
       "L 362.803456 -179.628146 \n",
       "L 359.524114 -171.335858 \n",
       "L 356.244772 -163.558616 \n",
       "L 352.96543 -171.867087 \n",
       "L 349.686088 -180.155864 \n",
       "L 346.406765 -188.363352 \n",
       "L 343.127423 -196.43529 \n",
       "L 339.84808 -204.320997 \n",
       "L 336.568738 -211.9727 \n",
       "L 333.289396 -219.346433 \n",
       "L 330.010073 -226.40398 \n",
       "L 326.730731 -233.112533 \n",
       "L 323.451389 -239.445316 \n",
       "L 320.172047 -245.381767 \n",
       "L 316.892705 -250.907521 \n",
       "L 313.613382 -256.01455 \n",
       "L 310.33402 -260.700737 \n",
       "L 307.054697 -264.969435 \n",
       "L 303.775355 -268.829096 \n",
       "L 300.496013 -272.292573 \n",
       "L 297.21669 -275.376318 \n",
       "L 293.937329 -278.099871 \n",
       "L 290.658006 -280.484671 \n",
       "L 287.378664 -282.553608 \n",
       "L 284.099322 -284.329887 \n",
       "L 280.81998 -285.836376 \n",
       "L 277.540637 -287.094785 \n",
       "L 274.261315 -288.124979 \n",
       "L 270.981953 -288.9443 \n",
       "L 267.70263 -289.567017 \n",
       "L 264.423288 -290.003908 \n",
       "L 261.143946 -290.261794 \n",
       "L 257.864623 -290.343375 \n",
       "L 254.585262 -290.247047 \n",
       "L 251.305939 -289.966914 \n",
       "L 248.026597 -289.492839 \n",
       "L 244.747254 -288.810773 \n",
       "L 241.467912 -287.90313 \n",
       "L 238.18857 -286.749216 \n",
       "L 234.909247 -285.32605 \n",
       "L 231.629886 -283.608996 \n",
       "L 228.350563 -281.572795 \n",
       "L 225.071221 -279.192466 \n",
       "L 221.791879 -276.444483 \n",
       "L 218.512556 -273.307895 \n",
       "L 215.233204 -269.765403 \n",
       "L 211.953871 -265.804708 \n",
       "L 208.674529 -261.419444 \n",
       "L 205.395187 -256.610279 \n",
       "L 202.115855 -251.385853 \n",
       "L 198.836512 -245.763425 \n",
       "L 195.55717 -239.769565 \n",
       "L 192.277838 -233.440289 \n",
       "L 188.998496 -226.821264 \n",
       "L 185.719153 -219.967514 \n",
       "L 182.439821 -212.943037 \n",
       "L 179.160479 -205.819774 \n",
       "L 175.881137 -198.676946 \n",
       "L 172.601804 -191.599264 \n",
       "L 169.322462 -184.675609 \n",
       "L 166.04312 -177.997609 \n",
       "L 162.763787 -171.65686 \n",
       "L 159.484445 -165.744344 \n",
       "L 156.205103 -163.39698 \n",
       "L 152.92577 -167.302535 \n",
       "L 149.646428 -170.573609 \n",
       "L 146.367086 -173.156137 \n",
       "L 143.087754 -175.005192 \n",
       "L 139.808412 -176.08853 \n",
       "L 136.529069 -176.386615 \n",
       "L 133.249737 -175.893108 \n",
       "L 129.970395 -174.61493 \n",
       "L 126.691057 -172.573134 \n",
       "L 123.41172 -169.800289 \n",
       "L 120.132378 -166.342356 \n",
       "L 116.853041 -162.255169 \n",
       "L 113.573703 -159.644318 \n",
       "L 110.294361 -164.927898 \n",
       "L 107.015024 -170.729807 \n",
       "L 103.735686 -176.959709 \n",
       "L 100.456344 -183.528746 \n",
       "L 97.177007 -190.345977 \n",
       "L 93.89767 -197.321098 \n",
       "L 90.61833 -204.367029 \n",
       "L 87.33899 -211.400095 \n",
       "L 84.059653 -218.342726 \n",
       "L 80.780313 -225.124416 \n",
       "L 77.500973 -231.682603 \n",
       "L 74.221636 -237.963844 \n",
       "L 70.942296 -243.923636 \n",
       "L 67.662958 -249.527082 \n",
       "L 64.383619 -254.748664 \n",
       "L 61.10428 -259.5719 \n",
       "L 57.824941 -263.988945 \n",
       "L 54.545602 -267.999748 \n",
       "z\n",
       "\" style=\"stroke: #ff7f0e; stroke-opacity: 0.5; stroke-width: 0.8\"/>\n",
       "    </defs>\n",
       "    <g clip-path=\"url(#p60fa01c9f4)\">\n",
       "     <use xlink:href=\"#mc2fbb6acc2\" x=\"0\" y=\"322.539375\" style=\"fill: #ff7f0e; fill-opacity: 0.5; stroke: #ff7f0e; stroke-opacity: 0.5; stroke-width: 0.8\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"line2d_16\">\n",
       "    <defs>\n",
       "     <path id=\"mb2278b66b5\" d=\"M -5 5 \n",
       "L 5 -5 \n",
       "M -5 -5 \n",
       "L 5 5 \n",
       "\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "    </defs>\n",
       "    <g clip-path=\"url(#p60fa01c9f4)\">\n",
       "     <use xlink:href=\"#mb2278b66b5\" x=\"356.349693\" y=\"159.25008\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     <use xlink:href=\"#mb2278b66b5\" x=\"157.258364\" y=\"160.520769\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     <use xlink:href=\"#mb2278b66b5\" x=\"114.255683\" y=\"163.925163\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"line2d_17\">\n",
       "    <path d=\"M 54.545602 157.383429 \n",
       "L 57.824941 157.848424 \n",
       "L 61.10428 158.324035 \n",
       "L 64.383619 158.80673 \n",
       "L 67.662958 159.292608 \n",
       "L 70.942296 159.777443 \n",
       "L 74.221636 160.256747 \n",
       "L 77.500973 160.725838 \n",
       "L 80.780313 161.179899 \n",
       "L 84.059653 161.614087 \n",
       "L 87.33899 162.023587 \n",
       "L 90.61833 162.403721 \n",
       "L 93.89767 162.750027 \n",
       "L 97.177007 163.058353 \n",
       "L 100.456344 163.324949 \n",
       "L 103.735686 163.546525 \n",
       "L 107.015024 163.720329 \n",
       "L 110.294361 163.844211 \n",
       "L 113.573703 163.916647 \n",
       "L 116.853041 163.936809 \n",
       "L 120.132378 163.904535 \n",
       "L 123.41172 163.820363 \n",
       "L 126.691057 163.685502 \n",
       "L 129.970395 163.501817 \n",
       "L 133.249737 163.271763 \n",
       "L 136.529069 162.998365 \n",
       "L 139.808412 162.685115 \n",
       "L 143.087754 162.335925 \n",
       "L 146.367086 161.955041 \n",
       "L 149.646428 161.546948 \n",
       "L 152.92577 161.116298 \n",
       "L 156.205103 160.667819 \n",
       "L 159.484445 160.206224 \n",
       "L 162.763787 159.736152 \n",
       "L 166.04312 159.262078 \n",
       "L 169.322462 158.788263 \n",
       "L 172.601804 158.318693 \n",
       "L 175.881137 157.85704 \n",
       "L 179.160479 157.406623 \n",
       "L 182.439821 156.970393 \n",
       "L 185.719153 156.550919 \n",
       "L 188.998496 156.150375 \n",
       "L 192.277838 155.770564 \n",
       "L 195.55717 155.412924 \n",
       "L 198.836512 155.078546 \n",
       "L 202.115855 154.76821 \n",
       "L 205.395187 154.482415 \n",
       "L 208.674529 154.22141 \n",
       "L 211.953871 153.985238 \n",
       "L 215.233204 153.773772 \n",
       "L 218.512556 153.586748 \n",
       "L 221.791879 153.42381 \n",
       "L 225.071221 153.284532 \n",
       "L 228.350563 153.168459 \n",
       "L 231.629886 153.075129 \n",
       "L 234.909247 153.004089 \n",
       "L 238.18857 152.954921 \n",
       "L 241.467912 152.927245 \n",
       "L 244.747254 152.920729 \n",
       "L 248.026597 152.935088 \n",
       "L 251.305939 152.970078 \n",
       "L 254.585262 153.025488 \n",
       "L 257.864623 153.101125 \n",
       "L 261.143946 153.196792 \n",
       "L 264.423288 153.31227 \n",
       "L 267.70263 153.447294 \n",
       "L 270.981953 153.601517 \n",
       "L 274.261315 153.774497 \n",
       "L 277.540637 153.965652 \n",
       "L 280.81998 154.17425 \n",
       "L 284.099322 154.399375 \n",
       "L 287.378664 154.639901 \n",
       "L 290.658006 154.894487 \n",
       "L 293.937329 155.16155 \n",
       "L 297.21669 155.439281 \n",
       "L 300.496013 155.725605 \n",
       "L 303.775355 156.018238 \n",
       "L 307.054697 156.31466 \n",
       "L 310.33402 156.612159 \n",
       "L 313.613382 156.907853 \n",
       "L 316.892705 157.198726 \n",
       "L 320.172047 157.481676 \n",
       "L 323.451389 157.753558 \n",
       "L 326.730731 158.011232 \n",
       "L 330.010073 158.251631 \n",
       "L 333.289396 158.471805 \n",
       "L 336.568738 158.66899 \n",
       "L 339.84808 158.840657 \n",
       "L 343.127423 158.98455 \n",
       "L 346.406765 159.098764 \n",
       "L 349.686088 159.181772 \n",
       "L 352.96543 159.23244 \n",
       "L 356.244772 159.250065 \n",
       "L 359.524114 159.234416 \n",
       "L 362.803456 159.185687 \n",
       "L 366.082798 159.104544 \n",
       "L 369.362141 158.992071 \n",
       "L 372.641463 158.849758 \n",
       "L 375.920806 158.679488 \n",
       "L 379.200148 158.483452 \n",
       "\" clip-path=\"url(#p60fa01c9f4)\" style=\"fill: none; stroke: #1f77b4; stroke-width: 2; stroke-linecap: round\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_3\">\n",
       "    <path d=\"M 38.312875 275.237111 \n",
       "L 38.312875 28.558459 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_4\">\n",
       "    <path d=\"M 54.545602 286.212 \n",
       "L 379.200148 286.212 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"text_18\">\n",
       "    <!-- psi=2.00 -->\n",
       "    <g style=\"fill: #262626\" transform=\"translate(198.592375 14.1) scale(0.096 -0.096)\">\n",
       "     <defs>\n",
       "      <path id=\"ArialMT-70\" d=\"M 422 -1272 \n",
       "L 422 3319 \n",
       "L 934 3319 \n",
       "L 934 2888 \n",
       "Q 1116 3141 1344 3267 \n",
       "Q 1572 3394 1897 3394 \n",
       "Q 2322 3394 2647 3175 \n",
       "Q 2972 2956 3137 2557 \n",
       "Q 3303 2159 3303 1684 \n",
       "Q 3303 1175 3120 767 \n",
       "Q 2938 359 2589 142 \n",
       "Q 2241 -75 1856 -75 \n",
       "Q 1575 -75 1351 44 \n",
       "Q 1128 163 984 344 \n",
       "L 984 -1272 \n",
       "L 422 -1272 \n",
       "z\n",
       "M 931 1641 \n",
       "Q 931 1000 1190 694 \n",
       "Q 1450 388 1819 388 \n",
       "Q 2194 388 2461 705 \n",
       "Q 2728 1022 2728 1688 \n",
       "Q 2728 2322 2467 2637 \n",
       "Q 2206 2953 1844 2953 \n",
       "Q 1484 2953 1207 2617 \n",
       "Q 931 2281 931 1641 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-73\" d=\"M 197 991 \n",
       "L 753 1078 \n",
       "Q 800 744 1014 566 \n",
       "Q 1228 388 1613 388 \n",
       "Q 2000 388 2187 545 \n",
       "Q 2375 703 2375 916 \n",
       "Q 2375 1106 2209 1216 \n",
       "Q 2094 1291 1634 1406 \n",
       "Q 1016 1563 777 1677 \n",
       "Q 538 1791 414 1992 \n",
       "Q 291 2194 291 2438 \n",
       "Q 291 2659 392 2848 \n",
       "Q 494 3038 669 3163 \n",
       "Q 800 3259 1026 3326 \n",
       "Q 1253 3394 1513 3394 \n",
       "Q 1903 3394 2198 3281 \n",
       "Q 2494 3169 2634 2976 \n",
       "Q 2775 2784 2828 2463 \n",
       "L 2278 2388 \n",
       "Q 2241 2644 2061 2787 \n",
       "Q 1881 2931 1553 2931 \n",
       "Q 1166 2931 1000 2803 \n",
       "Q 834 2675 834 2503 \n",
       "Q 834 2394 903 2306 \n",
       "Q 972 2216 1119 2156 \n",
       "Q 1203 2125 1616 2013 \n",
       "Q 2213 1853 2448 1751 \n",
       "Q 2684 1650 2818 1456 \n",
       "Q 2953 1263 2953 975 \n",
       "Q 2953 694 2789 445 \n",
       "Q 2625 197 2315 61 \n",
       "Q 2006 -75 1616 -75 \n",
       "Q 969 -75 630 194 \n",
       "Q 291 463 197 991 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-69\" d=\"M 425 3934 \n",
       "L 425 4581 \n",
       "L 988 4581 \n",
       "L 988 3934 \n",
       "L 425 3934 \n",
       "z\n",
       "M 425 0 \n",
       "L 425 3319 \n",
       "L 988 3319 \n",
       "L 988 0 \n",
       "L 425 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-3d\" d=\"M 3381 2694 \n",
       "L 356 2694 \n",
       "L 356 3219 \n",
       "L 3381 3219 \n",
       "L 3381 2694 \n",
       "z\n",
       "M 3381 1303 \n",
       "L 356 1303 \n",
       "L 356 1828 \n",
       "L 3381 1828 \n",
       "L 3381 1303 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "     </defs>\n",
       "     <use xlink:href=\"#ArialMT-70\"/>\n",
       "     <use xlink:href=\"#ArialMT-73\" x=\"55.615234\"/>\n",
       "     <use xlink:href=\"#ArialMT-69\" x=\"105.615234\"/>\n",
       "     <use xlink:href=\"#ArialMT-3d\" x=\"127.832031\"/>\n",
       "     <use xlink:href=\"#ArialMT-32\" x=\"186.230469\"/>\n",
       "     <use xlink:href=\"#ArialMT-2e\" x=\"241.845703\"/>\n",
       "     <use xlink:href=\"#ArialMT-30\" x=\"269.628906\"/>\n",
       "     <use xlink:href=\"#ArialMT-30\" x=\"325.244141\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"legend_1\">\n",
       "    <g id=\"line2d_18\">\n",
       "     <g>\n",
       "      <use xlink:href=\"#mb2278b66b5\" x=\"307.608875\" y=\"31.238875\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"text_19\">\n",
       "     <!-- Observations -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(323.448875 34.318875) scale(0.088 -0.088)\">\n",
       "      <defs>\n",
       "       <path id=\"ArialMT-4f\" d=\"M 309 2231 \n",
       "Q 309 3372 921 4017 \n",
       "Q 1534 4663 2503 4663 \n",
       "Q 3138 4663 3647 4359 \n",
       "Q 4156 4056 4423 3514 \n",
       "Q 4691 2972 4691 2284 \n",
       "Q 4691 1588 4409 1038 \n",
       "Q 4128 488 3612 205 \n",
       "Q 3097 -78 2500 -78 \n",
       "Q 1853 -78 1343 234 \n",
       "Q 834 547 571 1087 \n",
       "Q 309 1628 309 2231 \n",
       "z\n",
       "M 934 2222 \n",
       "Q 934 1394 1379 917 \n",
       "Q 1825 441 2497 441 \n",
       "Q 3181 441 3623 922 \n",
       "Q 4066 1403 4066 2288 \n",
       "Q 4066 2847 3877 3264 \n",
       "Q 3688 3681 3323 3911 \n",
       "Q 2959 4141 2506 4141 \n",
       "Q 1863 4141 1398 3698 \n",
       "Q 934 3256 934 2222 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-62\" d=\"M 941 0 \n",
       "L 419 0 \n",
       "L 419 4581 \n",
       "L 981 4581 \n",
       "L 981 2947 \n",
       "Q 1338 3394 1891 3394 \n",
       "Q 2197 3394 2470 3270 \n",
       "Q 2744 3147 2920 2923 \n",
       "Q 3097 2700 3197 2384 \n",
       "Q 3297 2069 3297 1709 \n",
       "Q 3297 856 2875 390 \n",
       "Q 2453 -75 1863 -75 \n",
       "Q 1275 -75 941 416 \n",
       "L 941 0 \n",
       "z\n",
       "M 934 1684 \n",
       "Q 934 1088 1097 822 \n",
       "Q 1363 388 1816 388 \n",
       "Q 2184 388 2453 708 \n",
       "Q 2722 1028 2722 1663 \n",
       "Q 2722 2313 2464 2622 \n",
       "Q 2206 2931 1841 2931 \n",
       "Q 1472 2931 1203 2611 \n",
       "Q 934 2291 934 1684 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-65\" d=\"M 2694 1069 \n",
       "L 3275 997 \n",
       "Q 3138 488 2766 206 \n",
       "Q 2394 -75 1816 -75 \n",
       "Q 1088 -75 661 373 \n",
       "Q 234 822 234 1631 \n",
       "Q 234 2469 665 2931 \n",
       "Q 1097 3394 1784 3394 \n",
       "Q 2450 3394 2872 2941 \n",
       "Q 3294 2488 3294 1666 \n",
       "Q 3294 1616 3291 1516 \n",
       "L 816 1516 \n",
       "Q 847 969 1125 678 \n",
       "Q 1403 388 1819 388 \n",
       "Q 2128 388 2347 550 \n",
       "Q 2566 713 2694 1069 \n",
       "z\n",
       "M 847 1978 \n",
       "L 2700 1978 \n",
       "Q 2663 2397 2488 2606 \n",
       "Q 2219 2931 1791 2931 \n",
       "Q 1403 2931 1139 2672 \n",
       "Q 875 2413 847 1978 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-72\" d=\"M 416 0 \n",
       "L 416 3319 \n",
       "L 922 3319 \n",
       "L 922 2816 \n",
       "Q 1116 3169 1280 3281 \n",
       "Q 1444 3394 1641 3394 \n",
       "Q 1925 3394 2219 3213 \n",
       "L 2025 2691 \n",
       "Q 1819 2813 1613 2813 \n",
       "Q 1428 2813 1281 2702 \n",
       "Q 1134 2591 1072 2394 \n",
       "Q 978 2094 978 1738 \n",
       "L 978 0 \n",
       "L 416 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-76\" d=\"M 1344 0 \n",
       "L 81 3319 \n",
       "L 675 3319 \n",
       "L 1388 1331 \n",
       "Q 1503 1009 1600 663 \n",
       "Q 1675 925 1809 1294 \n",
       "L 2547 3319 \n",
       "L 3125 3319 \n",
       "L 1869 0 \n",
       "L 1344 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-61\" d=\"M 2588 409 \n",
       "Q 2275 144 1986 34 \n",
       "Q 1697 -75 1366 -75 \n",
       "Q 819 -75 525 192 \n",
       "Q 231 459 231 875 \n",
       "Q 231 1119 342 1320 \n",
       "Q 453 1522 633 1644 \n",
       "Q 813 1766 1038 1828 \n",
       "Q 1203 1872 1538 1913 \n",
       "Q 2219 1994 2541 2106 \n",
       "Q 2544 2222 2544 2253 \n",
       "Q 2544 2597 2384 2738 \n",
       "Q 2169 2928 1744 2928 \n",
       "Q 1347 2928 1158 2789 \n",
       "Q 969 2650 878 2297 \n",
       "L 328 2372 \n",
       "Q 403 2725 575 2942 \n",
       "Q 747 3159 1072 3276 \n",
       "Q 1397 3394 1825 3394 \n",
       "Q 2250 3394 2515 3294 \n",
       "Q 2781 3194 2906 3042 \n",
       "Q 3031 2891 3081 2659 \n",
       "Q 3109 2516 3109 2141 \n",
       "L 3109 1391 \n",
       "Q 3109 606 3145 398 \n",
       "Q 3181 191 3288 0 \n",
       "L 2700 0 \n",
       "Q 2613 175 2588 409 \n",
       "z\n",
       "M 2541 1666 \n",
       "Q 2234 1541 1622 1453 \n",
       "Q 1275 1403 1131 1340 \n",
       "Q 988 1278 909 1158 \n",
       "Q 831 1038 831 891 \n",
       "Q 831 666 1001 516 \n",
       "Q 1172 366 1500 366 \n",
       "Q 1825 366 2078 508 \n",
       "Q 2331 650 2450 897 \n",
       "Q 2541 1088 2541 1459 \n",
       "L 2541 1666 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-74\" d=\"M 1650 503 \n",
       "L 1731 6 \n",
       "Q 1494 -44 1306 -44 \n",
       "Q 1000 -44 831 53 \n",
       "Q 663 150 594 308 \n",
       "Q 525 466 525 972 \n",
       "L 525 2881 \n",
       "L 113 2881 \n",
       "L 113 3319 \n",
       "L 525 3319 \n",
       "L 525 4141 \n",
       "L 1084 4478 \n",
       "L 1084 3319 \n",
       "L 1650 3319 \n",
       "L 1650 2881 \n",
       "L 1084 2881 \n",
       "L 1084 941 \n",
       "Q 1084 700 1114 631 \n",
       "Q 1144 563 1211 522 \n",
       "Q 1278 481 1403 481 \n",
       "Q 1497 481 1650 503 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-6f\" d=\"M 213 1659 \n",
       "Q 213 2581 725 3025 \n",
       "Q 1153 3394 1769 3394 \n",
       "Q 2453 3394 2887 2945 \n",
       "Q 3322 2497 3322 1706 \n",
       "Q 3322 1066 3130 698 \n",
       "Q 2938 331 2570 128 \n",
       "Q 2203 -75 1769 -75 \n",
       "Q 1072 -75 642 372 \n",
       "Q 213 819 213 1659 \n",
       "z\n",
       "M 791 1659 \n",
       "Q 791 1022 1069 705 \n",
       "Q 1347 388 1769 388 \n",
       "Q 2188 388 2466 706 \n",
       "Q 2744 1025 2744 1678 \n",
       "Q 2744 2294 2464 2611 \n",
       "Q 2184 2928 1769 2928 \n",
       "Q 1347 2928 1069 2612 \n",
       "Q 791 2297 791 1659 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-6e\" d=\"M 422 0 \n",
       "L 422 3319 \n",
       "L 928 3319 \n",
       "L 928 2847 \n",
       "Q 1294 3394 1984 3394 \n",
       "Q 2284 3394 2536 3286 \n",
       "Q 2788 3178 2913 3003 \n",
       "Q 3038 2828 3088 2588 \n",
       "Q 3119 2431 3119 2041 \n",
       "L 3119 0 \n",
       "L 2556 0 \n",
       "L 2556 2019 \n",
       "Q 2556 2363 2490 2533 \n",
       "Q 2425 2703 2258 2804 \n",
       "Q 2091 2906 1866 2906 \n",
       "Q 1506 2906 1245 2678 \n",
       "Q 984 2450 984 1813 \n",
       "L 984 0 \n",
       "L 422 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#ArialMT-4f\"/>\n",
       "      <use xlink:href=\"#ArialMT-62\" x=\"77.783203\"/>\n",
       "      <use xlink:href=\"#ArialMT-73\" x=\"133.398438\"/>\n",
       "      <use xlink:href=\"#ArialMT-65\" x=\"183.398438\"/>\n",
       "      <use xlink:href=\"#ArialMT-72\" x=\"239.013672\"/>\n",
       "      <use xlink:href=\"#ArialMT-76\" x=\"272.314453\"/>\n",
       "      <use xlink:href=\"#ArialMT-61\" x=\"322.314453\"/>\n",
       "      <use xlink:href=\"#ArialMT-74\" x=\"377.929688\"/>\n",
       "      <use xlink:href=\"#ArialMT-69\" x=\"405.712891\"/>\n",
       "      <use xlink:href=\"#ArialMT-6f\" x=\"427.929688\"/>\n",
       "      <use xlink:href=\"#ArialMT-6e\" x=\"483.544922\"/>\n",
       "      <use xlink:href=\"#ArialMT-73\" x=\"539.160156\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"line2d_19\">\n",
       "     <path d=\"M 298.808875 43.822875 \n",
       "L 307.608875 43.822875 \n",
       "L 316.408875 43.822875 \n",
       "\" style=\"fill: none; stroke: #1f77b4; stroke-width: 2; stroke-linecap: round\"/>\n",
       "    </g>\n",
       "    <g id=\"text_20\">\n",
       "     <!-- $m_n(x)$ -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(323.448875 46.902875) scale(0.088 -0.088)\">\n",
       "      <defs>\n",
       "       <path id=\"DejaVuSans-Oblique-6d\" d=\"M 5747 2113 \n",
       "L 5338 0 \n",
       "L 4763 0 \n",
       "L 5166 2094 \n",
       "Q 5191 2228 5203 2325 \n",
       "Q 5216 2422 5216 2491 \n",
       "Q 5216 2772 5059 2928 \n",
       "Q 4903 3084 4622 3084 \n",
       "Q 4203 3084 3875 2770 \n",
       "Q 3547 2456 3450 1953 \n",
       "L 3066 0 \n",
       "L 2491 0 \n",
       "L 2900 2094 \n",
       "Q 2925 2209 2937 2307 \n",
       "Q 2950 2406 2950 2484 \n",
       "Q 2950 2769 2794 2926 \n",
       "Q 2638 3084 2363 3084 \n",
       "Q 1938 3084 1609 2770 \n",
       "Q 1281 2456 1184 1953 \n",
       "L 800 0 \n",
       "L 225 0 \n",
       "L 909 3500 \n",
       "L 1484 3500 \n",
       "L 1375 2956 \n",
       "Q 1609 3263 1923 3423 \n",
       "Q 2238 3584 2597 3584 \n",
       "Q 2978 3584 3223 3384 \n",
       "Q 3469 3184 3519 2828 \n",
       "Q 3781 3197 4126 3390 \n",
       "Q 4472 3584 4856 3584 \n",
       "Q 5306 3584 5551 3325 \n",
       "Q 5797 3066 5797 2591 \n",
       "Q 5797 2488 5784 2364 \n",
       "Q 5772 2241 5747 2113 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-Oblique-6e\" d=\"M 3566 2113 \n",
       "L 3156 0 \n",
       "L 2578 0 \n",
       "L 2988 2091 \n",
       "Q 3016 2238 3031 2350 \n",
       "Q 3047 2463 3047 2528 \n",
       "Q 3047 2791 2881 2937 \n",
       "Q 2716 3084 2419 3084 \n",
       "Q 1956 3084 1622 2776 \n",
       "Q 1288 2469 1184 1941 \n",
       "L 800 0 \n",
       "L 225 0 \n",
       "L 903 3500 \n",
       "L 1478 3500 \n",
       "L 1363 2950 \n",
       "Q 1603 3253 1940 3418 \n",
       "Q 2278 3584 2650 3584 \n",
       "Q 3113 3584 3367 3334 \n",
       "Q 3622 3084 3622 2631 \n",
       "Q 3622 2519 3608 2391 \n",
       "Q 3594 2263 3566 2113 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-28\" d=\"M 1984 4856 \n",
       "Q 1566 4138 1362 3434 \n",
       "Q 1159 2731 1159 2009 \n",
       "Q 1159 1288 1364 580 \n",
       "Q 1569 -128 1984 -844 \n",
       "L 1484 -844 \n",
       "Q 1016 -109 783 600 \n",
       "Q 550 1309 550 2009 \n",
       "Q 550 2706 781 3412 \n",
       "Q 1013 4119 1484 4856 \n",
       "L 1984 4856 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-29\" d=\"M 513 4856 \n",
       "L 1013 4856 \n",
       "Q 1481 4119 1714 3412 \n",
       "Q 1947 2706 1947 2009 \n",
       "Q 1947 1309 1714 600 \n",
       "Q 1481 -109 1013 -844 \n",
       "L 513 -844 \n",
       "Q 928 -128 1133 580 \n",
       "Q 1338 1288 1338 2009 \n",
       "Q 1338 2731 1133 3434 \n",
       "Q 928 4138 513 4856 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-6d\" transform=\"translate(0 0.125)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-6e\" transform=\"translate(97.412109 -16.28125) scale(0.7)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-28\" transform=\"translate(144.511719 0.125)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-78\" transform=\"translate(183.525391 0.125)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-29\" transform=\"translate(242.705078 0.125)\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"patch_5\">\n",
       "     <path d=\"M 298.808875 61.059875 \n",
       "L 316.408875 61.059875 \n",
       "L 316.408875 54.899875 \n",
       "L 298.808875 54.899875 \n",
       "z\n",
       "\" style=\"fill: #1f77b4; fill-opacity: 0.5; stroke: #1f77b4; stroke-opacity: 0.5; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "    </g>\n",
       "    <g id=\"text_21\">\n",
       "     <!-- $f(\\mathbf{x}^*)$ 95% pred. -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(323.448875 61.059875) scale(0.088 -0.088)\">\n",
       "      <defs>\n",
       "       <path id=\"DejaVuSans-Oblique-66\" d=\"M 3059 4863 \n",
       "L 2969 4384 \n",
       "L 2419 4384 \n",
       "Q 2106 4384 1964 4261 \n",
       "Q 1822 4138 1753 3809 \n",
       "L 1691 3500 \n",
       "L 2638 3500 \n",
       "L 2553 3053 \n",
       "L 1606 3053 \n",
       "L 1013 0 \n",
       "L 434 0 \n",
       "L 1031 3053 \n",
       "L 481 3053 \n",
       "L 563 3500 \n",
       "L 1113 3500 \n",
       "L 1159 3744 \n",
       "Q 1278 4363 1576 4613 \n",
       "Q 1875 4863 2516 4863 \n",
       "L 3059 4863 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-Bold-78\" d=\"M 1422 1791 \n",
       "L 159 3500 \n",
       "L 1344 3500 \n",
       "L 2059 2463 \n",
       "L 2784 3500 \n",
       "L 3969 3500 \n",
       "L 2706 1797 \n",
       "L 4031 0 \n",
       "L 2847 0 \n",
       "L 2059 1106 \n",
       "L 1281 0 \n",
       "L 97 0 \n",
       "L 1422 1791 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-2a\" d=\"M 3009 3897 \n",
       "L 1888 3291 \n",
       "L 3009 2681 \n",
       "L 2828 2375 \n",
       "L 1778 3009 \n",
       "L 1778 1831 \n",
       "L 1422 1831 \n",
       "L 1422 3009 \n",
       "L 372 2375 \n",
       "L 191 2681 \n",
       "L 1313 3291 \n",
       "L 191 3897 \n",
       "L 372 4206 \n",
       "L 1422 3572 \n",
       "L 1422 4750 \n",
       "L 1778 4750 \n",
       "L 1778 3572 \n",
       "L 2828 4206 \n",
       "L 3009 3897 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-20\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-39\" d=\"M 350 1059 \n",
       "L 891 1109 \n",
       "Q 959 728 1153 556 \n",
       "Q 1347 384 1650 384 \n",
       "Q 1909 384 2104 503 \n",
       "Q 2300 622 2425 820 \n",
       "Q 2550 1019 2634 1356 \n",
       "Q 2719 1694 2719 2044 \n",
       "Q 2719 2081 2716 2156 \n",
       "Q 2547 1888 2255 1720 \n",
       "Q 1963 1553 1622 1553 \n",
       "Q 1053 1553 659 1965 \n",
       "Q 266 2378 266 3053 \n",
       "Q 266 3750 677 4175 \n",
       "Q 1088 4600 1706 4600 \n",
       "Q 2153 4600 2523 4359 \n",
       "Q 2894 4119 3086 3673 \n",
       "Q 3278 3228 3278 2384 \n",
       "Q 3278 1506 3087 986 \n",
       "Q 2897 466 2520 194 \n",
       "Q 2144 -78 1638 -78 \n",
       "Q 1100 -78 759 220 \n",
       "Q 419 519 350 1059 \n",
       "z\n",
       "M 2653 3081 \n",
       "Q 2653 3566 2395 3850 \n",
       "Q 2138 4134 1775 4134 \n",
       "Q 1400 4134 1122 3828 \n",
       "Q 844 3522 844 3034 \n",
       "Q 844 2597 1108 2323 \n",
       "Q 1372 2050 1759 2050 \n",
       "Q 2150 2050 2401 2323 \n",
       "Q 2653 2597 2653 3081 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-35\" d=\"M 266 1200 \n",
       "L 856 1250 \n",
       "Q 922 819 1161 601 \n",
       "Q 1400 384 1738 384 \n",
       "Q 2144 384 2425 690 \n",
       "Q 2706 997 2706 1503 \n",
       "Q 2706 1984 2436 2262 \n",
       "Q 2166 2541 1728 2541 \n",
       "Q 1456 2541 1237 2417 \n",
       "Q 1019 2294 894 2097 \n",
       "L 366 2166 \n",
       "L 809 4519 \n",
       "L 3088 4519 \n",
       "L 3088 3981 \n",
       "L 1259 3981 \n",
       "L 1013 2750 \n",
       "Q 1425 3038 1878 3038 \n",
       "Q 2478 3038 2890 2622 \n",
       "Q 3303 2206 3303 1553 \n",
       "Q 3303 931 2941 478 \n",
       "Q 2500 -78 1738 -78 \n",
       "Q 1113 -78 717 272 \n",
       "Q 322 622 266 1200 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-25\" d=\"M 372 3481 \n",
       "Q 372 3972 619 4315 \n",
       "Q 866 4659 1334 4659 \n",
       "Q 1766 4659 2048 4351 \n",
       "Q 2331 4044 2331 3447 \n",
       "Q 2331 2866 2045 2552 \n",
       "Q 1759 2238 1341 2238 \n",
       "Q 925 2238 648 2547 \n",
       "Q 372 2856 372 3481 \n",
       "z\n",
       "M 1350 4272 \n",
       "Q 1141 4272 1002 4090 \n",
       "Q 863 3909 863 3425 \n",
       "Q 863 2984 1003 2804 \n",
       "Q 1144 2625 1350 2625 \n",
       "Q 1563 2625 1702 2806 \n",
       "Q 1841 2988 1841 3469 \n",
       "Q 1841 3913 1700 4092 \n",
       "Q 1559 4272 1350 4272 \n",
       "z\n",
       "M 1353 -169 \n",
       "L 3859 4659 \n",
       "L 4316 4659 \n",
       "L 1819 -169 \n",
       "L 1353 -169 \n",
       "z\n",
       "M 3334 1075 \n",
       "Q 3334 1569 3581 1911 \n",
       "Q 3828 2253 4300 2253 \n",
       "Q 4731 2253 5014 1945 \n",
       "Q 5297 1638 5297 1041 \n",
       "Q 5297 459 5011 145 \n",
       "Q 4725 -169 4303 -169 \n",
       "Q 3888 -169 3611 142 \n",
       "Q 3334 453 3334 1075 \n",
       "z\n",
       "M 4316 1866 \n",
       "Q 4103 1866 3964 1684 \n",
       "Q 3825 1503 3825 1019 \n",
       "Q 3825 581 3965 400 \n",
       "Q 4106 219 4313 219 \n",
       "Q 4528 219 4667 400 \n",
       "Q 4806 581 4806 1063 \n",
       "Q 4806 1506 4665 1686 \n",
       "Q 4525 1866 4316 1866 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-64\" d=\"M 2575 0 \n",
       "L 2575 419 \n",
       "Q 2259 -75 1647 -75 \n",
       "Q 1250 -75 917 144 \n",
       "Q 584 363 401 755 \n",
       "Q 219 1147 219 1656 \n",
       "Q 219 2153 384 2558 \n",
       "Q 550 2963 881 3178 \n",
       "Q 1213 3394 1622 3394 \n",
       "Q 1922 3394 2156 3267 \n",
       "Q 2391 3141 2538 2938 \n",
       "L 2538 4581 \n",
       "L 3097 4581 \n",
       "L 3097 0 \n",
       "L 2575 0 \n",
       "z\n",
       "M 797 1656 \n",
       "Q 797 1019 1065 703 \n",
       "Q 1334 388 1700 388 \n",
       "Q 2069 388 2326 689 \n",
       "Q 2584 991 2584 1609 \n",
       "Q 2584 2291 2321 2609 \n",
       "Q 2059 2928 1675 2928 \n",
       "Q 1300 2928 1048 2622 \n",
       "Q 797 2316 797 1656 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-66\" transform=\"translate(0 0.765625)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-28\" transform=\"translate(35.205078 0.765625)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-Bold-78\" transform=\"translate(74.21875 0.765625)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-2a\" transform=\"translate(153.31543 39.046875) scale(0.7)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-29\" transform=\"translate(204.6875 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" transform=\"translate(243.701172 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-39\" transform=\"translate(271.484375 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-35\" transform=\"translate(327.099609 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-25\" transform=\"translate(382.714844 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" transform=\"translate(471.630859 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-70\" transform=\"translate(499.414062 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-72\" transform=\"translate(555.029297 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-65\" transform=\"translate(588.330078 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-64\" transform=\"translate(643.945312 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-2e\" transform=\"translate(699.560547 0.765625)\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"patch_6\">\n",
       "     <path d=\"M 298.808875 75.227875 \n",
       "L 316.408875 75.227875 \n",
       "L 316.408875 69.067875 \n",
       "L 298.808875 69.067875 \n",
       "z\n",
       "\" style=\"fill: #ff7f0e; fill-opacity: 0.5; stroke: #ff7f0e; stroke-opacity: 0.5; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "    </g>\n",
       "    <g id=\"text_22\">\n",
       "     <!-- $y^*$ 95% pred. -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(323.448875 75.227875) scale(0.088 -0.088)\">\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-79\" transform=\"translate(0 0.765625)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-2a\" transform=\"translate(77.283529 39.046875) scale(0.7)\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" transform=\"translate(128.655599 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-39\" transform=\"translate(156.438802 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-35\" transform=\"translate(212.054036 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-25\" transform=\"translate(267.669271 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" transform=\"translate(356.585286 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-70\" transform=\"translate(384.36849 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-72\" transform=\"translate(439.983724 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-65\" transform=\"translate(473.284505 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-64\" transform=\"translate(528.89974 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-2e\" transform=\"translate(584.514974 0.765625)\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "  </g>\n",
       "  <g id=\"axes_2\">\n",
       "   <g id=\"matplotlib.axis_3\">\n",
       "    <g id=\"ytick_10\">\n",
       "     <g id=\"line2d_20\">\n",
       "      <defs>\n",
       "       <path id=\"m4407f3fd7b\" d=\"M 0 0 \n",
       "L 4.8 0 \n",
       "\" style=\"stroke: #262626\"/>\n",
       "      </defs>\n",
       "      <g>\n",
       "       <use xlink:href=\"#m4407f3fd7b\" x=\"395.432875\" y=\"274.116\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_23\">\n",
       "      <!-- 0.000 -->\n",
       "      <g style=\"fill: #ff7f0e\" transform=\"translate(403.732875 277.265437) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"83.398438\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"139.013672\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"194.628906\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_11\">\n",
       "     <g id=\"line2d_21\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m4407f3fd7b\" x=\"395.432875\" y=\"240.366016\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_24\">\n",
       "      <!-- 0.025 -->\n",
       "      <g style=\"fill: #ff7f0e\" transform=\"translate(403.732875 243.515453) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"83.398438\"/>\n",
       "       <use xlink:href=\"#ArialMT-32\" x=\"139.013672\"/>\n",
       "       <use xlink:href=\"#ArialMT-35\" x=\"194.628906\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_12\">\n",
       "     <g id=\"line2d_22\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m4407f3fd7b\" x=\"395.432875\" y=\"206.616031\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_25\">\n",
       "      <!-- 0.050 -->\n",
       "      <g style=\"fill: #ff7f0e\" transform=\"translate(403.732875 209.765469) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"83.398438\"/>\n",
       "       <use xlink:href=\"#ArialMT-35\" x=\"139.013672\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"194.628906\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_13\">\n",
       "     <g id=\"line2d_23\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m4407f3fd7b\" x=\"395.432875\" y=\"172.866047\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_26\">\n",
       "      <!-- 0.075 -->\n",
       "      <g style=\"fill: #ff7f0e\" transform=\"translate(403.732875 176.015484) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-37\" d=\"M 303 3981 \n",
       "L 303 4522 \n",
       "L 3269 4522 \n",
       "L 3269 4084 \n",
       "Q 2831 3619 2401 2847 \n",
       "Q 1972 2075 1738 1259 \n",
       "Q 1569 684 1522 0 \n",
       "L 944 0 \n",
       "Q 953 541 1156 1306 \n",
       "Q 1359 2072 1739 2783 \n",
       "Q 2119 3494 2547 3981 \n",
       "L 303 3981 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"83.398438\"/>\n",
       "       <use xlink:href=\"#ArialMT-37\" x=\"139.013672\"/>\n",
       "       <use xlink:href=\"#ArialMT-35\" x=\"194.628906\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_14\">\n",
       "     <g id=\"line2d_24\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m4407f3fd7b\" x=\"395.432875\" y=\"139.116063\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_27\">\n",
       "      <!-- 0.100 -->\n",
       "      <g style=\"fill: #ff7f0e\" transform=\"translate(403.732875 142.2655) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-31\" x=\"83.398438\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"139.013672\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"194.628906\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_15\">\n",
       "     <g id=\"line2d_25\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m4407f3fd7b\" x=\"395.432875\" y=\"105.366078\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_28\">\n",
       "      <!-- 0.125 -->\n",
       "      <g style=\"fill: #ff7f0e\" transform=\"translate(403.732875 108.515516) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-31\" x=\"83.398438\"/>\n",
       "       <use xlink:href=\"#ArialMT-32\" x=\"139.013672\"/>\n",
       "       <use xlink:href=\"#ArialMT-35\" x=\"194.628906\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_16\">\n",
       "     <g id=\"line2d_26\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m4407f3fd7b\" x=\"395.432875\" y=\"71.616094\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_29\">\n",
       "      <!-- 0.150 -->\n",
       "      <g style=\"fill: #ff7f0e\" transform=\"translate(403.732875 74.765531) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-31\" x=\"83.398438\"/>\n",
       "       <use xlink:href=\"#ArialMT-35\" x=\"139.013672\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"194.628906\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_17\">\n",
       "     <g id=\"line2d_27\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m4407f3fd7b\" x=\"395.432875\" y=\"37.866109\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_30\">\n",
       "      <!-- 0.175 -->\n",
       "      <g style=\"fill: #ff7f0e\" transform=\"translate(403.732875 41.015547) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-31\" x=\"83.398438\"/>\n",
       "       <use xlink:href=\"#ArialMT-37\" x=\"139.013672\"/>\n",
       "       <use xlink:href=\"#ArialMT-35\" x=\"194.628906\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"text_31\">\n",
       "     <!-- Information Acquisition Function -->\n",
       "     <g style=\"fill: #ff7f0e\" transform=\"translate(436.740625 221.18925) rotate(-90) scale(0.096 -0.096)\">\n",
       "      <defs>\n",
       "       <path id=\"ArialMT-49\" d=\"M 597 0 \n",
       "L 597 4581 \n",
       "L 1203 4581 \n",
       "L 1203 0 \n",
       "L 597 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-66\" d=\"M 556 0 \n",
       "L 556 2881 \n",
       "L 59 2881 \n",
       "L 59 3319 \n",
       "L 556 3319 \n",
       "L 556 3672 \n",
       "Q 556 4006 616 4169 \n",
       "Q 697 4388 901 4523 \n",
       "Q 1106 4659 1475 4659 \n",
       "Q 1713 4659 2000 4603 \n",
       "L 1916 4113 \n",
       "Q 1741 4144 1584 4144 \n",
       "Q 1328 4144 1222 4034 \n",
       "Q 1116 3925 1116 3625 \n",
       "L 1116 3319 \n",
       "L 1763 3319 \n",
       "L 1763 2881 \n",
       "L 1116 2881 \n",
       "L 1116 0 \n",
       "L 556 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-6d\" d=\"M 422 0 \n",
       "L 422 3319 \n",
       "L 925 3319 \n",
       "L 925 2853 \n",
       "Q 1081 3097 1340 3245 \n",
       "Q 1600 3394 1931 3394 \n",
       "Q 2300 3394 2536 3241 \n",
       "Q 2772 3088 2869 2813 \n",
       "Q 3263 3394 3894 3394 \n",
       "Q 4388 3394 4653 3120 \n",
       "Q 4919 2847 4919 2278 \n",
       "L 4919 0 \n",
       "L 4359 0 \n",
       "L 4359 2091 \n",
       "Q 4359 2428 4304 2576 \n",
       "Q 4250 2725 4106 2815 \n",
       "Q 3963 2906 3769 2906 \n",
       "Q 3419 2906 3187 2673 \n",
       "Q 2956 2441 2956 1928 \n",
       "L 2956 0 \n",
       "L 2394 0 \n",
       "L 2394 2156 \n",
       "Q 2394 2531 2256 2718 \n",
       "Q 2119 2906 1806 2906 \n",
       "Q 1569 2906 1367 2781 \n",
       "Q 1166 2656 1075 2415 \n",
       "Q 984 2175 984 1722 \n",
       "L 984 0 \n",
       "L 422 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-41\" d=\"M -9 0 \n",
       "L 1750 4581 \n",
       "L 2403 4581 \n",
       "L 4278 0 \n",
       "L 3588 0 \n",
       "L 3053 1388 \n",
       "L 1138 1388 \n",
       "L 634 0 \n",
       "L -9 0 \n",
       "z\n",
       "M 1313 1881 \n",
       "L 2866 1881 \n",
       "L 2388 3150 \n",
       "Q 2169 3728 2063 4100 \n",
       "Q 1975 3659 1816 3225 \n",
       "L 1313 1881 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-63\" d=\"M 2588 1216 \n",
       "L 3141 1144 \n",
       "Q 3050 572 2676 248 \n",
       "Q 2303 -75 1759 -75 \n",
       "Q 1078 -75 664 370 \n",
       "Q 250 816 250 1647 \n",
       "Q 250 2184 428 2587 \n",
       "Q 606 2991 970 3192 \n",
       "Q 1334 3394 1763 3394 \n",
       "Q 2303 3394 2647 3120 \n",
       "Q 2991 2847 3088 2344 \n",
       "L 2541 2259 \n",
       "Q 2463 2594 2264 2762 \n",
       "Q 2066 2931 1784 2931 \n",
       "Q 1359 2931 1093 2626 \n",
       "Q 828 2322 828 1663 \n",
       "Q 828 994 1084 691 \n",
       "Q 1341 388 1753 388 \n",
       "Q 2084 388 2306 591 \n",
       "Q 2528 794 2588 1216 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-71\" d=\"M 2538 -1272 \n",
       "L 2538 353 \n",
       "Q 2406 169 2170 47 \n",
       "Q 1934 -75 1669 -75 \n",
       "Q 1078 -75 651 397 \n",
       "Q 225 869 225 1691 \n",
       "Q 225 2191 398 2587 \n",
       "Q 572 2984 901 3189 \n",
       "Q 1231 3394 1625 3394 \n",
       "Q 2241 3394 2594 2875 \n",
       "L 2594 3319 \n",
       "L 3100 3319 \n",
       "L 3100 -1272 \n",
       "L 2538 -1272 \n",
       "z\n",
       "M 803 1669 \n",
       "Q 803 1028 1072 708 \n",
       "Q 1341 388 1716 388 \n",
       "Q 2075 388 2334 692 \n",
       "Q 2594 997 2594 1619 \n",
       "Q 2594 2281 2320 2615 \n",
       "Q 2047 2950 1678 2950 \n",
       "Q 1313 2950 1058 2639 \n",
       "Q 803 2328 803 1669 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-75\" d=\"M 2597 0 \n",
       "L 2597 488 \n",
       "Q 2209 -75 1544 -75 \n",
       "Q 1250 -75 995 37 \n",
       "Q 741 150 617 320 \n",
       "Q 494 491 444 738 \n",
       "Q 409 903 409 1263 \n",
       "L 409 3319 \n",
       "L 972 3319 \n",
       "L 972 1478 \n",
       "Q 972 1038 1006 884 \n",
       "Q 1059 663 1231 536 \n",
       "Q 1403 409 1656 409 \n",
       "Q 1909 409 2131 539 \n",
       "Q 2353 669 2445 892 \n",
       "Q 2538 1116 2538 1541 \n",
       "L 2538 3319 \n",
       "L 3100 3319 \n",
       "L 3100 0 \n",
       "L 2597 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-46\" d=\"M 525 0 \n",
       "L 525 4581 \n",
       "L 3616 4581 \n",
       "L 3616 4041 \n",
       "L 1131 4041 \n",
       "L 1131 2622 \n",
       "L 3281 2622 \n",
       "L 3281 2081 \n",
       "L 1131 2081 \n",
       "L 1131 0 \n",
       "L 525 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#ArialMT-49\"/>\n",
       "      <use xlink:href=\"#ArialMT-6e\" x=\"27.783203\"/>\n",
       "      <use xlink:href=\"#ArialMT-66\" x=\"83.398438\"/>\n",
       "      <use xlink:href=\"#ArialMT-6f\" x=\"111.181641\"/>\n",
       "      <use xlink:href=\"#ArialMT-72\" x=\"166.796875\"/>\n",
       "      <use xlink:href=\"#ArialMT-6d\" x=\"200.097656\"/>\n",
       "      <use xlink:href=\"#ArialMT-61\" x=\"283.398438\"/>\n",
       "      <use xlink:href=\"#ArialMT-74\" x=\"339.013672\"/>\n",
       "      <use xlink:href=\"#ArialMT-69\" x=\"366.796875\"/>\n",
       "      <use xlink:href=\"#ArialMT-6f\" x=\"389.013672\"/>\n",
       "      <use xlink:href=\"#ArialMT-6e\" x=\"444.628906\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" x=\"500.244141\"/>\n",
       "      <use xlink:href=\"#ArialMT-41\" x=\"522.527344\"/>\n",
       "      <use xlink:href=\"#ArialMT-63\" x=\"589.226562\"/>\n",
       "      <use xlink:href=\"#ArialMT-71\" x=\"639.226562\"/>\n",
       "      <use xlink:href=\"#ArialMT-75\" x=\"694.841797\"/>\n",
       "      <use xlink:href=\"#ArialMT-69\" x=\"750.457031\"/>\n",
       "      <use xlink:href=\"#ArialMT-73\" x=\"772.673828\"/>\n",
       "      <use xlink:href=\"#ArialMT-69\" x=\"822.673828\"/>\n",
       "      <use xlink:href=\"#ArialMT-74\" x=\"844.890625\"/>\n",
       "      <use xlink:href=\"#ArialMT-69\" x=\"872.673828\"/>\n",
       "      <use xlink:href=\"#ArialMT-6f\" x=\"894.890625\"/>\n",
       "      <use xlink:href=\"#ArialMT-6e\" x=\"950.505859\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" x=\"1006.121094\"/>\n",
       "      <use xlink:href=\"#ArialMT-46\" x=\"1033.904297\"/>\n",
       "      <use xlink:href=\"#ArialMT-75\" x=\"1094.988281\"/>\n",
       "      <use xlink:href=\"#ArialMT-6e\" x=\"1150.603516\"/>\n",
       "      <use xlink:href=\"#ArialMT-63\" x=\"1206.21875\"/>\n",
       "      <use xlink:href=\"#ArialMT-74\" x=\"1256.21875\"/>\n",
       "      <use xlink:href=\"#ArialMT-69\" x=\"1284.001953\"/>\n",
       "      <use xlink:href=\"#ArialMT-6f\" x=\"1306.21875\"/>\n",
       "      <use xlink:href=\"#ArialMT-6e\" x=\"1361.833984\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"line2d_28\">\n",
       "    <path d=\"M 54.545602 108.8526 \n",
       "L 57.824941 122.380784 \n",
       "L 61.10428 137.325657 \n",
       "L 64.383619 153.630328 \n",
       "L 67.662958 171.129722 \n",
       "L 70.942296 189.499801 \n",
       "L 74.221636 208.198182 \n",
       "L 77.500973 226.407932 \n",
       "L 80.780313 243.023204 \n",
       "L 84.059653 256.75718 \n",
       "L 87.33899 266.480801 \n",
       "L 90.61833 271.835989 \n",
       "L 93.89767 273.768225 \n",
       "L 97.177007 274.101114 \n",
       "L 100.456344 274.11596 \n",
       "L 103.735686 274.116 \n",
       "L 107.015024 274.116 \n",
       "L 110.294361 274.116 \n",
       "L 113.573703 274.116 \n",
       "L 116.853041 274.116 \n",
       "L 120.132378 274.116 \n",
       "L 123.41172 274.116 \n",
       "L 126.691057 274.116 \n",
       "L 129.970395 274.116 \n",
       "L 133.249737 274.116 \n",
       "L 136.529069 274.116 \n",
       "L 139.808412 274.116 \n",
       "L 143.087754 274.116 \n",
       "L 146.367086 274.116 \n",
       "L 149.646428 274.116 \n",
       "L 152.92577 274.116 \n",
       "L 156.205103 274.116 \n",
       "L 159.484445 274.116 \n",
       "L 162.763787 274.116 \n",
       "L 166.04312 274.116 \n",
       "L 169.322462 274.116 \n",
       "L 172.601804 274.109844 \n",
       "L 175.881137 273.852191 \n",
       "L 179.160479 271.906196 \n",
       "L 182.439821 265.903616 \n",
       "L 185.719153 254.613158 \n",
       "L 188.998496 238.625644 \n",
       "L 192.277838 219.519218 \n",
       "L 195.55717 198.967257 \n",
       "L 198.836512 178.308075 \n",
       "L 202.115855 158.456773 \n",
       "L 205.395187 139.965714 \n",
       "L 208.674529 123.120993 \n",
       "L 211.953871 108.030194 \n",
       "L 215.233204 94.688048 \n",
       "L 218.512556 83.022496 \n",
       "L 221.791879 72.925633 \n",
       "L 225.071221 64.271933 \n",
       "L 228.350563 56.93136 \n",
       "L 231.629886 50.77678 \n",
       "L 234.909247 45.687974 \n",
       "L 238.18857 41.554625 \n",
       "L 241.467912 38.278201 \n",
       "L 244.747254 35.772603 \n",
       "L 248.026597 33.964406 \n",
       "L 251.305939 32.794106 \n",
       "L 254.585262 32.215433 \n",
       "L 257.864623 32.196 \n",
       "L 261.143946 32.716777 \n",
       "L 264.423288 33.772615 \n",
       "L 267.70263 35.371238 \n",
       "L 270.981953 37.533848 \n",
       "L 274.261315 40.294081 \n",
       "L 277.540637 43.697763 \n",
       "L 280.81998 47.802748 \n",
       "L 284.099322 52.677996 \n",
       "L 287.378664 58.403208 \n",
       "L 290.658006 65.067543 \n",
       "L 293.937329 72.768724 \n",
       "L 297.21669 81.610917 \n",
       "L 300.496013 91.701061 \n",
       "L 303.775355 103.144043 \n",
       "L 307.054697 116.033286 \n",
       "L 310.33402 130.436419 \n",
       "L 313.613382 146.372073 \n",
       "L 316.892705 163.772695 \n",
       "L 320.172047 182.42871 \n",
       "L 323.451389 201.907212 \n",
       "L 326.730731 221.445821 \n",
       "L 330.010073 239.850742 \n",
       "L 333.289396 255.492573 \n",
       "L 336.568738 266.632198 \n",
       "L 339.84808 272.387545 \n",
       "L 343.127423 273.989266 \n",
       "L 346.406765 274.115477 \n",
       "L 349.686088 274.116 \n",
       "L 352.96543 274.116 \n",
       "L 356.244772 274.116 \n",
       "L 359.524114 274.116 \n",
       "L 362.803456 274.116 \n",
       "L 366.082798 274.115678 \n",
       "L 369.362141 274.015699 \n",
       "L 372.641463 272.587544 \n",
       "L 375.920806 267.160378 \n",
       "L 379.200148 256.353159 \n",
       "\" clip-path=\"url(#p60fa01c9f4)\" style=\"fill: none; stroke: #ff7f0e; stroke-width: 1.2; stroke-linecap: round\"/>\n",
       "   </g>\n",
       "   <g id=\"line2d_29\">\n",
       "    <path d=\"M 257.864623 274.116 \n",
       "L 257.864623 271.672364 \n",
       "L 257.864623 269.228727 \n",
       "L 257.864623 266.785091 \n",
       "L 257.864623 264.341455 \n",
       "L 257.864623 261.897819 \n",
       "L 257.864623 259.454182 \n",
       "L 257.864623 257.010546 \n",
       "L 257.864623 254.56691 \n",
       "L 257.864623 252.123273 \n",
       "L 257.864623 249.679637 \n",
       "L 257.864623 247.236001 \n",
       "L 257.864623 244.792365 \n",
       "L 257.864623 242.348728 \n",
       "L 257.864623 239.905092 \n",
       "L 257.864623 237.461456 \n",
       "L 257.864623 235.017819 \n",
       "L 257.864623 232.574183 \n",
       "L 257.864623 230.130547 \n",
       "L 257.864623 227.686913 \n",
       "L 257.864623 225.243274 \n",
       "L 257.864623 222.799635 \n",
       "L 257.864623 220.356002 \n",
       "L 257.864623 217.912368 \n",
       "L 257.864623 215.468729 \n",
       "L 257.864623 213.02509 \n",
       "L 257.864623 210.581457 \n",
       "L 257.864623 208.137823 \n",
       "L 257.864623 205.694184 \n",
       "L 257.864623 203.250545 \n",
       "L 257.864623 200.806911 \n",
       "L 257.864623 198.363278 \n",
       "L 257.864623 195.919639 \n",
       "L 257.864623 193.476 \n",
       "L 257.864623 191.032366 \n",
       "L 257.864623 188.588732 \n",
       "L 257.864623 186.145094 \n",
       "L 257.864623 183.701455 \n",
       "L 257.864623 181.257826 \n",
       "L 257.864623 178.814187 \n",
       "L 257.864623 176.370549 \n",
       "L 257.864623 173.92691 \n",
       "L 257.864623 171.483271 \n",
       "L 257.864623 169.039642 \n",
       "L 257.864623 166.596003 \n",
       "L 257.864623 164.152365 \n",
       "L 257.864623 161.708736 \n",
       "L 257.864623 159.265097 \n",
       "L 257.864623 156.821458 \n",
       "L 257.864623 154.377819 \n",
       "L 257.864623 151.934181 \n",
       "L 257.864623 149.490542 \n",
       "L 257.864623 147.046903 \n",
       "L 257.864623 144.603264 \n",
       "L 257.864623 142.159635 \n",
       "L 257.864623 139.715997 \n",
       "L 257.864623 137.272358 \n",
       "L 257.864623 134.828729 \n",
       "L 257.864623 132.38509 \n",
       "L 257.864623 129.941451 \n",
       "L 257.864623 127.497813 \n",
       "L 257.864623 125.054174 \n",
       "L 257.864623 122.610545 \n",
       "L 257.864623 120.166906 \n",
       "L 257.864623 117.723268 \n",
       "L 257.864623 115.279639 \n",
       "L 257.864623 112.836 \n",
       "L 257.864623 110.392361 \n",
       "L 257.864623 107.948722 \n",
       "L 257.864623 105.505084 \n",
       "L 257.864623 103.061445 \n",
       "L 257.864623 100.617806 \n",
       "L 257.864623 98.174167 \n",
       "L 257.864623 95.730549 \n",
       "L 257.864623 93.28691 \n",
       "L 257.864623 90.843271 \n",
       "L 257.864623 88.399632 \n",
       "L 257.864623 85.955993 \n",
       "L 257.864623 83.512375 \n",
       "L 257.864623 81.068736 \n",
       "L 257.864623 78.625097 \n",
       "L 257.864623 76.181458 \n",
       "L 257.864623 73.737819 \n",
       "L 257.864623 71.294181 \n",
       "L 257.864623 68.850542 \n",
       "L 257.864623 66.406903 \n",
       "L 257.864623 63.963264 \n",
       "L 257.864623 61.519625 \n",
       "L 257.864623 59.076007 \n",
       "L 257.864623 56.632368 \n",
       "L 257.864623 54.188729 \n",
       "L 257.864623 51.74509 \n",
       "L 257.864623 49.301451 \n",
       "L 257.864623 46.857813 \n",
       "L 257.864623 44.414174 \n",
       "L 257.864623 41.970555 \n",
       "L 257.864623 39.526916 \n",
       "L 257.864623 37.083278 \n",
       "L 257.864623 34.639639 \n",
       "L 257.864623 32.196 \n",
       "\" clip-path=\"url(#p60fa01c9f4)\" style=\"fill: none; stroke: #ff7f0e; stroke-linecap: round\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_7\">\n",
       "    <path d=\"M 38.312875 286.212 \n",
       "L 38.312875 20.1 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_8\">\n",
       "    <path d=\"M 395.432875 286.212 \n",
       "L 395.432875 20.1 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_9\">\n",
       "    <path d=\"M 38.312875 286.212 \n",
       "L 395.432875 286.212 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_10\">\n",
       "    <path d=\"M 38.312875 20.1 \n",
       "L 395.432875 20.1 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "  </g>\n",
       " </g>\n",
       " <defs>\n",
       "  <clipPath id=\"p60fa01c9f4\">\n",
       "   <rect x=\"38.312875\" y=\"20.1\" width=\"357.12\" height=\"266.112\"/>\n",
       "  </clipPath>\n",
       " </defs>\n",
       "</svg>\n"
      ],
      "text/plain": [
       "<Figure size 640x480 with 2 Axes>"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    }
   ],
   "source": [
    "plot_iaf(\n",
    "    x,\n",
    "    model,\n",
    "    poi,\n",
    "    alpha_params=dict(psi=2.0)\n",
    ")"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "## Questions\n",
    "+ Experiment with different values of $\\psi$.\n",
    "+ When do you get exploration?\n",
    "+ When do you get exploitation?"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "## Bayesian global optimization with the probability of improvement\n",
    "\n",
    "Let's run the Bayesian global optimization algorithm using the probability of improvement as the information acquisition function.\n",
    "I have included the generic function `maximize()` from the previous section.\n",
    "Here is how to use it:"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 6,
   "metadata": {
    "tags": [
     "hide-output"
    ]
   },
   "outputs": [
    {
     "data": {
      "image/svg+xml": [
       "<?xml version=\"1.0\" encoding=\"utf-8\" standalone=\"no\"?>\n",
       "<!DOCTYPE svg PUBLIC \"-//W3C//DTD SVG 1.1//EN\"\n",
       "  \"http://www.w3.org/Graphics/SVG/1.1/DTD/svg11.dtd\">\n",
       "<svg xmlns:xlink=\"http://www.w3.org/1999/xlink\" width=\"436.061375pt\" height=\"322.539375pt\" viewBox=\"0 0 436.061375 322.539375\" xmlns=\"http://www.w3.org/2000/svg\" version=\"1.1\">\n",
       " <metadata>\n",
       "  <rdf:RDF xmlns:dc=\"http://purl.org/dc/elements/1.1/\" xmlns:cc=\"http://creativecommons.org/ns#\" xmlns:rdf=\"http://www.w3.org/1999/02/22-rdf-syntax-ns#\">\n",
       "   <cc:Work>\n",
       "    <dc:type rdf:resource=\"http://purl.org/dc/dcmitype/StillImage\"/>\n",
       "    <dc:date>2023-10-23T15:18:33.946629</dc:date>\n",
       "    <dc:format>image/svg+xml</dc:format>\n",
       "    <dc:creator>\n",
       "     <cc:Agent>\n",
       "      <dc:title>Matplotlib v3.8.0, https://matplotlib.org/</dc:title>\n",
       "     </cc:Agent>\n",
       "    </dc:creator>\n",
       "   </cc:Work>\n",
       "  </rdf:RDF>\n",
       " </metadata>\n",
       " <defs>\n",
       "  <style type=\"text/css\">*{stroke-linejoin: round; stroke-linecap: butt}</style>\n",
       " </defs>\n",
       " <g id=\"figure_1\">\n",
       "  <g id=\"patch_1\">\n",
       "   <path d=\"M 0 322.539375 \n",
       "L 436.061375 322.539375 \n",
       "L 436.061375 0 \n",
       "L 0 0 \n",
       "z\n",
       "\" style=\"fill: #ffffff\"/>\n",
       "  </g>\n",
       "  <g id=\"axes_1\">\n",
       "   <g id=\"patch_2\">\n",
       "    <path d=\"M 38.312875 286.212 \n",
       "L 395.432875 286.212 \n",
       "L 395.432875 20.1 \n",
       "L 38.312875 20.1 \n",
       "z\n",
       "\" style=\"fill: #ffffff\"/>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_1\">\n",
       "    <g id=\"xtick_1\">\n",
       "     <g id=\"line2d_1\">\n",
       "      <defs>\n",
       "       <path id=\"m9a3b9316d8\" d=\"M 0 0 \n",
       "L 0 4.8 \n",
       "\" style=\"stroke: #262626\"/>\n",
       "      </defs>\n",
       "      <g>\n",
       "       <use xlink:href=\"#m9a3b9316d8\" x=\"54.545602\" y=\"286.212\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_1\">\n",
       "      <!-- 0.0 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(48.429602 300.810875) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-30\" d=\"M 266 2259 \n",
       "Q 266 3072 433 3567 \n",
       "Q 600 4063 929 4331 \n",
       "Q 1259 4600 1759 4600 \n",
       "Q 2128 4600 2406 4451 \n",
       "Q 2684 4303 2865 4023 \n",
       "Q 3047 3744 3150 3342 \n",
       "Q 3253 2941 3253 2259 \n",
       "Q 3253 1453 3087 958 \n",
       "Q 2922 463 2592 192 \n",
       "Q 2263 -78 1759 -78 \n",
       "Q 1097 -78 719 397 \n",
       "Q 266 969 266 2259 \n",
       "z\n",
       "M 844 2259 \n",
       "Q 844 1131 1108 757 \n",
       "Q 1372 384 1759 384 \n",
       "Q 2147 384 2411 759 \n",
       "Q 2675 1134 2675 2259 \n",
       "Q 2675 3391 2411 3762 \n",
       "Q 2147 4134 1753 4134 \n",
       "Q 1366 4134 1134 3806 \n",
       "Q 844 3388 844 2259 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "        <path id=\"ArialMT-2e\" d=\"M 581 0 \n",
       "L 581 641 \n",
       "L 1222 641 \n",
       "L 1222 0 \n",
       "L 581 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_2\">\n",
       "     <g id=\"line2d_2\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m9a3b9316d8\" x=\"119.476511\" y=\"286.212\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_2\">\n",
       "      <!-- 0.2 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(113.360511 300.810875) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-32\" d=\"M 3222 541 \n",
       "L 3222 0 \n",
       "L 194 0 \n",
       "Q 188 203 259 391 \n",
       "Q 375 700 629 1000 \n",
       "Q 884 1300 1366 1694 \n",
       "Q 2113 2306 2375 2664 \n",
       "Q 2638 3022 2638 3341 \n",
       "Q 2638 3675 2398 3904 \n",
       "Q 2159 4134 1775 4134 \n",
       "Q 1369 4134 1125 3890 \n",
       "Q 881 3647 878 3216 \n",
       "L 300 3275 \n",
       "Q 359 3922 746 4261 \n",
       "Q 1134 4600 1788 4600 \n",
       "Q 2447 4600 2831 4234 \n",
       "Q 3216 3869 3216 3328 \n",
       "Q 3216 3053 3103 2787 \n",
       "Q 2991 2522 2730 2228 \n",
       "Q 2469 1934 1863 1422 \n",
       "Q 1356 997 1212 845 \n",
       "Q 1069 694 975 541 \n",
       "L 3222 541 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-32\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_3\">\n",
       "     <g id=\"line2d_3\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m9a3b9316d8\" x=\"184.40742\" y=\"286.212\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_3\">\n",
       "      <!-- 0.4 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(178.29142 300.810875) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-34\" d=\"M 2069 0 \n",
       "L 2069 1097 \n",
       "L 81 1097 \n",
       "L 81 1613 \n",
       "L 2172 4581 \n",
       "L 2631 4581 \n",
       "L 2631 1613 \n",
       "L 3250 1613 \n",
       "L 3250 1097 \n",
       "L 2631 1097 \n",
       "L 2631 0 \n",
       "L 2069 0 \n",
       "z\n",
       "M 2069 1613 \n",
       "L 2069 3678 \n",
       "L 634 1613 \n",
       "L 2069 1613 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-34\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_4\">\n",
       "     <g id=\"line2d_4\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m9a3b9316d8\" x=\"249.33833\" y=\"286.212\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_4\">\n",
       "      <!-- 0.6 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(243.22233 300.810875) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-36\" d=\"M 3184 3459 \n",
       "L 2625 3416 \n",
       "Q 2550 3747 2413 3897 \n",
       "Q 2184 4138 1850 4138 \n",
       "Q 1581 4138 1378 3988 \n",
       "Q 1113 3794 959 3422 \n",
       "Q 806 3050 800 2363 \n",
       "Q 1003 2672 1297 2822 \n",
       "Q 1591 2972 1913 2972 \n",
       "Q 2475 2972 2870 2558 \n",
       "Q 3266 2144 3266 1488 \n",
       "Q 3266 1056 3080 686 \n",
       "Q 2894 316 2569 119 \n",
       "Q 2244 -78 1831 -78 \n",
       "Q 1128 -78 684 439 \n",
       "Q 241 956 241 2144 \n",
       "Q 241 3472 731 4075 \n",
       "Q 1159 4600 1884 4600 \n",
       "Q 2425 4600 2770 4297 \n",
       "Q 3116 3994 3184 3459 \n",
       "z\n",
       "M 888 1484 \n",
       "Q 888 1194 1011 928 \n",
       "Q 1134 663 1356 523 \n",
       "Q 1578 384 1822 384 \n",
       "Q 2178 384 2434 671 \n",
       "Q 2691 959 2691 1453 \n",
       "Q 2691 1928 2437 2201 \n",
       "Q 2184 2475 1800 2475 \n",
       "Q 1419 2475 1153 2201 \n",
       "Q 888 1928 888 1484 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-36\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_5\">\n",
       "     <g id=\"line2d_5\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m9a3b9316d8\" x=\"314.269239\" y=\"286.212\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_5\">\n",
       "      <!-- 0.8 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(308.153239 300.810875) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-38\" d=\"M 1131 2484 \n",
       "Q 781 2613 612 2850 \n",
       "Q 444 3088 444 3419 \n",
       "Q 444 3919 803 4259 \n",
       "Q 1163 4600 1759 4600 \n",
       "Q 2359 4600 2725 4251 \n",
       "Q 3091 3903 3091 3403 \n",
       "Q 3091 3084 2923 2848 \n",
       "Q 2756 2613 2416 2484 \n",
       "Q 2838 2347 3058 2040 \n",
       "Q 3278 1734 3278 1309 \n",
       "Q 3278 722 2862 322 \n",
       "Q 2447 -78 1769 -78 \n",
       "Q 1091 -78 675 323 \n",
       "Q 259 725 259 1325 \n",
       "Q 259 1772 486 2073 \n",
       "Q 713 2375 1131 2484 \n",
       "z\n",
       "M 1019 3438 \n",
       "Q 1019 3113 1228 2906 \n",
       "Q 1438 2700 1772 2700 \n",
       "Q 2097 2700 2305 2904 \n",
       "Q 2513 3109 2513 3406 \n",
       "Q 2513 3716 2298 3927 \n",
       "Q 2084 4138 1766 4138 \n",
       "Q 1444 4138 1231 3931 \n",
       "Q 1019 3725 1019 3438 \n",
       "z\n",
       "M 838 1322 \n",
       "Q 838 1081 952 856 \n",
       "Q 1066 631 1291 507 \n",
       "Q 1516 384 1775 384 \n",
       "Q 2178 384 2440 643 \n",
       "Q 2703 903 2703 1303 \n",
       "Q 2703 1709 2433 1975 \n",
       "Q 2163 2241 1756 2241 \n",
       "Q 1359 2241 1098 1978 \n",
       "Q 838 1716 838 1322 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-38\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_6\">\n",
       "     <g id=\"line2d_6\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m9a3b9316d8\" x=\"379.200148\" y=\"286.212\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_6\">\n",
       "      <!-- 1.0 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(373.084148 300.810875) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-31\" d=\"M 2384 0 \n",
       "L 1822 0 \n",
       "L 1822 3584 \n",
       "Q 1619 3391 1289 3197 \n",
       "Q 959 3003 697 2906 \n",
       "L 697 3450 \n",
       "Q 1169 3672 1522 3987 \n",
       "Q 1875 4303 2022 4600 \n",
       "L 2384 4600 \n",
       "L 2384 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-31\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"text_7\">\n",
       "     <!-- $x$ -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(213.992875 313.431375) scale(0.096 -0.096)\">\n",
       "      <defs>\n",
       "       <path id=\"DejaVuSans-Oblique-78\" d=\"M 3841 3500 \n",
       "L 2234 1784 \n",
       "L 3219 0 \n",
       "L 2559 0 \n",
       "L 1819 1388 \n",
       "L 531 0 \n",
       "L -166 0 \n",
       "L 1556 1844 \n",
       "L 641 3500 \n",
       "L 1300 3500 \n",
       "L 1972 2234 \n",
       "L 3144 3500 \n",
       "L 3841 3500 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-78\" transform=\"translate(0 0.3125)\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_2\">\n",
       "    <g id=\"ytick_1\">\n",
       "     <g id=\"line2d_7\">\n",
       "      <defs>\n",
       "       <path id=\"mf71bca907e\" d=\"M 0 0 \n",
       "L -4.8 0 \n",
       "\" style=\"stroke: #262626\"/>\n",
       "      </defs>\n",
       "      <g>\n",
       "       <use xlink:href=\"#mf71bca907e\" x=\"38.312875\" y=\"274.17984\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_8\">\n",
       "      <!-- −8 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(19.9795 277.329277) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-2212\" d=\"M 3381 1997 \n",
       "L 356 1997 \n",
       "L 356 2522 \n",
       "L 3381 2522 \n",
       "L 3381 1997 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-38\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_2\">\n",
       "     <g id=\"line2d_8\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mf71bca907e\" x=\"38.312875\" y=\"229.010602\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_9\">\n",
       "      <!-- −6 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(19.9795 232.16004) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-36\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_3\">\n",
       "     <g id=\"line2d_9\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mf71bca907e\" x=\"38.312875\" y=\"183.841364\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_10\">\n",
       "      <!-- −4 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(19.9795 186.990802) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-34\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_4\">\n",
       "     <g id=\"line2d_10\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mf71bca907e\" x=\"38.312875\" y=\"138.672127\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_11\">\n",
       "      <!-- −2 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(19.9795 141.821564) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-32\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_5\">\n",
       "     <g id=\"line2d_11\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mf71bca907e\" x=\"38.312875\" y=\"93.502889\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_12\">\n",
       "      <!-- 0 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(25.11925 96.652327) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_6\">\n",
       "     <g id=\"line2d_12\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mf71bca907e\" x=\"38.312875\" y=\"48.333651\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_13\">\n",
       "      <!-- 2 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(25.11925 51.483089) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-32\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"text_14\">\n",
       "     <!-- $y$ -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(13.9635 156.036) rotate(-90) scale(0.096 -0.096)\">\n",
       "      <defs>\n",
       "       <path id=\"DejaVuSans-Oblique-79\" d=\"M 1588 -325 \n",
       "Q 1188 -997 936 -1164 \n",
       "Q 684 -1331 294 -1331 \n",
       "L -159 -1331 \n",
       "L -63 -850 \n",
       "L 269 -850 \n",
       "Q 509 -850 678 -719 \n",
       "Q 847 -588 1056 -206 \n",
       "L 1234 128 \n",
       "L 459 3500 \n",
       "L 1069 3500 \n",
       "L 1650 819 \n",
       "L 3256 3500 \n",
       "L 3859 3500 \n",
       "L 1588 -325 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-79\" transform=\"translate(0 0.3125)\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"PolyCollection_1\">\n",
       "    <defs>\n",
       "     <path id=\"mb73ab9770a\" d=\"M 54.545602 -290.207726 \n",
       "L 54.545602 -139.940102 \n",
       "L 57.824941 -141.787485 \n",
       "L 61.10428 -143.985379 \n",
       "L 64.383619 -146.551665 \n",
       "L 67.662958 -149.498577 \n",
       "L 70.942296 -152.83171 \n",
       "L 74.221636 -156.54898 \n",
       "L 77.500973 -160.639984 \n",
       "L 80.780313 -165.085067 \n",
       "L 84.059653 -169.8551 \n",
       "L 87.33899 -174.910598 \n",
       "L 90.61833 -180.201654 \n",
       "L 93.89767 -185.667296 \n",
       "L 97.177007 -191.234136 \n",
       "L 100.456344 -196.814275 \n",
       "L 103.735686 -202.295532 \n",
       "L 107.015024 -207.51435 \n",
       "L 110.294361 -212.154641 \n",
       "L 113.573703 -215.431751 \n",
       "L 116.853041 -216.417784 \n",
       "L 120.132378 -216.05225 \n",
       "L 123.41172 -215.499003 \n",
       "L 126.691057 -215.142522 \n",
       "L 129.970395 -215.081564 \n",
       "L 133.249737 -215.323549 \n",
       "L 136.529069 -215.837674 \n",
       "L 139.808412 -216.56783 \n",
       "L 143.087754 -217.43672 \n",
       "L 146.367086 -218.339862 \n",
       "L 149.646428 -219.121924 \n",
       "L 152.92577 -219.489538 \n",
       "L 156.205103 -218.743811 \n",
       "L 159.484445 -215.76742 \n",
       "L 162.763787 -210.625252 \n",
       "L 166.04312 -204.185417 \n",
       "L 169.322462 -196.92103 \n",
       "L 172.601804 -189.06712 \n",
       "L 175.881137 -180.786755 \n",
       "L 179.160479 -172.221236 \n",
       "L 182.439821 -163.505486 \n",
       "L 185.719153 -154.772345 \n",
       "L 188.998496 -146.152597 \n",
       "L 192.277838 -137.774402 \n",
       "L 195.55717 -129.761482 \n",
       "L 198.836512 -122.231409 \n",
       "L 202.115855 -115.293846 \n",
       "L 205.395187 -109.048914 \n",
       "L 208.674529 -103.585211 \n",
       "L 211.953871 -98.978605 \n",
       "L 215.233204 -95.290687 \n",
       "L 218.512556 -92.567063 \n",
       "L 221.791879 -90.835626 \n",
       "L 225.071221 -90.102427 \n",
       "L 228.350563 -90.341966 \n",
       "L 231.629886 -91.461886 \n",
       "L 234.909247 -93.127061 \n",
       "L 238.18857 -93.665315 \n",
       "L 241.467912 -90.244785 \n",
       "L 244.747254 -85.387689 \n",
       "L 248.026597 -80.759782 \n",
       "L 251.305939 -76.715296 \n",
       "L 254.585262 -73.368492 \n",
       "L 257.864623 -70.76993 \n",
       "L 261.143946 -68.94283 \n",
       "L 264.423288 -67.893168 \n",
       "L 267.70263 -67.6143 \n",
       "L 270.981953 -68.089308 \n",
       "L 274.261315 -69.292872 \n",
       "L 277.540637 -71.192901 \n",
       "L 280.81998 -73.751961 \n",
       "L 284.099322 -76.928806 \n",
       "L 287.378664 -80.679584 \n",
       "L 290.658006 -84.959215 \n",
       "L 293.937329 -89.722167 \n",
       "L 297.21669 -94.923856 \n",
       "L 300.496013 -100.520624 \n",
       "L 303.775355 -106.471126 \n",
       "L 307.054697 -112.735874 \n",
       "L 310.33402 -119.277831 \n",
       "L 313.613382 -126.06231 \n",
       "L 316.892705 -133.056594 \n",
       "L 320.172047 -140.229809 \n",
       "L 323.451389 -147.552505 \n",
       "L 326.730731 -154.995907 \n",
       "L 330.010073 -162.531661 \n",
       "L 333.289396 -170.130931 \n",
       "L 336.568738 -177.763576 \n",
       "L 339.84808 -185.396726 \n",
       "L 343.127423 -192.990975 \n",
       "L 346.406765 -200.492717 \n",
       "L 349.686088 -207.802931 \n",
       "L 352.96543 -214.611017 \n",
       "L 356.244772 -219.090928 \n",
       "L 359.524114 -217.389418 \n",
       "L 362.803456 -213.095888 \n",
       "L 366.082798 -208.282456 \n",
       "L 369.362141 -203.317218 \n",
       "L 372.641463 -198.329209 \n",
       "L 375.920806 -193.394488 \n",
       "L 379.200148 -188.568606 \n",
       "L 379.200148 -269.06606 \n",
       "L 379.200148 -269.06606 \n",
       "L 375.920806 -263.432484 \n",
       "L 372.641463 -257.50745 \n",
       "L 369.362141 -251.321532 \n",
       "L 366.082798 -244.924007 \n",
       "L 362.803456 -238.415508 \n",
       "L 359.524114 -232.134344 \n",
       "L 356.244772 -228.121648 \n",
       "L 352.96543 -229.935125 \n",
       "L 349.686088 -233.689428 \n",
       "L 346.406765 -237.526737 \n",
       "L 343.127423 -241.105332 \n",
       "L 339.84808 -244.296799 \n",
       "L 336.568738 -247.020371 \n",
       "L 333.289396 -249.212824 \n",
       "L 330.010073 -250.821551 \n",
       "L 326.730731 -251.801817 \n",
       "L 323.451389 -252.116471 \n",
       "L 320.172047 -251.735815 \n",
       "L 316.892705 -250.638123 \n",
       "L 313.613382 -248.809868 \n",
       "L 310.33402 -246.245957 \n",
       "L 307.054697 -242.950257 \n",
       "L 303.775355 -238.935478 \n",
       "L 300.496013 -234.223426 \n",
       "L 297.21669 -228.845268 \n",
       "L 293.937329 -222.840941 \n",
       "L 290.658006 -216.259806 \n",
       "L 287.378664 -209.159504 \n",
       "L 284.099322 -201.606439 \n",
       "L 280.81998 -193.674751 \n",
       "L 277.540637 -185.446016 \n",
       "L 274.261315 -177.008435 \n",
       "L 270.981953 -168.455914 \n",
       "L 267.70263 -159.887487 \n",
       "L 264.423288 -151.405811 \n",
       "L 261.143946 -143.11672 \n",
       "L 257.864623 -135.128069 \n",
       "L 254.585262 -127.549793 \n",
       "L 251.305939 -120.495976 \n",
       "L 248.026597 -114.092802 \n",
       "L 244.747254 -108.512684 \n",
       "L 241.467912 -104.149161 \n",
       "L 238.18857 -102.686877 \n",
       "L 234.909247 -106.645662 \n",
       "L 231.629886 -113.169721 \n",
       "L 228.350563 -120.540959 \n",
       "L 225.071221 -128.357288 \n",
       "L 221.791879 -136.439099 \n",
       "L 218.512556 -144.654571 \n",
       "L 215.233204 -152.886703 \n",
       "L 211.953871 -161.025133 \n",
       "L 208.674529 -168.965243 \n",
       "L 205.395187 -176.608688 \n",
       "L 202.115855 -183.864965 \n",
       "L 198.836512 -190.653149 \n",
       "L 195.55717 -196.903498 \n",
       "L 192.277838 -202.558898 \n",
       "L 188.998496 -207.576369 \n",
       "L 185.719153 -211.927914 \n",
       "L 182.439821 -215.601617 \n",
       "L 179.160479 -218.6023 \n",
       "L 175.881137 -220.952679 \n",
       "L 172.601804 -222.695167 \n",
       "L 169.322462 -223.897425 \n",
       "L 166.04312 -224.668306 \n",
       "L 162.763787 -225.208479 \n",
       "L 159.484445 -225.976414 \n",
       "L 156.205103 -227.844675 \n",
       "L 152.92577 -230.900827 \n",
       "L 149.646428 -234.067094 \n",
       "L 146.367086 -236.699301 \n",
       "L 143.087754 -238.572235 \n",
       "L 139.808412 -239.60976 \n",
       "L 136.529069 -239.795824 \n",
       "L 133.249737 -239.147911 \n",
       "L 129.970395 -237.70909 \n",
       "L 126.691057 -235.549664 \n",
       "L 123.41172 -232.777747 \n",
       "L 120.132378 -229.590368 \n",
       "L 116.853041 -226.466044 \n",
       "L 113.573703 -224.656439 \n",
       "L 110.294361 -225.181532 \n",
       "L 107.015024 -227.185312 \n",
       "L 103.735686 -229.945448 \n",
       "L 100.456344 -233.19815 \n",
       "L 97.177007 -236.821799 \n",
       "L 93.89767 -240.735779 \n",
       "L 90.61833 -244.873836 \n",
       "L 87.33899 -249.174394 \n",
       "L 84.059653 -253.5794 \n",
       "L 80.780313 -258.033748 \n",
       "L 77.500973 -262.48556 \n",
       "L 74.221636 -266.887244 \n",
       "L 70.942296 -271.195559 \n",
       "L 67.662958 -275.372608 \n",
       "L 64.383619 -279.386003 \n",
       "L 61.10428 -283.209161 \n",
       "L 57.824941 -286.821404 \n",
       "L 54.545602 -290.207726 \n",
       "z\n",
       "\" style=\"stroke: #1f77b4; stroke-opacity: 0.5; stroke-width: 0.8\"/>\n",
       "    </defs>\n",
       "    <g clip-path=\"url(#pe10e24ab2f)\">\n",
       "     <use xlink:href=\"#mb73ab9770a\" x=\"0\" y=\"322.539375\" style=\"fill: #1f77b4; fill-opacity: 0.5; stroke: #1f77b4; stroke-opacity: 0.5; stroke-width: 0.8\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"PolyCollection_2\">\n",
       "    <defs>\n",
       "     <path id=\"mf62905d522\" d=\"M 54.545602 -139.940102 \n",
       "L 54.545602 -139.804453 \n",
       "L 57.824941 -141.646947 \n",
       "L 61.10428 -143.838988 \n",
       "L 64.383619 -146.398247 \n",
       "L 67.662958 -149.336706 \n",
       "L 70.942296 -152.659587 \n",
       "L 74.221636 -156.36438 \n",
       "L 77.500973 -160.440048 \n",
       "L 80.780313 -164.866076 \n",
       "L 84.059653 -169.612121 \n",
       "L 87.33899 -174.636872 \n",
       "L 90.61833 -179.887706 \n",
       "L 93.89767 -185.299262 \n",
       "L 97.177007 -190.7909 \n",
       "L 100.456344 -196.261902 \n",
       "L 103.735686 -201.57635 \n",
       "L 107.015024 -206.52674 \n",
       "L 110.294361 -210.741702 \n",
       "L 113.573703 -213.588375 \n",
       "L 116.853041 -214.685844 \n",
       "L 120.132378 -214.683571 \n",
       "L 123.41172 -214.38946 \n",
       "L 126.691057 -214.187443 \n",
       "L 129.970395 -214.213215 \n",
       "L 133.249737 -214.495924 \n",
       "L 136.529069 -215.014372 \n",
       "L 139.808412 -215.714013 \n",
       "L 143.087754 -216.511868 \n",
       "L 146.367086 -217.288753 \n",
       "L 149.646428 -217.862835 \n",
       "L 152.92577 -217.918027 \n",
       "L 156.205103 -216.882609 \n",
       "L 159.484445 -214.055871 \n",
       "L 162.763787 -209.339557 \n",
       "L 166.04312 -203.233569 \n",
       "L 169.322462 -196.184811 \n",
       "L 172.601804 -188.470973 \n",
       "L 175.881137 -180.285062 \n",
       "L 179.160479 -171.785439 \n",
       "L 182.439821 -163.116751 \n",
       "L 185.719153 -154.417575 \n",
       "L 188.998496 -145.822215 \n",
       "L 192.277838 -137.460987 \n",
       "L 195.55717 -129.458976 \n",
       "L 198.836512 -121.934503 \n",
       "L 202.115855 -114.997586 \n",
       "L 205.395187 -108.74826 \n",
       "L 208.674529 -103.274617 \n",
       "L 211.953871 -98.651502 \n",
       "L 215.233204 -94.938599 \n",
       "L 218.512556 -92.178274 \n",
       "L 221.791879 -90.392549 \n",
       "L 225.071221 -89.576331 \n",
       "L 228.350563 -89.680835 \n",
       "L 231.629886 -90.559515 \n",
       "L 234.909247 -91.756736 \n",
       "L 238.18857 -91.792543 \n",
       "L 241.467912 -88.906283 \n",
       "L 244.747254 -84.536729 \n",
       "L 248.026597 -80.158549 \n",
       "L 251.305939 -76.254138 \n",
       "L 254.585262 -72.99451 \n",
       "L 257.864623 -70.454458 \n",
       "L 261.143946 -68.668776 \n",
       "L 264.423288 -67.64957 \n",
       "L 267.70263 -67.393715 \n",
       "L 270.981953 -67.886438 \n",
       "L 274.261315 -69.103797 \n",
       "L 277.540637 -71.014606 \n",
       "L 280.81998 -73.582066 \n",
       "L 284.099322 -76.765373 \n",
       "L 287.378664 -80.520986 \n",
       "L 290.658006 -84.80401 \n",
       "L 293.937329 -89.569073 \n",
       "L 297.21669 -94.771688 \n",
       "L 300.496013 -100.368196 \n",
       "L 303.775355 -106.317288 \n",
       "L 307.054697 -112.579376 \n",
       "L 310.33402 -119.117348 \n",
       "L 313.613382 -125.896324 \n",
       "L 316.892705 -132.883329 \n",
       "L 320.172047 -140.047131 \n",
       "L 323.451389 -147.357744 \n",
       "L 326.730731 -154.785607 \n",
       "L 330.010073 -162.301174 \n",
       "L 333.289396 -169.873779 \n",
       "L 336.568738 -177.470223 \n",
       "L 339.84808 -185.052346 \n",
       "L 343.127423 -192.570605 \n",
       "L 346.406765 -199.949761 \n",
       "L 349.686088 -207.037413 \n",
       "L 352.96543 -213.37871 \n",
       "L 356.244772 -217.219499 \n",
       "L 359.524114 -216.115738 \n",
       "L 362.803456 -212.314217 \n",
       "L 366.082798 -207.733854 \n",
       "L 369.362141 -202.895898 \n",
       "L 372.641463 -197.986431 \n",
       "L 375.920806 -193.104383 \n",
       "L 379.200148 -188.315945 \n",
       "L 379.200148 -188.568606 \n",
       "L 379.200148 -188.568606 \n",
       "L 375.920806 -193.394488 \n",
       "L 372.641463 -198.329209 \n",
       "L 369.362141 -203.317218 \n",
       "L 366.082798 -208.282456 \n",
       "L 362.803456 -213.095888 \n",
       "L 359.524114 -217.389418 \n",
       "L 356.244772 -219.090928 \n",
       "L 352.96543 -214.611017 \n",
       "L 349.686088 -207.802931 \n",
       "L 346.406765 -200.492717 \n",
       "L 343.127423 -192.990975 \n",
       "L 339.84808 -185.396726 \n",
       "L 336.568738 -177.763576 \n",
       "L 333.289396 -170.130931 \n",
       "L 330.010073 -162.531661 \n",
       "L 326.730731 -154.995907 \n",
       "L 323.451389 -147.552505 \n",
       "L 320.172047 -140.229809 \n",
       "L 316.892705 -133.056594 \n",
       "L 313.613382 -126.06231 \n",
       "L 310.33402 -119.277831 \n",
       "L 307.054697 -112.735874 \n",
       "L 303.775355 -106.471126 \n",
       "L 300.496013 -100.520624 \n",
       "L 297.21669 -94.923856 \n",
       "L 293.937329 -89.722167 \n",
       "L 290.658006 -84.959215 \n",
       "L 287.378664 -80.679584 \n",
       "L 284.099322 -76.928806 \n",
       "L 280.81998 -73.751961 \n",
       "L 277.540637 -71.192901 \n",
       "L 274.261315 -69.292872 \n",
       "L 270.981953 -68.089308 \n",
       "L 267.70263 -67.6143 \n",
       "L 264.423288 -67.893168 \n",
       "L 261.143946 -68.94283 \n",
       "L 257.864623 -70.76993 \n",
       "L 254.585262 -73.368492 \n",
       "L 251.305939 -76.715296 \n",
       "L 248.026597 -80.759782 \n",
       "L 244.747254 -85.387689 \n",
       "L 241.467912 -90.244785 \n",
       "L 238.18857 -93.665315 \n",
       "L 234.909247 -93.127061 \n",
       "L 231.629886 -91.461886 \n",
       "L 228.350563 -90.341966 \n",
       "L 225.071221 -90.102427 \n",
       "L 221.791879 -90.835626 \n",
       "L 218.512556 -92.567063 \n",
       "L 215.233204 -95.290687 \n",
       "L 211.953871 -98.978605 \n",
       "L 208.674529 -103.585211 \n",
       "L 205.395187 -109.048914 \n",
       "L 202.115855 -115.293846 \n",
       "L 198.836512 -122.231409 \n",
       "L 195.55717 -129.761482 \n",
       "L 192.277838 -137.774402 \n",
       "L 188.998496 -146.152597 \n",
       "L 185.719153 -154.772345 \n",
       "L 182.439821 -163.505486 \n",
       "L 179.160479 -172.221236 \n",
       "L 175.881137 -180.786755 \n",
       "L 172.601804 -189.06712 \n",
       "L 169.322462 -196.92103 \n",
       "L 166.04312 -204.185417 \n",
       "L 162.763787 -210.625252 \n",
       "L 159.484445 -215.76742 \n",
       "L 156.205103 -218.743811 \n",
       "L 152.92577 -219.489538 \n",
       "L 149.646428 -219.121924 \n",
       "L 146.367086 -218.339862 \n",
       "L 143.087754 -217.43672 \n",
       "L 139.808412 -216.56783 \n",
       "L 136.529069 -215.837674 \n",
       "L 133.249737 -215.323549 \n",
       "L 129.970395 -215.081564 \n",
       "L 126.691057 -215.142522 \n",
       "L 123.41172 -215.499003 \n",
       "L 120.132378 -216.05225 \n",
       "L 116.853041 -216.417784 \n",
       "L 113.573703 -215.431751 \n",
       "L 110.294361 -212.154641 \n",
       "L 107.015024 -207.51435 \n",
       "L 103.735686 -202.295532 \n",
       "L 100.456344 -196.814275 \n",
       "L 97.177007 -191.234136 \n",
       "L 93.89767 -185.667296 \n",
       "L 90.61833 -180.201654 \n",
       "L 87.33899 -174.910598 \n",
       "L 84.059653 -169.8551 \n",
       "L 80.780313 -165.085067 \n",
       "L 77.500973 -160.639984 \n",
       "L 74.221636 -156.54898 \n",
       "L 70.942296 -152.83171 \n",
       "L 67.662958 -149.498577 \n",
       "L 64.383619 -146.551665 \n",
       "L 61.10428 -143.985379 \n",
       "L 57.824941 -141.787485 \n",
       "L 54.545602 -139.940102 \n",
       "z\n",
       "\" style=\"stroke: #ff7f0e; stroke-opacity: 0.5; stroke-width: 0.8\"/>\n",
       "    </defs>\n",
       "    <g clip-path=\"url(#pe10e24ab2f)\">\n",
       "     <use xlink:href=\"#mf62905d522\" x=\"0\" y=\"322.539375\" style=\"fill: #ff7f0e; fill-opacity: 0.5; stroke: #ff7f0e; stroke-opacity: 0.5; stroke-width: 0.8\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"PolyCollection_3\">\n",
       "    <defs>\n",
       "     <path id=\"meb1aa581d3\" d=\"M 54.545602 -290.343375 \n",
       "L 54.545602 -290.207726 \n",
       "L 57.824941 -286.821404 \n",
       "L 61.10428 -283.209161 \n",
       "L 64.383619 -279.386003 \n",
       "L 67.662958 -275.372608 \n",
       "L 70.942296 -271.195559 \n",
       "L 74.221636 -266.887244 \n",
       "L 77.500973 -262.48556 \n",
       "L 80.780313 -258.033748 \n",
       "L 84.059653 -253.5794 \n",
       "L 87.33899 -249.174394 \n",
       "L 90.61833 -244.873836 \n",
       "L 93.89767 -240.735779 \n",
       "L 97.177007 -236.821799 \n",
       "L 100.456344 -233.19815 \n",
       "L 103.735686 -229.945448 \n",
       "L 107.015024 -227.185312 \n",
       "L 110.294361 -225.181532 \n",
       "L 113.573703 -224.656439 \n",
       "L 116.853041 -226.466044 \n",
       "L 120.132378 -229.590368 \n",
       "L 123.41172 -232.777747 \n",
       "L 126.691057 -235.549664 \n",
       "L 129.970395 -237.70909 \n",
       "L 133.249737 -239.147911 \n",
       "L 136.529069 -239.795824 \n",
       "L 139.808412 -239.60976 \n",
       "L 143.087754 -238.572235 \n",
       "L 146.367086 -236.699301 \n",
       "L 149.646428 -234.067094 \n",
       "L 152.92577 -230.900827 \n",
       "L 156.205103 -227.844675 \n",
       "L 159.484445 -225.976414 \n",
       "L 162.763787 -225.208479 \n",
       "L 166.04312 -224.668306 \n",
       "L 169.322462 -223.897425 \n",
       "L 172.601804 -222.695167 \n",
       "L 175.881137 -220.952679 \n",
       "L 179.160479 -218.6023 \n",
       "L 182.439821 -215.601617 \n",
       "L 185.719153 -211.927914 \n",
       "L 188.998496 -207.576369 \n",
       "L 192.277838 -202.558898 \n",
       "L 195.55717 -196.903498 \n",
       "L 198.836512 -190.653149 \n",
       "L 202.115855 -183.864965 \n",
       "L 205.395187 -176.608688 \n",
       "L 208.674529 -168.965243 \n",
       "L 211.953871 -161.025133 \n",
       "L 215.233204 -152.886703 \n",
       "L 218.512556 -144.654571 \n",
       "L 221.791879 -136.439099 \n",
       "L 225.071221 -128.357288 \n",
       "L 228.350563 -120.540959 \n",
       "L 231.629886 -113.169721 \n",
       "L 234.909247 -106.645662 \n",
       "L 238.18857 -102.686877 \n",
       "L 241.467912 -104.149161 \n",
       "L 244.747254 -108.512684 \n",
       "L 248.026597 -114.092802 \n",
       "L 251.305939 -120.495976 \n",
       "L 254.585262 -127.549793 \n",
       "L 257.864623 -135.128069 \n",
       "L 261.143946 -143.11672 \n",
       "L 264.423288 -151.405811 \n",
       "L 267.70263 -159.887487 \n",
       "L 270.981953 -168.455914 \n",
       "L 274.261315 -177.008435 \n",
       "L 277.540637 -185.446016 \n",
       "L 280.81998 -193.674751 \n",
       "L 284.099322 -201.606439 \n",
       "L 287.378664 -209.159504 \n",
       "L 290.658006 -216.259806 \n",
       "L 293.937329 -222.840941 \n",
       "L 297.21669 -228.845268 \n",
       "L 300.496013 -234.223426 \n",
       "L 303.775355 -238.935478 \n",
       "L 307.054697 -242.950257 \n",
       "L 310.33402 -246.245957 \n",
       "L 313.613382 -248.809868 \n",
       "L 316.892705 -250.638123 \n",
       "L 320.172047 -251.735815 \n",
       "L 323.451389 -252.116471 \n",
       "L 326.730731 -251.801817 \n",
       "L 330.010073 -250.821551 \n",
       "L 333.289396 -249.212824 \n",
       "L 336.568738 -247.020371 \n",
       "L 339.84808 -244.296799 \n",
       "L 343.127423 -241.105332 \n",
       "L 346.406765 -237.526737 \n",
       "L 349.686088 -233.689428 \n",
       "L 352.96543 -229.935125 \n",
       "L 356.244772 -228.121648 \n",
       "L 359.524114 -232.134344 \n",
       "L 362.803456 -238.415508 \n",
       "L 366.082798 -244.924007 \n",
       "L 369.362141 -251.321532 \n",
       "L 372.641463 -257.50745 \n",
       "L 375.920806 -263.432484 \n",
       "L 379.200148 -269.06606 \n",
       "L 379.200148 -269.318721 \n",
       "L 379.200148 -269.318721 \n",
       "L 375.920806 -263.722589 \n",
       "L 372.641463 -257.850228 \n",
       "L 369.362141 -251.74285 \n",
       "L 366.082798 -245.472609 \n",
       "L 362.803456 -239.197179 \n",
       "L 359.524114 -233.408025 \n",
       "L 356.244772 -229.993077 \n",
       "L 352.96543 -231.167434 \n",
       "L 349.686088 -234.454946 \n",
       "L 346.406765 -238.069691 \n",
       "L 343.127423 -241.525702 \n",
       "L 339.84808 -244.641178 \n",
       "L 336.568738 -247.313721 \n",
       "L 333.289396 -249.469979 \n",
       "L 330.010073 -251.052035 \n",
       "L 326.730731 -252.012118 \n",
       "L 323.451389 -252.311232 \n",
       "L 320.172047 -251.918488 \n",
       "L 316.892705 -250.811389 \n",
       "L 313.613382 -248.975859 \n",
       "L 310.33402 -246.406444 \n",
       "L 307.054697 -243.106755 \n",
       "L 303.775355 -239.089321 \n",
       "L 300.496013 -234.375854 \n",
       "L 297.21669 -228.997442 \n",
       "L 293.937329 -222.994031 \n",
       "L 290.658006 -216.415011 \n",
       "L 287.378664 -209.318107 \n",
       "L 284.099322 -201.769867 \n",
       "L 280.81998 -193.84464 \n",
       "L 277.540637 -185.624311 \n",
       "L 274.261315 -177.197515 \n",
       "L 270.981953 -168.658784 \n",
       "L 267.70263 -160.108067 \n",
       "L 264.423288 -151.64941 \n",
       "L 261.143946 -143.390769 \n",
       "L 257.864623 -135.443541 \n",
       "L 254.585262 -127.923774 \n",
       "L 251.305939 -120.957134 \n",
       "L 248.026597 -114.694035 \n",
       "L 244.747254 -109.363643 \n",
       "L 241.467912 -105.487663 \n",
       "L 238.18857 -104.55965 \n",
       "L 234.909247 -108.015987 \n",
       "L 231.629886 -114.072093 \n",
       "L 228.350563 -121.20209 \n",
       "L 225.071221 -128.883384 \n",
       "L 221.791879 -136.882175 \n",
       "L 218.512556 -145.043365 \n",
       "L 215.233204 -153.238791 \n",
       "L 211.953871 -161.352236 \n",
       "L 208.674529 -169.275831 \n",
       "L 205.395187 -176.909342 \n",
       "L 202.115855 -184.161228 \n",
       "L 198.836512 -190.95005 \n",
       "L 195.55717 -197.206007 \n",
       "L 192.277838 -202.872311 \n",
       "L 188.998496 -207.906752 \n",
       "L 185.719153 -212.282678 \n",
       "L 182.439821 -215.99035 \n",
       "L 179.160479 -219.038094 \n",
       "L 175.881137 -221.454371 \n",
       "L 172.601804 -223.291314 \n",
       "L 169.322462 -224.633646 \n",
       "L 166.04312 -225.620154 \n",
       "L 162.763787 -226.494175 \n",
       "L 159.484445 -227.687963 \n",
       "L 156.205103 -229.705876 \n",
       "L 152.92577 -232.472337 \n",
       "L 149.646428 -235.326182 \n",
       "L 146.367086 -237.75041 \n",
       "L 143.087754 -239.497087 \n",
       "L 139.808412 -240.463577 \n",
       "L 136.529069 -240.619126 \n",
       "L 133.249737 -239.975536 \n",
       "L 129.970395 -238.577439 \n",
       "L 126.691057 -236.504743 \n",
       "L 123.41172 -233.88729 \n",
       "L 120.132378 -230.959046 \n",
       "L 116.853041 -228.197984 \n",
       "L 113.573703 -226.499815 \n",
       "L 110.294361 -226.594472 \n",
       "L 107.015024 -228.172921 \n",
       "L 103.735686 -230.664632 \n",
       "L 100.456344 -233.750525 \n",
       "L 97.177007 -237.265035 \n",
       "L 93.89767 -241.103813 \n",
       "L 90.61833 -245.187787 \n",
       "L 87.33899 -249.448117 \n",
       "L 84.059653 -253.822383 \n",
       "L 80.780313 -258.25274 \n",
       "L 77.500973 -262.685495 \n",
       "L 74.221636 -267.071844 \n",
       "L 70.942296 -271.367683 \n",
       "L 67.662958 -275.53449 \n",
       "L 64.383619 -279.539421 \n",
       "L 61.10428 -283.355552 \n",
       "L 57.824941 -286.961942 \n",
       "L 54.545602 -290.343375 \n",
       "z\n",
       "\" style=\"stroke: #ff7f0e; stroke-opacity: 0.5; stroke-width: 0.8\"/>\n",
       "    </defs>\n",
       "    <g clip-path=\"url(#pe10e24ab2f)\">\n",
       "     <use xlink:href=\"#meb1aa581d3\" x=\"0\" y=\"322.539375\" style=\"fill: #ff7f0e; fill-opacity: 0.5; stroke: #ff7f0e; stroke-opacity: 0.5; stroke-width: 0.8\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"line2d_13\">\n",
       "    <defs>\n",
       "     <path id=\"m2665a1dde7\" d=\"M -5 5 \n",
       "L 5 -5 \n",
       "M -5 -5 \n",
       "L 5 5 \n",
       "\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "    </defs>\n",
       "    <g clip-path=\"url(#pe10e24ab2f)\">\n",
       "     <use xlink:href=\"#m2665a1dde7\" x=\"356.349693\" y=\"98.887993\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     <use xlink:href=\"#m2665a1dde7\" x=\"157.258364\" y=\"99.818695\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     <use xlink:href=\"#m2665a1dde7\" x=\"114.255683\" y=\"102.312204\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     <use xlink:href=\"#m2665a1dde7\" x=\"238.18857\" y=\"224.723454\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"line2d_14\">\n",
       "    <path d=\"M 54.545602 107.465461 \n",
       "L 57.824941 108.234931 \n",
       "L 61.10428 108.942105 \n",
       "L 64.383619 109.570541 \n",
       "L 67.662958 110.10378 \n",
       "L 70.942296 110.525742 \n",
       "L 74.221636 110.821264 \n",
       "L 77.500973 110.976605 \n",
       "L 80.780313 110.979966 \n",
       "L 84.059653 110.822125 \n",
       "L 87.33899 110.496879 \n",
       "L 90.61833 110.001628 \n",
       "L 93.89767 109.337837 \n",
       "L 97.177007 108.511407 \n",
       "L 100.456344 107.533162 \n",
       "L 103.735686 106.418885 \n",
       "L 107.015024 105.189544 \n",
       "L 110.294361 103.871288 \n",
       "L 113.573703 102.49528 \n",
       "L 116.853041 101.097461 \n",
       "L 120.132378 99.718066 \n",
       "L 123.41172 98.401 \n",
       "L 126.691057 97.193282 \n",
       "L 129.970395 96.144048 \n",
       "L 133.249737 95.303645 \n",
       "L 136.529069 94.722626 \n",
       "L 139.808412 94.45058 \n",
       "L 143.087754 94.534897 \n",
       "L 146.367086 95.019793 \n",
       "L 149.646428 95.944866 \n",
       "L 152.92577 97.344193 \n",
       "L 156.205103 99.245132 \n",
       "L 159.484445 101.667458 \n",
       "L 162.763787 104.622509 \n",
       "L 166.04312 108.112514 \n",
       "L 169.322462 112.130147 \n",
       "L 172.601804 116.658232 \n",
       "L 175.881137 121.669659 \n",
       "L 179.160479 127.127608 \n",
       "L 182.439821 132.985824 \n",
       "L 185.719153 139.189247 \n",
       "L 188.998496 145.674892 \n",
       "L 192.277838 152.372728 \n",
       "L 195.55717 159.206885 \n",
       "L 198.836512 166.097096 \n",
       "L 202.115855 172.959969 \n",
       "L 205.395187 179.710574 \n",
       "L 208.674529 186.264151 \n",
       "L 211.953871 192.537503 \n",
       "L 215.233204 198.45068 \n",
       "L 218.512556 203.928555 \n",
       "L 221.791879 208.902013 \n",
       "L 225.071221 213.309517 \n",
       "L 228.350563 217.097912 \n",
       "L 231.629886 220.223571 \n",
       "L 234.909247 222.653013 \n",
       "L 238.18857 224.363279 \n",
       "L 241.467912 225.342402 \n",
       "L 244.747254 225.589189 \n",
       "L 248.026597 225.113083 \n",
       "L 251.305939 223.933739 \n",
       "L 254.585262 222.080233 \n",
       "L 257.864623 219.590376 \n",
       "L 261.143946 216.509602 \n",
       "L 264.423288 212.889885 \n",
       "L 267.70263 208.788484 \n",
       "L 270.981953 204.266762 \n",
       "L 274.261315 199.388719 \n",
       "L 277.540637 194.219919 \n",
       "L 280.81998 188.826022 \n",
       "L 284.099322 183.271755 \n",
       "L 287.378664 177.619828 \n",
       "L 290.658006 171.929864 \n",
       "L 293.937329 166.257821 \n",
       "L 297.21669 160.654813 \n",
       "L 300.496013 155.167347 \n",
       "L 303.775355 149.836073 \n",
       "L 307.054697 144.696312 \n",
       "L 310.33402 139.777481 \n",
       "L 313.613382 135.103283 \n",
       "L 316.892705 130.692018 \n",
       "L 320.172047 126.556564 \n",
       "L 323.451389 122.704887 \n",
       "L 326.730731 119.140513 \n",
       "L 330.010073 115.86277 \n",
       "L 333.289396 112.867497 \n",
       "L 336.568738 110.147403 \n",
       "L 339.84808 107.692613 \n",
       "L 343.127423 105.491222 \n",
       "L 346.406765 103.529648 \n",
       "L 349.686088 101.793195 \n",
       "L 352.96543 100.266304 \n",
       "L 356.244772 98.933087 \n",
       "L 359.524114 97.777494 \n",
       "L 362.803456 96.783677 \n",
       "L 366.082798 95.936144 \n",
       "L 369.362141 95.22 \n",
       "L 372.641463 94.621044 \n",
       "L 375.920806 94.12589 \n",
       "L 379.200148 93.722041 \n",
       "\" clip-path=\"url(#pe10e24ab2f)\" style=\"fill: none; stroke: #1f77b4; stroke-width: 2; stroke-linecap: round\"/>\n",
       "   </g>\n",
       "   <g id=\"line2d_15\">\n",
       "    <path d=\"M 54.545602 183.182344 \n",
       "L 57.824941 177.670912 \n",
       "L 61.10428 172.17993 \n",
       "L 64.383619 166.729764 \n",
       "L 67.662958 161.340702 \n",
       "L 70.942296 156.032808 \n",
       "L 74.221636 150.825949 \n",
       "L 77.500973 145.739647 \n",
       "L 80.780313 140.793032 \n",
       "L 84.059653 136.004815 \n",
       "L 87.33899 131.393164 \n",
       "L 90.61833 126.975682 \n",
       "L 93.89767 122.76933 \n",
       "L 97.177007 118.790374 \n",
       "L 100.456344 115.054312 \n",
       "L 103.735686 111.575865 \n",
       "L 107.015024 108.368877 \n",
       "L 110.294361 105.446293 \n",
       "L 113.573703 102.820092 \n",
       "L 116.853041 100.501282 \n",
       "L 120.132378 98.49984 \n",
       "L 123.41172 96.82466 \n",
       "L 126.691057 95.483552 \n",
       "L 129.970395 94.483197 \n",
       "L 133.249737 93.829115 \n",
       "L 136.529069 93.525655 \n",
       "L 139.808412 93.575979 \n",
       "L 143.087754 93.982021 \n",
       "L 146.367086 94.744495 \n",
       "L 149.646428 95.862891 \n",
       "L 152.92577 97.335443 \n",
       "L 156.205103 99.159124 \n",
       "L 159.484445 101.329691 \n",
       "L 162.763787 103.841603 \n",
       "L 166.04312 106.688104 \n",
       "L 169.322462 109.861169 \n",
       "L 172.601804 113.351532 \n",
       "L 175.881137 117.148687 \n",
       "L 179.160479 121.240881 \n",
       "L 182.439821 125.615179 \n",
       "L 185.719153 130.257354 \n",
       "L 188.998496 135.152035 \n",
       "L 192.277838 140.282583 \n",
       "L 195.55717 145.631228 \n",
       "L 198.836512 151.178953 \n",
       "L 202.115855 156.905537 \n",
       "L 205.395187 162.789588 \n",
       "L 208.674529 168.80854 \n",
       "L 211.953871 174.938576 \n",
       "L 215.233204 181.154727 \n",
       "L 218.512556 187.430809 \n",
       "L 221.791879 193.739366 \n",
       "L 225.071221 200.051799 \n",
       "L 228.350563 206.338247 \n",
       "L 231.629886 212.567445 \n",
       "L 234.909247 218.707141 \n",
       "L 238.18857 224.723454 \n",
       "L 241.467912 230.581482 \n",
       "L 244.747254 236.244845 \n",
       "L 248.026597 241.675896 \n",
       "L 251.305939 246.835726 \n",
       "L 254.585262 251.684024 \n",
       "L 257.864623 256.179329 \n",
       "L 261.143946 260.2789 \n",
       "L 264.423288 263.938926 \n",
       "L 267.70263 267.114565 \n",
       "L 270.981953 269.76022 \n",
       "L 274.261315 271.829627 \n",
       "L 277.540637 273.276262 \n",
       "L 280.81998 274.053679 \n",
       "L 284.099322 274.116 \n",
       "L 287.378664 273.418523 \n",
       "L 290.658006 271.918526 \n",
       "L 293.937329 269.576153 \n",
       "L 297.21669 266.355445 \n",
       "L 300.496013 262.226108 \n",
       "L 303.775355 257.164484 \n",
       "L 307.054697 251.156032 \n",
       "L 310.33402 244.197437 \n",
       "L 313.613382 236.298885 \n",
       "L 316.892705 227.487527 \n",
       "L 320.172047 217.810369 \n",
       "L 323.451389 207.338112 \n",
       "L 326.730731 196.169153 \n",
       "L 330.010073 184.433605 \n",
       "L 333.289396 172.297546 \n",
       "L 336.568738 159.967093 \n",
       "L 339.84808 147.691643 \n",
       "L 343.127423 135.766584 \n",
       "L 346.406765 124.534313 \n",
       "L 349.686088 114.382433 \n",
       "L 352.96543 105.738988 \n",
       "L 356.244772 99.063763 \n",
       "L 359.524114 94.83256 \n",
       "L 362.803456 93.515408 \n",
       "L 366.082798 95.545653 \n",
       "L 369.362141 101.279522 \n",
       "L 372.641463 110.945739 \n",
       "L 375.920806 124.585451 \n",
       "L 379.200148 141.985347 \n",
       "\" clip-path=\"url(#pe10e24ab2f)\" style=\"fill: none; stroke-dasharray: 7.68,1.92,1.2,1.92; stroke-dashoffset: 0; stroke: #bf00bf; stroke-width: 1.2\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_3\">\n",
       "    <path d=\"M 38.312875 274.17984 \n",
       "L 38.312875 48.333651 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_4\">\n",
       "    <path d=\"M 54.545602 286.212 \n",
       "L 379.200148 286.212 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"text_15\">\n",
       "    <!-- N=0, psi=0.10 -->\n",
       "    <g style=\"fill: #262626\" transform=\"translate(186.986125 14.1) scale(0.096 -0.096)\">\n",
       "     <defs>\n",
       "      <path id=\"ArialMT-4e\" d=\"M 488 0 \n",
       "L 488 4581 \n",
       "L 1109 4581 \n",
       "L 3516 984 \n",
       "L 3516 4581 \n",
       "L 4097 4581 \n",
       "L 4097 0 \n",
       "L 3475 0 \n",
       "L 1069 3600 \n",
       "L 1069 0 \n",
       "L 488 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-3d\" d=\"M 3381 2694 \n",
       "L 356 2694 \n",
       "L 356 3219 \n",
       "L 3381 3219 \n",
       "L 3381 2694 \n",
       "z\n",
       "M 3381 1303 \n",
       "L 356 1303 \n",
       "L 356 1828 \n",
       "L 3381 1828 \n",
       "L 3381 1303 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-2c\" d=\"M 569 0 \n",
       "L 569 641 \n",
       "L 1209 641 \n",
       "L 1209 0 \n",
       "Q 1209 -353 1084 -570 \n",
       "Q 959 -788 688 -906 \n",
       "L 531 -666 \n",
       "Q 709 -588 793 -436 \n",
       "Q 878 -284 888 0 \n",
       "L 569 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-20\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-70\" d=\"M 422 -1272 \n",
       "L 422 3319 \n",
       "L 934 3319 \n",
       "L 934 2888 \n",
       "Q 1116 3141 1344 3267 \n",
       "Q 1572 3394 1897 3394 \n",
       "Q 2322 3394 2647 3175 \n",
       "Q 2972 2956 3137 2557 \n",
       "Q 3303 2159 3303 1684 \n",
       "Q 3303 1175 3120 767 \n",
       "Q 2938 359 2589 142 \n",
       "Q 2241 -75 1856 -75 \n",
       "Q 1575 -75 1351 44 \n",
       "Q 1128 163 984 344 \n",
       "L 984 -1272 \n",
       "L 422 -1272 \n",
       "z\n",
       "M 931 1641 \n",
       "Q 931 1000 1190 694 \n",
       "Q 1450 388 1819 388 \n",
       "Q 2194 388 2461 705 \n",
       "Q 2728 1022 2728 1688 \n",
       "Q 2728 2322 2467 2637 \n",
       "Q 2206 2953 1844 2953 \n",
       "Q 1484 2953 1207 2617 \n",
       "Q 931 2281 931 1641 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-73\" d=\"M 197 991 \n",
       "L 753 1078 \n",
       "Q 800 744 1014 566 \n",
       "Q 1228 388 1613 388 \n",
       "Q 2000 388 2187 545 \n",
       "Q 2375 703 2375 916 \n",
       "Q 2375 1106 2209 1216 \n",
       "Q 2094 1291 1634 1406 \n",
       "Q 1016 1563 777 1677 \n",
       "Q 538 1791 414 1992 \n",
       "Q 291 2194 291 2438 \n",
       "Q 291 2659 392 2848 \n",
       "Q 494 3038 669 3163 \n",
       "Q 800 3259 1026 3326 \n",
       "Q 1253 3394 1513 3394 \n",
       "Q 1903 3394 2198 3281 \n",
       "Q 2494 3169 2634 2976 \n",
       "Q 2775 2784 2828 2463 \n",
       "L 2278 2388 \n",
       "Q 2241 2644 2061 2787 \n",
       "Q 1881 2931 1553 2931 \n",
       "Q 1166 2931 1000 2803 \n",
       "Q 834 2675 834 2503 \n",
       "Q 834 2394 903 2306 \n",
       "Q 972 2216 1119 2156 \n",
       "Q 1203 2125 1616 2013 \n",
       "Q 2213 1853 2448 1751 \n",
       "Q 2684 1650 2818 1456 \n",
       "Q 2953 1263 2953 975 \n",
       "Q 2953 694 2789 445 \n",
       "Q 2625 197 2315 61 \n",
       "Q 2006 -75 1616 -75 \n",
       "Q 969 -75 630 194 \n",
       "Q 291 463 197 991 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-69\" d=\"M 425 3934 \n",
       "L 425 4581 \n",
       "L 988 4581 \n",
       "L 988 3934 \n",
       "L 425 3934 \n",
       "z\n",
       "M 425 0 \n",
       "L 425 3319 \n",
       "L 988 3319 \n",
       "L 988 0 \n",
       "L 425 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "     </defs>\n",
       "     <use xlink:href=\"#ArialMT-4e\"/>\n",
       "     <use xlink:href=\"#ArialMT-3d\" x=\"72.216797\"/>\n",
       "     <use xlink:href=\"#ArialMT-30\" x=\"130.615234\"/>\n",
       "     <use xlink:href=\"#ArialMT-2c\" x=\"186.230469\"/>\n",
       "     <use xlink:href=\"#ArialMT-20\" x=\"214.013672\"/>\n",
       "     <use xlink:href=\"#ArialMT-70\" x=\"241.796875\"/>\n",
       "     <use xlink:href=\"#ArialMT-73\" x=\"297.412109\"/>\n",
       "     <use xlink:href=\"#ArialMT-69\" x=\"347.412109\"/>\n",
       "     <use xlink:href=\"#ArialMT-3d\" x=\"369.628906\"/>\n",
       "     <use xlink:href=\"#ArialMT-30\" x=\"428.027344\"/>\n",
       "     <use xlink:href=\"#ArialMT-2e\" x=\"483.642578\"/>\n",
       "     <use xlink:href=\"#ArialMT-31\" x=\"511.425781\"/>\n",
       "     <use xlink:href=\"#ArialMT-30\" x=\"567.041016\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"legend_1\">\n",
       "    <g id=\"line2d_16\">\n",
       "     <g>\n",
       "      <use xlink:href=\"#m2665a1dde7\" x=\"307.608875\" y=\"31.238875\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"text_16\">\n",
       "     <!-- Observations -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(323.448875 34.318875) scale(0.088 -0.088)\">\n",
       "      <defs>\n",
       "       <path id=\"ArialMT-4f\" d=\"M 309 2231 \n",
       "Q 309 3372 921 4017 \n",
       "Q 1534 4663 2503 4663 \n",
       "Q 3138 4663 3647 4359 \n",
       "Q 4156 4056 4423 3514 \n",
       "Q 4691 2972 4691 2284 \n",
       "Q 4691 1588 4409 1038 \n",
       "Q 4128 488 3612 205 \n",
       "Q 3097 -78 2500 -78 \n",
       "Q 1853 -78 1343 234 \n",
       "Q 834 547 571 1087 \n",
       "Q 309 1628 309 2231 \n",
       "z\n",
       "M 934 2222 \n",
       "Q 934 1394 1379 917 \n",
       "Q 1825 441 2497 441 \n",
       "Q 3181 441 3623 922 \n",
       "Q 4066 1403 4066 2288 \n",
       "Q 4066 2847 3877 3264 \n",
       "Q 3688 3681 3323 3911 \n",
       "Q 2959 4141 2506 4141 \n",
       "Q 1863 4141 1398 3698 \n",
       "Q 934 3256 934 2222 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-62\" d=\"M 941 0 \n",
       "L 419 0 \n",
       "L 419 4581 \n",
       "L 981 4581 \n",
       "L 981 2947 \n",
       "Q 1338 3394 1891 3394 \n",
       "Q 2197 3394 2470 3270 \n",
       "Q 2744 3147 2920 2923 \n",
       "Q 3097 2700 3197 2384 \n",
       "Q 3297 2069 3297 1709 \n",
       "Q 3297 856 2875 390 \n",
       "Q 2453 -75 1863 -75 \n",
       "Q 1275 -75 941 416 \n",
       "L 941 0 \n",
       "z\n",
       "M 934 1684 \n",
       "Q 934 1088 1097 822 \n",
       "Q 1363 388 1816 388 \n",
       "Q 2184 388 2453 708 \n",
       "Q 2722 1028 2722 1663 \n",
       "Q 2722 2313 2464 2622 \n",
       "Q 2206 2931 1841 2931 \n",
       "Q 1472 2931 1203 2611 \n",
       "Q 934 2291 934 1684 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-65\" d=\"M 2694 1069 \n",
       "L 3275 997 \n",
       "Q 3138 488 2766 206 \n",
       "Q 2394 -75 1816 -75 \n",
       "Q 1088 -75 661 373 \n",
       "Q 234 822 234 1631 \n",
       "Q 234 2469 665 2931 \n",
       "Q 1097 3394 1784 3394 \n",
       "Q 2450 3394 2872 2941 \n",
       "Q 3294 2488 3294 1666 \n",
       "Q 3294 1616 3291 1516 \n",
       "L 816 1516 \n",
       "Q 847 969 1125 678 \n",
       "Q 1403 388 1819 388 \n",
       "Q 2128 388 2347 550 \n",
       "Q 2566 713 2694 1069 \n",
       "z\n",
       "M 847 1978 \n",
       "L 2700 1978 \n",
       "Q 2663 2397 2488 2606 \n",
       "Q 2219 2931 1791 2931 \n",
       "Q 1403 2931 1139 2672 \n",
       "Q 875 2413 847 1978 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-72\" d=\"M 416 0 \n",
       "L 416 3319 \n",
       "L 922 3319 \n",
       "L 922 2816 \n",
       "Q 1116 3169 1280 3281 \n",
       "Q 1444 3394 1641 3394 \n",
       "Q 1925 3394 2219 3213 \n",
       "L 2025 2691 \n",
       "Q 1819 2813 1613 2813 \n",
       "Q 1428 2813 1281 2702 \n",
       "Q 1134 2591 1072 2394 \n",
       "Q 978 2094 978 1738 \n",
       "L 978 0 \n",
       "L 416 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-76\" d=\"M 1344 0 \n",
       "L 81 3319 \n",
       "L 675 3319 \n",
       "L 1388 1331 \n",
       "Q 1503 1009 1600 663 \n",
       "Q 1675 925 1809 1294 \n",
       "L 2547 3319 \n",
       "L 3125 3319 \n",
       "L 1869 0 \n",
       "L 1344 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-61\" d=\"M 2588 409 \n",
       "Q 2275 144 1986 34 \n",
       "Q 1697 -75 1366 -75 \n",
       "Q 819 -75 525 192 \n",
       "Q 231 459 231 875 \n",
       "Q 231 1119 342 1320 \n",
       "Q 453 1522 633 1644 \n",
       "Q 813 1766 1038 1828 \n",
       "Q 1203 1872 1538 1913 \n",
       "Q 2219 1994 2541 2106 \n",
       "Q 2544 2222 2544 2253 \n",
       "Q 2544 2597 2384 2738 \n",
       "Q 2169 2928 1744 2928 \n",
       "Q 1347 2928 1158 2789 \n",
       "Q 969 2650 878 2297 \n",
       "L 328 2372 \n",
       "Q 403 2725 575 2942 \n",
       "Q 747 3159 1072 3276 \n",
       "Q 1397 3394 1825 3394 \n",
       "Q 2250 3394 2515 3294 \n",
       "Q 2781 3194 2906 3042 \n",
       "Q 3031 2891 3081 2659 \n",
       "Q 3109 2516 3109 2141 \n",
       "L 3109 1391 \n",
       "Q 3109 606 3145 398 \n",
       "Q 3181 191 3288 0 \n",
       "L 2700 0 \n",
       "Q 2613 175 2588 409 \n",
       "z\n",
       "M 2541 1666 \n",
       "Q 2234 1541 1622 1453 \n",
       "Q 1275 1403 1131 1340 \n",
       "Q 988 1278 909 1158 \n",
       "Q 831 1038 831 891 \n",
       "Q 831 666 1001 516 \n",
       "Q 1172 366 1500 366 \n",
       "Q 1825 366 2078 508 \n",
       "Q 2331 650 2450 897 \n",
       "Q 2541 1088 2541 1459 \n",
       "L 2541 1666 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-74\" d=\"M 1650 503 \n",
       "L 1731 6 \n",
       "Q 1494 -44 1306 -44 \n",
       "Q 1000 -44 831 53 \n",
       "Q 663 150 594 308 \n",
       "Q 525 466 525 972 \n",
       "L 525 2881 \n",
       "L 113 2881 \n",
       "L 113 3319 \n",
       "L 525 3319 \n",
       "L 525 4141 \n",
       "L 1084 4478 \n",
       "L 1084 3319 \n",
       "L 1650 3319 \n",
       "L 1650 2881 \n",
       "L 1084 2881 \n",
       "L 1084 941 \n",
       "Q 1084 700 1114 631 \n",
       "Q 1144 563 1211 522 \n",
       "Q 1278 481 1403 481 \n",
       "Q 1497 481 1650 503 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-6f\" d=\"M 213 1659 \n",
       "Q 213 2581 725 3025 \n",
       "Q 1153 3394 1769 3394 \n",
       "Q 2453 3394 2887 2945 \n",
       "Q 3322 2497 3322 1706 \n",
       "Q 3322 1066 3130 698 \n",
       "Q 2938 331 2570 128 \n",
       "Q 2203 -75 1769 -75 \n",
       "Q 1072 -75 642 372 \n",
       "Q 213 819 213 1659 \n",
       "z\n",
       "M 791 1659 \n",
       "Q 791 1022 1069 705 \n",
       "Q 1347 388 1769 388 \n",
       "Q 2188 388 2466 706 \n",
       "Q 2744 1025 2744 1678 \n",
       "Q 2744 2294 2464 2611 \n",
       "Q 2184 2928 1769 2928 \n",
       "Q 1347 2928 1069 2612 \n",
       "Q 791 2297 791 1659 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-6e\" d=\"M 422 0 \n",
       "L 422 3319 \n",
       "L 928 3319 \n",
       "L 928 2847 \n",
       "Q 1294 3394 1984 3394 \n",
       "Q 2284 3394 2536 3286 \n",
       "Q 2788 3178 2913 3003 \n",
       "Q 3038 2828 3088 2588 \n",
       "Q 3119 2431 3119 2041 \n",
       "L 3119 0 \n",
       "L 2556 0 \n",
       "L 2556 2019 \n",
       "Q 2556 2363 2490 2533 \n",
       "Q 2425 2703 2258 2804 \n",
       "Q 2091 2906 1866 2906 \n",
       "Q 1506 2906 1245 2678 \n",
       "Q 984 2450 984 1813 \n",
       "L 984 0 \n",
       "L 422 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#ArialMT-4f\"/>\n",
       "      <use xlink:href=\"#ArialMT-62\" x=\"77.783203\"/>\n",
       "      <use xlink:href=\"#ArialMT-73\" x=\"133.398438\"/>\n",
       "      <use xlink:href=\"#ArialMT-65\" x=\"183.398438\"/>\n",
       "      <use xlink:href=\"#ArialMT-72\" x=\"239.013672\"/>\n",
       "      <use xlink:href=\"#ArialMT-76\" x=\"272.314453\"/>\n",
       "      <use xlink:href=\"#ArialMT-61\" x=\"322.314453\"/>\n",
       "      <use xlink:href=\"#ArialMT-74\" x=\"377.929688\"/>\n",
       "      <use xlink:href=\"#ArialMT-69\" x=\"405.712891\"/>\n",
       "      <use xlink:href=\"#ArialMT-6f\" x=\"427.929688\"/>\n",
       "      <use xlink:href=\"#ArialMT-6e\" x=\"483.544922\"/>\n",
       "      <use xlink:href=\"#ArialMT-73\" x=\"539.160156\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"line2d_17\">\n",
       "     <path d=\"M 298.808875 43.822875 \n",
       "L 307.608875 43.822875 \n",
       "L 316.408875 43.822875 \n",
       "\" style=\"fill: none; stroke: #1f77b4; stroke-width: 2; stroke-linecap: round\"/>\n",
       "    </g>\n",
       "    <g id=\"text_17\">\n",
       "     <!-- $m_n(x)$ -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(323.448875 46.902875) scale(0.088 -0.088)\">\n",
       "      <defs>\n",
       "       <path id=\"DejaVuSans-Oblique-6d\" d=\"M 5747 2113 \n",
       "L 5338 0 \n",
       "L 4763 0 \n",
       "L 5166 2094 \n",
       "Q 5191 2228 5203 2325 \n",
       "Q 5216 2422 5216 2491 \n",
       "Q 5216 2772 5059 2928 \n",
       "Q 4903 3084 4622 3084 \n",
       "Q 4203 3084 3875 2770 \n",
       "Q 3547 2456 3450 1953 \n",
       "L 3066 0 \n",
       "L 2491 0 \n",
       "L 2900 2094 \n",
       "Q 2925 2209 2937 2307 \n",
       "Q 2950 2406 2950 2484 \n",
       "Q 2950 2769 2794 2926 \n",
       "Q 2638 3084 2363 3084 \n",
       "Q 1938 3084 1609 2770 \n",
       "Q 1281 2456 1184 1953 \n",
       "L 800 0 \n",
       "L 225 0 \n",
       "L 909 3500 \n",
       "L 1484 3500 \n",
       "L 1375 2956 \n",
       "Q 1609 3263 1923 3423 \n",
       "Q 2238 3584 2597 3584 \n",
       "Q 2978 3584 3223 3384 \n",
       "Q 3469 3184 3519 2828 \n",
       "Q 3781 3197 4126 3390 \n",
       "Q 4472 3584 4856 3584 \n",
       "Q 5306 3584 5551 3325 \n",
       "Q 5797 3066 5797 2591 \n",
       "Q 5797 2488 5784 2364 \n",
       "Q 5772 2241 5747 2113 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-Oblique-6e\" d=\"M 3566 2113 \n",
       "L 3156 0 \n",
       "L 2578 0 \n",
       "L 2988 2091 \n",
       "Q 3016 2238 3031 2350 \n",
       "Q 3047 2463 3047 2528 \n",
       "Q 3047 2791 2881 2937 \n",
       "Q 2716 3084 2419 3084 \n",
       "Q 1956 3084 1622 2776 \n",
       "Q 1288 2469 1184 1941 \n",
       "L 800 0 \n",
       "L 225 0 \n",
       "L 903 3500 \n",
       "L 1478 3500 \n",
       "L 1363 2950 \n",
       "Q 1603 3253 1940 3418 \n",
       "Q 2278 3584 2650 3584 \n",
       "Q 3113 3584 3367 3334 \n",
       "Q 3622 3084 3622 2631 \n",
       "Q 3622 2519 3608 2391 \n",
       "Q 3594 2263 3566 2113 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-28\" d=\"M 1984 4856 \n",
       "Q 1566 4138 1362 3434 \n",
       "Q 1159 2731 1159 2009 \n",
       "Q 1159 1288 1364 580 \n",
       "Q 1569 -128 1984 -844 \n",
       "L 1484 -844 \n",
       "Q 1016 -109 783 600 \n",
       "Q 550 1309 550 2009 \n",
       "Q 550 2706 781 3412 \n",
       "Q 1013 4119 1484 4856 \n",
       "L 1984 4856 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-29\" d=\"M 513 4856 \n",
       "L 1013 4856 \n",
       "Q 1481 4119 1714 3412 \n",
       "Q 1947 2706 1947 2009 \n",
       "Q 1947 1309 1714 600 \n",
       "Q 1481 -109 1013 -844 \n",
       "L 513 -844 \n",
       "Q 928 -128 1133 580 \n",
       "Q 1338 1288 1338 2009 \n",
       "Q 1338 2731 1133 3434 \n",
       "Q 928 4138 513 4856 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-6d\" transform=\"translate(0 0.125)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-6e\" transform=\"translate(97.412109 -16.28125) scale(0.7)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-28\" transform=\"translate(144.511719 0.125)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-78\" transform=\"translate(183.525391 0.125)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-29\" transform=\"translate(242.705078 0.125)\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"patch_5\">\n",
       "     <path d=\"M 298.808875 61.059875 \n",
       "L 316.408875 61.059875 \n",
       "L 316.408875 54.899875 \n",
       "L 298.808875 54.899875 \n",
       "z\n",
       "\" style=\"fill: #1f77b4; fill-opacity: 0.5; stroke: #1f77b4; stroke-opacity: 0.5; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "    </g>\n",
       "    <g id=\"text_18\">\n",
       "     <!-- $f(\\mathbf{x}^*)$ 95% pred. -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(323.448875 61.059875) scale(0.088 -0.088)\">\n",
       "      <defs>\n",
       "       <path id=\"DejaVuSans-Oblique-66\" d=\"M 3059 4863 \n",
       "L 2969 4384 \n",
       "L 2419 4384 \n",
       "Q 2106 4384 1964 4261 \n",
       "Q 1822 4138 1753 3809 \n",
       "L 1691 3500 \n",
       "L 2638 3500 \n",
       "L 2553 3053 \n",
       "L 1606 3053 \n",
       "L 1013 0 \n",
       "L 434 0 \n",
       "L 1031 3053 \n",
       "L 481 3053 \n",
       "L 563 3500 \n",
       "L 1113 3500 \n",
       "L 1159 3744 \n",
       "Q 1278 4363 1576 4613 \n",
       "Q 1875 4863 2516 4863 \n",
       "L 3059 4863 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-Bold-78\" d=\"M 1422 1791 \n",
       "L 159 3500 \n",
       "L 1344 3500 \n",
       "L 2059 2463 \n",
       "L 2784 3500 \n",
       "L 3969 3500 \n",
       "L 2706 1797 \n",
       "L 4031 0 \n",
       "L 2847 0 \n",
       "L 2059 1106 \n",
       "L 1281 0 \n",
       "L 97 0 \n",
       "L 1422 1791 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-2a\" d=\"M 3009 3897 \n",
       "L 1888 3291 \n",
       "L 3009 2681 \n",
       "L 2828 2375 \n",
       "L 1778 3009 \n",
       "L 1778 1831 \n",
       "L 1422 1831 \n",
       "L 1422 3009 \n",
       "L 372 2375 \n",
       "L 191 2681 \n",
       "L 1313 3291 \n",
       "L 191 3897 \n",
       "L 372 4206 \n",
       "L 1422 3572 \n",
       "L 1422 4750 \n",
       "L 1778 4750 \n",
       "L 1778 3572 \n",
       "L 2828 4206 \n",
       "L 3009 3897 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-39\" d=\"M 350 1059 \n",
       "L 891 1109 \n",
       "Q 959 728 1153 556 \n",
       "Q 1347 384 1650 384 \n",
       "Q 1909 384 2104 503 \n",
       "Q 2300 622 2425 820 \n",
       "Q 2550 1019 2634 1356 \n",
       "Q 2719 1694 2719 2044 \n",
       "Q 2719 2081 2716 2156 \n",
       "Q 2547 1888 2255 1720 \n",
       "Q 1963 1553 1622 1553 \n",
       "Q 1053 1553 659 1965 \n",
       "Q 266 2378 266 3053 \n",
       "Q 266 3750 677 4175 \n",
       "Q 1088 4600 1706 4600 \n",
       "Q 2153 4600 2523 4359 \n",
       "Q 2894 4119 3086 3673 \n",
       "Q 3278 3228 3278 2384 \n",
       "Q 3278 1506 3087 986 \n",
       "Q 2897 466 2520 194 \n",
       "Q 2144 -78 1638 -78 \n",
       "Q 1100 -78 759 220 \n",
       "Q 419 519 350 1059 \n",
       "z\n",
       "M 2653 3081 \n",
       "Q 2653 3566 2395 3850 \n",
       "Q 2138 4134 1775 4134 \n",
       "Q 1400 4134 1122 3828 \n",
       "Q 844 3522 844 3034 \n",
       "Q 844 2597 1108 2323 \n",
       "Q 1372 2050 1759 2050 \n",
       "Q 2150 2050 2401 2323 \n",
       "Q 2653 2597 2653 3081 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-35\" d=\"M 266 1200 \n",
       "L 856 1250 \n",
       "Q 922 819 1161 601 \n",
       "Q 1400 384 1738 384 \n",
       "Q 2144 384 2425 690 \n",
       "Q 2706 997 2706 1503 \n",
       "Q 2706 1984 2436 2262 \n",
       "Q 2166 2541 1728 2541 \n",
       "Q 1456 2541 1237 2417 \n",
       "Q 1019 2294 894 2097 \n",
       "L 366 2166 \n",
       "L 809 4519 \n",
       "L 3088 4519 \n",
       "L 3088 3981 \n",
       "L 1259 3981 \n",
       "L 1013 2750 \n",
       "Q 1425 3038 1878 3038 \n",
       "Q 2478 3038 2890 2622 \n",
       "Q 3303 2206 3303 1553 \n",
       "Q 3303 931 2941 478 \n",
       "Q 2500 -78 1738 -78 \n",
       "Q 1113 -78 717 272 \n",
       "Q 322 622 266 1200 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-25\" d=\"M 372 3481 \n",
       "Q 372 3972 619 4315 \n",
       "Q 866 4659 1334 4659 \n",
       "Q 1766 4659 2048 4351 \n",
       "Q 2331 4044 2331 3447 \n",
       "Q 2331 2866 2045 2552 \n",
       "Q 1759 2238 1341 2238 \n",
       "Q 925 2238 648 2547 \n",
       "Q 372 2856 372 3481 \n",
       "z\n",
       "M 1350 4272 \n",
       "Q 1141 4272 1002 4090 \n",
       "Q 863 3909 863 3425 \n",
       "Q 863 2984 1003 2804 \n",
       "Q 1144 2625 1350 2625 \n",
       "Q 1563 2625 1702 2806 \n",
       "Q 1841 2988 1841 3469 \n",
       "Q 1841 3913 1700 4092 \n",
       "Q 1559 4272 1350 4272 \n",
       "z\n",
       "M 1353 -169 \n",
       "L 3859 4659 \n",
       "L 4316 4659 \n",
       "L 1819 -169 \n",
       "L 1353 -169 \n",
       "z\n",
       "M 3334 1075 \n",
       "Q 3334 1569 3581 1911 \n",
       "Q 3828 2253 4300 2253 \n",
       "Q 4731 2253 5014 1945 \n",
       "Q 5297 1638 5297 1041 \n",
       "Q 5297 459 5011 145 \n",
       "Q 4725 -169 4303 -169 \n",
       "Q 3888 -169 3611 142 \n",
       "Q 3334 453 3334 1075 \n",
       "z\n",
       "M 4316 1866 \n",
       "Q 4103 1866 3964 1684 \n",
       "Q 3825 1503 3825 1019 \n",
       "Q 3825 581 3965 400 \n",
       "Q 4106 219 4313 219 \n",
       "Q 4528 219 4667 400 \n",
       "Q 4806 581 4806 1063 \n",
       "Q 4806 1506 4665 1686 \n",
       "Q 4525 1866 4316 1866 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-64\" d=\"M 2575 0 \n",
       "L 2575 419 \n",
       "Q 2259 -75 1647 -75 \n",
       "Q 1250 -75 917 144 \n",
       "Q 584 363 401 755 \n",
       "Q 219 1147 219 1656 \n",
       "Q 219 2153 384 2558 \n",
       "Q 550 2963 881 3178 \n",
       "Q 1213 3394 1622 3394 \n",
       "Q 1922 3394 2156 3267 \n",
       "Q 2391 3141 2538 2938 \n",
       "L 2538 4581 \n",
       "L 3097 4581 \n",
       "L 3097 0 \n",
       "L 2575 0 \n",
       "z\n",
       "M 797 1656 \n",
       "Q 797 1019 1065 703 \n",
       "Q 1334 388 1700 388 \n",
       "Q 2069 388 2326 689 \n",
       "Q 2584 991 2584 1609 \n",
       "Q 2584 2291 2321 2609 \n",
       "Q 2059 2928 1675 2928 \n",
       "Q 1300 2928 1048 2622 \n",
       "Q 797 2316 797 1656 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-66\" transform=\"translate(0 0.765625)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-28\" transform=\"translate(35.205078 0.765625)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-Bold-78\" transform=\"translate(74.21875 0.765625)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-2a\" transform=\"translate(153.31543 39.046875) scale(0.7)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-29\" transform=\"translate(204.6875 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" transform=\"translate(243.701172 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-39\" transform=\"translate(271.484375 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-35\" transform=\"translate(327.099609 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-25\" transform=\"translate(382.714844 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" transform=\"translate(471.630859 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-70\" transform=\"translate(499.414062 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-72\" transform=\"translate(555.029297 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-65\" transform=\"translate(588.330078 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-64\" transform=\"translate(643.945312 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-2e\" transform=\"translate(699.560547 0.765625)\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"patch_6\">\n",
       "     <path d=\"M 298.808875 75.227875 \n",
       "L 316.408875 75.227875 \n",
       "L 316.408875 69.067875 \n",
       "L 298.808875 69.067875 \n",
       "z\n",
       "\" style=\"fill: #ff7f0e; fill-opacity: 0.5; stroke: #ff7f0e; stroke-opacity: 0.5; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "    </g>\n",
       "    <g id=\"text_19\">\n",
       "     <!-- $y^*$ 95% pred. -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(323.448875 75.227875) scale(0.088 -0.088)\">\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-79\" transform=\"translate(0 0.765625)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-2a\" transform=\"translate(77.283529 39.046875) scale(0.7)\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" transform=\"translate(128.655599 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-39\" transform=\"translate(156.438802 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-35\" transform=\"translate(212.054036 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-25\" transform=\"translate(267.669271 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" transform=\"translate(356.585286 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-70\" transform=\"translate(384.36849 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-72\" transform=\"translate(439.983724 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-65\" transform=\"translate(473.284505 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-64\" transform=\"translate(528.89974 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-2e\" transform=\"translate(584.514974 0.765625)\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"line2d_18\">\n",
       "     <path d=\"M 298.808875 84.69475 \n",
       "L 307.608875 84.69475 \n",
       "L 316.408875 84.69475 \n",
       "\" style=\"fill: none; stroke-dasharray: 7.68,1.92,1.2,1.92; stroke-dashoffset: 0; stroke: #bf00bf; stroke-width: 1.2\"/>\n",
       "    </g>\n",
       "    <g id=\"text_20\">\n",
       "     <!-- True function -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(323.448875 87.77475) scale(0.088 -0.088)\">\n",
       "      <defs>\n",
       "       <path id=\"ArialMT-54\" d=\"M 1659 0 \n",
       "L 1659 4041 \n",
       "L 150 4041 \n",
       "L 150 4581 \n",
       "L 3781 4581 \n",
       "L 3781 4041 \n",
       "L 2266 4041 \n",
       "L 2266 0 \n",
       "L 1659 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-75\" d=\"M 2597 0 \n",
       "L 2597 488 \n",
       "Q 2209 -75 1544 -75 \n",
       "Q 1250 -75 995 37 \n",
       "Q 741 150 617 320 \n",
       "Q 494 491 444 738 \n",
       "Q 409 903 409 1263 \n",
       "L 409 3319 \n",
       "L 972 3319 \n",
       "L 972 1478 \n",
       "Q 972 1038 1006 884 \n",
       "Q 1059 663 1231 536 \n",
       "Q 1403 409 1656 409 \n",
       "Q 1909 409 2131 539 \n",
       "Q 2353 669 2445 892 \n",
       "Q 2538 1116 2538 1541 \n",
       "L 2538 3319 \n",
       "L 3100 3319 \n",
       "L 3100 0 \n",
       "L 2597 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-66\" d=\"M 556 0 \n",
       "L 556 2881 \n",
       "L 59 2881 \n",
       "L 59 3319 \n",
       "L 556 3319 \n",
       "L 556 3672 \n",
       "Q 556 4006 616 4169 \n",
       "Q 697 4388 901 4523 \n",
       "Q 1106 4659 1475 4659 \n",
       "Q 1713 4659 2000 4603 \n",
       "L 1916 4113 \n",
       "Q 1741 4144 1584 4144 \n",
       "Q 1328 4144 1222 4034 \n",
       "Q 1116 3925 1116 3625 \n",
       "L 1116 3319 \n",
       "L 1763 3319 \n",
       "L 1763 2881 \n",
       "L 1116 2881 \n",
       "L 1116 0 \n",
       "L 556 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-63\" d=\"M 2588 1216 \n",
       "L 3141 1144 \n",
       "Q 3050 572 2676 248 \n",
       "Q 2303 -75 1759 -75 \n",
       "Q 1078 -75 664 370 \n",
       "Q 250 816 250 1647 \n",
       "Q 250 2184 428 2587 \n",
       "Q 606 2991 970 3192 \n",
       "Q 1334 3394 1763 3394 \n",
       "Q 2303 3394 2647 3120 \n",
       "Q 2991 2847 3088 2344 \n",
       "L 2541 2259 \n",
       "Q 2463 2594 2264 2762 \n",
       "Q 2066 2931 1784 2931 \n",
       "Q 1359 2931 1093 2626 \n",
       "Q 828 2322 828 1663 \n",
       "Q 828 994 1084 691 \n",
       "Q 1341 388 1753 388 \n",
       "Q 2084 388 2306 591 \n",
       "Q 2528 794 2588 1216 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#ArialMT-54\"/>\n",
       "      <use xlink:href=\"#ArialMT-72\" x=\"57.333984\"/>\n",
       "      <use xlink:href=\"#ArialMT-75\" x=\"90.634766\"/>\n",
       "      <use xlink:href=\"#ArialMT-65\" x=\"146.25\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" x=\"201.865234\"/>\n",
       "      <use xlink:href=\"#ArialMT-66\" x=\"229.648438\"/>\n",
       "      <use xlink:href=\"#ArialMT-75\" x=\"257.431641\"/>\n",
       "      <use xlink:href=\"#ArialMT-6e\" x=\"313.046875\"/>\n",
       "      <use xlink:href=\"#ArialMT-63\" x=\"368.662109\"/>\n",
       "      <use xlink:href=\"#ArialMT-74\" x=\"418.662109\"/>\n",
       "      <use xlink:href=\"#ArialMT-69\" x=\"446.445312\"/>\n",
       "      <use xlink:href=\"#ArialMT-6f\" x=\"468.662109\"/>\n",
       "      <use xlink:href=\"#ArialMT-6e\" x=\"524.277344\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "  </g>\n",
       "  <g id=\"axes_2\">\n",
       "   <g id=\"matplotlib.axis_3\">\n",
       "    <g id=\"ytick_7\">\n",
       "     <g id=\"line2d_19\">\n",
       "      <defs>\n",
       "       <path id=\"m098d0c0caa\" d=\"M 0 0 \n",
       "L 4.8 0 \n",
       "\" style=\"stroke: #262626\"/>\n",
       "      </defs>\n",
       "      <g>\n",
       "       <use xlink:href=\"#m098d0c0caa\" x=\"395.432875\" y=\"274.116\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_21\">\n",
       "      <!-- 0.0 -->\n",
       "      <g style=\"fill: #ff7f0e\" transform=\"translate(403.732875 277.265437) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_8\">\n",
       "     <g id=\"line2d_20\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m098d0c0caa\" x=\"395.432875\" y=\"237.130954\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_22\">\n",
       "      <!-- 0.1 -->\n",
       "      <g style=\"fill: #ff7f0e\" transform=\"translate(403.732875 240.280392) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-31\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_9\">\n",
       "     <g id=\"line2d_21\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m098d0c0caa\" x=\"395.432875\" y=\"200.145909\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_23\">\n",
       "      <!-- 0.2 -->\n",
       "      <g style=\"fill: #ff7f0e\" transform=\"translate(403.732875 203.295346) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-32\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_10\">\n",
       "     <g id=\"line2d_22\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m098d0c0caa\" x=\"395.432875\" y=\"163.160863\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_24\">\n",
       "      <!-- 0.3 -->\n",
       "      <g style=\"fill: #ff7f0e\" transform=\"translate(403.732875 166.3103) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-33\" d=\"M 269 1209 \n",
       "L 831 1284 \n",
       "Q 928 806 1161 595 \n",
       "Q 1394 384 1728 384 \n",
       "Q 2125 384 2398 659 \n",
       "Q 2672 934 2672 1341 \n",
       "Q 2672 1728 2419 1979 \n",
       "Q 2166 2231 1775 2231 \n",
       "Q 1616 2231 1378 2169 \n",
       "L 1441 2663 \n",
       "Q 1497 2656 1531 2656 \n",
       "Q 1891 2656 2178 2843 \n",
       "Q 2466 3031 2466 3422 \n",
       "Q 2466 3731 2256 3934 \n",
       "Q 2047 4138 1716 4138 \n",
       "Q 1388 4138 1169 3931 \n",
       "Q 950 3725 888 3313 \n",
       "L 325 3413 \n",
       "Q 428 3978 793 4289 \n",
       "Q 1159 4600 1703 4600 \n",
       "Q 2078 4600 2393 4439 \n",
       "Q 2709 4278 2876 4000 \n",
       "Q 3044 3722 3044 3409 \n",
       "Q 3044 3113 2884 2869 \n",
       "Q 2725 2625 2413 2481 \n",
       "Q 2819 2388 3044 2092 \n",
       "Q 3269 1797 3269 1353 \n",
       "Q 3269 753 2831 336 \n",
       "Q 2394 -81 1725 -81 \n",
       "Q 1122 -81 723 278 \n",
       "Q 325 638 269 1209 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-33\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_11\">\n",
       "     <g id=\"line2d_23\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m098d0c0caa\" x=\"395.432875\" y=\"126.175817\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_25\">\n",
       "      <!-- 0.4 -->\n",
       "      <g style=\"fill: #ff7f0e\" transform=\"translate(403.732875 129.325255) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-34\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_12\">\n",
       "     <g id=\"line2d_24\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m098d0c0caa\" x=\"395.432875\" y=\"89.190771\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_26\">\n",
       "      <!-- 0.5 -->\n",
       "      <g style=\"fill: #ff7f0e\" transform=\"translate(403.732875 92.340209) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-35\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_13\">\n",
       "     <g id=\"line2d_25\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m098d0c0caa\" x=\"395.432875\" y=\"52.205726\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_27\">\n",
       "      <!-- 0.6 -->\n",
       "      <g style=\"fill: #ff7f0e\" transform=\"translate(403.732875 55.355163) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-36\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"text_28\">\n",
       "     <!-- Information Acquisition Function -->\n",
       "     <g style=\"fill: #ff7f0e\" transform=\"translate(426.953375 221.18925) rotate(-90) scale(0.096 -0.096)\">\n",
       "      <defs>\n",
       "       <path id=\"ArialMT-49\" d=\"M 597 0 \n",
       "L 597 4581 \n",
       "L 1203 4581 \n",
       "L 1203 0 \n",
       "L 597 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-6d\" d=\"M 422 0 \n",
       "L 422 3319 \n",
       "L 925 3319 \n",
       "L 925 2853 \n",
       "Q 1081 3097 1340 3245 \n",
       "Q 1600 3394 1931 3394 \n",
       "Q 2300 3394 2536 3241 \n",
       "Q 2772 3088 2869 2813 \n",
       "Q 3263 3394 3894 3394 \n",
       "Q 4388 3394 4653 3120 \n",
       "Q 4919 2847 4919 2278 \n",
       "L 4919 0 \n",
       "L 4359 0 \n",
       "L 4359 2091 \n",
       "Q 4359 2428 4304 2576 \n",
       "Q 4250 2725 4106 2815 \n",
       "Q 3963 2906 3769 2906 \n",
       "Q 3419 2906 3187 2673 \n",
       "Q 2956 2441 2956 1928 \n",
       "L 2956 0 \n",
       "L 2394 0 \n",
       "L 2394 2156 \n",
       "Q 2394 2531 2256 2718 \n",
       "Q 2119 2906 1806 2906 \n",
       "Q 1569 2906 1367 2781 \n",
       "Q 1166 2656 1075 2415 \n",
       "Q 984 2175 984 1722 \n",
       "L 984 0 \n",
       "L 422 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-41\" d=\"M -9 0 \n",
       "L 1750 4581 \n",
       "L 2403 4581 \n",
       "L 4278 0 \n",
       "L 3588 0 \n",
       "L 3053 1388 \n",
       "L 1138 1388 \n",
       "L 634 0 \n",
       "L -9 0 \n",
       "z\n",
       "M 1313 1881 \n",
       "L 2866 1881 \n",
       "L 2388 3150 \n",
       "Q 2169 3728 2063 4100 \n",
       "Q 1975 3659 1816 3225 \n",
       "L 1313 1881 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-71\" d=\"M 2538 -1272 \n",
       "L 2538 353 \n",
       "Q 2406 169 2170 47 \n",
       "Q 1934 -75 1669 -75 \n",
       "Q 1078 -75 651 397 \n",
       "Q 225 869 225 1691 \n",
       "Q 225 2191 398 2587 \n",
       "Q 572 2984 901 3189 \n",
       "Q 1231 3394 1625 3394 \n",
       "Q 2241 3394 2594 2875 \n",
       "L 2594 3319 \n",
       "L 3100 3319 \n",
       "L 3100 -1272 \n",
       "L 2538 -1272 \n",
       "z\n",
       "M 803 1669 \n",
       "Q 803 1028 1072 708 \n",
       "Q 1341 388 1716 388 \n",
       "Q 2075 388 2334 692 \n",
       "Q 2594 997 2594 1619 \n",
       "Q 2594 2281 2320 2615 \n",
       "Q 2047 2950 1678 2950 \n",
       "Q 1313 2950 1058 2639 \n",
       "Q 803 2328 803 1669 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-46\" d=\"M 525 0 \n",
       "L 525 4581 \n",
       "L 3616 4581 \n",
       "L 3616 4041 \n",
       "L 1131 4041 \n",
       "L 1131 2622 \n",
       "L 3281 2622 \n",
       "L 3281 2081 \n",
       "L 1131 2081 \n",
       "L 1131 0 \n",
       "L 525 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#ArialMT-49\"/>\n",
       "      <use xlink:href=\"#ArialMT-6e\" x=\"27.783203\"/>\n",
       "      <use xlink:href=\"#ArialMT-66\" x=\"83.398438\"/>\n",
       "      <use xlink:href=\"#ArialMT-6f\" x=\"111.181641\"/>\n",
       "      <use xlink:href=\"#ArialMT-72\" x=\"166.796875\"/>\n",
       "      <use xlink:href=\"#ArialMT-6d\" x=\"200.097656\"/>\n",
       "      <use xlink:href=\"#ArialMT-61\" x=\"283.398438\"/>\n",
       "      <use xlink:href=\"#ArialMT-74\" x=\"339.013672\"/>\n",
       "      <use xlink:href=\"#ArialMT-69\" x=\"366.796875\"/>\n",
       "      <use xlink:href=\"#ArialMT-6f\" x=\"389.013672\"/>\n",
       "      <use xlink:href=\"#ArialMT-6e\" x=\"444.628906\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" x=\"500.244141\"/>\n",
       "      <use xlink:href=\"#ArialMT-41\" x=\"522.527344\"/>\n",
       "      <use xlink:href=\"#ArialMT-63\" x=\"589.226562\"/>\n",
       "      <use xlink:href=\"#ArialMT-71\" x=\"639.226562\"/>\n",
       "      <use xlink:href=\"#ArialMT-75\" x=\"694.841797\"/>\n",
       "      <use xlink:href=\"#ArialMT-69\" x=\"750.457031\"/>\n",
       "      <use xlink:href=\"#ArialMT-73\" x=\"772.673828\"/>\n",
       "      <use xlink:href=\"#ArialMT-69\" x=\"822.673828\"/>\n",
       "      <use xlink:href=\"#ArialMT-74\" x=\"844.890625\"/>\n",
       "      <use xlink:href=\"#ArialMT-69\" x=\"872.673828\"/>\n",
       "      <use xlink:href=\"#ArialMT-6f\" x=\"894.890625\"/>\n",
       "      <use xlink:href=\"#ArialMT-6e\" x=\"950.505859\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" x=\"1006.121094\"/>\n",
       "      <use xlink:href=\"#ArialMT-46\" x=\"1033.904297\"/>\n",
       "      <use xlink:href=\"#ArialMT-75\" x=\"1094.988281\"/>\n",
       "      <use xlink:href=\"#ArialMT-6e\" x=\"1150.603516\"/>\n",
       "      <use xlink:href=\"#ArialMT-63\" x=\"1206.21875\"/>\n",
       "      <use xlink:href=\"#ArialMT-74\" x=\"1256.21875\"/>\n",
       "      <use xlink:href=\"#ArialMT-69\" x=\"1284.001953\"/>\n",
       "      <use xlink:href=\"#ArialMT-6f\" x=\"1306.21875\"/>\n",
       "      <use xlink:href=\"#ArialMT-6e\" x=\"1361.833984\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"line2d_26\">\n",
       "    <path d=\"M 54.545602 131.167431 \n",
       "L 57.824941 135.623237 \n",
       "L 61.10428 140.317613 \n",
       "L 64.383619 145.266252 \n",
       "L 67.662958 150.490034 \n",
       "L 70.942296 156.016512 \n",
       "L 74.221636 161.881951 \n",
       "L 77.500973 168.134277 \n",
       "L 80.780313 174.836526 \n",
       "L 84.059653 182.072898 \n",
       "L 87.33899 189.954776 \n",
       "L 90.61833 198.629991 \n",
       "L 93.89767 208.290069 \n",
       "L 97.177007 219.164374 \n",
       "L 100.456344 231.466279 \n",
       "L 103.735686 245.13429 \n",
       "L 107.015024 258.998962 \n",
       "L 110.294361 269.275942 \n",
       "L 113.573703 272.086478 \n",
       "L 116.853041 260.189801 \n",
       "L 120.132378 207.268865 \n",
       "L 123.41172 148.045331 \n",
       "L 126.691057 105.461877 \n",
       "L 129.970395 76.543336 \n",
       "L 133.249737 56.614149 \n",
       "L 136.529069 42.996874 \n",
       "L 139.808412 34.681971 \n",
       "L 143.087754 32.196 \n",
       "L 146.367086 38.484545 \n",
       "L 149.646428 62.303406 \n",
       "L 152.92577 125.770323 \n",
       "L 156.205103 227.827994 \n",
       "L 159.484445 265.167275 \n",
       "L 162.763787 268.872941 \n",
       "L 166.04312 269.50545 \n",
       "L 169.322462 270.132867 \n",
       "L 172.601804 270.935078 \n",
       "L 175.881137 271.777972 \n",
       "L 179.160479 272.538011 \n",
       "L 182.439821 273.145709 \n",
       "L 185.719153 273.580344 \n",
       "L 188.998496 273.856411 \n",
       "L 192.277838 274.009105 \n",
       "L 195.55717 274.080309 \n",
       "L 198.836512 274.106962 \n",
       "L 202.115855 274.114435 \n",
       "L 205.395187 274.115835 \n",
       "L 208.674529 274.115989 \n",
       "L 211.953871 274.116 \n",
       "L 215.233204 274.116 \n",
       "L 218.512556 274.116 \n",
       "L 221.791879 274.116 \n",
       "L 225.071221 274.116 \n",
       "L 228.350563 274.116 \n",
       "L 231.629886 274.116 \n",
       "L 234.909247 274.116 \n",
       "L 238.18857 274.116 \n",
       "L 241.467912 274.116 \n",
       "L 244.747254 274.116 \n",
       "L 248.026597 274.116 \n",
       "L 251.305939 274.116 \n",
       "L 254.585262 274.116 \n",
       "L 257.864623 274.116 \n",
       "L 261.143946 274.116 \n",
       "L 264.423288 274.116 \n",
       "L 267.70263 274.11578 \n",
       "L 270.981953 274.112693 \n",
       "L 274.261315 274.090902 \n",
       "L 277.540637 273.998744 \n",
       "L 280.81998 273.726953 \n",
       "L 284.099322 273.109875 \n",
       "L 287.378664 271.954992 \n",
       "L 290.658006 270.086221 \n",
       "L 293.937329 267.38118 \n",
       "L 297.21669 263.790786 \n",
       "L 300.496013 259.340965 \n",
       "L 303.775355 254.120524 \n",
       "L 307.054697 248.263759 \n",
       "L 310.33402 241.931323 \n",
       "L 313.613382 235.294227 \n",
       "L 316.892705 228.52267 \n",
       "L 320.172047 221.778271 \n",
       "L 323.451389 215.212303 \n",
       "L 326.730731 208.96799 \n",
       "L 330.010073 203.187313 \n",
       "L 333.289396 198.02636 \n",
       "L 336.568738 193.681682 \n",
       "L 339.84808 190.44384 \n",
       "L 343.127423 188.811268 \n",
       "L 346.406765 189.770426 \n",
       "L 349.686088 195.535275 \n",
       "L 352.96543 210.784493 \n",
       "L 356.244772 217.237294 \n",
       "L 359.524114 134.408282 \n",
       "L 362.803456 92.783557 \n",
       "L 366.082798 78.032815 \n",
       "L 369.362141 71.900832 \n",
       "L 372.641463 69.221132 \n",
       "L 375.920806 68.164767 \n",
       "L 379.200148 67.947383 \n",
       "\" clip-path=\"url(#pe10e24ab2f)\" style=\"fill: none; stroke: #ff7f0e; stroke-width: 1.2; stroke-linecap: round\"/>\n",
       "   </g>\n",
       "   <g id=\"line2d_27\">\n",
       "    <path d=\"M 143.087754 274.116 \n",
       "L 143.087754 271.672364 \n",
       "L 143.087754 269.228727 \n",
       "L 143.087754 266.785091 \n",
       "L 143.087754 264.341455 \n",
       "L 143.087754 261.897818 \n",
       "L 143.087754 259.454182 \n",
       "L 143.087754 257.010546 \n",
       "L 143.087754 254.566909 \n",
       "L 143.087754 252.123273 \n",
       "L 143.087754 249.679637 \n",
       "L 143.087754 247.236 \n",
       "L 143.087754 244.792364 \n",
       "L 143.087754 242.348728 \n",
       "L 143.087754 239.905091 \n",
       "L 143.087754 237.461455 \n",
       "L 143.087754 235.017819 \n",
       "L 143.087754 232.574182 \n",
       "L 143.087754 230.130546 \n",
       "L 143.087754 227.686907 \n",
       "L 143.087754 225.243273 \n",
       "L 143.087754 222.79964 \n",
       "L 143.087754 220.356001 \n",
       "L 143.087754 217.912362 \n",
       "L 143.087754 215.468728 \n",
       "L 143.087754 213.025094 \n",
       "L 143.087754 210.581455 \n",
       "L 143.087754 208.137816 \n",
       "L 143.087754 205.694183 \n",
       "L 143.087754 203.250549 \n",
       "L 143.087754 200.80691 \n",
       "L 143.087754 198.363271 \n",
       "L 143.087754 195.919637 \n",
       "L 143.087754 193.476004 \n",
       "L 143.087754 191.032365 \n",
       "L 143.087754 188.588725 \n",
       "L 143.087754 186.145092 \n",
       "L 143.087754 183.701458 \n",
       "L 143.087754 181.257814 \n",
       "L 143.087754 178.81418 \n",
       "L 143.087754 176.370547 \n",
       "L 143.087754 173.926913 \n",
       "L 143.087754 171.483279 \n",
       "L 143.087754 169.039635 \n",
       "L 143.087754 166.596001 \n",
       "L 143.087754 164.152368 \n",
       "L 143.087754 161.708723 \n",
       "L 143.087754 159.265089 \n",
       "L 143.087754 156.821456 \n",
       "L 143.087754 154.377822 \n",
       "L 143.087754 151.934178 \n",
       "L 143.087754 149.490544 \n",
       "L 143.087754 147.046911 \n",
       "L 143.087754 144.603277 \n",
       "L 143.087754 142.159632 \n",
       "L 143.087754 139.715999 \n",
       "L 143.087754 137.272365 \n",
       "L 143.087754 134.828721 \n",
       "L 143.087754 132.385087 \n",
       "L 143.087754 129.941453 \n",
       "L 143.087754 127.49782 \n",
       "L 143.087754 125.054186 \n",
       "L 143.087754 122.610542 \n",
       "L 143.087754 120.166908 \n",
       "L 143.087754 117.723275 \n",
       "L 143.087754 115.27963 \n",
       "L 143.087754 112.835996 \n",
       "L 143.087754 110.392363 \n",
       "L 143.087754 107.948729 \n",
       "L 143.087754 105.505096 \n",
       "L 143.087754 103.061451 \n",
       "L 143.087754 100.617817 \n",
       "L 143.087754 98.174184 \n",
       "L 143.087754 95.730539 \n",
       "L 143.087754 93.286906 \n",
       "L 143.087754 90.843272 \n",
       "L 143.087754 88.399627 \n",
       "L 143.087754 85.956005 \n",
       "L 143.087754 83.51236 \n",
       "L 143.087754 81.068716 \n",
       "L 143.087754 78.625093 \n",
       "L 143.087754 76.181449 \n",
       "L 143.087754 73.737826 \n",
       "L 143.087754 71.294181 \n",
       "L 143.087754 68.850537 \n",
       "L 143.087754 66.406914 \n",
       "L 143.087754 63.96327 \n",
       "L 143.087754 61.519647 \n",
       "L 143.087754 59.076002 \n",
       "L 143.087754 56.632358 \n",
       "L 143.087754 54.188735 \n",
       "L 143.087754 51.745091 \n",
       "L 143.087754 49.301446 \n",
       "L 143.087754 46.857824 \n",
       "L 143.087754 44.414179 \n",
       "L 143.087754 41.970534 \n",
       "L 143.087754 39.526912 \n",
       "L 143.087754 37.083267 \n",
       "L 143.087754 34.639645 \n",
       "L 143.087754 32.196 \n",
       "\" clip-path=\"url(#pe10e24ab2f)\" style=\"fill: none; stroke: #ff7f0e; stroke-linecap: round\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_7\">\n",
       "    <path d=\"M 38.312875 286.212 \n",
       "L 38.312875 20.1 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_8\">\n",
       "    <path d=\"M 395.432875 286.212 \n",
       "L 395.432875 20.1 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_9\">\n",
       "    <path d=\"M 38.312875 286.212 \n",
       "L 395.432875 286.212 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_10\">\n",
       "    <path d=\"M 38.312875 20.1 \n",
       "L 395.432875 20.1 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "  </g>\n",
       " </g>\n",
       " <defs>\n",
       "  <clipPath id=\"pe10e24ab2f\">\n",
       "   <rect x=\"38.312875\" y=\"20.1\" width=\"357.12\" height=\"266.112\"/>\n",
       "  </clipPath>\n",
       " </defs>\n",
       "</svg>\n"
      ],
      "text/plain": [
       "<Figure size 640x480 with 2 Axes>"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "image/svg+xml": [
       "<?xml version=\"1.0\" encoding=\"utf-8\" standalone=\"no\"?>\n",
       "<!DOCTYPE svg PUBLIC \"-//W3C//DTD SVG 1.1//EN\"\n",
       "  \"http://www.w3.org/Graphics/SVG/1.1/DTD/svg11.dtd\">\n",
       "<svg xmlns:xlink=\"http://www.w3.org/1999/xlink\" width=\"436.061375pt\" height=\"322.539375pt\" viewBox=\"0 0 436.061375 322.539375\" xmlns=\"http://www.w3.org/2000/svg\" version=\"1.1\">\n",
       " <metadata>\n",
       "  <rdf:RDF xmlns:dc=\"http://purl.org/dc/elements/1.1/\" xmlns:cc=\"http://creativecommons.org/ns#\" xmlns:rdf=\"http://www.w3.org/1999/02/22-rdf-syntax-ns#\">\n",
       "   <cc:Work>\n",
       "    <dc:type rdf:resource=\"http://purl.org/dc/dcmitype/StillImage\"/>\n",
       "    <dc:date>2023-10-23T15:18:34.021484</dc:date>\n",
       "    <dc:format>image/svg+xml</dc:format>\n",
       "    <dc:creator>\n",
       "     <cc:Agent>\n",
       "      <dc:title>Matplotlib v3.8.0, https://matplotlib.org/</dc:title>\n",
       "     </cc:Agent>\n",
       "    </dc:creator>\n",
       "   </cc:Work>\n",
       "  </rdf:RDF>\n",
       " </metadata>\n",
       " <defs>\n",
       "  <style type=\"text/css\">*{stroke-linejoin: round; stroke-linecap: butt}</style>\n",
       " </defs>\n",
       " <g id=\"figure_1\">\n",
       "  <g id=\"patch_1\">\n",
       "   <path d=\"M 0 322.539375 \n",
       "L 436.061375 322.539375 \n",
       "L 436.061375 0 \n",
       "L 0 0 \n",
       "z\n",
       "\" style=\"fill: #ffffff\"/>\n",
       "  </g>\n",
       "  <g id=\"axes_1\">\n",
       "   <g id=\"patch_2\">\n",
       "    <path d=\"M 38.312875 286.212 \n",
       "L 395.432875 286.212 \n",
       "L 395.432875 20.1 \n",
       "L 38.312875 20.1 \n",
       "z\n",
       "\" style=\"fill: #ffffff\"/>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_1\">\n",
       "    <g id=\"xtick_1\">\n",
       "     <g id=\"line2d_1\">\n",
       "      <defs>\n",
       "       <path id=\"m464989b311\" d=\"M 0 0 \n",
       "L 0 4.8 \n",
       "\" style=\"stroke: #262626\"/>\n",
       "      </defs>\n",
       "      <g>\n",
       "       <use xlink:href=\"#m464989b311\" x=\"54.545602\" y=\"286.212\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_1\">\n",
       "      <!-- 0.0 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(48.429602 300.810875) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-30\" d=\"M 266 2259 \n",
       "Q 266 3072 433 3567 \n",
       "Q 600 4063 929 4331 \n",
       "Q 1259 4600 1759 4600 \n",
       "Q 2128 4600 2406 4451 \n",
       "Q 2684 4303 2865 4023 \n",
       "Q 3047 3744 3150 3342 \n",
       "Q 3253 2941 3253 2259 \n",
       "Q 3253 1453 3087 958 \n",
       "Q 2922 463 2592 192 \n",
       "Q 2263 -78 1759 -78 \n",
       "Q 1097 -78 719 397 \n",
       "Q 266 969 266 2259 \n",
       "z\n",
       "M 844 2259 \n",
       "Q 844 1131 1108 757 \n",
       "Q 1372 384 1759 384 \n",
       "Q 2147 384 2411 759 \n",
       "Q 2675 1134 2675 2259 \n",
       "Q 2675 3391 2411 3762 \n",
       "Q 2147 4134 1753 4134 \n",
       "Q 1366 4134 1134 3806 \n",
       "Q 844 3388 844 2259 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "        <path id=\"ArialMT-2e\" d=\"M 581 0 \n",
       "L 581 641 \n",
       "L 1222 641 \n",
       "L 1222 0 \n",
       "L 581 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_2\">\n",
       "     <g id=\"line2d_2\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m464989b311\" x=\"119.476511\" y=\"286.212\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_2\">\n",
       "      <!-- 0.2 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(113.360511 300.810875) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-32\" d=\"M 3222 541 \n",
       "L 3222 0 \n",
       "L 194 0 \n",
       "Q 188 203 259 391 \n",
       "Q 375 700 629 1000 \n",
       "Q 884 1300 1366 1694 \n",
       "Q 2113 2306 2375 2664 \n",
       "Q 2638 3022 2638 3341 \n",
       "Q 2638 3675 2398 3904 \n",
       "Q 2159 4134 1775 4134 \n",
       "Q 1369 4134 1125 3890 \n",
       "Q 881 3647 878 3216 \n",
       "L 300 3275 \n",
       "Q 359 3922 746 4261 \n",
       "Q 1134 4600 1788 4600 \n",
       "Q 2447 4600 2831 4234 \n",
       "Q 3216 3869 3216 3328 \n",
       "Q 3216 3053 3103 2787 \n",
       "Q 2991 2522 2730 2228 \n",
       "Q 2469 1934 1863 1422 \n",
       "Q 1356 997 1212 845 \n",
       "Q 1069 694 975 541 \n",
       "L 3222 541 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-32\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_3\">\n",
       "     <g id=\"line2d_3\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m464989b311\" x=\"184.40742\" y=\"286.212\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_3\">\n",
       "      <!-- 0.4 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(178.29142 300.810875) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-34\" d=\"M 2069 0 \n",
       "L 2069 1097 \n",
       "L 81 1097 \n",
       "L 81 1613 \n",
       "L 2172 4581 \n",
       "L 2631 4581 \n",
       "L 2631 1613 \n",
       "L 3250 1613 \n",
       "L 3250 1097 \n",
       "L 2631 1097 \n",
       "L 2631 0 \n",
       "L 2069 0 \n",
       "z\n",
       "M 2069 1613 \n",
       "L 2069 3678 \n",
       "L 634 1613 \n",
       "L 2069 1613 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-34\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_4\">\n",
       "     <g id=\"line2d_4\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m464989b311\" x=\"249.33833\" y=\"286.212\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_4\">\n",
       "      <!-- 0.6 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(243.22233 300.810875) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-36\" d=\"M 3184 3459 \n",
       "L 2625 3416 \n",
       "Q 2550 3747 2413 3897 \n",
       "Q 2184 4138 1850 4138 \n",
       "Q 1581 4138 1378 3988 \n",
       "Q 1113 3794 959 3422 \n",
       "Q 806 3050 800 2363 \n",
       "Q 1003 2672 1297 2822 \n",
       "Q 1591 2972 1913 2972 \n",
       "Q 2475 2972 2870 2558 \n",
       "Q 3266 2144 3266 1488 \n",
       "Q 3266 1056 3080 686 \n",
       "Q 2894 316 2569 119 \n",
       "Q 2244 -78 1831 -78 \n",
       "Q 1128 -78 684 439 \n",
       "Q 241 956 241 2144 \n",
       "Q 241 3472 731 4075 \n",
       "Q 1159 4600 1884 4600 \n",
       "Q 2425 4600 2770 4297 \n",
       "Q 3116 3994 3184 3459 \n",
       "z\n",
       "M 888 1484 \n",
       "Q 888 1194 1011 928 \n",
       "Q 1134 663 1356 523 \n",
       "Q 1578 384 1822 384 \n",
       "Q 2178 384 2434 671 \n",
       "Q 2691 959 2691 1453 \n",
       "Q 2691 1928 2437 2201 \n",
       "Q 2184 2475 1800 2475 \n",
       "Q 1419 2475 1153 2201 \n",
       "Q 888 1928 888 1484 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-36\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_5\">\n",
       "     <g id=\"line2d_5\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m464989b311\" x=\"314.269239\" y=\"286.212\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_5\">\n",
       "      <!-- 0.8 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(308.153239 300.810875) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-38\" d=\"M 1131 2484 \n",
       "Q 781 2613 612 2850 \n",
       "Q 444 3088 444 3419 \n",
       "Q 444 3919 803 4259 \n",
       "Q 1163 4600 1759 4600 \n",
       "Q 2359 4600 2725 4251 \n",
       "Q 3091 3903 3091 3403 \n",
       "Q 3091 3084 2923 2848 \n",
       "Q 2756 2613 2416 2484 \n",
       "Q 2838 2347 3058 2040 \n",
       "Q 3278 1734 3278 1309 \n",
       "Q 3278 722 2862 322 \n",
       "Q 2447 -78 1769 -78 \n",
       "Q 1091 -78 675 323 \n",
       "Q 259 725 259 1325 \n",
       "Q 259 1772 486 2073 \n",
       "Q 713 2375 1131 2484 \n",
       "z\n",
       "M 1019 3438 \n",
       "Q 1019 3113 1228 2906 \n",
       "Q 1438 2700 1772 2700 \n",
       "Q 2097 2700 2305 2904 \n",
       "Q 2513 3109 2513 3406 \n",
       "Q 2513 3716 2298 3927 \n",
       "Q 2084 4138 1766 4138 \n",
       "Q 1444 4138 1231 3931 \n",
       "Q 1019 3725 1019 3438 \n",
       "z\n",
       "M 838 1322 \n",
       "Q 838 1081 952 856 \n",
       "Q 1066 631 1291 507 \n",
       "Q 1516 384 1775 384 \n",
       "Q 2178 384 2440 643 \n",
       "Q 2703 903 2703 1303 \n",
       "Q 2703 1709 2433 1975 \n",
       "Q 2163 2241 1756 2241 \n",
       "Q 1359 2241 1098 1978 \n",
       "Q 838 1716 838 1322 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-38\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_6\">\n",
       "     <g id=\"line2d_6\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m464989b311\" x=\"379.200148\" y=\"286.212\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_6\">\n",
       "      <!-- 1.0 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(373.084148 300.810875) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-31\" d=\"M 2384 0 \n",
       "L 1822 0 \n",
       "L 1822 3584 \n",
       "Q 1619 3391 1289 3197 \n",
       "Q 959 3003 697 2906 \n",
       "L 697 3450 \n",
       "Q 1169 3672 1522 3987 \n",
       "Q 1875 4303 2022 4600 \n",
       "L 2384 4600 \n",
       "L 2384 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-31\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"text_7\">\n",
       "     <!-- $x$ -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(213.992875 313.431375) scale(0.096 -0.096)\">\n",
       "      <defs>\n",
       "       <path id=\"DejaVuSans-Oblique-78\" d=\"M 3841 3500 \n",
       "L 2234 1784 \n",
       "L 3219 0 \n",
       "L 2559 0 \n",
       "L 1819 1388 \n",
       "L 531 0 \n",
       "L -166 0 \n",
       "L 1556 1844 \n",
       "L 641 3500 \n",
       "L 1300 3500 \n",
       "L 1972 2234 \n",
       "L 3144 3500 \n",
       "L 3841 3500 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-78\" transform=\"translate(0 0.3125)\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_2\">\n",
       "    <g id=\"ytick_1\">\n",
       "     <g id=\"line2d_7\">\n",
       "      <defs>\n",
       "       <path id=\"mc489c6ca71\" d=\"M 0 0 \n",
       "L -4.8 0 \n",
       "\" style=\"stroke: #262626\"/>\n",
       "      </defs>\n",
       "      <g>\n",
       "       <use xlink:href=\"#mc489c6ca71\" x=\"38.312875\" y=\"274.182605\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_8\">\n",
       "      <!-- −8 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(19.9795 277.332043) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-2212\" d=\"M 3381 1997 \n",
       "L 356 1997 \n",
       "L 356 2522 \n",
       "L 3381 2522 \n",
       "L 3381 1997 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-38\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_2\">\n",
       "     <g id=\"line2d_8\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mc489c6ca71\" x=\"38.312875\" y=\"227.056791\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_9\">\n",
       "      <!-- −6 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(19.9795 230.206229) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-36\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_3\">\n",
       "     <g id=\"line2d_9\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mc489c6ca71\" x=\"38.312875\" y=\"179.930977\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_10\">\n",
       "      <!-- −4 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(19.9795 183.080415) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-34\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_4\">\n",
       "     <g id=\"line2d_10\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mc489c6ca71\" x=\"38.312875\" y=\"132.805163\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_11\">\n",
       "      <!-- −2 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(19.9795 135.954601) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-32\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_5\">\n",
       "     <g id=\"line2d_11\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mc489c6ca71\" x=\"38.312875\" y=\"85.679349\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_12\">\n",
       "      <!-- 0 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(25.11925 88.828787) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_6\">\n",
       "     <g id=\"line2d_12\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mc489c6ca71\" x=\"38.312875\" y=\"38.553535\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_13\">\n",
       "      <!-- 2 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(25.11925 41.702973) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-32\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"text_14\">\n",
       "     <!-- $y$ -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(13.9635 156.036) rotate(-90) scale(0.096 -0.096)\">\n",
       "      <defs>\n",
       "       <path id=\"DejaVuSans-Oblique-79\" d=\"M 1588 -325 \n",
       "Q 1188 -997 936 -1164 \n",
       "Q 684 -1331 294 -1331 \n",
       "L -159 -1331 \n",
       "L -63 -850 \n",
       "L 269 -850 \n",
       "Q 509 -850 678 -719 \n",
       "Q 847 -588 1056 -206 \n",
       "L 1234 128 \n",
       "L 459 3500 \n",
       "L 1069 3500 \n",
       "L 1650 819 \n",
       "L 3256 3500 \n",
       "L 3859 3500 \n",
       "L 1588 -325 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-79\" transform=\"translate(0 0.3125)\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"PolyCollection_1\">\n",
       "    <defs>\n",
       "     <path id=\"m8b88ed1f8e\" d=\"M 54.545602 -290.18407 \n",
       "L 54.545602 -150.935832 \n",
       "L 57.824941 -153.564434 \n",
       "L 61.10428 -156.512135 \n",
       "L 64.383619 -159.773406 \n",
       "L 67.662958 -163.335939 \n",
       "L 70.942296 -167.180701 \n",
       "L 74.221636 -171.281743 \n",
       "L 77.500973 -175.606442 \n",
       "L 80.780313 -180.116136 \n",
       "L 84.059653 -184.76654 \n",
       "L 87.33899 -189.507667 \n",
       "L 90.61833 -194.285431 \n",
       "L 93.89767 -199.040801 \n",
       "L 97.177007 -203.709728 \n",
       "L 100.456344 -208.221973 \n",
       "L 103.735686 -212.495162 \n",
       "L 107.015024 -216.425941 \n",
       "L 110.294361 -219.874373 \n",
       "L 113.573703 -222.666139 \n",
       "L 116.853041 -224.708062 \n",
       "L 120.132378 -226.154021 \n",
       "L 123.41172 -227.293539 \n",
       "L 126.691057 -228.318749 \n",
       "L 129.970395 -229.293406 \n",
       "L 133.249737 -230.204473 \n",
       "L 136.529069 -231.002669 \n",
       "L 139.808412 -231.612894 \n",
       "L 143.087754 -231.937583 \n",
       "L 146.367086 -231.840945 \n",
       "L 149.646428 -231.117174 \n",
       "L 152.92577 -229.495537 \n",
       "L 156.205103 -226.787393 \n",
       "L 159.484445 -223.017046 \n",
       "L 162.763787 -218.313039 \n",
       "L 166.04312 -212.789272 \n",
       "L 169.322462 -206.537366 \n",
       "L 172.601804 -199.640233 \n",
       "L 175.881137 -192.186509 \n",
       "L 179.160479 -184.273648 \n",
       "L 182.439821 -176.01015 \n",
       "L 185.719153 -167.515821 \n",
       "L 188.998496 -158.91913 \n",
       "L 192.277838 -150.355066 \n",
       "L 195.55717 -141.962133 \n",
       "L 198.836512 -133.879429 \n",
       "L 202.115855 -126.242724 \n",
       "L 205.395187 -119.18206 \n",
       "L 208.674529 -112.817806 \n",
       "L 211.953871 -107.258195 \n",
       "L 215.233204 -102.596325 \n",
       "L 218.512556 -98.907497 \n",
       "L 221.791879 -96.246048 \n",
       "L 225.071221 -94.64001 \n",
       "L 228.350563 -94.079552 \n",
       "L 231.629886 -94.477823 \n",
       "L 234.909247 -95.491247 \n",
       "L 238.18857 -95.621479 \n",
       "L 241.467912 -92.602174 \n",
       "L 244.747254 -88.239487 \n",
       "L 248.026597 -83.995865 \n",
       "L 251.305939 -80.244892 \n",
       "L 254.585262 -77.115522 \n",
       "L 257.864623 -74.669135 \n",
       "L 261.143946 -72.938752 \n",
       "L 264.423288 -71.9398 \n",
       "L 267.70263 -71.675121 \n",
       "L 270.981953 -72.137009 \n",
       "L 274.261315 -73.30899 \n",
       "L 277.540637 -75.16719 \n",
       "L 280.81998 -77.681643 \n",
       "L 284.099322 -80.817721 \n",
       "L 287.378664 -84.537199 \n",
       "L 290.658006 -88.799653 \n",
       "L 293.937329 -93.563307 \n",
       "L 297.21669 -98.786343 \n",
       "L 300.496013 -104.427053 \n",
       "L 303.775355 -110.445249 \n",
       "L 307.054697 -116.801964 \n",
       "L 310.33402 -123.460053 \n",
       "L 313.613382 -130.384248 \n",
       "L 316.892705 -137.540808 \n",
       "L 320.172047 -144.897587 \n",
       "L 323.451389 -152.423553 \n",
       "L 326.730731 -160.088134 \n",
       "L 330.010073 -167.861049 \n",
       "L 333.289396 -175.711383 \n",
       "L 336.568738 -183.606817 \n",
       "L 339.84808 -191.512133 \n",
       "L 343.127423 -199.385301 \n",
       "L 346.406765 -207.169539 \n",
       "L 349.686088 -214.760542 \n",
       "L 352.96543 -221.833505 \n",
       "L 356.244772 -226.484348 \n",
       "L 359.524114 -224.700237 \n",
       "L 362.803456 -220.214317 \n",
       "L 366.082798 -215.186165 \n",
       "L 369.362141 -210.000144 \n",
       "L 372.641463 -204.791018 \n",
       "L 375.920806 -199.638281 \n",
       "L 379.200148 -194.599875 \n",
       "L 379.200148 -278.553276 \n",
       "L 379.200148 -278.553276 \n",
       "L 375.920806 -272.678554 \n",
       "L 372.641463 -266.501601 \n",
       "L 369.362141 -260.054608 \n",
       "L 366.082798 -253.389458 \n",
       "L 362.803456 -246.611617 \n",
       "L 359.524114 -240.074692 \n",
       "L 356.244772 -235.906258 \n",
       "L 352.96543 -237.806704 \n",
       "L 349.686088 -241.729973 \n",
       "L 346.406765 -245.739094 \n",
       "L 343.127423 -249.476983 \n",
       "L 339.84808 -252.808834 \n",
       "L 336.568738 -255.649579 \n",
       "L 333.289396 -257.932329 \n",
       "L 330.010073 -259.601163 \n",
       "L 326.730731 -260.608285 \n",
       "L 323.451389 -260.913743 \n",
       "L 320.172047 -260.485339 \n",
       "L 316.892705 -259.299183 \n",
       "L 313.613382 -257.340003 \n",
       "L 310.33402 -254.601508 \n",
       "L 307.054697 -251.0869 \n",
       "L 303.775355 -246.808975 \n",
       "L 300.496013 -241.790412 \n",
       "L 297.21669 -236.064153 \n",
       "L 293.937329 -229.672939 \n",
       "L 290.658006 -222.670049 \n",
       "L 287.378664 -215.11823 \n",
       "L 284.099322 -207.09026 \n",
       "L 280.81998 -198.667934 \n",
       "L 277.540637 -189.941785 \n",
       "L 274.261315 -181.010164 \n",
       "L 270.981953 -171.978315 \n",
       "L 267.70263 -162.957594 \n",
       "L 264.423288 -154.063759 \n",
       "L 261.143946 -145.41631 \n",
       "L 257.864623 -137.137189 \n",
       "L 254.585262 -129.350353 \n",
       "L 251.305939 -122.184411 \n",
       "L 248.026597 -115.780855 \n",
       "L 244.747254 -110.331443 \n",
       "L 241.467912 -106.25331 \n",
       "L 238.18857 -105.031914 \n",
       "L 234.909247 -108.474849 \n",
       "L 231.629886 -114.295185 \n",
       "L 228.350563 -120.951656 \n",
       "L 225.071221 -128.036173 \n",
       "L 221.791879 -135.376267 \n",
       "L 218.512556 -142.856959 \n",
       "L 215.233204 -150.383515 \n",
       "L 211.953871 -157.871426 \n",
       "L 208.674529 -165.244166 \n",
       "L 205.395187 -172.432505 \n",
       "L 202.115855 -179.374835 \n",
       "L 198.836512 -186.01743 \n",
       "L 195.55717 -192.314967 \n",
       "L 192.277838 -198.229881 \n",
       "L 188.998496 -203.73332 \n",
       "L 185.719153 -208.803705 \n",
       "L 182.439821 -213.426941 \n",
       "L 179.160479 -217.595927 \n",
       "L 175.881137 -221.310293 \n",
       "L 172.601804 -224.575779 \n",
       "L 169.322462 -227.405954 \n",
       "L 166.04312 -229.825183 \n",
       "L 162.763787 -231.872425 \n",
       "L 159.484445 -233.615789 \n",
       "L 156.205103 -235.165649 \n",
       "L 152.92577 -236.666358 \n",
       "L 149.646428 -238.176243 \n",
       "L 146.367086 -239.557318 \n",
       "L 143.087754 -240.604507 \n",
       "L 139.808412 -241.190465 \n",
       "L 136.529069 -241.26865 \n",
       "L 133.249737 -240.8389 \n",
       "L 129.970395 -239.929451 \n",
       "L 126.691057 -238.597801 \n",
       "L 123.41172 -236.938634 \n",
       "L 120.132378 -235.122203 \n",
       "L 116.853041 -233.443734 \n",
       "L 113.573703 -232.290359 \n",
       "L 110.294361 -231.906584 \n",
       "L 107.015024 -232.281482 \n",
       "L 103.735686 -233.313248 \n",
       "L 100.456344 -234.924079 \n",
       "L 97.177007 -237.061767 \n",
       "L 93.89767 -239.683913 \n",
       "L 90.61833 -242.749351 \n",
       "L 87.33899 -246.212066 \n",
       "L 84.059653 -250.021037 \n",
       "L 80.780313 -254.120784 \n",
       "L 77.500973 -258.451371 \n",
       "L 74.221636 -262.951307 \n",
       "L 70.942296 -267.558364 \n",
       "L 67.662958 -272.21133 \n",
       "L 64.383619 -276.851791 \n",
       "L 61.10428 -281.425635 \n",
       "L 57.824941 -285.883938 \n",
       "L 54.545602 -290.18407 \n",
       "z\n",
       "\" style=\"stroke: #1f77b4; stroke-opacity: 0.5; stroke-width: 0.8\"/>\n",
       "    </defs>\n",
       "    <g clip-path=\"url(#p9fc75de91c)\">\n",
       "     <use xlink:href=\"#m8b88ed1f8e\" x=\"0\" y=\"322.539375\" style=\"fill: #1f77b4; fill-opacity: 0.5; stroke: #1f77b4; stroke-opacity: 0.5; stroke-width: 0.8\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"PolyCollection_2\">\n",
       "    <defs>\n",
       "     <path id=\"mdb6b6873be\" d=\"M 54.545602 -150.935832 \n",
       "L 54.545602 -150.776527 \n",
       "L 57.824941 -153.396809 \n",
       "L 61.10428 -156.334594 \n",
       "L 64.383619 -159.584023 \n",
       "L 67.662958 -163.132343 \n",
       "L 70.942296 -166.959937 \n",
       "L 74.221636 -171.040114 \n",
       "L 77.500973 -175.339229 \n",
       "L 80.780313 -179.81725 \n",
       "L 84.059653 -184.427959 \n",
       "L 87.33899 -189.118677 \n",
       "L 90.61833 -193.831436 \n",
       "L 93.89767 -198.501529 \n",
       "L 97.177007 -203.056637 \n",
       "L 100.456344 -207.41467 \n",
       "L 103.735686 -211.47807 \n",
       "L 107.015024 -215.131025 \n",
       "L 110.294361 -218.248362 \n",
       "L 113.573703 -220.742907 \n",
       "L 116.853041 -222.650447 \n",
       "L 120.132378 -224.133077 \n",
       "L 123.41172 -225.373283 \n",
       "L 126.691057 -226.485245 \n",
       "L 129.970395 -227.505812 \n",
       "L 133.249737 -228.416675 \n",
       "L 136.529069 -229.167445 \n",
       "L 139.808412 -229.682982 \n",
       "L 143.087754 -229.868911 \n",
       "L 146.367086 -229.608644 \n",
       "L 149.646428 -228.758921 \n",
       "L 152.92577 -227.159496 \n",
       "L 156.205103 -224.671188 \n",
       "L 159.484445 -221.224749 \n",
       "L 162.763787 -216.836058 \n",
       "L 166.04312 -211.572548 \n",
       "L 169.322462 -205.522516 \n",
       "L 172.601804 -198.779322 \n",
       "L 175.881137 -191.442938 \n",
       "L 179.160479 -183.619996 \n",
       "L 182.439821 -175.425738 \n",
       "L 185.719153 -166.984762 \n",
       "L 188.998496 -158.428923 \n",
       "L 192.277838 -149.895595 \n",
       "L 195.55717 -141.524875 \n",
       "L 198.836512 -133.4569 \n",
       "L 202.115855 -125.82797 \n",
       "L 205.395187 -118.768217 \n",
       "L 208.674529 -112.397559 \n",
       "L 211.953871 -106.82315 \n",
       "L 215.233204 -102.136022 \n",
       "L 218.512556 -98.407858 \n",
       "L 221.791879 -95.6865 \n",
       "L 225.071221 -93.987757 \n",
       "L 228.350563 -93.277067 \n",
       "L 231.629886 -93.414243 \n",
       "L 234.909247 -93.961083 \n",
       "L 238.18857 -93.667304 \n",
       "L 241.467912 -91.133357 \n",
       "L 244.747254 -87.276208 \n",
       "L 248.026597 -83.311882 \n",
       "L 251.305939 -79.721883 \n",
       "L 254.585262 -76.693758 \n",
       "L 257.864623 -74.315616 \n",
       "L 261.143946 -72.633614 \n",
       "L 264.423288 -71.670268 \n",
       "L 267.70263 -71.432465 \n",
       "L 270.981953 -71.91507 \n",
       "L 274.261315 -73.103175 \n",
       "L 277.540637 -74.974015 \n",
       "L 280.81998 -77.498367 \n",
       "L 284.099322 -80.642085 \n",
       "L 287.378664 -84.367349 \n",
       "L 290.658006 -88.633971 \n",
       "L 293.937329 -93.400333 \n",
       "L 297.21669 -98.624751 \n",
       "L 300.496013 -104.265552 \n",
       "L 303.775355 -110.28259 \n",
       "L 307.054697 -116.636788 \n",
       "L 310.33402 -123.290922 \n",
       "L 313.613382 -130.209567 \n",
       "L 316.892705 -137.358677 \n",
       "L 320.172047 -144.705772 \n",
       "L 323.451389 -152.219232 \n",
       "L 326.730731 -159.867679 \n",
       "L 330.010073 -167.619605 \n",
       "L 333.289396 -175.442159 \n",
       "L 336.568738 -183.299859 \n",
       "L 339.84808 -191.15194 \n",
       "L 343.127423 -198.945804 \n",
       "L 346.406765 -206.602084 \n",
       "L 349.686088 -213.96079 \n",
       "L 352.96543 -220.546798 \n",
       "L 356.244772 -224.531856 \n",
       "L 359.524114 -223.370707 \n",
       "L 362.803456 -219.398231 \n",
       "L 366.082798 -214.61343 \n",
       "L 369.362141 -209.560323 \n",
       "L 372.641463 -204.433212 \n",
       "L 375.920806 -199.335479 \n",
       "L 379.200148 -194.336171 \n",
       "L 379.200148 -194.599875 \n",
       "L 379.200148 -194.599875 \n",
       "L 375.920806 -199.638281 \n",
       "L 372.641463 -204.791018 \n",
       "L 369.362141 -210.000144 \n",
       "L 366.082798 -215.186165 \n",
       "L 362.803456 -220.214317 \n",
       "L 359.524114 -224.700237 \n",
       "L 356.244772 -226.484348 \n",
       "L 352.96543 -221.833505 \n",
       "L 349.686088 -214.760542 \n",
       "L 346.406765 -207.169539 \n",
       "L 343.127423 -199.385301 \n",
       "L 339.84808 -191.512133 \n",
       "L 336.568738 -183.606817 \n",
       "L 333.289396 -175.711383 \n",
       "L 330.010073 -167.861049 \n",
       "L 326.730731 -160.088134 \n",
       "L 323.451389 -152.423553 \n",
       "L 320.172047 -144.897587 \n",
       "L 316.892705 -137.540808 \n",
       "L 313.613382 -130.384248 \n",
       "L 310.33402 -123.460053 \n",
       "L 307.054697 -116.801964 \n",
       "L 303.775355 -110.445249 \n",
       "L 300.496013 -104.427053 \n",
       "L 297.21669 -98.786343 \n",
       "L 293.937329 -93.563307 \n",
       "L 290.658006 -88.799653 \n",
       "L 287.378664 -84.537199 \n",
       "L 284.099322 -80.817721 \n",
       "L 280.81998 -77.681643 \n",
       "L 277.540637 -75.16719 \n",
       "L 274.261315 -73.30899 \n",
       "L 270.981953 -72.137009 \n",
       "L 267.70263 -71.675121 \n",
       "L 264.423288 -71.9398 \n",
       "L 261.143946 -72.938752 \n",
       "L 257.864623 -74.669135 \n",
       "L 254.585262 -77.115522 \n",
       "L 251.305939 -80.244892 \n",
       "L 248.026597 -83.995865 \n",
       "L 244.747254 -88.239487 \n",
       "L 241.467912 -92.602174 \n",
       "L 238.18857 -95.621479 \n",
       "L 234.909247 -95.491247 \n",
       "L 231.629886 -94.477823 \n",
       "L 228.350563 -94.079552 \n",
       "L 225.071221 -94.64001 \n",
       "L 221.791879 -96.246048 \n",
       "L 218.512556 -98.907497 \n",
       "L 215.233204 -102.596325 \n",
       "L 211.953871 -107.258195 \n",
       "L 208.674529 -112.817806 \n",
       "L 205.395187 -119.18206 \n",
       "L 202.115855 -126.242724 \n",
       "L 198.836512 -133.879429 \n",
       "L 195.55717 -141.962133 \n",
       "L 192.277838 -150.355066 \n",
       "L 188.998496 -158.91913 \n",
       "L 185.719153 -167.515821 \n",
       "L 182.439821 -176.01015 \n",
       "L 179.160479 -184.273648 \n",
       "L 175.881137 -192.186509 \n",
       "L 172.601804 -199.640233 \n",
       "L 169.322462 -206.537366 \n",
       "L 166.04312 -212.789272 \n",
       "L 162.763787 -218.313039 \n",
       "L 159.484445 -223.017046 \n",
       "L 156.205103 -226.787393 \n",
       "L 152.92577 -229.495537 \n",
       "L 149.646428 -231.117174 \n",
       "L 146.367086 -231.840945 \n",
       "L 143.087754 -231.937583 \n",
       "L 139.808412 -231.612894 \n",
       "L 136.529069 -231.002669 \n",
       "L 133.249737 -230.204473 \n",
       "L 129.970395 -229.293406 \n",
       "L 126.691057 -228.318749 \n",
       "L 123.41172 -227.293539 \n",
       "L 120.132378 -226.154021 \n",
       "L 116.853041 -224.708062 \n",
       "L 113.573703 -222.666139 \n",
       "L 110.294361 -219.874373 \n",
       "L 107.015024 -216.425941 \n",
       "L 103.735686 -212.495162 \n",
       "L 100.456344 -208.221973 \n",
       "L 97.177007 -203.709728 \n",
       "L 93.89767 -199.040801 \n",
       "L 90.61833 -194.285431 \n",
       "L 87.33899 -189.507667 \n",
       "L 84.059653 -184.76654 \n",
       "L 80.780313 -180.116136 \n",
       "L 77.500973 -175.606442 \n",
       "L 74.221636 -171.281743 \n",
       "L 70.942296 -167.180701 \n",
       "L 67.662958 -163.335939 \n",
       "L 64.383619 -159.773406 \n",
       "L 61.10428 -156.512135 \n",
       "L 57.824941 -153.564434 \n",
       "L 54.545602 -150.935832 \n",
       "z\n",
       "\" style=\"stroke: #ff7f0e; stroke-opacity: 0.5; stroke-width: 0.8\"/>\n",
       "    </defs>\n",
       "    <g clip-path=\"url(#p9fc75de91c)\">\n",
       "     <use xlink:href=\"#mdb6b6873be\" x=\"0\" y=\"322.539375\" style=\"fill: #ff7f0e; fill-opacity: 0.5; stroke: #ff7f0e; stroke-opacity: 0.5; stroke-width: 0.8\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"PolyCollection_3\">\n",
       "    <defs>\n",
       "     <path id=\"m0b7fab8627\" d=\"M 54.545602 -290.343375 \n",
       "L 54.545602 -290.18407 \n",
       "L 57.824941 -285.883938 \n",
       "L 61.10428 -281.425635 \n",
       "L 64.383619 -276.851791 \n",
       "L 67.662958 -272.21133 \n",
       "L 70.942296 -267.558364 \n",
       "L 74.221636 -262.951307 \n",
       "L 77.500973 -258.451371 \n",
       "L 80.780313 -254.120784 \n",
       "L 84.059653 -250.021037 \n",
       "L 87.33899 -246.212066 \n",
       "L 90.61833 -242.749351 \n",
       "L 93.89767 -239.683913 \n",
       "L 97.177007 -237.061767 \n",
       "L 100.456344 -234.924079 \n",
       "L 103.735686 -233.313248 \n",
       "L 107.015024 -232.281482 \n",
       "L 110.294361 -231.906584 \n",
       "L 113.573703 -232.290359 \n",
       "L 116.853041 -233.443734 \n",
       "L 120.132378 -235.122203 \n",
       "L 123.41172 -236.938634 \n",
       "L 126.691057 -238.597801 \n",
       "L 129.970395 -239.929451 \n",
       "L 133.249737 -240.8389 \n",
       "L 136.529069 -241.26865 \n",
       "L 139.808412 -241.190465 \n",
       "L 143.087754 -240.604507 \n",
       "L 146.367086 -239.557318 \n",
       "L 149.646428 -238.176243 \n",
       "L 152.92577 -236.666358 \n",
       "L 156.205103 -235.165649 \n",
       "L 159.484445 -233.615789 \n",
       "L 162.763787 -231.872425 \n",
       "L 166.04312 -229.825183 \n",
       "L 169.322462 -227.405954 \n",
       "L 172.601804 -224.575779 \n",
       "L 175.881137 -221.310293 \n",
       "L 179.160479 -217.595927 \n",
       "L 182.439821 -213.426941 \n",
       "L 185.719153 -208.803705 \n",
       "L 188.998496 -203.73332 \n",
       "L 192.277838 -198.229881 \n",
       "L 195.55717 -192.314967 \n",
       "L 198.836512 -186.01743 \n",
       "L 202.115855 -179.374835 \n",
       "L 205.395187 -172.432505 \n",
       "L 208.674529 -165.244166 \n",
       "L 211.953871 -157.871426 \n",
       "L 215.233204 -150.383515 \n",
       "L 218.512556 -142.856959 \n",
       "L 221.791879 -135.376267 \n",
       "L 225.071221 -128.036173 \n",
       "L 228.350563 -120.951656 \n",
       "L 231.629886 -114.295185 \n",
       "L 234.909247 -108.474849 \n",
       "L 238.18857 -105.031914 \n",
       "L 241.467912 -106.25331 \n",
       "L 244.747254 -110.331443 \n",
       "L 248.026597 -115.780855 \n",
       "L 251.305939 -122.184411 \n",
       "L 254.585262 -129.350353 \n",
       "L 257.864623 -137.137189 \n",
       "L 261.143946 -145.41631 \n",
       "L 264.423288 -154.063759 \n",
       "L 267.70263 -162.957594 \n",
       "L 270.981953 -171.978315 \n",
       "L 274.261315 -181.010164 \n",
       "L 277.540637 -189.941785 \n",
       "L 280.81998 -198.667934 \n",
       "L 284.099322 -207.09026 \n",
       "L 287.378664 -215.11823 \n",
       "L 290.658006 -222.670049 \n",
       "L 293.937329 -229.672939 \n",
       "L 297.21669 -236.064153 \n",
       "L 300.496013 -241.790412 \n",
       "L 303.775355 -246.808975 \n",
       "L 307.054697 -251.0869 \n",
       "L 310.33402 -254.601508 \n",
       "L 313.613382 -257.340003 \n",
       "L 316.892705 -259.299183 \n",
       "L 320.172047 -260.485339 \n",
       "L 323.451389 -260.913743 \n",
       "L 326.730731 -260.608285 \n",
       "L 330.010073 -259.601163 \n",
       "L 333.289396 -257.932329 \n",
       "L 336.568738 -255.649579 \n",
       "L 339.84808 -252.808834 \n",
       "L 343.127423 -249.476983 \n",
       "L 346.406765 -245.739094 \n",
       "L 349.686088 -241.729973 \n",
       "L 352.96543 -237.806704 \n",
       "L 356.244772 -235.906258 \n",
       "L 359.524114 -240.074692 \n",
       "L 362.803456 -246.611617 \n",
       "L 366.082798 -253.389458 \n",
       "L 369.362141 -260.054608 \n",
       "L 372.641463 -266.501601 \n",
       "L 375.920806 -272.678554 \n",
       "L 379.200148 -278.553276 \n",
       "L 379.200148 -278.81698 \n",
       "L 379.200148 -278.81698 \n",
       "L 375.920806 -272.981355 \n",
       "L 372.641463 -266.859407 \n",
       "L 369.362141 -260.494428 \n",
       "L 366.082798 -253.962194 \n",
       "L 362.803456 -247.427702 \n",
       "L 359.524114 -241.404221 \n",
       "L 356.244772 -237.85875 \n",
       "L 352.96543 -239.09341 \n",
       "L 349.686088 -242.529725 \n",
       "L 346.406765 -246.306547 \n",
       "L 343.127423 -249.916481 \n",
       "L 339.84808 -253.169027 \n",
       "L 336.568738 -255.956538 \n",
       "L 333.289396 -258.201553 \n",
       "L 330.010073 -259.842606 \n",
       "L 326.730731 -260.828734 \n",
       "L 323.451389 -261.118064 \n",
       "L 320.172047 -260.677154 \n",
       "L 316.892705 -259.481308 \n",
       "L 313.613382 -257.514689 \n",
       "L 310.33402 -254.770638 \n",
       "L 307.054697 -251.252082 \n",
       "L 303.775355 -246.97164 \n",
       "L 300.496013 -241.951902 \n",
       "L 297.21669 -236.225744 \n",
       "L 293.937329 -229.835912 \n",
       "L 290.658006 -222.835736 \n",
       "L 287.378664 -215.28808 \n",
       "L 284.099322 -207.26589 \n",
       "L 280.81998 -198.851222 \n",
       "L 277.540637 -190.134955 \n",
       "L 274.261315 -181.215973 \n",
       "L 270.981953 -172.200258 \n",
       "L 267.70263 -163.200246 \n",
       "L 264.423288 -154.333297 \n",
       "L 261.143946 -145.721442 \n",
       "L 257.864623 -137.490708 \n",
       "L 254.585262 -129.772117 \n",
       "L 251.305939 -122.70742 \n",
       "L 248.026597 -116.464837 \n",
       "L 244.747254 -111.294722 \n",
       "L 241.467912 -107.722127 \n",
       "L 238.18857 -106.986089 \n",
       "L 234.909247 -110.005013 \n",
       "L 231.629886 -115.358764 \n",
       "L 228.350563 -121.754141 \n",
       "L 225.071221 -128.688426 \n",
       "L 221.791879 -135.935815 \n",
       "L 218.512556 -143.356598 \n",
       "L 215.233204 -150.843818 \n",
       "L 211.953871 -158.306471 \n",
       "L 208.674529 -165.664408 \n",
       "L 205.395187 -172.846349 \n",
       "L 202.115855 -179.789583 \n",
       "L 198.836512 -186.439959 \n",
       "L 195.55717 -192.752225 \n",
       "L 192.277838 -198.689355 \n",
       "L 188.998496 -204.223524 \n",
       "L 185.719153 -209.334765 \n",
       "L 182.439821 -214.011355 \n",
       "L 179.160479 -218.249577 \n",
       "L 175.881137 -222.053863 \n",
       "L 172.601804 -225.43669 \n",
       "L 169.322462 -228.420806 \n",
       "L 166.04312 -231.041908 \n",
       "L 162.763787 -233.349406 \n",
       "L 159.484445 -235.408086 \n",
       "L 156.205103 -237.281854 \n",
       "L 152.92577 -239.0024 \n",
       "L 149.646428 -240.534496 \n",
       "L 146.367086 -241.789618 \n",
       "L 143.087754 -242.673179 \n",
       "L 139.808412 -243.120377 \n",
       "L 136.529069 -243.103874 \n",
       "L 133.249737 -242.626698 \n",
       "L 129.970395 -241.717045 \n",
       "L 126.691057 -240.431306 \n",
       "L 123.41172 -238.858889 \n",
       "L 120.132378 -237.143149 \n",
       "L 116.853041 -235.501348 \n",
       "L 113.573703 -234.21359 \n",
       "L 110.294361 -233.532595 \n",
       "L 107.015024 -233.576399 \n",
       "L 103.735686 -234.330342 \n",
       "L 100.456344 -235.731383 \n",
       "L 97.177007 -237.714858 \n",
       "L 93.89767 -240.223185 \n",
       "L 90.61833 -243.203345 \n",
       "L 87.33899 -246.601051 \n",
       "L 84.059653 -250.359616 \n",
       "L 80.780313 -254.419672 \n",
       "L 77.500973 -258.71858 \n",
       "L 74.221636 -263.192936 \n",
       "L 70.942296 -267.779128 \n",
       "L 67.662958 -272.414926 \n",
       "L 64.383619 -277.041174 \n",
       "L 61.10428 -281.603176 \n",
       "L 57.824941 -286.051563 \n",
       "L 54.545602 -290.343375 \n",
       "z\n",
       "\" style=\"stroke: #ff7f0e; stroke-opacity: 0.5; stroke-width: 0.8\"/>\n",
       "    </defs>\n",
       "    <g clip-path=\"url(#p9fc75de91c)\">\n",
       "     <use xlink:href=\"#m0b7fab8627\" x=\"0\" y=\"322.539375\" style=\"fill: #ff7f0e; fill-opacity: 0.5; stroke: #ff7f0e; stroke-opacity: 0.5; stroke-width: 0.8\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"line2d_13\">\n",
       "    <defs>\n",
       "     <path id=\"mbebab0d61a\" d=\"M -5 5 \n",
       "L 5 -5 \n",
       "M -5 -5 \n",
       "L 5 5 \n",
       "\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "    </defs>\n",
       "    <g clip-path=\"url(#p9fc75de91c)\">\n",
       "     <use xlink:href=\"#mbebab0d61a\" x=\"356.349693\" y=\"91.297718\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     <use xlink:href=\"#mbebab0d61a\" x=\"157.258364\" y=\"92.268734\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     <use xlink:href=\"#mbebab0d61a\" x=\"114.255683\" y=\"94.870253\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     <use xlink:href=\"#mbebab0d61a\" x=\"238.18857\" y=\"222.583938\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     <use xlink:href=\"#mbebab0d61a\" x=\"143.087754\" y=\"86.179235\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"line2d_14\">\n",
       "    <path d=\"M 54.545602 101.979424 \n",
       "L 57.824941 102.815189 \n",
       "L 61.10428 103.57049 \n",
       "L 64.383619 104.226778 \n",
       "L 67.662958 104.765741 \n",
       "L 70.942296 105.169843 \n",
       "L 74.221636 105.42285 \n",
       "L 77.500973 105.510469 \n",
       "L 80.780313 105.420915 \n",
       "L 84.059653 105.145588 \n",
       "L 87.33899 104.67951 \n",
       "L 90.61833 104.021984 \n",
       "L 93.89767 103.177018 \n",
       "L 97.177007 102.153627 \n",
       "L 100.456344 100.966348 \n",
       "L 103.735686 99.63517 \n",
       "L 107.015024 98.185663 \n",
       "L 110.294361 96.648896 \n",
       "L 113.573703 95.061126 \n",
       "L 116.853041 93.463477 \n",
       "L 120.132378 91.901263 \n",
       "L 123.41172 90.423289 \n",
       "L 126.691057 89.0811 \n",
       "L 129.970395 87.927946 \n",
       "L 133.249737 87.017689 \n",
       "L 136.529069 86.403716 \n",
       "L 139.808412 86.137696 \n",
       "L 143.087754 86.26833 \n",
       "L 146.367086 86.840244 \n",
       "L 149.646428 87.892666 \n",
       "L 152.92577 89.458427 \n",
       "L 156.205103 91.562854 \n",
       "L 159.484445 94.222958 \n",
       "L 162.763787 97.446643 \n",
       "L 166.04312 101.232148 \n",
       "L 169.322462 105.567715 \n",
       "L 172.601804 110.431369 \n",
       "L 175.881137 115.790975 \n",
       "L 179.160479 121.604588 \n",
       "L 182.439821 127.820829 \n",
       "L 185.719153 134.379612 \n",
       "L 188.998496 141.213152 \n",
       "L 192.277838 148.2469 \n",
       "L 195.55717 155.400825 \n",
       "L 198.836512 162.590946 \n",
       "L 202.115855 169.730596 \n",
       "L 205.395187 176.732092 \n",
       "L 208.674529 183.508392 \n",
       "L 211.953871 189.974565 \n",
       "L 215.233204 196.049455 \n",
       "L 218.512556 201.657144 \n",
       "L 221.791879 206.728218 \n",
       "L 225.071221 211.201284 \n",
       "L 228.350563 215.023771 \n",
       "L 231.629886 218.152871 \n",
       "L 234.909247 220.556327 \n",
       "L 238.18857 222.212678 \n",
       "L 241.467912 223.111633 \n",
       "L 244.747254 223.25391 \n",
       "L 248.026597 222.651015 \n",
       "L 251.305939 221.324723 \n",
       "L 254.585262 219.306437 \n",
       "L 257.864623 216.636213 \n",
       "L 261.143946 213.361847 \n",
       "L 264.423288 209.537596 \n",
       "L 267.70263 205.22302 \n",
       "L 270.981953 200.481713 \n",
       "L 274.261315 195.379798 \n",
       "L 277.540637 189.98489 \n",
       "L 280.81998 184.364584 \n",
       "L 284.099322 178.585388 \n",
       "L 287.378664 172.71166 \n",
       "L 290.658006 166.804524 \n",
       "L 293.937329 160.921252 \n",
       "L 297.21669 155.11413 \n",
       "L 300.496013 149.430645 \n",
       "L 303.775355 143.912263 \n",
       "L 307.054697 138.594943 \n",
       "L 310.33402 133.508595 \n",
       "L 313.613382 128.677248 \n",
       "L 316.892705 124.119381 \n",
       "L 320.172047 119.847911 \n",
       "L 323.451389 115.870725 \n",
       "L 326.730731 112.191167 \n",
       "L 330.010073 108.808269 \n",
       "L 333.289396 105.717518 \n",
       "L 336.568738 102.911178 \n",
       "L 339.84808 100.378891 \n",
       "L 343.127423 98.108233 \n",
       "L 346.406765 96.085059 \n",
       "L 349.686088 94.294117 \n",
       "L 352.96543 92.719271 \n",
       "L 356.244772 91.344072 \n",
       "L 359.524114 90.151911 \n",
       "L 362.803456 89.126408 \n",
       "L 366.082798 88.251563 \n",
       "L 369.362141 87.511998 \n",
       "L 372.641463 86.893064 \n",
       "L 375.920806 86.380957 \n",
       "L 379.200148 85.9628 \n",
       "\" clip-path=\"url(#p9fc75de91c)\" style=\"fill: none; stroke: #1f77b4; stroke-width: 2; stroke-linecap: round\"/>\n",
       "   </g>\n",
       "   <g id=\"line2d_15\">\n",
       "    <path d=\"M 54.545602 179.24341 \n",
       "L 57.824941 173.493242 \n",
       "L 61.10428 167.76441 \n",
       "L 64.383619 162.078161 \n",
       "L 67.662958 156.455663 \n",
       "L 70.942296 150.917849 \n",
       "L 74.221636 145.485448 \n",
       "L 77.500973 140.178824 \n",
       "L 80.780313 135.017938 \n",
       "L 84.059653 130.022312 \n",
       "L 87.33899 125.210901 \n",
       "L 90.61833 120.602069 \n",
       "L 93.89767 116.213512 \n",
       "L 97.177007 112.062201 \n",
       "L 100.456344 108.164306 \n",
       "L 103.735686 104.535185 \n",
       "L 107.015024 101.189281 \n",
       "L 110.294361 98.1401 \n",
       "L 113.573703 95.400141 \n",
       "L 116.853041 92.980888 \n",
       "L 120.132378 90.89275 \n",
       "L 123.41172 89.145008 \n",
       "L 126.691057 87.745808 \n",
       "L 129.970395 86.702121 \n",
       "L 133.249737 86.019706 \n",
       "L 136.529069 85.703101 \n",
       "L 139.808412 85.755606 \n",
       "L 143.087754 86.179235 \n",
       "L 146.367086 86.974738 \n",
       "L 149.646428 88.141579 \n",
       "L 152.92577 89.677916 \n",
       "L 156.205103 91.580592 \n",
       "L 159.484445 93.845181 \n",
       "L 162.763787 96.465901 \n",
       "L 166.04312 99.435702 \n",
       "L 169.322462 102.746213 \n",
       "L 172.601804 106.387767 \n",
       "L 175.881137 110.349402 \n",
       "L 179.160479 114.618855 \n",
       "L 182.439821 119.182633 \n",
       "L 185.719153 124.025892 \n",
       "L 188.998496 129.132593 \n",
       "L 192.277838 134.485379 \n",
       "L 195.55717 140.065709 \n",
       "L 198.836512 145.853742 \n",
       "L 202.115855 151.828382 \n",
       "L 205.395187 157.96731 \n",
       "L 208.674529 164.246982 \n",
       "L 211.953871 170.64255 \n",
       "L 215.233204 177.127964 \n",
       "L 218.512556 183.675904 \n",
       "L 221.791879 190.257726 \n",
       "L 225.071221 196.843592 \n",
       "L 228.350563 203.402347 \n",
       "L 231.629886 209.901373 \n",
       "L 234.909247 216.307019 \n",
       "L 238.18857 222.583938 \n",
       "L 241.467912 228.695716 \n",
       "L 244.747254 234.604397 \n",
       "L 248.026597 240.270703 \n",
       "L 251.305939 245.654038 \n",
       "L 254.585262 250.712347 \n",
       "L 257.864623 255.402374 \n",
       "L 261.143946 259.679524 \n",
       "L 264.423288 263.49809 \n",
       "L 267.70263 266.811287 \n",
       "L 270.981953 269.571542 \n",
       "L 274.261315 271.730589 \n",
       "L 277.540637 273.239887 \n",
       "L 280.81998 274.050979 \n",
       "L 284.099322 274.116 \n",
       "L 287.378664 273.388311 \n",
       "L 290.658006 271.823339 \n",
       "L 293.937329 269.379502 \n",
       "L 297.21669 266.019284 \n",
       "L 300.496013 261.711079 \n",
       "L 303.775355 256.430202 \n",
       "L 307.054697 250.161485 \n",
       "L 310.33402 242.901467 \n",
       "L 313.613382 234.660778 \n",
       "L 316.892705 225.467742 \n",
       "L 320.172047 215.371403 \n",
       "L 323.451389 204.445523 \n",
       "L 326.730731 192.792763 \n",
       "L 330.010073 180.548871 \n",
       "L 333.289396 167.88712 \n",
       "L 336.568738 155.022554 \n",
       "L 339.84808 142.215373 \n",
       "L 343.127423 129.773763 \n",
       "L 346.406765 118.054948 \n",
       "L 349.686088 107.463324 \n",
       "L 352.96543 98.445474 \n",
       "L 356.244772 91.481101 \n",
       "L 359.524114 87.066617 \n",
       "L 362.803456 85.692411 \n",
       "L 366.082798 87.810598 \n",
       "L 369.362141 93.79284 \n",
       "L 372.641463 103.877763 \n",
       "L 375.920806 118.108301 \n",
       "L 379.200148 136.261901 \n",
       "\" clip-path=\"url(#p9fc75de91c)\" style=\"fill: none; stroke-dasharray: 7.68,1.92,1.2,1.92; stroke-dashoffset: 0; stroke: #bf00bf; stroke-width: 1.2\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_3\">\n",
       "    <path d=\"M 38.312875 274.182605 \n",
       "L 38.312875 38.553535 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_4\">\n",
       "    <path d=\"M 54.545602 286.212 \n",
       "L 379.200148 286.212 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"text_15\">\n",
       "    <!-- N=1, psi=0.10 -->\n",
       "    <g style=\"fill: #262626\" transform=\"translate(186.986125 14.1) scale(0.096 -0.096)\">\n",
       "     <defs>\n",
       "      <path id=\"ArialMT-4e\" d=\"M 488 0 \n",
       "L 488 4581 \n",
       "L 1109 4581 \n",
       "L 3516 984 \n",
       "L 3516 4581 \n",
       "L 4097 4581 \n",
       "L 4097 0 \n",
       "L 3475 0 \n",
       "L 1069 3600 \n",
       "L 1069 0 \n",
       "L 488 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-3d\" d=\"M 3381 2694 \n",
       "L 356 2694 \n",
       "L 356 3219 \n",
       "L 3381 3219 \n",
       "L 3381 2694 \n",
       "z\n",
       "M 3381 1303 \n",
       "L 356 1303 \n",
       "L 356 1828 \n",
       "L 3381 1828 \n",
       "L 3381 1303 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-2c\" d=\"M 569 0 \n",
       "L 569 641 \n",
       "L 1209 641 \n",
       "L 1209 0 \n",
       "Q 1209 -353 1084 -570 \n",
       "Q 959 -788 688 -906 \n",
       "L 531 -666 \n",
       "Q 709 -588 793 -436 \n",
       "Q 878 -284 888 0 \n",
       "L 569 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-20\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-70\" d=\"M 422 -1272 \n",
       "L 422 3319 \n",
       "L 934 3319 \n",
       "L 934 2888 \n",
       "Q 1116 3141 1344 3267 \n",
       "Q 1572 3394 1897 3394 \n",
       "Q 2322 3394 2647 3175 \n",
       "Q 2972 2956 3137 2557 \n",
       "Q 3303 2159 3303 1684 \n",
       "Q 3303 1175 3120 767 \n",
       "Q 2938 359 2589 142 \n",
       "Q 2241 -75 1856 -75 \n",
       "Q 1575 -75 1351 44 \n",
       "Q 1128 163 984 344 \n",
       "L 984 -1272 \n",
       "L 422 -1272 \n",
       "z\n",
       "M 931 1641 \n",
       "Q 931 1000 1190 694 \n",
       "Q 1450 388 1819 388 \n",
       "Q 2194 388 2461 705 \n",
       "Q 2728 1022 2728 1688 \n",
       "Q 2728 2322 2467 2637 \n",
       "Q 2206 2953 1844 2953 \n",
       "Q 1484 2953 1207 2617 \n",
       "Q 931 2281 931 1641 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-73\" d=\"M 197 991 \n",
       "L 753 1078 \n",
       "Q 800 744 1014 566 \n",
       "Q 1228 388 1613 388 \n",
       "Q 2000 388 2187 545 \n",
       "Q 2375 703 2375 916 \n",
       "Q 2375 1106 2209 1216 \n",
       "Q 2094 1291 1634 1406 \n",
       "Q 1016 1563 777 1677 \n",
       "Q 538 1791 414 1992 \n",
       "Q 291 2194 291 2438 \n",
       "Q 291 2659 392 2848 \n",
       "Q 494 3038 669 3163 \n",
       "Q 800 3259 1026 3326 \n",
       "Q 1253 3394 1513 3394 \n",
       "Q 1903 3394 2198 3281 \n",
       "Q 2494 3169 2634 2976 \n",
       "Q 2775 2784 2828 2463 \n",
       "L 2278 2388 \n",
       "Q 2241 2644 2061 2787 \n",
       "Q 1881 2931 1553 2931 \n",
       "Q 1166 2931 1000 2803 \n",
       "Q 834 2675 834 2503 \n",
       "Q 834 2394 903 2306 \n",
       "Q 972 2216 1119 2156 \n",
       "Q 1203 2125 1616 2013 \n",
       "Q 2213 1853 2448 1751 \n",
       "Q 2684 1650 2818 1456 \n",
       "Q 2953 1263 2953 975 \n",
       "Q 2953 694 2789 445 \n",
       "Q 2625 197 2315 61 \n",
       "Q 2006 -75 1616 -75 \n",
       "Q 969 -75 630 194 \n",
       "Q 291 463 197 991 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-69\" d=\"M 425 3934 \n",
       "L 425 4581 \n",
       "L 988 4581 \n",
       "L 988 3934 \n",
       "L 425 3934 \n",
       "z\n",
       "M 425 0 \n",
       "L 425 3319 \n",
       "L 988 3319 \n",
       "L 988 0 \n",
       "L 425 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "     </defs>\n",
       "     <use xlink:href=\"#ArialMT-4e\"/>\n",
       "     <use xlink:href=\"#ArialMT-3d\" x=\"72.216797\"/>\n",
       "     <use xlink:href=\"#ArialMT-31\" x=\"130.615234\"/>\n",
       "     <use xlink:href=\"#ArialMT-2c\" x=\"186.230469\"/>\n",
       "     <use xlink:href=\"#ArialMT-20\" x=\"214.013672\"/>\n",
       "     <use xlink:href=\"#ArialMT-70\" x=\"241.796875\"/>\n",
       "     <use xlink:href=\"#ArialMT-73\" x=\"297.412109\"/>\n",
       "     <use xlink:href=\"#ArialMT-69\" x=\"347.412109\"/>\n",
       "     <use xlink:href=\"#ArialMT-3d\" x=\"369.628906\"/>\n",
       "     <use xlink:href=\"#ArialMT-30\" x=\"428.027344\"/>\n",
       "     <use xlink:href=\"#ArialMT-2e\" x=\"483.642578\"/>\n",
       "     <use xlink:href=\"#ArialMT-31\" x=\"511.425781\"/>\n",
       "     <use xlink:href=\"#ArialMT-30\" x=\"567.041016\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"legend_1\">\n",
       "    <g id=\"line2d_16\">\n",
       "     <g>\n",
       "      <use xlink:href=\"#mbebab0d61a\" x=\"55.032875\" y=\"220.007125\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"text_16\">\n",
       "     <!-- Observations -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(70.872875 223.087125) scale(0.088 -0.088)\">\n",
       "      <defs>\n",
       "       <path id=\"ArialMT-4f\" d=\"M 309 2231 \n",
       "Q 309 3372 921 4017 \n",
       "Q 1534 4663 2503 4663 \n",
       "Q 3138 4663 3647 4359 \n",
       "Q 4156 4056 4423 3514 \n",
       "Q 4691 2972 4691 2284 \n",
       "Q 4691 1588 4409 1038 \n",
       "Q 4128 488 3612 205 \n",
       "Q 3097 -78 2500 -78 \n",
       "Q 1853 -78 1343 234 \n",
       "Q 834 547 571 1087 \n",
       "Q 309 1628 309 2231 \n",
       "z\n",
       "M 934 2222 \n",
       "Q 934 1394 1379 917 \n",
       "Q 1825 441 2497 441 \n",
       "Q 3181 441 3623 922 \n",
       "Q 4066 1403 4066 2288 \n",
       "Q 4066 2847 3877 3264 \n",
       "Q 3688 3681 3323 3911 \n",
       "Q 2959 4141 2506 4141 \n",
       "Q 1863 4141 1398 3698 \n",
       "Q 934 3256 934 2222 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-62\" d=\"M 941 0 \n",
       "L 419 0 \n",
       "L 419 4581 \n",
       "L 981 4581 \n",
       "L 981 2947 \n",
       "Q 1338 3394 1891 3394 \n",
       "Q 2197 3394 2470 3270 \n",
       "Q 2744 3147 2920 2923 \n",
       "Q 3097 2700 3197 2384 \n",
       "Q 3297 2069 3297 1709 \n",
       "Q 3297 856 2875 390 \n",
       "Q 2453 -75 1863 -75 \n",
       "Q 1275 -75 941 416 \n",
       "L 941 0 \n",
       "z\n",
       "M 934 1684 \n",
       "Q 934 1088 1097 822 \n",
       "Q 1363 388 1816 388 \n",
       "Q 2184 388 2453 708 \n",
       "Q 2722 1028 2722 1663 \n",
       "Q 2722 2313 2464 2622 \n",
       "Q 2206 2931 1841 2931 \n",
       "Q 1472 2931 1203 2611 \n",
       "Q 934 2291 934 1684 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-65\" d=\"M 2694 1069 \n",
       "L 3275 997 \n",
       "Q 3138 488 2766 206 \n",
       "Q 2394 -75 1816 -75 \n",
       "Q 1088 -75 661 373 \n",
       "Q 234 822 234 1631 \n",
       "Q 234 2469 665 2931 \n",
       "Q 1097 3394 1784 3394 \n",
       "Q 2450 3394 2872 2941 \n",
       "Q 3294 2488 3294 1666 \n",
       "Q 3294 1616 3291 1516 \n",
       "L 816 1516 \n",
       "Q 847 969 1125 678 \n",
       "Q 1403 388 1819 388 \n",
       "Q 2128 388 2347 550 \n",
       "Q 2566 713 2694 1069 \n",
       "z\n",
       "M 847 1978 \n",
       "L 2700 1978 \n",
       "Q 2663 2397 2488 2606 \n",
       "Q 2219 2931 1791 2931 \n",
       "Q 1403 2931 1139 2672 \n",
       "Q 875 2413 847 1978 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-72\" d=\"M 416 0 \n",
       "L 416 3319 \n",
       "L 922 3319 \n",
       "L 922 2816 \n",
       "Q 1116 3169 1280 3281 \n",
       "Q 1444 3394 1641 3394 \n",
       "Q 1925 3394 2219 3213 \n",
       "L 2025 2691 \n",
       "Q 1819 2813 1613 2813 \n",
       "Q 1428 2813 1281 2702 \n",
       "Q 1134 2591 1072 2394 \n",
       "Q 978 2094 978 1738 \n",
       "L 978 0 \n",
       "L 416 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-76\" d=\"M 1344 0 \n",
       "L 81 3319 \n",
       "L 675 3319 \n",
       "L 1388 1331 \n",
       "Q 1503 1009 1600 663 \n",
       "Q 1675 925 1809 1294 \n",
       "L 2547 3319 \n",
       "L 3125 3319 \n",
       "L 1869 0 \n",
       "L 1344 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-61\" d=\"M 2588 409 \n",
       "Q 2275 144 1986 34 \n",
       "Q 1697 -75 1366 -75 \n",
       "Q 819 -75 525 192 \n",
       "Q 231 459 231 875 \n",
       "Q 231 1119 342 1320 \n",
       "Q 453 1522 633 1644 \n",
       "Q 813 1766 1038 1828 \n",
       "Q 1203 1872 1538 1913 \n",
       "Q 2219 1994 2541 2106 \n",
       "Q 2544 2222 2544 2253 \n",
       "Q 2544 2597 2384 2738 \n",
       "Q 2169 2928 1744 2928 \n",
       "Q 1347 2928 1158 2789 \n",
       "Q 969 2650 878 2297 \n",
       "L 328 2372 \n",
       "Q 403 2725 575 2942 \n",
       "Q 747 3159 1072 3276 \n",
       "Q 1397 3394 1825 3394 \n",
       "Q 2250 3394 2515 3294 \n",
       "Q 2781 3194 2906 3042 \n",
       "Q 3031 2891 3081 2659 \n",
       "Q 3109 2516 3109 2141 \n",
       "L 3109 1391 \n",
       "Q 3109 606 3145 398 \n",
       "Q 3181 191 3288 0 \n",
       "L 2700 0 \n",
       "Q 2613 175 2588 409 \n",
       "z\n",
       "M 2541 1666 \n",
       "Q 2234 1541 1622 1453 \n",
       "Q 1275 1403 1131 1340 \n",
       "Q 988 1278 909 1158 \n",
       "Q 831 1038 831 891 \n",
       "Q 831 666 1001 516 \n",
       "Q 1172 366 1500 366 \n",
       "Q 1825 366 2078 508 \n",
       "Q 2331 650 2450 897 \n",
       "Q 2541 1088 2541 1459 \n",
       "L 2541 1666 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-74\" d=\"M 1650 503 \n",
       "L 1731 6 \n",
       "Q 1494 -44 1306 -44 \n",
       "Q 1000 -44 831 53 \n",
       "Q 663 150 594 308 \n",
       "Q 525 466 525 972 \n",
       "L 525 2881 \n",
       "L 113 2881 \n",
       "L 113 3319 \n",
       "L 525 3319 \n",
       "L 525 4141 \n",
       "L 1084 4478 \n",
       "L 1084 3319 \n",
       "L 1650 3319 \n",
       "L 1650 2881 \n",
       "L 1084 2881 \n",
       "L 1084 941 \n",
       "Q 1084 700 1114 631 \n",
       "Q 1144 563 1211 522 \n",
       "Q 1278 481 1403 481 \n",
       "Q 1497 481 1650 503 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-6f\" d=\"M 213 1659 \n",
       "Q 213 2581 725 3025 \n",
       "Q 1153 3394 1769 3394 \n",
       "Q 2453 3394 2887 2945 \n",
       "Q 3322 2497 3322 1706 \n",
       "Q 3322 1066 3130 698 \n",
       "Q 2938 331 2570 128 \n",
       "Q 2203 -75 1769 -75 \n",
       "Q 1072 -75 642 372 \n",
       "Q 213 819 213 1659 \n",
       "z\n",
       "M 791 1659 \n",
       "Q 791 1022 1069 705 \n",
       "Q 1347 388 1769 388 \n",
       "Q 2188 388 2466 706 \n",
       "Q 2744 1025 2744 1678 \n",
       "Q 2744 2294 2464 2611 \n",
       "Q 2184 2928 1769 2928 \n",
       "Q 1347 2928 1069 2612 \n",
       "Q 791 2297 791 1659 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-6e\" d=\"M 422 0 \n",
       "L 422 3319 \n",
       "L 928 3319 \n",
       "L 928 2847 \n",
       "Q 1294 3394 1984 3394 \n",
       "Q 2284 3394 2536 3286 \n",
       "Q 2788 3178 2913 3003 \n",
       "Q 3038 2828 3088 2588 \n",
       "Q 3119 2431 3119 2041 \n",
       "L 3119 0 \n",
       "L 2556 0 \n",
       "L 2556 2019 \n",
       "Q 2556 2363 2490 2533 \n",
       "Q 2425 2703 2258 2804 \n",
       "Q 2091 2906 1866 2906 \n",
       "Q 1506 2906 1245 2678 \n",
       "Q 984 2450 984 1813 \n",
       "L 984 0 \n",
       "L 422 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#ArialMT-4f\"/>\n",
       "      <use xlink:href=\"#ArialMT-62\" x=\"77.783203\"/>\n",
       "      <use xlink:href=\"#ArialMT-73\" x=\"133.398438\"/>\n",
       "      <use xlink:href=\"#ArialMT-65\" x=\"183.398438\"/>\n",
       "      <use xlink:href=\"#ArialMT-72\" x=\"239.013672\"/>\n",
       "      <use xlink:href=\"#ArialMT-76\" x=\"272.314453\"/>\n",
       "      <use xlink:href=\"#ArialMT-61\" x=\"322.314453\"/>\n",
       "      <use xlink:href=\"#ArialMT-74\" x=\"377.929688\"/>\n",
       "      <use xlink:href=\"#ArialMT-69\" x=\"405.712891\"/>\n",
       "      <use xlink:href=\"#ArialMT-6f\" x=\"427.929688\"/>\n",
       "      <use xlink:href=\"#ArialMT-6e\" x=\"483.544922\"/>\n",
       "      <use xlink:href=\"#ArialMT-73\" x=\"539.160156\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"line2d_17\">\n",
       "     <path d=\"M 46.232875 232.591125 \n",
       "L 55.032875 232.591125 \n",
       "L 63.832875 232.591125 \n",
       "\" style=\"fill: none; stroke: #1f77b4; stroke-width: 2; stroke-linecap: round\"/>\n",
       "    </g>\n",
       "    <g id=\"text_17\">\n",
       "     <!-- $m_n(x)$ -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(70.872875 235.671125) scale(0.088 -0.088)\">\n",
       "      <defs>\n",
       "       <path id=\"DejaVuSans-Oblique-6d\" d=\"M 5747 2113 \n",
       "L 5338 0 \n",
       "L 4763 0 \n",
       "L 5166 2094 \n",
       "Q 5191 2228 5203 2325 \n",
       "Q 5216 2422 5216 2491 \n",
       "Q 5216 2772 5059 2928 \n",
       "Q 4903 3084 4622 3084 \n",
       "Q 4203 3084 3875 2770 \n",
       "Q 3547 2456 3450 1953 \n",
       "L 3066 0 \n",
       "L 2491 0 \n",
       "L 2900 2094 \n",
       "Q 2925 2209 2937 2307 \n",
       "Q 2950 2406 2950 2484 \n",
       "Q 2950 2769 2794 2926 \n",
       "Q 2638 3084 2363 3084 \n",
       "Q 1938 3084 1609 2770 \n",
       "Q 1281 2456 1184 1953 \n",
       "L 800 0 \n",
       "L 225 0 \n",
       "L 909 3500 \n",
       "L 1484 3500 \n",
       "L 1375 2956 \n",
       "Q 1609 3263 1923 3423 \n",
       "Q 2238 3584 2597 3584 \n",
       "Q 2978 3584 3223 3384 \n",
       "Q 3469 3184 3519 2828 \n",
       "Q 3781 3197 4126 3390 \n",
       "Q 4472 3584 4856 3584 \n",
       "Q 5306 3584 5551 3325 \n",
       "Q 5797 3066 5797 2591 \n",
       "Q 5797 2488 5784 2364 \n",
       "Q 5772 2241 5747 2113 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-Oblique-6e\" d=\"M 3566 2113 \n",
       "L 3156 0 \n",
       "L 2578 0 \n",
       "L 2988 2091 \n",
       "Q 3016 2238 3031 2350 \n",
       "Q 3047 2463 3047 2528 \n",
       "Q 3047 2791 2881 2937 \n",
       "Q 2716 3084 2419 3084 \n",
       "Q 1956 3084 1622 2776 \n",
       "Q 1288 2469 1184 1941 \n",
       "L 800 0 \n",
       "L 225 0 \n",
       "L 903 3500 \n",
       "L 1478 3500 \n",
       "L 1363 2950 \n",
       "Q 1603 3253 1940 3418 \n",
       "Q 2278 3584 2650 3584 \n",
       "Q 3113 3584 3367 3334 \n",
       "Q 3622 3084 3622 2631 \n",
       "Q 3622 2519 3608 2391 \n",
       "Q 3594 2263 3566 2113 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-28\" d=\"M 1984 4856 \n",
       "Q 1566 4138 1362 3434 \n",
       "Q 1159 2731 1159 2009 \n",
       "Q 1159 1288 1364 580 \n",
       "Q 1569 -128 1984 -844 \n",
       "L 1484 -844 \n",
       "Q 1016 -109 783 600 \n",
       "Q 550 1309 550 2009 \n",
       "Q 550 2706 781 3412 \n",
       "Q 1013 4119 1484 4856 \n",
       "L 1984 4856 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-29\" d=\"M 513 4856 \n",
       "L 1013 4856 \n",
       "Q 1481 4119 1714 3412 \n",
       "Q 1947 2706 1947 2009 \n",
       "Q 1947 1309 1714 600 \n",
       "Q 1481 -109 1013 -844 \n",
       "L 513 -844 \n",
       "Q 928 -128 1133 580 \n",
       "Q 1338 1288 1338 2009 \n",
       "Q 1338 2731 1133 3434 \n",
       "Q 928 4138 513 4856 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-6d\" transform=\"translate(0 0.125)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-6e\" transform=\"translate(97.412109 -16.28125) scale(0.7)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-28\" transform=\"translate(144.511719 0.125)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-78\" transform=\"translate(183.525391 0.125)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-29\" transform=\"translate(242.705078 0.125)\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"patch_5\">\n",
       "     <path d=\"M 46.232875 249.828125 \n",
       "L 63.832875 249.828125 \n",
       "L 63.832875 243.668125 \n",
       "L 46.232875 243.668125 \n",
       "z\n",
       "\" style=\"fill: #1f77b4; fill-opacity: 0.5; stroke: #1f77b4; stroke-opacity: 0.5; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "    </g>\n",
       "    <g id=\"text_18\">\n",
       "     <!-- $f(\\mathbf{x}^*)$ 95% pred. -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(70.872875 249.828125) scale(0.088 -0.088)\">\n",
       "      <defs>\n",
       "       <path id=\"DejaVuSans-Oblique-66\" d=\"M 3059 4863 \n",
       "L 2969 4384 \n",
       "L 2419 4384 \n",
       "Q 2106 4384 1964 4261 \n",
       "Q 1822 4138 1753 3809 \n",
       "L 1691 3500 \n",
       "L 2638 3500 \n",
       "L 2553 3053 \n",
       "L 1606 3053 \n",
       "L 1013 0 \n",
       "L 434 0 \n",
       "L 1031 3053 \n",
       "L 481 3053 \n",
       "L 563 3500 \n",
       "L 1113 3500 \n",
       "L 1159 3744 \n",
       "Q 1278 4363 1576 4613 \n",
       "Q 1875 4863 2516 4863 \n",
       "L 3059 4863 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-Bold-78\" d=\"M 1422 1791 \n",
       "L 159 3500 \n",
       "L 1344 3500 \n",
       "L 2059 2463 \n",
       "L 2784 3500 \n",
       "L 3969 3500 \n",
       "L 2706 1797 \n",
       "L 4031 0 \n",
       "L 2847 0 \n",
       "L 2059 1106 \n",
       "L 1281 0 \n",
       "L 97 0 \n",
       "L 1422 1791 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-2a\" d=\"M 3009 3897 \n",
       "L 1888 3291 \n",
       "L 3009 2681 \n",
       "L 2828 2375 \n",
       "L 1778 3009 \n",
       "L 1778 1831 \n",
       "L 1422 1831 \n",
       "L 1422 3009 \n",
       "L 372 2375 \n",
       "L 191 2681 \n",
       "L 1313 3291 \n",
       "L 191 3897 \n",
       "L 372 4206 \n",
       "L 1422 3572 \n",
       "L 1422 4750 \n",
       "L 1778 4750 \n",
       "L 1778 3572 \n",
       "L 2828 4206 \n",
       "L 3009 3897 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-39\" d=\"M 350 1059 \n",
       "L 891 1109 \n",
       "Q 959 728 1153 556 \n",
       "Q 1347 384 1650 384 \n",
       "Q 1909 384 2104 503 \n",
       "Q 2300 622 2425 820 \n",
       "Q 2550 1019 2634 1356 \n",
       "Q 2719 1694 2719 2044 \n",
       "Q 2719 2081 2716 2156 \n",
       "Q 2547 1888 2255 1720 \n",
       "Q 1963 1553 1622 1553 \n",
       "Q 1053 1553 659 1965 \n",
       "Q 266 2378 266 3053 \n",
       "Q 266 3750 677 4175 \n",
       "Q 1088 4600 1706 4600 \n",
       "Q 2153 4600 2523 4359 \n",
       "Q 2894 4119 3086 3673 \n",
       "Q 3278 3228 3278 2384 \n",
       "Q 3278 1506 3087 986 \n",
       "Q 2897 466 2520 194 \n",
       "Q 2144 -78 1638 -78 \n",
       "Q 1100 -78 759 220 \n",
       "Q 419 519 350 1059 \n",
       "z\n",
       "M 2653 3081 \n",
       "Q 2653 3566 2395 3850 \n",
       "Q 2138 4134 1775 4134 \n",
       "Q 1400 4134 1122 3828 \n",
       "Q 844 3522 844 3034 \n",
       "Q 844 2597 1108 2323 \n",
       "Q 1372 2050 1759 2050 \n",
       "Q 2150 2050 2401 2323 \n",
       "Q 2653 2597 2653 3081 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-35\" d=\"M 266 1200 \n",
       "L 856 1250 \n",
       "Q 922 819 1161 601 \n",
       "Q 1400 384 1738 384 \n",
       "Q 2144 384 2425 690 \n",
       "Q 2706 997 2706 1503 \n",
       "Q 2706 1984 2436 2262 \n",
       "Q 2166 2541 1728 2541 \n",
       "Q 1456 2541 1237 2417 \n",
       "Q 1019 2294 894 2097 \n",
       "L 366 2166 \n",
       "L 809 4519 \n",
       "L 3088 4519 \n",
       "L 3088 3981 \n",
       "L 1259 3981 \n",
       "L 1013 2750 \n",
       "Q 1425 3038 1878 3038 \n",
       "Q 2478 3038 2890 2622 \n",
       "Q 3303 2206 3303 1553 \n",
       "Q 3303 931 2941 478 \n",
       "Q 2500 -78 1738 -78 \n",
       "Q 1113 -78 717 272 \n",
       "Q 322 622 266 1200 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-25\" d=\"M 372 3481 \n",
       "Q 372 3972 619 4315 \n",
       "Q 866 4659 1334 4659 \n",
       "Q 1766 4659 2048 4351 \n",
       "Q 2331 4044 2331 3447 \n",
       "Q 2331 2866 2045 2552 \n",
       "Q 1759 2238 1341 2238 \n",
       "Q 925 2238 648 2547 \n",
       "Q 372 2856 372 3481 \n",
       "z\n",
       "M 1350 4272 \n",
       "Q 1141 4272 1002 4090 \n",
       "Q 863 3909 863 3425 \n",
       "Q 863 2984 1003 2804 \n",
       "Q 1144 2625 1350 2625 \n",
       "Q 1563 2625 1702 2806 \n",
       "Q 1841 2988 1841 3469 \n",
       "Q 1841 3913 1700 4092 \n",
       "Q 1559 4272 1350 4272 \n",
       "z\n",
       "M 1353 -169 \n",
       "L 3859 4659 \n",
       "L 4316 4659 \n",
       "L 1819 -169 \n",
       "L 1353 -169 \n",
       "z\n",
       "M 3334 1075 \n",
       "Q 3334 1569 3581 1911 \n",
       "Q 3828 2253 4300 2253 \n",
       "Q 4731 2253 5014 1945 \n",
       "Q 5297 1638 5297 1041 \n",
       "Q 5297 459 5011 145 \n",
       "Q 4725 -169 4303 -169 \n",
       "Q 3888 -169 3611 142 \n",
       "Q 3334 453 3334 1075 \n",
       "z\n",
       "M 4316 1866 \n",
       "Q 4103 1866 3964 1684 \n",
       "Q 3825 1503 3825 1019 \n",
       "Q 3825 581 3965 400 \n",
       "Q 4106 219 4313 219 \n",
       "Q 4528 219 4667 400 \n",
       "Q 4806 581 4806 1063 \n",
       "Q 4806 1506 4665 1686 \n",
       "Q 4525 1866 4316 1866 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-64\" d=\"M 2575 0 \n",
       "L 2575 419 \n",
       "Q 2259 -75 1647 -75 \n",
       "Q 1250 -75 917 144 \n",
       "Q 584 363 401 755 \n",
       "Q 219 1147 219 1656 \n",
       "Q 219 2153 384 2558 \n",
       "Q 550 2963 881 3178 \n",
       "Q 1213 3394 1622 3394 \n",
       "Q 1922 3394 2156 3267 \n",
       "Q 2391 3141 2538 2938 \n",
       "L 2538 4581 \n",
       "L 3097 4581 \n",
       "L 3097 0 \n",
       "L 2575 0 \n",
       "z\n",
       "M 797 1656 \n",
       "Q 797 1019 1065 703 \n",
       "Q 1334 388 1700 388 \n",
       "Q 2069 388 2326 689 \n",
       "Q 2584 991 2584 1609 \n",
       "Q 2584 2291 2321 2609 \n",
       "Q 2059 2928 1675 2928 \n",
       "Q 1300 2928 1048 2622 \n",
       "Q 797 2316 797 1656 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-66\" transform=\"translate(0 0.765625)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-28\" transform=\"translate(35.205078 0.765625)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-Bold-78\" transform=\"translate(74.21875 0.765625)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-2a\" transform=\"translate(153.31543 39.046875) scale(0.7)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-29\" transform=\"translate(204.6875 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" transform=\"translate(243.701172 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-39\" transform=\"translate(271.484375 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-35\" transform=\"translate(327.099609 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-25\" transform=\"translate(382.714844 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" transform=\"translate(471.630859 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-70\" transform=\"translate(499.414062 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-72\" transform=\"translate(555.029297 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-65\" transform=\"translate(588.330078 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-64\" transform=\"translate(643.945312 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-2e\" transform=\"translate(699.560547 0.765625)\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"patch_6\">\n",
       "     <path d=\"M 46.232875 263.996125 \n",
       "L 63.832875 263.996125 \n",
       "L 63.832875 257.836125 \n",
       "L 46.232875 257.836125 \n",
       "z\n",
       "\" style=\"fill: #ff7f0e; fill-opacity: 0.5; stroke: #ff7f0e; stroke-opacity: 0.5; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "    </g>\n",
       "    <g id=\"text_19\">\n",
       "     <!-- $y^*$ 95% pred. -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(70.872875 263.996125) scale(0.088 -0.088)\">\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-79\" transform=\"translate(0 0.765625)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-2a\" transform=\"translate(77.283529 39.046875) scale(0.7)\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" transform=\"translate(128.655599 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-39\" transform=\"translate(156.438802 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-35\" transform=\"translate(212.054036 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-25\" transform=\"translate(267.669271 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" transform=\"translate(356.585286 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-70\" transform=\"translate(384.36849 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-72\" transform=\"translate(439.983724 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-65\" transform=\"translate(473.284505 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-64\" transform=\"translate(528.89974 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-2e\" transform=\"translate(584.514974 0.765625)\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"line2d_18\">\n",
       "     <path d=\"M 46.232875 273.463 \n",
       "L 55.032875 273.463 \n",
       "L 63.832875 273.463 \n",
       "\" style=\"fill: none; stroke-dasharray: 7.68,1.92,1.2,1.92; stroke-dashoffset: 0; stroke: #bf00bf; stroke-width: 1.2\"/>\n",
       "    </g>\n",
       "    <g id=\"text_20\">\n",
       "     <!-- True function -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(70.872875 276.543) scale(0.088 -0.088)\">\n",
       "      <defs>\n",
       "       <path id=\"ArialMT-54\" d=\"M 1659 0 \n",
       "L 1659 4041 \n",
       "L 150 4041 \n",
       "L 150 4581 \n",
       "L 3781 4581 \n",
       "L 3781 4041 \n",
       "L 2266 4041 \n",
       "L 2266 0 \n",
       "L 1659 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-75\" d=\"M 2597 0 \n",
       "L 2597 488 \n",
       "Q 2209 -75 1544 -75 \n",
       "Q 1250 -75 995 37 \n",
       "Q 741 150 617 320 \n",
       "Q 494 491 444 738 \n",
       "Q 409 903 409 1263 \n",
       "L 409 3319 \n",
       "L 972 3319 \n",
       "L 972 1478 \n",
       "Q 972 1038 1006 884 \n",
       "Q 1059 663 1231 536 \n",
       "Q 1403 409 1656 409 \n",
       "Q 1909 409 2131 539 \n",
       "Q 2353 669 2445 892 \n",
       "Q 2538 1116 2538 1541 \n",
       "L 2538 3319 \n",
       "L 3100 3319 \n",
       "L 3100 0 \n",
       "L 2597 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-66\" d=\"M 556 0 \n",
       "L 556 2881 \n",
       "L 59 2881 \n",
       "L 59 3319 \n",
       "L 556 3319 \n",
       "L 556 3672 \n",
       "Q 556 4006 616 4169 \n",
       "Q 697 4388 901 4523 \n",
       "Q 1106 4659 1475 4659 \n",
       "Q 1713 4659 2000 4603 \n",
       "L 1916 4113 \n",
       "Q 1741 4144 1584 4144 \n",
       "Q 1328 4144 1222 4034 \n",
       "Q 1116 3925 1116 3625 \n",
       "L 1116 3319 \n",
       "L 1763 3319 \n",
       "L 1763 2881 \n",
       "L 1116 2881 \n",
       "L 1116 0 \n",
       "L 556 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-63\" d=\"M 2588 1216 \n",
       "L 3141 1144 \n",
       "Q 3050 572 2676 248 \n",
       "Q 2303 -75 1759 -75 \n",
       "Q 1078 -75 664 370 \n",
       "Q 250 816 250 1647 \n",
       "Q 250 2184 428 2587 \n",
       "Q 606 2991 970 3192 \n",
       "Q 1334 3394 1763 3394 \n",
       "Q 2303 3394 2647 3120 \n",
       "Q 2991 2847 3088 2344 \n",
       "L 2541 2259 \n",
       "Q 2463 2594 2264 2762 \n",
       "Q 2066 2931 1784 2931 \n",
       "Q 1359 2931 1093 2626 \n",
       "Q 828 2322 828 1663 \n",
       "Q 828 994 1084 691 \n",
       "Q 1341 388 1753 388 \n",
       "Q 2084 388 2306 591 \n",
       "Q 2528 794 2588 1216 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#ArialMT-54\"/>\n",
       "      <use xlink:href=\"#ArialMT-72\" x=\"57.333984\"/>\n",
       "      <use xlink:href=\"#ArialMT-75\" x=\"90.634766\"/>\n",
       "      <use xlink:href=\"#ArialMT-65\" x=\"146.25\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" x=\"201.865234\"/>\n",
       "      <use xlink:href=\"#ArialMT-66\" x=\"229.648438\"/>\n",
       "      <use xlink:href=\"#ArialMT-75\" x=\"257.431641\"/>\n",
       "      <use xlink:href=\"#ArialMT-6e\" x=\"313.046875\"/>\n",
       "      <use xlink:href=\"#ArialMT-63\" x=\"368.662109\"/>\n",
       "      <use xlink:href=\"#ArialMT-74\" x=\"418.662109\"/>\n",
       "      <use xlink:href=\"#ArialMT-69\" x=\"446.445312\"/>\n",
       "      <use xlink:href=\"#ArialMT-6f\" x=\"468.662109\"/>\n",
       "      <use xlink:href=\"#ArialMT-6e\" x=\"524.277344\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "  </g>\n",
       "  <g id=\"axes_2\">\n",
       "   <g id=\"matplotlib.axis_3\">\n",
       "    <g id=\"ytick_7\">\n",
       "     <g id=\"line2d_19\">\n",
       "      <defs>\n",
       "       <path id=\"me155e087b7\" d=\"M 0 0 \n",
       "L 4.8 0 \n",
       "\" style=\"stroke: #262626\"/>\n",
       "      </defs>\n",
       "      <g>\n",
       "       <use xlink:href=\"#me155e087b7\" x=\"395.432875\" y=\"274.116\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_21\">\n",
       "      <!-- 0.0 -->\n",
       "      <g style=\"fill: #ff7f0e\" transform=\"translate(403.732875 277.265437) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_8\">\n",
       "     <g id=\"line2d_20\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#me155e087b7\" x=\"395.432875\" y=\"221.455599\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_22\">\n",
       "      <!-- 0.1 -->\n",
       "      <g style=\"fill: #ff7f0e\" transform=\"translate(403.732875 224.605036) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-31\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_9\">\n",
       "     <g id=\"line2d_21\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#me155e087b7\" x=\"395.432875\" y=\"168.795197\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_23\">\n",
       "      <!-- 0.2 -->\n",
       "      <g style=\"fill: #ff7f0e\" transform=\"translate(403.732875 171.944635) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-32\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_10\">\n",
       "     <g id=\"line2d_22\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#me155e087b7\" x=\"395.432875\" y=\"116.134796\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_24\">\n",
       "      <!-- 0.3 -->\n",
       "      <g style=\"fill: #ff7f0e\" transform=\"translate(403.732875 119.284233) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-33\" d=\"M 269 1209 \n",
       "L 831 1284 \n",
       "Q 928 806 1161 595 \n",
       "Q 1394 384 1728 384 \n",
       "Q 2125 384 2398 659 \n",
       "Q 2672 934 2672 1341 \n",
       "Q 2672 1728 2419 1979 \n",
       "Q 2166 2231 1775 2231 \n",
       "Q 1616 2231 1378 2169 \n",
       "L 1441 2663 \n",
       "Q 1497 2656 1531 2656 \n",
       "Q 1891 2656 2178 2843 \n",
       "Q 2466 3031 2466 3422 \n",
       "Q 2466 3731 2256 3934 \n",
       "Q 2047 4138 1716 4138 \n",
       "Q 1388 4138 1169 3931 \n",
       "Q 950 3725 888 3313 \n",
       "L 325 3413 \n",
       "Q 428 3978 793 4289 \n",
       "Q 1159 4600 1703 4600 \n",
       "Q 2078 4600 2393 4439 \n",
       "Q 2709 4278 2876 4000 \n",
       "Q 3044 3722 3044 3409 \n",
       "Q 3044 3113 2884 2869 \n",
       "Q 2725 2625 2413 2481 \n",
       "Q 2819 2388 3044 2092 \n",
       "Q 3269 1797 3269 1353 \n",
       "Q 3269 753 2831 336 \n",
       "Q 2394 -81 1725 -81 \n",
       "Q 1122 -81 723 278 \n",
       "Q 325 638 269 1209 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-33\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_11\">\n",
       "     <g id=\"line2d_23\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#me155e087b7\" x=\"395.432875\" y=\"63.474394\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_25\">\n",
       "      <!-- 0.4 -->\n",
       "      <g style=\"fill: #ff7f0e\" transform=\"translate(403.732875 66.623832) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-34\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"text_26\">\n",
       "     <!-- Information Acquisition Function -->\n",
       "     <g style=\"fill: #ff7f0e\" transform=\"translate(426.953375 221.18925) rotate(-90) scale(0.096 -0.096)\">\n",
       "      <defs>\n",
       "       <path id=\"ArialMT-49\" d=\"M 597 0 \n",
       "L 597 4581 \n",
       "L 1203 4581 \n",
       "L 1203 0 \n",
       "L 597 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-6d\" d=\"M 422 0 \n",
       "L 422 3319 \n",
       "L 925 3319 \n",
       "L 925 2853 \n",
       "Q 1081 3097 1340 3245 \n",
       "Q 1600 3394 1931 3394 \n",
       "Q 2300 3394 2536 3241 \n",
       "Q 2772 3088 2869 2813 \n",
       "Q 3263 3394 3894 3394 \n",
       "Q 4388 3394 4653 3120 \n",
       "Q 4919 2847 4919 2278 \n",
       "L 4919 0 \n",
       "L 4359 0 \n",
       "L 4359 2091 \n",
       "Q 4359 2428 4304 2576 \n",
       "Q 4250 2725 4106 2815 \n",
       "Q 3963 2906 3769 2906 \n",
       "Q 3419 2906 3187 2673 \n",
       "Q 2956 2441 2956 1928 \n",
       "L 2956 0 \n",
       "L 2394 0 \n",
       "L 2394 2156 \n",
       "Q 2394 2531 2256 2718 \n",
       "Q 2119 2906 1806 2906 \n",
       "Q 1569 2906 1367 2781 \n",
       "Q 1166 2656 1075 2415 \n",
       "Q 984 2175 984 1722 \n",
       "L 984 0 \n",
       "L 422 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-41\" d=\"M -9 0 \n",
       "L 1750 4581 \n",
       "L 2403 4581 \n",
       "L 4278 0 \n",
       "L 3588 0 \n",
       "L 3053 1388 \n",
       "L 1138 1388 \n",
       "L 634 0 \n",
       "L -9 0 \n",
       "z\n",
       "M 1313 1881 \n",
       "L 2866 1881 \n",
       "L 2388 3150 \n",
       "Q 2169 3728 2063 4100 \n",
       "Q 1975 3659 1816 3225 \n",
       "L 1313 1881 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-71\" d=\"M 2538 -1272 \n",
       "L 2538 353 \n",
       "Q 2406 169 2170 47 \n",
       "Q 1934 -75 1669 -75 \n",
       "Q 1078 -75 651 397 \n",
       "Q 225 869 225 1691 \n",
       "Q 225 2191 398 2587 \n",
       "Q 572 2984 901 3189 \n",
       "Q 1231 3394 1625 3394 \n",
       "Q 2241 3394 2594 2875 \n",
       "L 2594 3319 \n",
       "L 3100 3319 \n",
       "L 3100 -1272 \n",
       "L 2538 -1272 \n",
       "z\n",
       "M 803 1669 \n",
       "Q 803 1028 1072 708 \n",
       "Q 1341 388 1716 388 \n",
       "Q 2075 388 2334 692 \n",
       "Q 2594 997 2594 1619 \n",
       "Q 2594 2281 2320 2615 \n",
       "Q 2047 2950 1678 2950 \n",
       "Q 1313 2950 1058 2639 \n",
       "Q 803 2328 803 1669 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-46\" d=\"M 525 0 \n",
       "L 525 4581 \n",
       "L 3616 4581 \n",
       "L 3616 4041 \n",
       "L 1131 4041 \n",
       "L 1131 2622 \n",
       "L 3281 2622 \n",
       "L 3281 2081 \n",
       "L 1131 2081 \n",
       "L 1131 0 \n",
       "L 525 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#ArialMT-49\"/>\n",
       "      <use xlink:href=\"#ArialMT-6e\" x=\"27.783203\"/>\n",
       "      <use xlink:href=\"#ArialMT-66\" x=\"83.398438\"/>\n",
       "      <use xlink:href=\"#ArialMT-6f\" x=\"111.181641\"/>\n",
       "      <use xlink:href=\"#ArialMT-72\" x=\"166.796875\"/>\n",
       "      <use xlink:href=\"#ArialMT-6d\" x=\"200.097656\"/>\n",
       "      <use xlink:href=\"#ArialMT-61\" x=\"283.398438\"/>\n",
       "      <use xlink:href=\"#ArialMT-74\" x=\"339.013672\"/>\n",
       "      <use xlink:href=\"#ArialMT-69\" x=\"366.796875\"/>\n",
       "      <use xlink:href=\"#ArialMT-6f\" x=\"389.013672\"/>\n",
       "      <use xlink:href=\"#ArialMT-6e\" x=\"444.628906\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" x=\"500.244141\"/>\n",
       "      <use xlink:href=\"#ArialMT-41\" x=\"522.527344\"/>\n",
       "      <use xlink:href=\"#ArialMT-63\" x=\"589.226562\"/>\n",
       "      <use xlink:href=\"#ArialMT-71\" x=\"639.226562\"/>\n",
       "      <use xlink:href=\"#ArialMT-75\" x=\"694.841797\"/>\n",
       "      <use xlink:href=\"#ArialMT-69\" x=\"750.457031\"/>\n",
       "      <use xlink:href=\"#ArialMT-73\" x=\"772.673828\"/>\n",
       "      <use xlink:href=\"#ArialMT-69\" x=\"822.673828\"/>\n",
       "      <use xlink:href=\"#ArialMT-74\" x=\"844.890625\"/>\n",
       "      <use xlink:href=\"#ArialMT-69\" x=\"872.673828\"/>\n",
       "      <use xlink:href=\"#ArialMT-6f\" x=\"894.890625\"/>\n",
       "      <use xlink:href=\"#ArialMT-6e\" x=\"950.505859\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" x=\"1006.121094\"/>\n",
       "      <use xlink:href=\"#ArialMT-46\" x=\"1033.904297\"/>\n",
       "      <use xlink:href=\"#ArialMT-75\" x=\"1094.988281\"/>\n",
       "      <use xlink:href=\"#ArialMT-6e\" x=\"1150.603516\"/>\n",
       "      <use xlink:href=\"#ArialMT-63\" x=\"1206.21875\"/>\n",
       "      <use xlink:href=\"#ArialMT-74\" x=\"1256.21875\"/>\n",
       "      <use xlink:href=\"#ArialMT-69\" x=\"1284.001953\"/>\n",
       "      <use xlink:href=\"#ArialMT-6f\" x=\"1306.21875\"/>\n",
       "      <use xlink:href=\"#ArialMT-6e\" x=\"1361.833984\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"line2d_24\">\n",
       "    <path d=\"M 54.545602 115.613795 \n",
       "L 57.824941 125.119209 \n",
       "L 61.10428 135.315773 \n",
       "L 64.383619 146.21965 \n",
       "L 67.662958 157.830716 \n",
       "L 70.942296 170.1232 \n",
       "L 74.221636 183.031738 \n",
       "L 77.500973 196.432471 \n",
       "L 80.780313 210.119087 \n",
       "L 84.059653 223.773311 \n",
       "L 87.33899 236.93143 \n",
       "L 90.61833 248.974223 \n",
       "L 93.89767 259.158294 \n",
       "L 97.177007 266.765375 \n",
       "L 100.456344 271.423502 \n",
       "L 103.735686 273.489259 \n",
       "L 107.015024 274.039429 \n",
       "L 110.294361 274.110711 \n",
       "L 113.573703 274.115215 \n",
       "L 116.853041 274.113332 \n",
       "L 120.132378 274.033183 \n",
       "L 123.41172 272.484857 \n",
       "L 126.691057 263.389026 \n",
       "L 129.970395 241.825972 \n",
       "L 133.249737 213.689509 \n",
       "L 136.529069 191.274301 \n",
       "L 139.808412 186.258727 \n",
       "L 143.087754 205.903877 \n",
       "L 146.367086 243.100719 \n",
       "L 149.646428 268.558951 \n",
       "L 152.92577 273.676505 \n",
       "L 156.205103 274.058136 \n",
       "L 159.484445 274.09315 \n",
       "L 162.763787 274.100604 \n",
       "L 166.04312 274.104528 \n",
       "L 169.322462 274.107902 \n",
       "L 172.601804 274.110805 \n",
       "L 175.881137 274.113018 \n",
       "L 179.160479 274.114478 \n",
       "L 182.439821 274.115325 \n",
       "L 185.719153 274.115749 \n",
       "L 188.998496 274.115922 \n",
       "L 192.277838 274.115984 \n",
       "L 195.55717 274.116 \n",
       "L 198.836512 274.116 \n",
       "L 202.115855 274.116 \n",
       "L 205.395187 274.116 \n",
       "L 208.674529 274.116 \n",
       "L 211.953871 274.116 \n",
       "L 215.233204 274.116 \n",
       "L 218.512556 274.116 \n",
       "L 221.791879 274.116 \n",
       "L 225.071221 274.116 \n",
       "L 228.350563 274.116 \n",
       "L 231.629886 274.116 \n",
       "L 234.909247 274.116 \n",
       "L 238.18857 274.116 \n",
       "L 241.467912 274.116 \n",
       "L 244.747254 274.116 \n",
       "L 248.026597 274.116 \n",
       "L 251.305939 274.116 \n",
       "L 254.585262 274.116 \n",
       "L 257.864623 274.116 \n",
       "L 261.143946 274.116 \n",
       "L 264.423288 274.116 \n",
       "L 267.70263 274.115969 \n",
       "L 270.981953 274.115215 \n",
       "L 274.261315 274.106976 \n",
       "L 277.540637 274.059188 \n",
       "L 280.81998 273.882379 \n",
       "L 284.099322 273.409377 \n",
       "L 287.378664 272.411927 \n",
       "L 290.658006 270.651435 \n",
       "L 293.937329 267.93753 \n",
       "L 297.21669 264.169662 \n",
       "L 300.496013 259.352523 \n",
       "L 303.775355 253.587732 \n",
       "L 307.054697 247.053416 \n",
       "L 310.33402 239.978801 \n",
       "L 313.613382 232.622432 \n",
       "L 316.892705 225.256584 \n",
       "L 320.172047 218.15948 \n",
       "L 323.451389 211.616579 \n",
       "L 326.730731 205.931796 \n",
       "L 330.010073 201.450054 \n",
       "L 333.289396 198.5998 \n",
       "L 336.568738 197.963015 \n",
       "L 339.84808 200.398633 \n",
       "L 343.127423 207.24209 \n",
       "L 346.406765 220.53827 \n",
       "L 349.686088 242.411045 \n",
       "L 352.96543 267.298344 \n",
       "L 356.244772 273.745276 \n",
       "L 359.524114 247.881527 \n",
       "L 362.803456 163.106183 \n",
       "L 366.082798 104.847005 \n",
       "L 369.362141 71.862077 \n",
       "L 372.641463 52.346748 \n",
       "L 375.920806 40.148318 \n",
       "L 379.200148 32.196 \n",
       "\" clip-path=\"url(#p9fc75de91c)\" style=\"fill: none; stroke: #ff7f0e; stroke-width: 1.2; stroke-linecap: round\"/>\n",
       "   </g>\n",
       "   <g id=\"line2d_25\">\n",
       "    <path d=\"M 379.200148 274.116 \n",
       "L 379.200148 271.672364 \n",
       "L 379.200148 269.228727 \n",
       "L 379.200148 266.785091 \n",
       "L 379.200148 264.341455 \n",
       "L 379.200148 261.897819 \n",
       "L 379.200148 259.454182 \n",
       "L 379.200148 257.010545 \n",
       "L 379.200148 254.566909 \n",
       "L 379.200148 252.123274 \n",
       "L 379.200148 249.679638 \n",
       "L 379.200148 247.236 \n",
       "L 379.200148 244.792364 \n",
       "L 379.200148 242.348728 \n",
       "L 379.200148 239.905091 \n",
       "L 379.200148 237.461457 \n",
       "L 379.200148 235.017819 \n",
       "L 379.200148 232.574181 \n",
       "L 379.200148 230.130547 \n",
       "L 379.200148 227.686909 \n",
       "L 379.200148 225.243276 \n",
       "L 379.200148 222.799638 \n",
       "L 379.200148 220.356 \n",
       "L 379.200148 217.912366 \n",
       "L 379.200148 215.468728 \n",
       "L 379.200148 213.025091 \n",
       "L 379.200148 210.581457 \n",
       "L 379.200148 208.137819 \n",
       "L 379.200148 205.694181 \n",
       "L 379.200148 203.250543 \n",
       "L 379.200148 200.806913 \n",
       "L 379.200148 198.363276 \n",
       "L 379.200148 195.919638 \n",
       "L 379.200148 193.476 \n",
       "L 379.200148 191.032362 \n",
       "L 379.200148 188.588732 \n",
       "L 379.200148 186.145094 \n",
       "L 379.200148 183.701457 \n",
       "L 379.200148 181.257819 \n",
       "L 379.200148 178.814181 \n",
       "L 379.200148 176.370551 \n",
       "L 379.200148 173.926913 \n",
       "L 379.200148 171.483276 \n",
       "L 379.200148 169.039638 \n",
       "L 379.200148 166.596 \n",
       "L 379.200148 164.152362 \n",
       "L 379.200148 161.708732 \n",
       "L 379.200148 159.265094 \n",
       "L 379.200148 156.821457 \n",
       "L 379.200148 154.377819 \n",
       "L 379.200148 151.934181 \n",
       "L 379.200148 149.490543 \n",
       "L 379.200148 147.046906 \n",
       "L 379.200148 144.603268 \n",
       "L 379.200148 142.159638 \n",
       "L 379.200148 139.716 \n",
       "L 379.200148 137.272362 \n",
       "L 379.200148 134.828724 \n",
       "L 379.200148 132.385087 \n",
       "L 379.200148 129.941449 \n",
       "L 379.200148 127.497827 \n",
       "L 379.200148 125.054173 \n",
       "L 379.200148 122.610551 \n",
       "L 379.200148 120.166898 \n",
       "L 379.200148 117.723276 \n",
       "L 379.200148 115.279638 \n",
       "L 379.200148 112.836 \n",
       "L 379.200148 110.392362 \n",
       "L 379.200148 107.948724 \n",
       "L 379.200148 105.505087 \n",
       "L 379.200148 103.061449 \n",
       "L 379.200148 100.617827 \n",
       "L 379.200148 98.174173 \n",
       "L 379.200148 95.730551 \n",
       "L 379.200148 93.286913 \n",
       "L 379.200148 90.843276 \n",
       "L 379.200148 88.399638 \n",
       "L 379.200148 85.956 \n",
       "L 379.200148 83.512362 \n",
       "L 379.200148 81.068724 \n",
       "L 379.200148 78.625087 \n",
       "L 379.200148 76.181449 \n",
       "L 379.200148 73.737827 \n",
       "L 379.200148 71.294173 \n",
       "L 379.200148 68.850551 \n",
       "L 379.200148 66.406913 \n",
       "L 379.200148 63.963276 \n",
       "L 379.200148 61.519638 \n",
       "L 379.200148 59.076 \n",
       "L 379.200148 56.632362 \n",
       "L 379.200148 54.188724 \n",
       "L 379.200148 51.745087 \n",
       "L 379.200148 49.301449 \n",
       "L 379.200148 46.857811 \n",
       "L 379.200148 44.414173 \n",
       "L 379.200148 41.970551 \n",
       "L 379.200148 39.526913 \n",
       "L 379.200148 37.083276 \n",
       "L 379.200148 34.639638 \n",
       "L 379.200148 32.196 \n",
       "\" clip-path=\"url(#p9fc75de91c)\" style=\"fill: none; stroke: #ff7f0e; stroke-linecap: round\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_7\">\n",
       "    <path d=\"M 38.312875 286.212 \n",
       "L 38.312875 20.1 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_8\">\n",
       "    <path d=\"M 395.432875 286.212 \n",
       "L 395.432875 20.1 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_9\">\n",
       "    <path d=\"M 38.312875 286.212 \n",
       "L 395.432875 286.212 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_10\">\n",
       "    <path d=\"M 38.312875 20.1 \n",
       "L 395.432875 20.1 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "  </g>\n",
       " </g>\n",
       " <defs>\n",
       "  <clipPath id=\"p9fc75de91c\">\n",
       "   <rect x=\"38.312875\" y=\"20.1\" width=\"357.12\" height=\"266.112\"/>\n",
       "  </clipPath>\n",
       " </defs>\n",
       "</svg>\n"
      ],
      "text/plain": [
       "<Figure size 640x480 with 2 Axes>"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "image/svg+xml": [
       "<?xml version=\"1.0\" encoding=\"utf-8\" standalone=\"no\"?>\n",
       "<!DOCTYPE svg PUBLIC \"-//W3C//DTD SVG 1.1//EN\"\n",
       "  \"http://www.w3.org/Graphics/SVG/1.1/DTD/svg11.dtd\">\n",
       "<svg xmlns:xlink=\"http://www.w3.org/1999/xlink\" width=\"436.061375pt\" height=\"322.539375pt\" viewBox=\"0 0 436.061375 322.539375\" xmlns=\"http://www.w3.org/2000/svg\" version=\"1.1\">\n",
       " <metadata>\n",
       "  <rdf:RDF xmlns:dc=\"http://purl.org/dc/elements/1.1/\" xmlns:cc=\"http://creativecommons.org/ns#\" xmlns:rdf=\"http://www.w3.org/1999/02/22-rdf-syntax-ns#\">\n",
       "   <cc:Work>\n",
       "    <dc:type rdf:resource=\"http://purl.org/dc/dcmitype/StillImage\"/>\n",
       "    <dc:date>2023-10-23T15:18:34.094493</dc:date>\n",
       "    <dc:format>image/svg+xml</dc:format>\n",
       "    <dc:creator>\n",
       "     <cc:Agent>\n",
       "      <dc:title>Matplotlib v3.8.0, https://matplotlib.org/</dc:title>\n",
       "     </cc:Agent>\n",
       "    </dc:creator>\n",
       "   </cc:Work>\n",
       "  </rdf:RDF>\n",
       " </metadata>\n",
       " <defs>\n",
       "  <style type=\"text/css\">*{stroke-linejoin: round; stroke-linecap: butt}</style>\n",
       " </defs>\n",
       " <g id=\"figure_1\">\n",
       "  <g id=\"patch_1\">\n",
       "   <path d=\"M 0 322.539375 \n",
       "L 436.061375 322.539375 \n",
       "L 436.061375 0 \n",
       "L 0 0 \n",
       "z\n",
       "\" style=\"fill: #ffffff\"/>\n",
       "  </g>\n",
       "  <g id=\"axes_1\">\n",
       "   <g id=\"patch_2\">\n",
       "    <path d=\"M 38.312875 286.212 \n",
       "L 395.432875 286.212 \n",
       "L 395.432875 20.1 \n",
       "L 38.312875 20.1 \n",
       "z\n",
       "\" style=\"fill: #ffffff\"/>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_1\">\n",
       "    <g id=\"xtick_1\">\n",
       "     <g id=\"line2d_1\">\n",
       "      <defs>\n",
       "       <path id=\"mc73fb1159a\" d=\"M 0 0 \n",
       "L 0 4.8 \n",
       "\" style=\"stroke: #262626\"/>\n",
       "      </defs>\n",
       "      <g>\n",
       "       <use xlink:href=\"#mc73fb1159a\" x=\"54.545602\" y=\"286.212\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_1\">\n",
       "      <!-- 0.0 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(48.429602 300.810875) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-30\" d=\"M 266 2259 \n",
       "Q 266 3072 433 3567 \n",
       "Q 600 4063 929 4331 \n",
       "Q 1259 4600 1759 4600 \n",
       "Q 2128 4600 2406 4451 \n",
       "Q 2684 4303 2865 4023 \n",
       "Q 3047 3744 3150 3342 \n",
       "Q 3253 2941 3253 2259 \n",
       "Q 3253 1453 3087 958 \n",
       "Q 2922 463 2592 192 \n",
       "Q 2263 -78 1759 -78 \n",
       "Q 1097 -78 719 397 \n",
       "Q 266 969 266 2259 \n",
       "z\n",
       "M 844 2259 \n",
       "Q 844 1131 1108 757 \n",
       "Q 1372 384 1759 384 \n",
       "Q 2147 384 2411 759 \n",
       "Q 2675 1134 2675 2259 \n",
       "Q 2675 3391 2411 3762 \n",
       "Q 2147 4134 1753 4134 \n",
       "Q 1366 4134 1134 3806 \n",
       "Q 844 3388 844 2259 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "        <path id=\"ArialMT-2e\" d=\"M 581 0 \n",
       "L 581 641 \n",
       "L 1222 641 \n",
       "L 1222 0 \n",
       "L 581 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_2\">\n",
       "     <g id=\"line2d_2\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mc73fb1159a\" x=\"119.476511\" y=\"286.212\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_2\">\n",
       "      <!-- 0.2 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(113.360511 300.810875) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-32\" d=\"M 3222 541 \n",
       "L 3222 0 \n",
       "L 194 0 \n",
       "Q 188 203 259 391 \n",
       "Q 375 700 629 1000 \n",
       "Q 884 1300 1366 1694 \n",
       "Q 2113 2306 2375 2664 \n",
       "Q 2638 3022 2638 3341 \n",
       "Q 2638 3675 2398 3904 \n",
       "Q 2159 4134 1775 4134 \n",
       "Q 1369 4134 1125 3890 \n",
       "Q 881 3647 878 3216 \n",
       "L 300 3275 \n",
       "Q 359 3922 746 4261 \n",
       "Q 1134 4600 1788 4600 \n",
       "Q 2447 4600 2831 4234 \n",
       "Q 3216 3869 3216 3328 \n",
       "Q 3216 3053 3103 2787 \n",
       "Q 2991 2522 2730 2228 \n",
       "Q 2469 1934 1863 1422 \n",
       "Q 1356 997 1212 845 \n",
       "Q 1069 694 975 541 \n",
       "L 3222 541 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-32\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_3\">\n",
       "     <g id=\"line2d_3\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mc73fb1159a\" x=\"184.40742\" y=\"286.212\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_3\">\n",
       "      <!-- 0.4 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(178.29142 300.810875) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-34\" d=\"M 2069 0 \n",
       "L 2069 1097 \n",
       "L 81 1097 \n",
       "L 81 1613 \n",
       "L 2172 4581 \n",
       "L 2631 4581 \n",
       "L 2631 1613 \n",
       "L 3250 1613 \n",
       "L 3250 1097 \n",
       "L 2631 1097 \n",
       "L 2631 0 \n",
       "L 2069 0 \n",
       "z\n",
       "M 2069 1613 \n",
       "L 2069 3678 \n",
       "L 634 1613 \n",
       "L 2069 1613 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-34\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_4\">\n",
       "     <g id=\"line2d_4\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mc73fb1159a\" x=\"249.33833\" y=\"286.212\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_4\">\n",
       "      <!-- 0.6 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(243.22233 300.810875) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-36\" d=\"M 3184 3459 \n",
       "L 2625 3416 \n",
       "Q 2550 3747 2413 3897 \n",
       "Q 2184 4138 1850 4138 \n",
       "Q 1581 4138 1378 3988 \n",
       "Q 1113 3794 959 3422 \n",
       "Q 806 3050 800 2363 \n",
       "Q 1003 2672 1297 2822 \n",
       "Q 1591 2972 1913 2972 \n",
       "Q 2475 2972 2870 2558 \n",
       "Q 3266 2144 3266 1488 \n",
       "Q 3266 1056 3080 686 \n",
       "Q 2894 316 2569 119 \n",
       "Q 2244 -78 1831 -78 \n",
       "Q 1128 -78 684 439 \n",
       "Q 241 956 241 2144 \n",
       "Q 241 3472 731 4075 \n",
       "Q 1159 4600 1884 4600 \n",
       "Q 2425 4600 2770 4297 \n",
       "Q 3116 3994 3184 3459 \n",
       "z\n",
       "M 888 1484 \n",
       "Q 888 1194 1011 928 \n",
       "Q 1134 663 1356 523 \n",
       "Q 1578 384 1822 384 \n",
       "Q 2178 384 2434 671 \n",
       "Q 2691 959 2691 1453 \n",
       "Q 2691 1928 2437 2201 \n",
       "Q 2184 2475 1800 2475 \n",
       "Q 1419 2475 1153 2201 \n",
       "Q 888 1928 888 1484 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-36\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_5\">\n",
       "     <g id=\"line2d_5\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mc73fb1159a\" x=\"314.269239\" y=\"286.212\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_5\">\n",
       "      <!-- 0.8 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(308.153239 300.810875) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-38\" d=\"M 1131 2484 \n",
       "Q 781 2613 612 2850 \n",
       "Q 444 3088 444 3419 \n",
       "Q 444 3919 803 4259 \n",
       "Q 1163 4600 1759 4600 \n",
       "Q 2359 4600 2725 4251 \n",
       "Q 3091 3903 3091 3403 \n",
       "Q 3091 3084 2923 2848 \n",
       "Q 2756 2613 2416 2484 \n",
       "Q 2838 2347 3058 2040 \n",
       "Q 3278 1734 3278 1309 \n",
       "Q 3278 722 2862 322 \n",
       "Q 2447 -78 1769 -78 \n",
       "Q 1091 -78 675 323 \n",
       "Q 259 725 259 1325 \n",
       "Q 259 1772 486 2073 \n",
       "Q 713 2375 1131 2484 \n",
       "z\n",
       "M 1019 3438 \n",
       "Q 1019 3113 1228 2906 \n",
       "Q 1438 2700 1772 2700 \n",
       "Q 2097 2700 2305 2904 \n",
       "Q 2513 3109 2513 3406 \n",
       "Q 2513 3716 2298 3927 \n",
       "Q 2084 4138 1766 4138 \n",
       "Q 1444 4138 1231 3931 \n",
       "Q 1019 3725 1019 3438 \n",
       "z\n",
       "M 838 1322 \n",
       "Q 838 1081 952 856 \n",
       "Q 1066 631 1291 507 \n",
       "Q 1516 384 1775 384 \n",
       "Q 2178 384 2440 643 \n",
       "Q 2703 903 2703 1303 \n",
       "Q 2703 1709 2433 1975 \n",
       "Q 2163 2241 1756 2241 \n",
       "Q 1359 2241 1098 1978 \n",
       "Q 838 1716 838 1322 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-38\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_6\">\n",
       "     <g id=\"line2d_6\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mc73fb1159a\" x=\"379.200148\" y=\"286.212\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_6\">\n",
       "      <!-- 1.0 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(373.084148 300.810875) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-31\" d=\"M 2384 0 \n",
       "L 1822 0 \n",
       "L 1822 3584 \n",
       "Q 1619 3391 1289 3197 \n",
       "Q 959 3003 697 2906 \n",
       "L 697 3450 \n",
       "Q 1169 3672 1522 3987 \n",
       "Q 1875 4303 2022 4600 \n",
       "L 2384 4600 \n",
       "L 2384 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-31\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"text_7\">\n",
       "     <!-- $x$ -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(213.992875 313.431375) scale(0.096 -0.096)\">\n",
       "      <defs>\n",
       "       <path id=\"DejaVuSans-Oblique-78\" d=\"M 3841 3500 \n",
       "L 2234 1784 \n",
       "L 3219 0 \n",
       "L 2559 0 \n",
       "L 1819 1388 \n",
       "L 531 0 \n",
       "L -166 0 \n",
       "L 1556 1844 \n",
       "L 641 3500 \n",
       "L 1300 3500 \n",
       "L 1972 2234 \n",
       "L 3144 3500 \n",
       "L 3841 3500 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-78\" transform=\"translate(0 0.3125)\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_2\">\n",
       "    <g id=\"ytick_1\">\n",
       "     <g id=\"line2d_7\">\n",
       "      <defs>\n",
       "       <path id=\"m67fa61bd70\" d=\"M 0 0 \n",
       "L -4.8 0 \n",
       "\" style=\"stroke: #262626\"/>\n",
       "      </defs>\n",
       "      <g>\n",
       "       <use xlink:href=\"#m67fa61bd70\" x=\"38.312875\" y=\"274.182046\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_8\">\n",
       "      <!-- −8 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(19.9795 277.331484) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-2212\" d=\"M 3381 1997 \n",
       "L 356 1997 \n",
       "L 356 2522 \n",
       "L 3381 2522 \n",
       "L 3381 1997 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-38\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_2\">\n",
       "     <g id=\"line2d_8\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m67fa61bd70\" x=\"38.312875\" y=\"227.451705\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_9\">\n",
       "      <!-- −6 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(19.9795 230.601142) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-36\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_3\">\n",
       "     <g id=\"line2d_9\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m67fa61bd70\" x=\"38.312875\" y=\"180.721363\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_10\">\n",
       "      <!-- −4 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(19.9795 183.870801) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-34\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_4\">\n",
       "     <g id=\"line2d_10\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m67fa61bd70\" x=\"38.312875\" y=\"133.991021\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_11\">\n",
       "      <!-- −2 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(19.9795 137.140459) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-32\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_5\">\n",
       "     <g id=\"line2d_11\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m67fa61bd70\" x=\"38.312875\" y=\"87.26068\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_12\">\n",
       "      <!-- 0 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(25.11925 90.410117) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_6\">\n",
       "     <g id=\"line2d_12\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m67fa61bd70\" x=\"38.312875\" y=\"40.530338\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_13\">\n",
       "      <!-- 2 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(25.11925 43.679776) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-32\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"text_14\">\n",
       "     <!-- $y$ -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(13.9635 156.036) rotate(-90) scale(0.096 -0.096)\">\n",
       "      <defs>\n",
       "       <path id=\"DejaVuSans-Oblique-79\" d=\"M 1588 -325 \n",
       "Q 1188 -997 936 -1164 \n",
       "Q 684 -1331 294 -1331 \n",
       "L -159 -1331 \n",
       "L -63 -850 \n",
       "L 269 -850 \n",
       "Q 509 -850 678 -719 \n",
       "Q 847 -588 1056 -206 \n",
       "L 1234 128 \n",
       "L 459 3500 \n",
       "L 1069 3500 \n",
       "L 1650 819 \n",
       "L 3256 3500 \n",
       "L 3859 3500 \n",
       "L 1588 -325 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-79\" transform=\"translate(0 0.3125)\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"PolyCollection_1\">\n",
       "    <defs>\n",
       "     <path id=\"m8aa76b43d0\" d=\"M 54.545602 -288.71304 \n",
       "L 54.545602 -150.636014 \n",
       "L 57.824941 -153.239131 \n",
       "L 61.10428 -156.152558 \n",
       "L 64.383619 -159.370679 \n",
       "L 67.662958 -162.881384 \n",
       "L 70.942296 -166.666034 \n",
       "L 74.221636 -170.69932 \n",
       "L 77.500973 -174.949545 \n",
       "L 80.780313 -179.379164 \n",
       "L 84.059653 -183.945325 \n",
       "L 87.33899 -188.599598 \n",
       "L 90.61833 -193.289585 \n",
       "L 93.89767 -197.958264 \n",
       "L 97.177007 -202.543238 \n",
       "L 100.456344 -206.976293 \n",
       "L 103.735686 -211.17716 \n",
       "L 107.015024 -215.044325 \n",
       "L 110.294361 -218.439899 \n",
       "L 113.573703 -221.191515 \n",
       "L 116.853041 -223.207128 \n",
       "L 120.132378 -224.638809 \n",
       "L 123.41172 -225.773299 \n",
       "L 126.691057 -226.799934 \n",
       "L 129.970395 -227.780679 \n",
       "L 133.249737 -228.70056 \n",
       "L 136.529069 -229.508514 \n",
       "L 139.808412 -230.127119 \n",
       "L 143.087754 -230.456884 \n",
       "L 146.367086 -230.359598 \n",
       "L 149.646428 -229.628319 \n",
       "L 152.92577 -227.991021 \n",
       "L 156.205103 -225.257962 \n",
       "L 159.484445 -221.450841 \n",
       "L 162.763787 -216.694745 \n",
       "L 166.04312 -211.101549 \n",
       "L 169.322462 -204.760498 \n",
       "L 172.601804 -197.754452 \n",
       "L 175.881137 -190.171851 \n",
       "L 179.160479 -182.111593 \n",
       "L 182.439821 -173.684358 \n",
       "L 185.719153 -165.013622 \n",
       "L 188.998496 -156.231929 \n",
       "L 192.277838 -147.480224 \n",
       "L 195.55717 -138.903761 \n",
       "L 198.836512 -130.649468 \n",
       "L 202.115855 -122.862388 \n",
       "L 205.395187 -115.682292 \n",
       "L 208.674529 -109.240545 \n",
       "L 211.953871 -103.656997 \n",
       "L 215.233204 -99.036755 \n",
       "L 218.512556 -95.467547 \n",
       "L 221.791879 -93.01612 \n",
       "L 225.071221 -91.722728 \n",
       "L 228.350563 -91.589187 \n",
       "L 231.629886 -92.539447 \n",
       "L 234.909247 -94.241861 \n",
       "L 238.18857 -95.250257 \n",
       "L 241.467912 -93.428919 \n",
       "L 244.747254 -90.522523 \n",
       "L 248.026597 -87.961041 \n",
       "L 251.305939 -86.122435 \n",
       "L 254.585262 -85.139932 \n",
       "L 257.864623 -85.076103 \n",
       "L 261.143946 -85.960862 \n",
       "L 264.423288 -87.802265 \n",
       "L 267.70263 -90.590697 \n",
       "L 270.981953 -94.300354 \n",
       "L 274.261315 -98.890837 \n",
       "L 277.540637 -104.307676 \n",
       "L 280.81998 -110.483678 \n",
       "L 284.099322 -117.340185 \n",
       "L 287.378664 -124.787552 \n",
       "L 290.658006 -132.727268 \n",
       "L 293.937329 -141.052777 \n",
       "L 297.21669 -149.651317 \n",
       "L 300.496013 -158.404683 \n",
       "L 303.775355 -167.192057 \n",
       "L 307.054697 -175.890329 \n",
       "L 310.33402 -184.376625 \n",
       "L 313.613382 -192.529749 \n",
       "L 316.892705 -200.231969 \n",
       "L 320.172047 -207.37069 \n",
       "L 323.451389 -213.840265 \n",
       "L 326.730731 -219.543017 \n",
       "L 330.010073 -224.391613 \n",
       "L 333.289396 -228.309201 \n",
       "L 336.568738 -231.230492 \n",
       "L 339.84808 -233.100723 \n",
       "L 343.127423 -233.871486 \n",
       "L 346.406765 -233.49577 \n",
       "L 349.686088 -231.909988 \n",
       "L 352.96543 -229.005929 \n",
       "L 356.244772 -224.664585 \n",
       "L 359.524114 -219.02456 \n",
       "L 362.803456 -212.62883 \n",
       "L 366.082798 -206.04191 \n",
       "L 369.362141 -199.587474 \n",
       "L 372.641463 -193.383802 \n",
       "L 375.920806 -187.337085 \n",
       "L 379.200148 -181.097432 \n",
       "L 379.200148 -190.385267 \n",
       "L 379.200148 -190.385267 \n",
       "L 375.920806 -196.237219 \n",
       "L 372.641463 -202.759676 \n",
       "L 369.362141 -209.397427 \n",
       "L 366.082798 -215.838693 \n",
       "L 362.803456 -221.979109 \n",
       "L 359.524114 -227.916087 \n",
       "L 356.244772 -233.99069 \n",
       "L 352.96543 -240.529618 \n",
       "L 349.686088 -247.465984 \n",
       "L 346.406765 -254.491375 \n",
       "L 343.127423 -261.327343 \n",
       "L 339.84808 -267.761493 \n",
       "L 336.568738 -273.622969 \n",
       "L 333.289396 -278.767365 \n",
       "L 330.010073 -283.072136 \n",
       "L 326.730731 -286.43358 \n",
       "L 323.451389 -288.766602 \n",
       "L 320.172047 -290.004805 \n",
       "L 316.892705 -290.101039 \n",
       "L 313.613382 -289.027394 \n",
       "L 310.33402 -286.775114 \n",
       "L 307.054697 -283.35437 \n",
       "L 303.775355 -278.793639 \n",
       "L 300.496013 -273.138798 \n",
       "L 297.21669 -266.452437 \n",
       "L 293.937329 -258.812017 \n",
       "L 290.658006 -250.309477 \n",
       "L 287.378664 -241.048739 \n",
       "L 284.099322 -231.145042 \n",
       "L 280.81998 -220.722775 \n",
       "L 277.540637 -209.914281 \n",
       "L 274.261315 -198.857674 \n",
       "L 270.981953 -187.695431 \n",
       "L 267.70263 -176.572883 \n",
       "L 264.423288 -165.635891 \n",
       "L 261.143946 -155.030209 \n",
       "L 257.864623 -144.89964 \n",
       "L 254.585262 -135.38578 \n",
       "L 251.305939 -126.630649 \n",
       "L 248.026597 -118.785322 \n",
       "L 244.747254 -112.046825 \n",
       "L 241.467912 -106.831578 \n",
       "L 238.18857 -104.581699 \n",
       "L 234.909247 -107.027778 \n",
       "L 231.629886 -111.994015 \n",
       "L 228.350563 -117.968726 \n",
       "L 225.071221 -124.530599 \n",
       "L 221.791879 -131.491322 \n",
       "L 218.512556 -138.719772 \n",
       "L 215.233204 -146.105043 \n",
       "L 211.953871 -153.546834 \n",
       "L 208.674529 -160.953374 \n",
       "L 205.395187 -168.24069 \n",
       "L 202.115855 -175.333394 \n",
       "L 198.836512 -182.16496 \n",
       "L 195.55717 -188.678045 \n",
       "L 192.277838 -194.824645 \n",
       "L 188.998496 -200.566339 \n",
       "L 185.719153 -205.873325 \n",
       "L 182.439821 -210.724923 \n",
       "L 179.160479 -215.108054 \n",
       "L 175.881137 -219.018353 \n",
       "L 172.601804 -222.458399 \n",
       "L 169.322462 -225.440038 \n",
       "L 166.04312 -227.986308 \n",
       "L 162.763787 -230.136741 \n",
       "L 159.484445 -231.95927 \n",
       "L 156.205103 -233.565742 \n",
       "L 152.92577 -235.101555 \n",
       "L 149.646428 -236.62769 \n",
       "L 146.367086 -238.010784 \n",
       "L 143.087754 -239.050369 \n",
       "L 139.808412 -239.623885 \n",
       "L 136.529069 -239.687929 \n",
       "L 133.249737 -239.245575 \n",
       "L 129.970395 -238.327273 \n",
       "L 126.691057 -236.992526 \n",
       "L 123.41172 -235.337058 \n",
       "L 120.132378 -233.531358 \n",
       "L 116.853041 -231.869107 \n",
       "L 113.573703 -230.735039 \n",
       "L 110.294361 -230.371386 \n",
       "L 107.015024 -230.767233 \n",
       "L 103.735686 -231.820997 \n",
       "L 100.456344 -233.454673 \n",
       "L 97.177007 -235.615331 \n",
       "L 93.89767 -238.259853 \n",
       "L 90.61833 -241.346176 \n",
       "L 87.33899 -244.827094 \n",
       "L 84.059653 -248.650831 \n",
       "L 80.780313 -252.761058 \n",
       "L 77.500973 -257.09719 \n",
       "L 74.221636 -261.597296 \n",
       "L 70.942296 -266.198834 \n",
       "L 67.662958 -270.840462 \n",
       "L 64.383619 -275.463834 \n",
       "L 61.10428 -280.015019 \n",
       "L 57.824941 -284.445479 \n",
       "L 54.545602 -288.71304 \n",
       "z\n",
       "\" style=\"stroke: #1f77b4; stroke-opacity: 0.5; stroke-width: 0.8\"/>\n",
       "    </defs>\n",
       "    <g clip-path=\"url(#p640d5b1e44)\">\n",
       "     <use xlink:href=\"#m8aa76b43d0\" x=\"0\" y=\"322.539375\" style=\"fill: #1f77b4; fill-opacity: 0.5; stroke: #1f77b4; stroke-opacity: 0.5; stroke-width: 0.8\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"PolyCollection_2\">\n",
       "    <defs>\n",
       "     <path id=\"m723ceafe02\" d=\"M 54.545602 -150.636014 \n",
       "L 54.545602 -150.478041 \n",
       "L 57.824941 -153.072913 \n",
       "L 61.10428 -155.976508 \n",
       "L 64.383619 -159.18288 \n",
       "L 67.662958 -162.679491 \n",
       "L 70.942296 -166.447117 \n",
       "L 74.221636 -170.459713 \n",
       "L 77.500973 -174.68457 \n",
       "L 80.780313 -179.082781 \n",
       "L 84.059653 -183.60958 \n",
       "L 87.33899 -188.213873 \n",
       "L 90.61833 -192.839401 \n",
       "L 93.89767 -197.423514 \n",
       "L 97.177007 -201.895628 \n",
       "L 100.456344 -206.175774 \n",
       "L 103.735686 -210.168622 \n",
       "L 107.015024 -213.760303 \n",
       "L 110.294361 -216.827559 \n",
       "L 113.573703 -219.284433 \n",
       "L 116.853041 -221.166717 \n",
       "L 120.132378 -222.634766 \n",
       "L 123.41172 -223.869101 \n",
       "L 126.691057 -224.98179 \n",
       "L 129.970395 -226.008061 \n",
       "L 133.249737 -226.927743 \n",
       "L 136.529069 -227.688636 \n",
       "L 139.808412 -228.213341 \n",
       "L 143.087754 -228.405458 \n",
       "L 146.367086 -228.145951 \n",
       "L 149.646428 -227.289764 \n",
       "L 152.92577 -225.674561 \n",
       "L 156.205103 -223.159489 \n",
       "L 159.484445 -219.67341 \n",
       "L 162.763787 -215.229837 \n",
       "L 166.04312 -209.894522 \n",
       "L 169.322462 -203.753549 \n",
       "L 172.601804 -196.900045 \n",
       "L 175.881137 -189.433723 \n",
       "L 179.160479 -181.462552 \n",
       "L 182.439821 -173.103903 \n",
       "L 185.719153 -164.485989 \n",
       "L 188.998496 -155.744728 \n",
       "L 192.277838 -147.023388 \n",
       "L 195.55717 -138.468835 \n",
       "L 198.836512 -130.229014 \n",
       "L 202.115855 -122.449455 \n",
       "L 205.395187 -115.270038 \n",
       "L 208.674529 -108.821663 \n",
       "L 211.953871 -103.223063 \n",
       "L 215.233204 -98.577285 \n",
       "L 218.512556 -94.968424 \n",
       "L 221.791879 -92.456689 \n",
       "L 225.071221 -91.070099 \n",
       "L 228.350563 -90.785838 \n",
       "L 231.629886 -91.475189 \n",
       "L 234.909247 -92.716038 \n",
       "L 238.18857 -93.31247 \n",
       "L 241.467912 -91.960474 \n",
       "L 244.747254 -89.551763 \n",
       "L 248.026597 -87.26817 \n",
       "L 251.305939 -85.590333 \n",
       "L 254.585262 -84.709028 \n",
       "L 257.864623 -84.713273 \n",
       "L 261.143946 -85.646129 \n",
       "L 264.423288 -87.522706 \n",
       "L 267.70263 -90.337476 \n",
       "L 270.981953 -94.06712 \n",
       "L 274.261315 -98.672878 \n",
       "L 277.540637 -104.101304 \n",
       "L 280.81998 -110.285952 \n",
       "L 284.099322 -117.148631 \n",
       "L 287.378664 -124.600032 \n",
       "L 290.658006 -132.541831 \n",
       "L 293.937329 -140.867619 \n",
       "L 297.21669 -149.464654 \n",
       "L 300.496013 -158.214672 \n",
       "L 303.775355 -166.996727 \n",
       "L 307.054697 -175.687506 \n",
       "L 310.33402 -184.163808 \n",
       "L 313.613382 -192.30398 \n",
       "L 316.892705 -199.989633 \n",
       "L 320.172047 -207.107266 \n",
       "L 323.451389 -213.54994 \n",
       "L 326.730731 -219.218134 \n",
       "L 330.010073 -224.021805 \n",
       "L 333.289396 -227.880071 \n",
       "L 336.568738 -230.721483 \n",
       "L 339.84808 -232.481749 \n",
       "L 343.127423 -233.097923 \n",
       "L 346.406765 -232.502659 \n",
       "L 349.686088 -230.61415 \n",
       "L 352.96543 -227.349142 \n",
       "L 356.244772 -222.726023 \n",
       "L 359.524114 -217.020358 \n",
       "L 362.803456 -210.69381 \n",
       "L 366.082798 -204.170406 \n",
       "L 369.362141 -197.717789 \n",
       "L 372.641463 -191.452525 \n",
       "L 375.920806 -185.334221 \n",
       "L 379.200148 -179.153239 \n",
       "L 379.200148 -181.097432 \n",
       "L 379.200148 -181.097432 \n",
       "L 375.920806 -187.337085 \n",
       "L 372.641463 -193.383802 \n",
       "L 369.362141 -199.587474 \n",
       "L 366.082798 -206.04191 \n",
       "L 362.803456 -212.62883 \n",
       "L 359.524114 -219.02456 \n",
       "L 356.244772 -224.664585 \n",
       "L 352.96543 -229.005929 \n",
       "L 349.686088 -231.909988 \n",
       "L 346.406765 -233.49577 \n",
       "L 343.127423 -233.871486 \n",
       "L 339.84808 -233.100723 \n",
       "L 336.568738 -231.230492 \n",
       "L 333.289396 -228.309201 \n",
       "L 330.010073 -224.391613 \n",
       "L 326.730731 -219.543017 \n",
       "L 323.451389 -213.840265 \n",
       "L 320.172047 -207.37069 \n",
       "L 316.892705 -200.231969 \n",
       "L 313.613382 -192.529749 \n",
       "L 310.33402 -184.376625 \n",
       "L 307.054697 -175.890329 \n",
       "L 303.775355 -167.192057 \n",
       "L 300.496013 -158.404683 \n",
       "L 297.21669 -149.651317 \n",
       "L 293.937329 -141.052777 \n",
       "L 290.658006 -132.727268 \n",
       "L 287.378664 -124.787552 \n",
       "L 284.099322 -117.340185 \n",
       "L 280.81998 -110.483678 \n",
       "L 277.540637 -104.307676 \n",
       "L 274.261315 -98.890837 \n",
       "L 270.981953 -94.300354 \n",
       "L 267.70263 -90.590697 \n",
       "L 264.423288 -87.802265 \n",
       "L 261.143946 -85.960862 \n",
       "L 257.864623 -85.076103 \n",
       "L 254.585262 -85.139932 \n",
       "L 251.305939 -86.122435 \n",
       "L 248.026597 -87.961041 \n",
       "L 244.747254 -90.522523 \n",
       "L 241.467912 -93.428919 \n",
       "L 238.18857 -95.250257 \n",
       "L 234.909247 -94.241861 \n",
       "L 231.629886 -92.539447 \n",
       "L 228.350563 -91.589187 \n",
       "L 225.071221 -91.722728 \n",
       "L 221.791879 -93.01612 \n",
       "L 218.512556 -95.467547 \n",
       "L 215.233204 -99.036755 \n",
       "L 211.953871 -103.656997 \n",
       "L 208.674529 -109.240545 \n",
       "L 205.395187 -115.682292 \n",
       "L 202.115855 -122.862388 \n",
       "L 198.836512 -130.649468 \n",
       "L 195.55717 -138.903761 \n",
       "L 192.277838 -147.480224 \n",
       "L 188.998496 -156.231929 \n",
       "L 185.719153 -165.013622 \n",
       "L 182.439821 -173.684358 \n",
       "L 179.160479 -182.111593 \n",
       "L 175.881137 -190.171851 \n",
       "L 172.601804 -197.754452 \n",
       "L 169.322462 -204.760498 \n",
       "L 166.04312 -211.101549 \n",
       "L 162.763787 -216.694745 \n",
       "L 159.484445 -221.450841 \n",
       "L 156.205103 -225.257962 \n",
       "L 152.92577 -227.991021 \n",
       "L 149.646428 -229.628319 \n",
       "L 146.367086 -230.359598 \n",
       "L 143.087754 -230.456884 \n",
       "L 139.808412 -230.127119 \n",
       "L 136.529069 -229.508514 \n",
       "L 133.249737 -228.70056 \n",
       "L 129.970395 -227.780679 \n",
       "L 126.691057 -226.799934 \n",
       "L 123.41172 -225.773299 \n",
       "L 120.132378 -224.638809 \n",
       "L 116.853041 -223.207128 \n",
       "L 113.573703 -221.191515 \n",
       "L 110.294361 -218.439899 \n",
       "L 107.015024 -215.044325 \n",
       "L 103.735686 -211.17716 \n",
       "L 100.456344 -206.976293 \n",
       "L 97.177007 -202.543238 \n",
       "L 93.89767 -197.958264 \n",
       "L 90.61833 -193.289585 \n",
       "L 87.33899 -188.599598 \n",
       "L 84.059653 -183.945325 \n",
       "L 80.780313 -179.379164 \n",
       "L 77.500973 -174.949545 \n",
       "L 74.221636 -170.69932 \n",
       "L 70.942296 -166.666034 \n",
       "L 67.662958 -162.881384 \n",
       "L 64.383619 -159.370679 \n",
       "L 61.10428 -156.152558 \n",
       "L 57.824941 -153.239131 \n",
       "L 54.545602 -150.636014 \n",
       "z\n",
       "\" style=\"stroke: #ff7f0e; stroke-opacity: 0.5; stroke-width: 0.8\"/>\n",
       "    </defs>\n",
       "    <g clip-path=\"url(#p640d5b1e44)\">\n",
       "     <use xlink:href=\"#m723ceafe02\" x=\"0\" y=\"322.539375\" style=\"fill: #ff7f0e; fill-opacity: 0.5; stroke: #ff7f0e; stroke-opacity: 0.5; stroke-width: 0.8\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"PolyCollection_3\">\n",
       "    <defs>\n",
       "     <path id=\"m9a6924f53e\" d=\"M 54.545602 -288.871014 \n",
       "L 54.545602 -288.71304 \n",
       "L 57.824941 -284.445479 \n",
       "L 61.10428 -280.015019 \n",
       "L 64.383619 -275.463834 \n",
       "L 67.662958 -270.840462 \n",
       "L 70.942296 -266.198834 \n",
       "L 74.221636 -261.597296 \n",
       "L 77.500973 -257.09719 \n",
       "L 80.780313 -252.761058 \n",
       "L 84.059653 -248.650831 \n",
       "L 87.33899 -244.827094 \n",
       "L 90.61833 -241.346176 \n",
       "L 93.89767 -238.259853 \n",
       "L 97.177007 -235.615331 \n",
       "L 100.456344 -233.454673 \n",
       "L 103.735686 -231.820997 \n",
       "L 107.015024 -230.767233 \n",
       "L 110.294361 -230.371386 \n",
       "L 113.573703 -230.735039 \n",
       "L 116.853041 -231.869107 \n",
       "L 120.132378 -233.531358 \n",
       "L 123.41172 -235.337058 \n",
       "L 126.691057 -236.992526 \n",
       "L 129.970395 -238.327273 \n",
       "L 133.249737 -239.245575 \n",
       "L 136.529069 -239.687929 \n",
       "L 139.808412 -239.623885 \n",
       "L 143.087754 -239.050369 \n",
       "L 146.367086 -238.010784 \n",
       "L 149.646428 -236.62769 \n",
       "L 152.92577 -235.101555 \n",
       "L 156.205103 -233.565742 \n",
       "L 159.484445 -231.95927 \n",
       "L 162.763787 -230.136741 \n",
       "L 166.04312 -227.986308 \n",
       "L 169.322462 -225.440038 \n",
       "L 172.601804 -222.458399 \n",
       "L 175.881137 -219.018353 \n",
       "L 179.160479 -215.108054 \n",
       "L 182.439821 -210.724923 \n",
       "L 185.719153 -205.873325 \n",
       "L 188.998496 -200.566339 \n",
       "L 192.277838 -194.824645 \n",
       "L 195.55717 -188.678045 \n",
       "L 198.836512 -182.16496 \n",
       "L 202.115855 -175.333394 \n",
       "L 205.395187 -168.24069 \n",
       "L 208.674529 -160.953374 \n",
       "L 211.953871 -153.546834 \n",
       "L 215.233204 -146.105043 \n",
       "L 218.512556 -138.719772 \n",
       "L 221.791879 -131.491322 \n",
       "L 225.071221 -124.530599 \n",
       "L 228.350563 -117.968726 \n",
       "L 231.629886 -111.994015 \n",
       "L 234.909247 -107.027778 \n",
       "L 238.18857 -104.581699 \n",
       "L 241.467912 -106.831578 \n",
       "L 244.747254 -112.046825 \n",
       "L 248.026597 -118.785322 \n",
       "L 251.305939 -126.630649 \n",
       "L 254.585262 -135.38578 \n",
       "L 257.864623 -144.89964 \n",
       "L 261.143946 -155.030209 \n",
       "L 264.423288 -165.635891 \n",
       "L 267.70263 -176.572883 \n",
       "L 270.981953 -187.695431 \n",
       "L 274.261315 -198.857674 \n",
       "L 277.540637 -209.914281 \n",
       "L 280.81998 -220.722775 \n",
       "L 284.099322 -231.145042 \n",
       "L 287.378664 -241.048739 \n",
       "L 290.658006 -250.309477 \n",
       "L 293.937329 -258.812017 \n",
       "L 297.21669 -266.452437 \n",
       "L 300.496013 -273.138798 \n",
       "L 303.775355 -278.793639 \n",
       "L 307.054697 -283.35437 \n",
       "L 310.33402 -286.775114 \n",
       "L 313.613382 -289.027394 \n",
       "L 316.892705 -290.101039 \n",
       "L 320.172047 -290.004805 \n",
       "L 323.451389 -288.766602 \n",
       "L 326.730731 -286.43358 \n",
       "L 330.010073 -283.072136 \n",
       "L 333.289396 -278.767365 \n",
       "L 336.568738 -273.622969 \n",
       "L 339.84808 -267.761493 \n",
       "L 343.127423 -261.327343 \n",
       "L 346.406765 -254.491375 \n",
       "L 349.686088 -247.465984 \n",
       "L 352.96543 -240.529618 \n",
       "L 356.244772 -233.99069 \n",
       "L 359.524114 -227.916087 \n",
       "L 362.803456 -221.979109 \n",
       "L 366.082798 -215.838693 \n",
       "L 369.362141 -209.397427 \n",
       "L 372.641463 -202.759676 \n",
       "L 375.920806 -196.237219 \n",
       "L 379.200148 -190.385267 \n",
       "L 379.200148 -192.329463 \n",
       "L 379.200148 -192.329463 \n",
       "L 375.920806 -198.240085 \n",
       "L 372.641463 -204.690954 \n",
       "L 369.362141 -211.267112 \n",
       "L 366.082798 -217.710199 \n",
       "L 362.803456 -223.914128 \n",
       "L 359.524114 -229.92029 \n",
       "L 356.244772 -235.929251 \n",
       "L 352.96543 -242.186405 \n",
       "L 349.686088 -248.761822 \n",
       "L 346.406765 -255.484488 \n",
       "L 343.127423 -262.100906 \n",
       "L 339.84808 -268.380467 \n",
       "L 336.568738 -274.131977 \n",
       "L 333.289396 -279.196495 \n",
       "L 330.010073 -283.441946 \n",
       "L 326.730731 -286.758463 \n",
       "L 323.451389 -289.05693 \n",
       "L 320.172047 -290.268232 \n",
       "L 316.892705 -290.343375 \n",
       "L 313.613382 -289.253163 \n",
       "L 310.33402 -286.987931 \n",
       "L 307.054697 -283.557193 \n",
       "L 303.775355 -278.98897 \n",
       "L 300.496013 -273.328808 \n",
       "L 297.21669 -266.6391 \n",
       "L 293.937329 -258.99717 \n",
       "L 290.658006 -250.494909 \n",
       "L 287.378664 -241.236265 \n",
       "L 284.099322 -231.336601 \n",
       "L 280.81998 -220.920507 \n",
       "L 277.540637 -210.120653 \n",
       "L 274.261315 -199.075639 \n",
       "L 270.981953 -187.928664 \n",
       "L 267.70263 -176.826105 \n",
       "L 264.423288 -165.91545 \n",
       "L 261.143946 -155.344942 \n",
       "L 257.864623 -145.26247 \n",
       "L 254.585262 -135.816684 \n",
       "L 251.305939 -127.16275 \n",
       "L 248.026597 -119.478194 \n",
       "L 244.747254 -113.017585 \n",
       "L 241.467912 -108.300023 \n",
       "L 238.18857 -106.519486 \n",
       "L 234.909247 -108.553601 \n",
       "L 231.629886 -113.058273 \n",
       "L 228.350563 -118.772075 \n",
       "L 225.071221 -125.183227 \n",
       "L 221.791879 -132.050753 \n",
       "L 218.512556 -139.218895 \n",
       "L 215.233204 -146.564508 \n",
       "L 211.953871 -153.980769 \n",
       "L 208.674529 -161.372262 \n",
       "L 205.395187 -168.652943 \n",
       "L 202.115855 -175.746327 \n",
       "L 198.836512 -182.585425 \n",
       "L 195.55717 -189.112968 \n",
       "L 192.277838 -195.281478 \n",
       "L 188.998496 -201.053541 \n",
       "L 185.719153 -206.400958 \n",
       "L 182.439821 -211.305375 \n",
       "L 179.160479 -215.757093 \n",
       "L 175.881137 -219.75648 \n",
       "L 172.601804 -223.312807 \n",
       "L 169.322462 -226.44699 \n",
       "L 166.04312 -229.193334 \n",
       "L 162.763787 -231.60165 \n",
       "L 159.484445 -233.736699 \n",
       "L 156.205103 -235.664216 \n",
       "L 152.92577 -237.418014 \n",
       "L 149.646428 -238.966245 \n",
       "L 146.367086 -240.22443 \n",
       "L 143.087754 -241.101796 \n",
       "L 139.808412 -241.537664 \n",
       "L 136.529069 -241.507807 \n",
       "L 133.249737 -241.018391 \n",
       "L 129.970395 -240.099891 \n",
       "L 126.691057 -238.81067 \n",
       "L 123.41172 -237.241256 \n",
       "L 120.132378 -235.535402 \n",
       "L 116.853041 -233.909516 \n",
       "L 113.573703 -232.642122 \n",
       "L 110.294361 -231.983725 \n",
       "L 107.015024 -232.051254 \n",
       "L 103.735686 -232.829535 \n",
       "L 100.456344 -234.255192 \n",
       "L 97.177007 -236.262943 \n",
       "L 93.89767 -238.794603 \n",
       "L 90.61833 -241.796363 \n",
       "L 87.33899 -245.21282 \n",
       "L 84.059653 -248.986573 \n",
       "L 80.780313 -253.057443 \n",
       "L 77.500973 -257.362163 \n",
       "L 74.221636 -261.836902 \n",
       "L 70.942296 -266.417745 \n",
       "L 67.662958 -271.04236 \n",
       "L 64.383619 -275.651633 \n",
       "L 61.10428 -280.19107 \n",
       "L 57.824941 -284.611708 \n",
       "L 54.545602 -288.871014 \n",
       "z\n",
       "\" style=\"stroke: #ff7f0e; stroke-opacity: 0.5; stroke-width: 0.8\"/>\n",
       "    </defs>\n",
       "    <g clip-path=\"url(#p640d5b1e44)\">\n",
       "     <use xlink:href=\"#m9a6924f53e\" x=\"0\" y=\"322.539375\" style=\"fill: #ff7f0e; fill-opacity: 0.5; stroke: #ff7f0e; stroke-opacity: 0.5; stroke-width: 0.8\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"line2d_13\">\n",
       "    <defs>\n",
       "     <path id=\"ma34a7aa6c0\" d=\"M -5 5 \n",
       "L 5 -5 \n",
       "M -5 -5 \n",
       "L 5 5 \n",
       "\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "    </defs>\n",
       "    <g clip-path=\"url(#p640d5b1e44)\">\n",
       "     <use xlink:href=\"#ma34a7aa6c0\" x=\"356.349693\" y=\"92.8319\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     <use xlink:href=\"#ma34a7aa6c0\" x=\"157.258364\" y=\"93.794767\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     <use xlink:href=\"#ma34a7aa6c0\" x=\"114.255683\" y=\"96.374455\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     <use xlink:href=\"#ma34a7aa6c0\" x=\"238.18857\" y=\"223.016387\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     <use xlink:href=\"#ma34a7aa6c0\" x=\"143.087754\" y=\"87.756371\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     <use xlink:href=\"#ma34a7aa6c0\" x=\"379.200148\" y=\"137.418751\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"line2d_14\">\n",
       "    <path d=\"M 54.545602 102.864851 \n",
       "L 57.824941 103.697067 \n",
       "L 61.10428 104.455585 \n",
       "L 64.383619 105.122117 \n",
       "L 67.662958 105.678451 \n",
       "L 70.942296 106.106943 \n",
       "L 74.221636 106.391066 \n",
       "L 77.500973 106.516008 \n",
       "L 80.780313 106.469263 \n",
       "L 84.059653 106.241298 \n",
       "L 87.33899 105.826028 \n",
       "L 90.61833 105.221494 \n",
       "L 93.89767 104.430316 \n",
       "L 97.177007 103.46009 \n",
       "L 100.456344 102.323892 \n",
       "L 103.735686 101.040296 \n",
       "L 107.015024 99.633596 \n",
       "L 110.294361 98.133733 \n",
       "L 113.573703 96.576098 \n",
       "L 116.853041 95.001258 \n",
       "L 120.132378 93.454291 \n",
       "L 123.41172 91.984197 \n",
       "L 126.691057 90.643145 \n",
       "L 129.970395 89.485399 \n",
       "L 133.249737 88.566308 \n",
       "L 136.529069 87.941154 \n",
       "L 139.808412 87.663873 \n",
       "L 143.087754 87.785748 \n",
       "L 146.367086 88.354184 \n",
       "L 149.646428 89.41137 \n",
       "L 152.92577 90.993087 \n",
       "L 156.205103 93.127523 \n",
       "L 159.484445 95.83432 \n",
       "L 162.763787 99.123632 \n",
       "L 166.04312 102.995447 \n",
       "L 169.322462 107.439106 \n",
       "L 172.601804 112.432949 \n",
       "L 175.881137 117.944273 \n",
       "L 179.160479 123.929552 \n",
       "L 182.439821 130.334735 \n",
       "L 185.719153 137.095902 \n",
       "L 188.998496 144.140241 \n",
       "L 192.277838 151.386941 \n",
       "L 195.55717 158.748475 \n",
       "L 198.836512 166.132158 \n",
       "L 202.115855 173.441484 \n",
       "L 205.395187 180.577884 \n",
       "L 208.674529 187.442413 \n",
       "L 211.953871 193.937459 \n",
       "L 215.233204 199.968479 \n",
       "L 218.512556 205.445716 \n",
       "L 221.791879 210.285654 \n",
       "L 225.071221 214.412712 \n",
       "L 228.350563 217.760418 \n",
       "L 231.629886 220.272644 \n",
       "L 234.909247 221.904555 \n",
       "L 238.18857 222.623397 \n",
       "L 241.467912 222.409126 \n",
       "L 244.747254 221.254701 \n",
       "L 248.026597 219.166193 \n",
       "L 251.305939 216.162833 \n",
       "L 254.585262 212.276519 \n",
       "L 257.864623 207.551503 \n",
       "L 261.143946 202.043839 \n",
       "L 264.423288 195.820297 \n",
       "L 267.70263 188.957585 \n",
       "L 270.981953 181.54148 \n",
       "L 274.261315 173.665119 \n",
       "L 277.540637 165.428396 \n",
       "L 280.81998 156.936145 \n",
       "L 284.099322 148.296762 \n",
       "L 287.378664 139.62123 \n",
       "L 290.658006 131.021002 \n",
       "L 293.937329 122.606981 \n",
       "L 297.21669 114.487498 \n",
       "L 300.496013 106.767635 \n",
       "L 303.775355 99.546527 \n",
       "L 307.054697 92.917026 \n",
       "L 310.33402 86.963506 \n",
       "L 313.613382 81.760804 \n",
       "L 316.892705 77.372871 \n",
       "L 320.172047 73.851626 \n",
       "L 323.451389 71.235942 \n",
       "L 326.730731 69.551075 \n",
       "L 330.010073 68.807499 \n",
       "L 333.289396 69.001092 \n",
       "L 336.568738 70.112645 \n",
       "L 339.84808 72.108267 \n",
       "L 343.127423 74.939961 \n",
       "L 346.406765 78.545802 \n",
       "L 349.686088 82.851389 \n",
       "L 352.96543 87.771601 \n",
       "L 356.244772 93.211738 \n",
       "L 359.524114 99.069052 \n",
       "L 362.803456 105.235405 \n",
       "L 366.082798 111.599073 \n",
       "L 369.362141 118.046924 \n",
       "L 372.641463 124.467636 \n",
       "L 375.920806 130.752222 \n",
       "L 379.200148 136.798026 \n",
       "\" clip-path=\"url(#p640d5b1e44)\" style=\"fill: none; stroke: #1f77b4; stroke-width: 2; stroke-linecap: round\"/>\n",
       "   </g>\n",
       "   <g id=\"line2d_15\">\n",
       "    <path d=\"M 54.545602 180.039566 \n",
       "L 57.824941 174.337652 \n",
       "L 61.10428 168.656896 \n",
       "L 64.383619 163.018365 \n",
       "L 67.662958 157.44305 \n",
       "L 70.942296 151.951709 \n",
       "L 74.221636 146.564895 \n",
       "L 77.500973 141.302804 \n",
       "L 80.780313 136.185227 \n",
       "L 84.059653 131.231524 \n",
       "L 87.33899 126.460489 \n",
       "L 90.61833 121.890333 \n",
       "L 93.89767 117.538604 \n",
       "L 97.177007 113.422131 \n",
       "L 100.456344 109.556947 \n",
       "L 103.735686 105.95828 \n",
       "L 107.015024 102.640455 \n",
       "L 110.294361 99.616862 \n",
       "L 113.573703 96.899897 \n",
       "L 116.853041 94.500946 \n",
       "L 120.132378 92.430331 \n",
       "L 123.41172 90.697256 \n",
       "L 126.691057 89.309797 \n",
       "L 129.970395 88.274869 \n",
       "L 133.249737 87.59818 \n",
       "L 136.529069 87.284233 \n",
       "L 139.808412 87.336296 \n",
       "L 143.087754 87.756371 \n",
       "L 146.367086 88.545198 \n",
       "L 149.646428 89.702247 \n",
       "L 152.92577 91.225692 \n",
       "L 156.205103 93.112401 \n",
       "L 159.484445 95.357985 \n",
       "L 162.763787 97.956713 \n",
       "L 166.04312 100.901592 \n",
       "L 169.322462 104.184322 \n",
       "L 172.601804 107.795316 \n",
       "L 175.881137 111.723706 \n",
       "L 179.160479 115.95733 \n",
       "L 182.439821 120.482809 \n",
       "L 185.719153 125.285424 \n",
       "L 188.998496 130.349271 \n",
       "L 192.277838 135.657137 \n",
       "L 195.55717 141.190638 \n",
       "L 198.836512 146.930098 \n",
       "L 202.115855 152.854601 \n",
       "L 205.395187 158.942012 \n",
       "L 208.674529 165.168986 \n",
       "L 211.953871 171.510883 \n",
       "L 215.233204 177.941872 \n",
       "L 218.512556 184.434864 \n",
       "L 221.791879 190.961451 \n",
       "L 225.071221 197.49205 \n",
       "L 228.350563 203.995765 \n",
       "L 231.629886 210.440252 \n",
       "L 234.909247 216.792143 \n",
       "L 238.18857 223.016387 \n",
       "L 241.467912 229.076876 \n",
       "L 244.747254 234.935972 \n",
       "L 248.026597 240.554727 \n",
       "L 251.305939 245.892886 \n",
       "L 254.585262 250.908747 \n",
       "L 257.864623 255.559416 \n",
       "L 261.143946 259.800673 \n",
       "L 264.423288 263.587194 \n",
       "L 267.70263 266.872587 \n",
       "L 270.981953 269.609679 \n",
       "L 274.261315 271.750607 \n",
       "L 277.540637 273.24724 \n",
       "L 280.81998 274.051525 \n",
       "L 284.099322 274.116 \n",
       "L 287.378664 273.394417 \n",
       "L 290.658006 271.842579 \n",
       "L 293.937329 269.41925 \n",
       "L 297.21669 266.087231 \n",
       "L 300.496013 261.815179 \n",
       "L 303.775355 256.578619 \n",
       "L 307.054697 250.362508 \n",
       "L 310.33402 243.163415 \n",
       "L 313.613382 234.99188 \n",
       "L 316.892705 225.87599 \n",
       "L 320.172047 215.864378 \n",
       "L 323.451389 205.030187 \n",
       "L 326.730731 193.475215 \n",
       "L 330.010073 181.334072 \n",
       "L 333.289396 168.778576 \n",
       "L 336.568738 156.021967 \n",
       "L 339.84808 143.322263 \n",
       "L 343.127423 130.98506 \n",
       "L 346.406765 119.364588 \n",
       "L 349.686088 108.861847 \n",
       "L 352.96543 99.919674 \n",
       "L 356.244772 93.013744 \n",
       "L 359.524114 88.636306 \n",
       "L 362.803456 87.273632 \n",
       "L 366.082798 89.374044 \n",
       "L 369.362141 95.306083 \n",
       "L 372.641463 105.306376 \n",
       "L 375.920806 119.417493 \n",
       "L 379.200148 137.418751 \n",
       "\" clip-path=\"url(#p640d5b1e44)\" style=\"fill: none; stroke-dasharray: 7.68,1.92,1.2,1.92; stroke-dashoffset: 0; stroke: #bf00bf; stroke-width: 1.2\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_3\">\n",
       "    <path d=\"M 38.312875 274.182046 \n",
       "L 38.312875 40.530338 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_4\">\n",
       "    <path d=\"M 54.545602 286.212 \n",
       "L 379.200148 286.212 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"text_15\">\n",
       "    <!-- N=2, psi=0.10 -->\n",
       "    <g style=\"fill: #262626\" transform=\"translate(186.986125 14.1) scale(0.096 -0.096)\">\n",
       "     <defs>\n",
       "      <path id=\"ArialMT-4e\" d=\"M 488 0 \n",
       "L 488 4581 \n",
       "L 1109 4581 \n",
       "L 3516 984 \n",
       "L 3516 4581 \n",
       "L 4097 4581 \n",
       "L 4097 0 \n",
       "L 3475 0 \n",
       "L 1069 3600 \n",
       "L 1069 0 \n",
       "L 488 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-3d\" d=\"M 3381 2694 \n",
       "L 356 2694 \n",
       "L 356 3219 \n",
       "L 3381 3219 \n",
       "L 3381 2694 \n",
       "z\n",
       "M 3381 1303 \n",
       "L 356 1303 \n",
       "L 356 1828 \n",
       "L 3381 1828 \n",
       "L 3381 1303 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-2c\" d=\"M 569 0 \n",
       "L 569 641 \n",
       "L 1209 641 \n",
       "L 1209 0 \n",
       "Q 1209 -353 1084 -570 \n",
       "Q 959 -788 688 -906 \n",
       "L 531 -666 \n",
       "Q 709 -588 793 -436 \n",
       "Q 878 -284 888 0 \n",
       "L 569 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-20\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-70\" d=\"M 422 -1272 \n",
       "L 422 3319 \n",
       "L 934 3319 \n",
       "L 934 2888 \n",
       "Q 1116 3141 1344 3267 \n",
       "Q 1572 3394 1897 3394 \n",
       "Q 2322 3394 2647 3175 \n",
       "Q 2972 2956 3137 2557 \n",
       "Q 3303 2159 3303 1684 \n",
       "Q 3303 1175 3120 767 \n",
       "Q 2938 359 2589 142 \n",
       "Q 2241 -75 1856 -75 \n",
       "Q 1575 -75 1351 44 \n",
       "Q 1128 163 984 344 \n",
       "L 984 -1272 \n",
       "L 422 -1272 \n",
       "z\n",
       "M 931 1641 \n",
       "Q 931 1000 1190 694 \n",
       "Q 1450 388 1819 388 \n",
       "Q 2194 388 2461 705 \n",
       "Q 2728 1022 2728 1688 \n",
       "Q 2728 2322 2467 2637 \n",
       "Q 2206 2953 1844 2953 \n",
       "Q 1484 2953 1207 2617 \n",
       "Q 931 2281 931 1641 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-73\" d=\"M 197 991 \n",
       "L 753 1078 \n",
       "Q 800 744 1014 566 \n",
       "Q 1228 388 1613 388 \n",
       "Q 2000 388 2187 545 \n",
       "Q 2375 703 2375 916 \n",
       "Q 2375 1106 2209 1216 \n",
       "Q 2094 1291 1634 1406 \n",
       "Q 1016 1563 777 1677 \n",
       "Q 538 1791 414 1992 \n",
       "Q 291 2194 291 2438 \n",
       "Q 291 2659 392 2848 \n",
       "Q 494 3038 669 3163 \n",
       "Q 800 3259 1026 3326 \n",
       "Q 1253 3394 1513 3394 \n",
       "Q 1903 3394 2198 3281 \n",
       "Q 2494 3169 2634 2976 \n",
       "Q 2775 2784 2828 2463 \n",
       "L 2278 2388 \n",
       "Q 2241 2644 2061 2787 \n",
       "Q 1881 2931 1553 2931 \n",
       "Q 1166 2931 1000 2803 \n",
       "Q 834 2675 834 2503 \n",
       "Q 834 2394 903 2306 \n",
       "Q 972 2216 1119 2156 \n",
       "Q 1203 2125 1616 2013 \n",
       "Q 2213 1853 2448 1751 \n",
       "Q 2684 1650 2818 1456 \n",
       "Q 2953 1263 2953 975 \n",
       "Q 2953 694 2789 445 \n",
       "Q 2625 197 2315 61 \n",
       "Q 2006 -75 1616 -75 \n",
       "Q 969 -75 630 194 \n",
       "Q 291 463 197 991 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-69\" d=\"M 425 3934 \n",
       "L 425 4581 \n",
       "L 988 4581 \n",
       "L 988 3934 \n",
       "L 425 3934 \n",
       "z\n",
       "M 425 0 \n",
       "L 425 3319 \n",
       "L 988 3319 \n",
       "L 988 0 \n",
       "L 425 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "     </defs>\n",
       "     <use xlink:href=\"#ArialMT-4e\"/>\n",
       "     <use xlink:href=\"#ArialMT-3d\" x=\"72.216797\"/>\n",
       "     <use xlink:href=\"#ArialMT-32\" x=\"130.615234\"/>\n",
       "     <use xlink:href=\"#ArialMT-2c\" x=\"186.230469\"/>\n",
       "     <use xlink:href=\"#ArialMT-20\" x=\"214.013672\"/>\n",
       "     <use xlink:href=\"#ArialMT-70\" x=\"241.796875\"/>\n",
       "     <use xlink:href=\"#ArialMT-73\" x=\"297.412109\"/>\n",
       "     <use xlink:href=\"#ArialMT-69\" x=\"347.412109\"/>\n",
       "     <use xlink:href=\"#ArialMT-3d\" x=\"369.628906\"/>\n",
       "     <use xlink:href=\"#ArialMT-30\" x=\"428.027344\"/>\n",
       "     <use xlink:href=\"#ArialMT-2e\" x=\"483.642578\"/>\n",
       "     <use xlink:href=\"#ArialMT-31\" x=\"511.425781\"/>\n",
       "     <use xlink:href=\"#ArialMT-30\" x=\"567.041016\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"legend_1\">\n",
       "    <g id=\"line2d_16\">\n",
       "     <g>\n",
       "      <use xlink:href=\"#ma34a7aa6c0\" x=\"55.032875\" y=\"220.007125\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"text_16\">\n",
       "     <!-- Observations -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(70.872875 223.087125) scale(0.088 -0.088)\">\n",
       "      <defs>\n",
       "       <path id=\"ArialMT-4f\" d=\"M 309 2231 \n",
       "Q 309 3372 921 4017 \n",
       "Q 1534 4663 2503 4663 \n",
       "Q 3138 4663 3647 4359 \n",
       "Q 4156 4056 4423 3514 \n",
       "Q 4691 2972 4691 2284 \n",
       "Q 4691 1588 4409 1038 \n",
       "Q 4128 488 3612 205 \n",
       "Q 3097 -78 2500 -78 \n",
       "Q 1853 -78 1343 234 \n",
       "Q 834 547 571 1087 \n",
       "Q 309 1628 309 2231 \n",
       "z\n",
       "M 934 2222 \n",
       "Q 934 1394 1379 917 \n",
       "Q 1825 441 2497 441 \n",
       "Q 3181 441 3623 922 \n",
       "Q 4066 1403 4066 2288 \n",
       "Q 4066 2847 3877 3264 \n",
       "Q 3688 3681 3323 3911 \n",
       "Q 2959 4141 2506 4141 \n",
       "Q 1863 4141 1398 3698 \n",
       "Q 934 3256 934 2222 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-62\" d=\"M 941 0 \n",
       "L 419 0 \n",
       "L 419 4581 \n",
       "L 981 4581 \n",
       "L 981 2947 \n",
       "Q 1338 3394 1891 3394 \n",
       "Q 2197 3394 2470 3270 \n",
       "Q 2744 3147 2920 2923 \n",
       "Q 3097 2700 3197 2384 \n",
       "Q 3297 2069 3297 1709 \n",
       "Q 3297 856 2875 390 \n",
       "Q 2453 -75 1863 -75 \n",
       "Q 1275 -75 941 416 \n",
       "L 941 0 \n",
       "z\n",
       "M 934 1684 \n",
       "Q 934 1088 1097 822 \n",
       "Q 1363 388 1816 388 \n",
       "Q 2184 388 2453 708 \n",
       "Q 2722 1028 2722 1663 \n",
       "Q 2722 2313 2464 2622 \n",
       "Q 2206 2931 1841 2931 \n",
       "Q 1472 2931 1203 2611 \n",
       "Q 934 2291 934 1684 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-65\" d=\"M 2694 1069 \n",
       "L 3275 997 \n",
       "Q 3138 488 2766 206 \n",
       "Q 2394 -75 1816 -75 \n",
       "Q 1088 -75 661 373 \n",
       "Q 234 822 234 1631 \n",
       "Q 234 2469 665 2931 \n",
       "Q 1097 3394 1784 3394 \n",
       "Q 2450 3394 2872 2941 \n",
       "Q 3294 2488 3294 1666 \n",
       "Q 3294 1616 3291 1516 \n",
       "L 816 1516 \n",
       "Q 847 969 1125 678 \n",
       "Q 1403 388 1819 388 \n",
       "Q 2128 388 2347 550 \n",
       "Q 2566 713 2694 1069 \n",
       "z\n",
       "M 847 1978 \n",
       "L 2700 1978 \n",
       "Q 2663 2397 2488 2606 \n",
       "Q 2219 2931 1791 2931 \n",
       "Q 1403 2931 1139 2672 \n",
       "Q 875 2413 847 1978 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-72\" d=\"M 416 0 \n",
       "L 416 3319 \n",
       "L 922 3319 \n",
       "L 922 2816 \n",
       "Q 1116 3169 1280 3281 \n",
       "Q 1444 3394 1641 3394 \n",
       "Q 1925 3394 2219 3213 \n",
       "L 2025 2691 \n",
       "Q 1819 2813 1613 2813 \n",
       "Q 1428 2813 1281 2702 \n",
       "Q 1134 2591 1072 2394 \n",
       "Q 978 2094 978 1738 \n",
       "L 978 0 \n",
       "L 416 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-76\" d=\"M 1344 0 \n",
       "L 81 3319 \n",
       "L 675 3319 \n",
       "L 1388 1331 \n",
       "Q 1503 1009 1600 663 \n",
       "Q 1675 925 1809 1294 \n",
       "L 2547 3319 \n",
       "L 3125 3319 \n",
       "L 1869 0 \n",
       "L 1344 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-61\" d=\"M 2588 409 \n",
       "Q 2275 144 1986 34 \n",
       "Q 1697 -75 1366 -75 \n",
       "Q 819 -75 525 192 \n",
       "Q 231 459 231 875 \n",
       "Q 231 1119 342 1320 \n",
       "Q 453 1522 633 1644 \n",
       "Q 813 1766 1038 1828 \n",
       "Q 1203 1872 1538 1913 \n",
       "Q 2219 1994 2541 2106 \n",
       "Q 2544 2222 2544 2253 \n",
       "Q 2544 2597 2384 2738 \n",
       "Q 2169 2928 1744 2928 \n",
       "Q 1347 2928 1158 2789 \n",
       "Q 969 2650 878 2297 \n",
       "L 328 2372 \n",
       "Q 403 2725 575 2942 \n",
       "Q 747 3159 1072 3276 \n",
       "Q 1397 3394 1825 3394 \n",
       "Q 2250 3394 2515 3294 \n",
       "Q 2781 3194 2906 3042 \n",
       "Q 3031 2891 3081 2659 \n",
       "Q 3109 2516 3109 2141 \n",
       "L 3109 1391 \n",
       "Q 3109 606 3145 398 \n",
       "Q 3181 191 3288 0 \n",
       "L 2700 0 \n",
       "Q 2613 175 2588 409 \n",
       "z\n",
       "M 2541 1666 \n",
       "Q 2234 1541 1622 1453 \n",
       "Q 1275 1403 1131 1340 \n",
       "Q 988 1278 909 1158 \n",
       "Q 831 1038 831 891 \n",
       "Q 831 666 1001 516 \n",
       "Q 1172 366 1500 366 \n",
       "Q 1825 366 2078 508 \n",
       "Q 2331 650 2450 897 \n",
       "Q 2541 1088 2541 1459 \n",
       "L 2541 1666 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-74\" d=\"M 1650 503 \n",
       "L 1731 6 \n",
       "Q 1494 -44 1306 -44 \n",
       "Q 1000 -44 831 53 \n",
       "Q 663 150 594 308 \n",
       "Q 525 466 525 972 \n",
       "L 525 2881 \n",
       "L 113 2881 \n",
       "L 113 3319 \n",
       "L 525 3319 \n",
       "L 525 4141 \n",
       "L 1084 4478 \n",
       "L 1084 3319 \n",
       "L 1650 3319 \n",
       "L 1650 2881 \n",
       "L 1084 2881 \n",
       "L 1084 941 \n",
       "Q 1084 700 1114 631 \n",
       "Q 1144 563 1211 522 \n",
       "Q 1278 481 1403 481 \n",
       "Q 1497 481 1650 503 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-6f\" d=\"M 213 1659 \n",
       "Q 213 2581 725 3025 \n",
       "Q 1153 3394 1769 3394 \n",
       "Q 2453 3394 2887 2945 \n",
       "Q 3322 2497 3322 1706 \n",
       "Q 3322 1066 3130 698 \n",
       "Q 2938 331 2570 128 \n",
       "Q 2203 -75 1769 -75 \n",
       "Q 1072 -75 642 372 \n",
       "Q 213 819 213 1659 \n",
       "z\n",
       "M 791 1659 \n",
       "Q 791 1022 1069 705 \n",
       "Q 1347 388 1769 388 \n",
       "Q 2188 388 2466 706 \n",
       "Q 2744 1025 2744 1678 \n",
       "Q 2744 2294 2464 2611 \n",
       "Q 2184 2928 1769 2928 \n",
       "Q 1347 2928 1069 2612 \n",
       "Q 791 2297 791 1659 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-6e\" d=\"M 422 0 \n",
       "L 422 3319 \n",
       "L 928 3319 \n",
       "L 928 2847 \n",
       "Q 1294 3394 1984 3394 \n",
       "Q 2284 3394 2536 3286 \n",
       "Q 2788 3178 2913 3003 \n",
       "Q 3038 2828 3088 2588 \n",
       "Q 3119 2431 3119 2041 \n",
       "L 3119 0 \n",
       "L 2556 0 \n",
       "L 2556 2019 \n",
       "Q 2556 2363 2490 2533 \n",
       "Q 2425 2703 2258 2804 \n",
       "Q 2091 2906 1866 2906 \n",
       "Q 1506 2906 1245 2678 \n",
       "Q 984 2450 984 1813 \n",
       "L 984 0 \n",
       "L 422 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#ArialMT-4f\"/>\n",
       "      <use xlink:href=\"#ArialMT-62\" x=\"77.783203\"/>\n",
       "      <use xlink:href=\"#ArialMT-73\" x=\"133.398438\"/>\n",
       "      <use xlink:href=\"#ArialMT-65\" x=\"183.398438\"/>\n",
       "      <use xlink:href=\"#ArialMT-72\" x=\"239.013672\"/>\n",
       "      <use xlink:href=\"#ArialMT-76\" x=\"272.314453\"/>\n",
       "      <use xlink:href=\"#ArialMT-61\" x=\"322.314453\"/>\n",
       "      <use xlink:href=\"#ArialMT-74\" x=\"377.929688\"/>\n",
       "      <use xlink:href=\"#ArialMT-69\" x=\"405.712891\"/>\n",
       "      <use xlink:href=\"#ArialMT-6f\" x=\"427.929688\"/>\n",
       "      <use xlink:href=\"#ArialMT-6e\" x=\"483.544922\"/>\n",
       "      <use xlink:href=\"#ArialMT-73\" x=\"539.160156\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"line2d_17\">\n",
       "     <path d=\"M 46.232875 232.591125 \n",
       "L 55.032875 232.591125 \n",
       "L 63.832875 232.591125 \n",
       "\" style=\"fill: none; stroke: #1f77b4; stroke-width: 2; stroke-linecap: round\"/>\n",
       "    </g>\n",
       "    <g id=\"text_17\">\n",
       "     <!-- $m_n(x)$ -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(70.872875 235.671125) scale(0.088 -0.088)\">\n",
       "      <defs>\n",
       "       <path id=\"DejaVuSans-Oblique-6d\" d=\"M 5747 2113 \n",
       "L 5338 0 \n",
       "L 4763 0 \n",
       "L 5166 2094 \n",
       "Q 5191 2228 5203 2325 \n",
       "Q 5216 2422 5216 2491 \n",
       "Q 5216 2772 5059 2928 \n",
       "Q 4903 3084 4622 3084 \n",
       "Q 4203 3084 3875 2770 \n",
       "Q 3547 2456 3450 1953 \n",
       "L 3066 0 \n",
       "L 2491 0 \n",
       "L 2900 2094 \n",
       "Q 2925 2209 2937 2307 \n",
       "Q 2950 2406 2950 2484 \n",
       "Q 2950 2769 2794 2926 \n",
       "Q 2638 3084 2363 3084 \n",
       "Q 1938 3084 1609 2770 \n",
       "Q 1281 2456 1184 1953 \n",
       "L 800 0 \n",
       "L 225 0 \n",
       "L 909 3500 \n",
       "L 1484 3500 \n",
       "L 1375 2956 \n",
       "Q 1609 3263 1923 3423 \n",
       "Q 2238 3584 2597 3584 \n",
       "Q 2978 3584 3223 3384 \n",
       "Q 3469 3184 3519 2828 \n",
       "Q 3781 3197 4126 3390 \n",
       "Q 4472 3584 4856 3584 \n",
       "Q 5306 3584 5551 3325 \n",
       "Q 5797 3066 5797 2591 \n",
       "Q 5797 2488 5784 2364 \n",
       "Q 5772 2241 5747 2113 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-Oblique-6e\" d=\"M 3566 2113 \n",
       "L 3156 0 \n",
       "L 2578 0 \n",
       "L 2988 2091 \n",
       "Q 3016 2238 3031 2350 \n",
       "Q 3047 2463 3047 2528 \n",
       "Q 3047 2791 2881 2937 \n",
       "Q 2716 3084 2419 3084 \n",
       "Q 1956 3084 1622 2776 \n",
       "Q 1288 2469 1184 1941 \n",
       "L 800 0 \n",
       "L 225 0 \n",
       "L 903 3500 \n",
       "L 1478 3500 \n",
       "L 1363 2950 \n",
       "Q 1603 3253 1940 3418 \n",
       "Q 2278 3584 2650 3584 \n",
       "Q 3113 3584 3367 3334 \n",
       "Q 3622 3084 3622 2631 \n",
       "Q 3622 2519 3608 2391 \n",
       "Q 3594 2263 3566 2113 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-28\" d=\"M 1984 4856 \n",
       "Q 1566 4138 1362 3434 \n",
       "Q 1159 2731 1159 2009 \n",
       "Q 1159 1288 1364 580 \n",
       "Q 1569 -128 1984 -844 \n",
       "L 1484 -844 \n",
       "Q 1016 -109 783 600 \n",
       "Q 550 1309 550 2009 \n",
       "Q 550 2706 781 3412 \n",
       "Q 1013 4119 1484 4856 \n",
       "L 1984 4856 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-29\" d=\"M 513 4856 \n",
       "L 1013 4856 \n",
       "Q 1481 4119 1714 3412 \n",
       "Q 1947 2706 1947 2009 \n",
       "Q 1947 1309 1714 600 \n",
       "Q 1481 -109 1013 -844 \n",
       "L 513 -844 \n",
       "Q 928 -128 1133 580 \n",
       "Q 1338 1288 1338 2009 \n",
       "Q 1338 2731 1133 3434 \n",
       "Q 928 4138 513 4856 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-6d\" transform=\"translate(0 0.125)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-6e\" transform=\"translate(97.412109 -16.28125) scale(0.7)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-28\" transform=\"translate(144.511719 0.125)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-78\" transform=\"translate(183.525391 0.125)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-29\" transform=\"translate(242.705078 0.125)\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"patch_5\">\n",
       "     <path d=\"M 46.232875 249.828125 \n",
       "L 63.832875 249.828125 \n",
       "L 63.832875 243.668125 \n",
       "L 46.232875 243.668125 \n",
       "z\n",
       "\" style=\"fill: #1f77b4; fill-opacity: 0.5; stroke: #1f77b4; stroke-opacity: 0.5; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "    </g>\n",
       "    <g id=\"text_18\">\n",
       "     <!-- $f(\\mathbf{x}^*)$ 95% pred. -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(70.872875 249.828125) scale(0.088 -0.088)\">\n",
       "      <defs>\n",
       "       <path id=\"DejaVuSans-Oblique-66\" d=\"M 3059 4863 \n",
       "L 2969 4384 \n",
       "L 2419 4384 \n",
       "Q 2106 4384 1964 4261 \n",
       "Q 1822 4138 1753 3809 \n",
       "L 1691 3500 \n",
       "L 2638 3500 \n",
       "L 2553 3053 \n",
       "L 1606 3053 \n",
       "L 1013 0 \n",
       "L 434 0 \n",
       "L 1031 3053 \n",
       "L 481 3053 \n",
       "L 563 3500 \n",
       "L 1113 3500 \n",
       "L 1159 3744 \n",
       "Q 1278 4363 1576 4613 \n",
       "Q 1875 4863 2516 4863 \n",
       "L 3059 4863 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-Bold-78\" d=\"M 1422 1791 \n",
       "L 159 3500 \n",
       "L 1344 3500 \n",
       "L 2059 2463 \n",
       "L 2784 3500 \n",
       "L 3969 3500 \n",
       "L 2706 1797 \n",
       "L 4031 0 \n",
       "L 2847 0 \n",
       "L 2059 1106 \n",
       "L 1281 0 \n",
       "L 97 0 \n",
       "L 1422 1791 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-2a\" d=\"M 3009 3897 \n",
       "L 1888 3291 \n",
       "L 3009 2681 \n",
       "L 2828 2375 \n",
       "L 1778 3009 \n",
       "L 1778 1831 \n",
       "L 1422 1831 \n",
       "L 1422 3009 \n",
       "L 372 2375 \n",
       "L 191 2681 \n",
       "L 1313 3291 \n",
       "L 191 3897 \n",
       "L 372 4206 \n",
       "L 1422 3572 \n",
       "L 1422 4750 \n",
       "L 1778 4750 \n",
       "L 1778 3572 \n",
       "L 2828 4206 \n",
       "L 3009 3897 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-39\" d=\"M 350 1059 \n",
       "L 891 1109 \n",
       "Q 959 728 1153 556 \n",
       "Q 1347 384 1650 384 \n",
       "Q 1909 384 2104 503 \n",
       "Q 2300 622 2425 820 \n",
       "Q 2550 1019 2634 1356 \n",
       "Q 2719 1694 2719 2044 \n",
       "Q 2719 2081 2716 2156 \n",
       "Q 2547 1888 2255 1720 \n",
       "Q 1963 1553 1622 1553 \n",
       "Q 1053 1553 659 1965 \n",
       "Q 266 2378 266 3053 \n",
       "Q 266 3750 677 4175 \n",
       "Q 1088 4600 1706 4600 \n",
       "Q 2153 4600 2523 4359 \n",
       "Q 2894 4119 3086 3673 \n",
       "Q 3278 3228 3278 2384 \n",
       "Q 3278 1506 3087 986 \n",
       "Q 2897 466 2520 194 \n",
       "Q 2144 -78 1638 -78 \n",
       "Q 1100 -78 759 220 \n",
       "Q 419 519 350 1059 \n",
       "z\n",
       "M 2653 3081 \n",
       "Q 2653 3566 2395 3850 \n",
       "Q 2138 4134 1775 4134 \n",
       "Q 1400 4134 1122 3828 \n",
       "Q 844 3522 844 3034 \n",
       "Q 844 2597 1108 2323 \n",
       "Q 1372 2050 1759 2050 \n",
       "Q 2150 2050 2401 2323 \n",
       "Q 2653 2597 2653 3081 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-35\" d=\"M 266 1200 \n",
       "L 856 1250 \n",
       "Q 922 819 1161 601 \n",
       "Q 1400 384 1738 384 \n",
       "Q 2144 384 2425 690 \n",
       "Q 2706 997 2706 1503 \n",
       "Q 2706 1984 2436 2262 \n",
       "Q 2166 2541 1728 2541 \n",
       "Q 1456 2541 1237 2417 \n",
       "Q 1019 2294 894 2097 \n",
       "L 366 2166 \n",
       "L 809 4519 \n",
       "L 3088 4519 \n",
       "L 3088 3981 \n",
       "L 1259 3981 \n",
       "L 1013 2750 \n",
       "Q 1425 3038 1878 3038 \n",
       "Q 2478 3038 2890 2622 \n",
       "Q 3303 2206 3303 1553 \n",
       "Q 3303 931 2941 478 \n",
       "Q 2500 -78 1738 -78 \n",
       "Q 1113 -78 717 272 \n",
       "Q 322 622 266 1200 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-25\" d=\"M 372 3481 \n",
       "Q 372 3972 619 4315 \n",
       "Q 866 4659 1334 4659 \n",
       "Q 1766 4659 2048 4351 \n",
       "Q 2331 4044 2331 3447 \n",
       "Q 2331 2866 2045 2552 \n",
       "Q 1759 2238 1341 2238 \n",
       "Q 925 2238 648 2547 \n",
       "Q 372 2856 372 3481 \n",
       "z\n",
       "M 1350 4272 \n",
       "Q 1141 4272 1002 4090 \n",
       "Q 863 3909 863 3425 \n",
       "Q 863 2984 1003 2804 \n",
       "Q 1144 2625 1350 2625 \n",
       "Q 1563 2625 1702 2806 \n",
       "Q 1841 2988 1841 3469 \n",
       "Q 1841 3913 1700 4092 \n",
       "Q 1559 4272 1350 4272 \n",
       "z\n",
       "M 1353 -169 \n",
       "L 3859 4659 \n",
       "L 4316 4659 \n",
       "L 1819 -169 \n",
       "L 1353 -169 \n",
       "z\n",
       "M 3334 1075 \n",
       "Q 3334 1569 3581 1911 \n",
       "Q 3828 2253 4300 2253 \n",
       "Q 4731 2253 5014 1945 \n",
       "Q 5297 1638 5297 1041 \n",
       "Q 5297 459 5011 145 \n",
       "Q 4725 -169 4303 -169 \n",
       "Q 3888 -169 3611 142 \n",
       "Q 3334 453 3334 1075 \n",
       "z\n",
       "M 4316 1866 \n",
       "Q 4103 1866 3964 1684 \n",
       "Q 3825 1503 3825 1019 \n",
       "Q 3825 581 3965 400 \n",
       "Q 4106 219 4313 219 \n",
       "Q 4528 219 4667 400 \n",
       "Q 4806 581 4806 1063 \n",
       "Q 4806 1506 4665 1686 \n",
       "Q 4525 1866 4316 1866 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-64\" d=\"M 2575 0 \n",
       "L 2575 419 \n",
       "Q 2259 -75 1647 -75 \n",
       "Q 1250 -75 917 144 \n",
       "Q 584 363 401 755 \n",
       "Q 219 1147 219 1656 \n",
       "Q 219 2153 384 2558 \n",
       "Q 550 2963 881 3178 \n",
       "Q 1213 3394 1622 3394 \n",
       "Q 1922 3394 2156 3267 \n",
       "Q 2391 3141 2538 2938 \n",
       "L 2538 4581 \n",
       "L 3097 4581 \n",
       "L 3097 0 \n",
       "L 2575 0 \n",
       "z\n",
       "M 797 1656 \n",
       "Q 797 1019 1065 703 \n",
       "Q 1334 388 1700 388 \n",
       "Q 2069 388 2326 689 \n",
       "Q 2584 991 2584 1609 \n",
       "Q 2584 2291 2321 2609 \n",
       "Q 2059 2928 1675 2928 \n",
       "Q 1300 2928 1048 2622 \n",
       "Q 797 2316 797 1656 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-66\" transform=\"translate(0 0.765625)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-28\" transform=\"translate(35.205078 0.765625)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-Bold-78\" transform=\"translate(74.21875 0.765625)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-2a\" transform=\"translate(153.31543 39.046875) scale(0.7)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-29\" transform=\"translate(204.6875 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" transform=\"translate(243.701172 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-39\" transform=\"translate(271.484375 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-35\" transform=\"translate(327.099609 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-25\" transform=\"translate(382.714844 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" transform=\"translate(471.630859 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-70\" transform=\"translate(499.414062 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-72\" transform=\"translate(555.029297 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-65\" transform=\"translate(588.330078 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-64\" transform=\"translate(643.945312 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-2e\" transform=\"translate(699.560547 0.765625)\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"patch_6\">\n",
       "     <path d=\"M 46.232875 263.996125 \n",
       "L 63.832875 263.996125 \n",
       "L 63.832875 257.836125 \n",
       "L 46.232875 257.836125 \n",
       "z\n",
       "\" style=\"fill: #ff7f0e; fill-opacity: 0.5; stroke: #ff7f0e; stroke-opacity: 0.5; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "    </g>\n",
       "    <g id=\"text_19\">\n",
       "     <!-- $y^*$ 95% pred. -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(70.872875 263.996125) scale(0.088 -0.088)\">\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-79\" transform=\"translate(0 0.765625)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-2a\" transform=\"translate(77.283529 39.046875) scale(0.7)\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" transform=\"translate(128.655599 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-39\" transform=\"translate(156.438802 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-35\" transform=\"translate(212.054036 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-25\" transform=\"translate(267.669271 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" transform=\"translate(356.585286 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-70\" transform=\"translate(384.36849 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-72\" transform=\"translate(439.983724 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-65\" transform=\"translate(473.284505 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-64\" transform=\"translate(528.89974 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-2e\" transform=\"translate(584.514974 0.765625)\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"line2d_18\">\n",
       "     <path d=\"M 46.232875 273.463 \n",
       "L 55.032875 273.463 \n",
       "L 63.832875 273.463 \n",
       "\" style=\"fill: none; stroke-dasharray: 7.68,1.92,1.2,1.92; stroke-dashoffset: 0; stroke: #bf00bf; stroke-width: 1.2\"/>\n",
       "    </g>\n",
       "    <g id=\"text_20\">\n",
       "     <!-- True function -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(70.872875 276.543) scale(0.088 -0.088)\">\n",
       "      <defs>\n",
       "       <path id=\"ArialMT-54\" d=\"M 1659 0 \n",
       "L 1659 4041 \n",
       "L 150 4041 \n",
       "L 150 4581 \n",
       "L 3781 4581 \n",
       "L 3781 4041 \n",
       "L 2266 4041 \n",
       "L 2266 0 \n",
       "L 1659 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-75\" d=\"M 2597 0 \n",
       "L 2597 488 \n",
       "Q 2209 -75 1544 -75 \n",
       "Q 1250 -75 995 37 \n",
       "Q 741 150 617 320 \n",
       "Q 494 491 444 738 \n",
       "Q 409 903 409 1263 \n",
       "L 409 3319 \n",
       "L 972 3319 \n",
       "L 972 1478 \n",
       "Q 972 1038 1006 884 \n",
       "Q 1059 663 1231 536 \n",
       "Q 1403 409 1656 409 \n",
       "Q 1909 409 2131 539 \n",
       "Q 2353 669 2445 892 \n",
       "Q 2538 1116 2538 1541 \n",
       "L 2538 3319 \n",
       "L 3100 3319 \n",
       "L 3100 0 \n",
       "L 2597 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-66\" d=\"M 556 0 \n",
       "L 556 2881 \n",
       "L 59 2881 \n",
       "L 59 3319 \n",
       "L 556 3319 \n",
       "L 556 3672 \n",
       "Q 556 4006 616 4169 \n",
       "Q 697 4388 901 4523 \n",
       "Q 1106 4659 1475 4659 \n",
       "Q 1713 4659 2000 4603 \n",
       "L 1916 4113 \n",
       "Q 1741 4144 1584 4144 \n",
       "Q 1328 4144 1222 4034 \n",
       "Q 1116 3925 1116 3625 \n",
       "L 1116 3319 \n",
       "L 1763 3319 \n",
       "L 1763 2881 \n",
       "L 1116 2881 \n",
       "L 1116 0 \n",
       "L 556 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-63\" d=\"M 2588 1216 \n",
       "L 3141 1144 \n",
       "Q 3050 572 2676 248 \n",
       "Q 2303 -75 1759 -75 \n",
       "Q 1078 -75 664 370 \n",
       "Q 250 816 250 1647 \n",
       "Q 250 2184 428 2587 \n",
       "Q 606 2991 970 3192 \n",
       "Q 1334 3394 1763 3394 \n",
       "Q 2303 3394 2647 3120 \n",
       "Q 2991 2847 3088 2344 \n",
       "L 2541 2259 \n",
       "Q 2463 2594 2264 2762 \n",
       "Q 2066 2931 1784 2931 \n",
       "Q 1359 2931 1093 2626 \n",
       "Q 828 2322 828 1663 \n",
       "Q 828 994 1084 691 \n",
       "Q 1341 388 1753 388 \n",
       "Q 2084 388 2306 591 \n",
       "Q 2528 794 2588 1216 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#ArialMT-54\"/>\n",
       "      <use xlink:href=\"#ArialMT-72\" x=\"57.333984\"/>\n",
       "      <use xlink:href=\"#ArialMT-75\" x=\"90.634766\"/>\n",
       "      <use xlink:href=\"#ArialMT-65\" x=\"146.25\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" x=\"201.865234\"/>\n",
       "      <use xlink:href=\"#ArialMT-66\" x=\"229.648438\"/>\n",
       "      <use xlink:href=\"#ArialMT-75\" x=\"257.431641\"/>\n",
       "      <use xlink:href=\"#ArialMT-6e\" x=\"313.046875\"/>\n",
       "      <use xlink:href=\"#ArialMT-63\" x=\"368.662109\"/>\n",
       "      <use xlink:href=\"#ArialMT-74\" x=\"418.662109\"/>\n",
       "      <use xlink:href=\"#ArialMT-69\" x=\"446.445312\"/>\n",
       "      <use xlink:href=\"#ArialMT-6f\" x=\"468.662109\"/>\n",
       "      <use xlink:href=\"#ArialMT-6e\" x=\"524.277344\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "  </g>\n",
       "  <g id=\"axes_2\">\n",
       "   <g id=\"matplotlib.axis_3\">\n",
       "    <g id=\"ytick_7\">\n",
       "     <g id=\"line2d_19\">\n",
       "      <defs>\n",
       "       <path id=\"m3a90fba441\" d=\"M 0 0 \n",
       "L 4.8 0 \n",
       "\" style=\"stroke: #262626\"/>\n",
       "      </defs>\n",
       "      <g>\n",
       "       <use xlink:href=\"#m3a90fba441\" x=\"395.432875\" y=\"274.116\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_21\">\n",
       "      <!-- 0.0 -->\n",
       "      <g style=\"fill: #ff7f0e\" transform=\"translate(403.732875 277.265437) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_8\">\n",
       "     <g id=\"line2d_20\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m3a90fba441\" x=\"395.432875\" y=\"222.520545\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_22\">\n",
       "      <!-- 0.2 -->\n",
       "      <g style=\"fill: #ff7f0e\" transform=\"translate(403.732875 225.669982) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-32\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_9\">\n",
       "     <g id=\"line2d_21\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m3a90fba441\" x=\"395.432875\" y=\"170.92509\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_23\">\n",
       "      <!-- 0.4 -->\n",
       "      <g style=\"fill: #ff7f0e\" transform=\"translate(403.732875 174.074527) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-34\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_10\">\n",
       "     <g id=\"line2d_22\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m3a90fba441\" x=\"395.432875\" y=\"119.329635\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_24\">\n",
       "      <!-- 0.6 -->\n",
       "      <g style=\"fill: #ff7f0e\" transform=\"translate(403.732875 122.479072) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-36\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_11\">\n",
       "     <g id=\"line2d_23\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m3a90fba441\" x=\"395.432875\" y=\"67.734179\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_25\">\n",
       "      <!-- 0.8 -->\n",
       "      <g style=\"fill: #ff7f0e\" transform=\"translate(403.732875 70.883617) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-38\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"text_26\">\n",
       "     <!-- Information Acquisition Function -->\n",
       "     <g style=\"fill: #ff7f0e\" transform=\"translate(426.953375 221.18925) rotate(-90) scale(0.096 -0.096)\">\n",
       "      <defs>\n",
       "       <path id=\"ArialMT-49\" d=\"M 597 0 \n",
       "L 597 4581 \n",
       "L 1203 4581 \n",
       "L 1203 0 \n",
       "L 597 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-6d\" d=\"M 422 0 \n",
       "L 422 3319 \n",
       "L 925 3319 \n",
       "L 925 2853 \n",
       "Q 1081 3097 1340 3245 \n",
       "Q 1600 3394 1931 3394 \n",
       "Q 2300 3394 2536 3241 \n",
       "Q 2772 3088 2869 2813 \n",
       "Q 3263 3394 3894 3394 \n",
       "Q 4388 3394 4653 3120 \n",
       "Q 4919 2847 4919 2278 \n",
       "L 4919 0 \n",
       "L 4359 0 \n",
       "L 4359 2091 \n",
       "Q 4359 2428 4304 2576 \n",
       "Q 4250 2725 4106 2815 \n",
       "Q 3963 2906 3769 2906 \n",
       "Q 3419 2906 3187 2673 \n",
       "Q 2956 2441 2956 1928 \n",
       "L 2956 0 \n",
       "L 2394 0 \n",
       "L 2394 2156 \n",
       "Q 2394 2531 2256 2718 \n",
       "Q 2119 2906 1806 2906 \n",
       "Q 1569 2906 1367 2781 \n",
       "Q 1166 2656 1075 2415 \n",
       "Q 984 2175 984 1722 \n",
       "L 984 0 \n",
       "L 422 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-41\" d=\"M -9 0 \n",
       "L 1750 4581 \n",
       "L 2403 4581 \n",
       "L 4278 0 \n",
       "L 3588 0 \n",
       "L 3053 1388 \n",
       "L 1138 1388 \n",
       "L 634 0 \n",
       "L -9 0 \n",
       "z\n",
       "M 1313 1881 \n",
       "L 2866 1881 \n",
       "L 2388 3150 \n",
       "Q 2169 3728 2063 4100 \n",
       "Q 1975 3659 1816 3225 \n",
       "L 1313 1881 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-71\" d=\"M 2538 -1272 \n",
       "L 2538 353 \n",
       "Q 2406 169 2170 47 \n",
       "Q 1934 -75 1669 -75 \n",
       "Q 1078 -75 651 397 \n",
       "Q 225 869 225 1691 \n",
       "Q 225 2191 398 2587 \n",
       "Q 572 2984 901 3189 \n",
       "Q 1231 3394 1625 3394 \n",
       "Q 2241 3394 2594 2875 \n",
       "L 2594 3319 \n",
       "L 3100 3319 \n",
       "L 3100 -1272 \n",
       "L 2538 -1272 \n",
       "z\n",
       "M 803 1669 \n",
       "Q 803 1028 1072 708 \n",
       "Q 1341 388 1716 388 \n",
       "Q 2075 388 2334 692 \n",
       "Q 2594 997 2594 1619 \n",
       "Q 2594 2281 2320 2615 \n",
       "Q 2047 2950 1678 2950 \n",
       "Q 1313 2950 1058 2639 \n",
       "Q 803 2328 803 1669 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-46\" d=\"M 525 0 \n",
       "L 525 4581 \n",
       "L 3616 4581 \n",
       "L 3616 4041 \n",
       "L 1131 4041 \n",
       "L 1131 2622 \n",
       "L 3281 2622 \n",
       "L 3281 2081 \n",
       "L 1131 2081 \n",
       "L 1131 0 \n",
       "L 525 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#ArialMT-49\"/>\n",
       "      <use xlink:href=\"#ArialMT-6e\" x=\"27.783203\"/>\n",
       "      <use xlink:href=\"#ArialMT-66\" x=\"83.398438\"/>\n",
       "      <use xlink:href=\"#ArialMT-6f\" x=\"111.181641\"/>\n",
       "      <use xlink:href=\"#ArialMT-72\" x=\"166.796875\"/>\n",
       "      <use xlink:href=\"#ArialMT-6d\" x=\"200.097656\"/>\n",
       "      <use xlink:href=\"#ArialMT-61\" x=\"283.398438\"/>\n",
       "      <use xlink:href=\"#ArialMT-74\" x=\"339.013672\"/>\n",
       "      <use xlink:href=\"#ArialMT-69\" x=\"366.796875\"/>\n",
       "      <use xlink:href=\"#ArialMT-6f\" x=\"389.013672\"/>\n",
       "      <use xlink:href=\"#ArialMT-6e\" x=\"444.628906\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" x=\"500.244141\"/>\n",
       "      <use xlink:href=\"#ArialMT-41\" x=\"522.527344\"/>\n",
       "      <use xlink:href=\"#ArialMT-63\" x=\"589.226562\"/>\n",
       "      <use xlink:href=\"#ArialMT-71\" x=\"639.226562\"/>\n",
       "      <use xlink:href=\"#ArialMT-75\" x=\"694.841797\"/>\n",
       "      <use xlink:href=\"#ArialMT-69\" x=\"750.457031\"/>\n",
       "      <use xlink:href=\"#ArialMT-73\" x=\"772.673828\"/>\n",
       "      <use xlink:href=\"#ArialMT-69\" x=\"822.673828\"/>\n",
       "      <use xlink:href=\"#ArialMT-74\" x=\"844.890625\"/>\n",
       "      <use xlink:href=\"#ArialMT-69\" x=\"872.673828\"/>\n",
       "      <use xlink:href=\"#ArialMT-6f\" x=\"894.890625\"/>\n",
       "      <use xlink:href=\"#ArialMT-6e\" x=\"950.505859\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" x=\"1006.121094\"/>\n",
       "      <use xlink:href=\"#ArialMT-46\" x=\"1033.904297\"/>\n",
       "      <use xlink:href=\"#ArialMT-75\" x=\"1094.988281\"/>\n",
       "      <use xlink:href=\"#ArialMT-6e\" x=\"1150.603516\"/>\n",
       "      <use xlink:href=\"#ArialMT-63\" x=\"1206.21875\"/>\n",
       "      <use xlink:href=\"#ArialMT-74\" x=\"1256.21875\"/>\n",
       "      <use xlink:href=\"#ArialMT-69\" x=\"1284.001953\"/>\n",
       "      <use xlink:href=\"#ArialMT-6f\" x=\"1306.21875\"/>\n",
       "      <use xlink:href=\"#ArialMT-6e\" x=\"1361.833984\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"line2d_24\">\n",
       "    <path d=\"M 54.545602 195.007404 \n",
       "L 57.824941 199.63961 \n",
       "L 61.10428 204.626217 \n",
       "L 64.383619 209.978073 \n",
       "L 67.662958 215.698131 \n",
       "L 70.942296 221.77681 \n",
       "L 74.221636 228.184773 \n",
       "L 77.500973 234.863249 \n",
       "L 80.780313 241.711391 \n",
       "L 84.059653 248.570874 \n",
       "L 87.33899 255.207702 \n",
       "L 90.61833 261.305764 \n",
       "L 93.89767 266.481888 \n",
       "L 97.177007 270.360532 \n",
       "L 100.456344 272.740921 \n",
       "L 103.735686 273.797027 \n",
       "L 107.015024 274.077405 \n",
       "L 110.294361 274.113386 \n",
       "L 113.573703 274.115623 \n",
       "L 116.853041 274.114754 \n",
       "L 120.132378 274.077097 \n",
       "L 123.41172 273.336666 \n",
       "L 126.691057 268.907423 \n",
       "L 129.970395 258.238916 \n",
       "L 133.249737 244.105358 \n",
       "L 136.529069 232.606119 \n",
       "L 139.808412 229.670226 \n",
       "L 143.087754 239.187446 \n",
       "L 146.367086 257.99026 \n",
       "L 149.646428 271.208061 \n",
       "L 152.92577 273.894461 \n",
       "L 156.205103 274.089368 \n",
       "L 159.484445 274.106497 \n",
       "L 162.763787 274.110134 \n",
       "L 166.04312 274.111956 \n",
       "L 169.322462 274.113348 \n",
       "L 172.601804 274.114424 \n",
       "L 175.881137 274.115162 \n",
       "L 179.160479 274.115608 \n",
       "L 182.439821 274.115839 \n",
       "L 185.719153 274.115946 \n",
       "L 188.998496 274.115985 \n",
       "L 192.277838 274.116 \n",
       "L 195.55717 274.116 \n",
       "L 198.836512 274.116 \n",
       "L 202.115855 274.116 \n",
       "L 205.395187 274.116 \n",
       "L 208.674529 274.116 \n",
       "L 211.953871 274.116 \n",
       "L 215.233204 274.116 \n",
       "L 218.512556 274.116 \n",
       "L 221.791879 274.116 \n",
       "L 225.071221 274.116 \n",
       "L 228.350563 274.116 \n",
       "L 231.629886 274.116 \n",
       "L 234.909247 274.116 \n",
       "L 238.18857 274.116 \n",
       "L 241.467912 274.116 \n",
       "L 244.747254 274.116 \n",
       "L 248.026597 274.116 \n",
       "L 251.305939 274.116 \n",
       "L 254.585262 274.116 \n",
       "L 257.864623 274.116 \n",
       "L 261.143946 274.116 \n",
       "L 264.423288 274.116 \n",
       "L 267.70263 274.115808 \n",
       "L 270.981953 274.111041 \n",
       "L 274.261315 274.062582 \n",
       "L 277.540637 273.800994 \n",
       "L 280.81998 272.89571 \n",
       "L 284.099322 270.619666 \n",
       "L 287.378664 266.09196 \n",
       "L 290.658006 258.530142 \n",
       "L 293.937329 247.475642 \n",
       "L 297.21669 232.902366 \n",
       "L 300.496013 215.203826 \n",
       "L 303.775355 195.093889 \n",
       "L 307.054697 173.478987 \n",
       "L 310.33402 151.329578 \n",
       "L 313.613382 129.576993 \n",
       "L 316.892705 109.038933 \n",
       "L 320.172047 90.371364 \n",
       "L 323.451389 74.044121 \n",
       "L 326.730731 60.336842 \n",
       "L 330.010073 49.349354 \n",
       "L 333.289396 41.041537 \n",
       "L 336.568738 35.312323 \n",
       "L 339.84808 32.196 \n",
       "L 343.127423 32.495906 \n",
       "L 346.406765 40.688551 \n",
       "L 349.686088 81.789936 \n",
       "L 352.96543 220.673628 \n",
       "L 356.244772 274.008686 \n",
       "L 359.524114 274.116 \n",
       "L 362.803456 274.116 \n",
       "L 366.082798 274.116 \n",
       "L 369.362141 274.116 \n",
       "L 372.641463 274.116 \n",
       "L 375.920806 274.116 \n",
       "L 379.200148 274.116 \n",
       "\" clip-path=\"url(#p640d5b1e44)\" style=\"fill: none; stroke: #ff7f0e; stroke-width: 1.2; stroke-linecap: round\"/>\n",
       "   </g>\n",
       "   <g id=\"line2d_25\">\n",
       "    <path d=\"M 339.84808 274.116 \n",
       "L 339.84808 271.672364 \n",
       "L 339.84808 269.228727 \n",
       "L 339.84808 266.785091 \n",
       "L 339.84808 264.341455 \n",
       "L 339.84808 261.897819 \n",
       "L 339.84808 259.454182 \n",
       "L 339.84808 257.010547 \n",
       "L 339.84808 254.56691 \n",
       "L 339.84808 252.123273 \n",
       "L 339.84808 249.679637 \n",
       "L 339.84808 247.236 \n",
       "L 339.84808 244.792363 \n",
       "L 339.84808 242.348728 \n",
       "L 339.84808 239.905093 \n",
       "L 339.84808 237.461456 \n",
       "L 339.84808 235.017819 \n",
       "L 339.84808 232.574182 \n",
       "L 339.84808 230.130545 \n",
       "L 339.84808 227.686912 \n",
       "L 339.84808 225.243275 \n",
       "L 339.84808 222.799638 \n",
       "L 339.84808 220.356001 \n",
       "L 339.84808 217.912364 \n",
       "L 339.84808 215.468727 \n",
       "L 339.84808 213.025094 \n",
       "L 339.84808 210.581457 \n",
       "L 339.84808 208.13782 \n",
       "L 339.84808 205.694186 \n",
       "L 339.84808 203.250546 \n",
       "L 339.84808 200.806912 \n",
       "L 339.84808 198.363271 \n",
       "L 339.84808 195.919638 \n",
       "L 339.84808 193.476005 \n",
       "L 339.84808 191.032364 \n",
       "L 339.84808 188.588731 \n",
       "L 339.84808 186.14509 \n",
       "L 339.84808 183.701457 \n",
       "L 339.84808 181.257824 \n",
       "L 339.84808 178.814183 \n",
       "L 339.84808 176.37055 \n",
       "L 339.84808 173.926909 \n",
       "L 339.84808 171.483276 \n",
       "L 339.84808 169.039643 \n",
       "L 339.84808 166.596002 \n",
       "L 339.84808 164.152369 \n",
       "L 339.84808 161.708728 \n",
       "L 339.84808 159.265094 \n",
       "L 339.84808 156.821454 \n",
       "L 339.84808 154.37782 \n",
       "L 339.84808 151.93418 \n",
       "L 339.84808 149.490546 \n",
       "L 339.84808 147.046906 \n",
       "L 339.84808 144.603265 \n",
       "L 339.84808 142.159639 \n",
       "L 339.84808 139.715998 \n",
       "L 339.84808 137.272357 \n",
       "L 339.84808 134.828732 \n",
       "L 339.84808 132.385091 \n",
       "L 339.84808 129.94145 \n",
       "L 339.84808 127.497825 \n",
       "L 339.84808 125.054168 \n",
       "L 339.84808 122.610543 \n",
       "L 339.84808 120.166917 \n",
       "L 339.84808 117.723261 \n",
       "L 339.84808 115.279636 \n",
       "L 339.84808 112.835995 \n",
       "L 339.84808 110.392354 \n",
       "L 339.84808 107.948729 \n",
       "L 339.84808 105.505088 \n",
       "L 339.84808 103.061447 \n",
       "L 339.84808 100.617821 \n",
       "L 339.84808 98.17418 \n",
       "L 339.84808 95.73054 \n",
       "L 339.84808 93.286914 \n",
       "L 339.84808 90.843273 \n",
       "L 339.84808 88.399632 \n",
       "L 339.84808 85.956007 \n",
       "L 339.84808 83.512366 \n",
       "L 339.84808 81.068725 \n",
       "L 339.84808 78.625084 \n",
       "L 339.84808 76.181459 \n",
       "L 339.84808 73.737818 \n",
       "L 339.84808 71.294177 \n",
       "L 339.84808 68.850536 \n",
       "L 339.84808 66.406911 \n",
       "L 339.84808 63.96327 \n",
       "L 339.84808 61.519629 \n",
       "L 339.84808 59.076003 \n",
       "L 339.84808 56.632363 \n",
       "L 339.84808 54.188722 \n",
       "L 339.84808 51.745096 \n",
       "L 339.84808 49.301455 \n",
       "L 339.84808 46.857814 \n",
       "L 339.84808 44.414189 \n",
       "L 339.84808 41.970548 \n",
       "L 339.84808 39.526907 \n",
       "L 339.84808 37.083266 \n",
       "L 339.84808 34.639641 \n",
       "L 339.84808 32.196 \n",
       "\" clip-path=\"url(#p640d5b1e44)\" style=\"fill: none; stroke: #ff7f0e; stroke-linecap: round\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_7\">\n",
       "    <path d=\"M 38.312875 286.212 \n",
       "L 38.312875 20.1 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_8\">\n",
       "    <path d=\"M 395.432875 286.212 \n",
       "L 395.432875 20.1 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_9\">\n",
       "    <path d=\"M 38.312875 286.212 \n",
       "L 395.432875 286.212 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_10\">\n",
       "    <path d=\"M 38.312875 20.1 \n",
       "L 395.432875 20.1 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "  </g>\n",
       " </g>\n",
       " <defs>\n",
       "  <clipPath id=\"p640d5b1e44\">\n",
       "   <rect x=\"38.312875\" y=\"20.1\" width=\"357.12\" height=\"266.112\"/>\n",
       "  </clipPath>\n",
       " </defs>\n",
       "</svg>\n"
      ],
      "text/plain": [
       "<Figure size 640x480 with 2 Axes>"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "image/svg+xml": [
       "<?xml version=\"1.0\" encoding=\"utf-8\" standalone=\"no\"?>\n",
       "<!DOCTYPE svg PUBLIC \"-//W3C//DTD SVG 1.1//EN\"\n",
       "  \"http://www.w3.org/Graphics/SVG/1.1/DTD/svg11.dtd\">\n",
       "<svg xmlns:xlink=\"http://www.w3.org/1999/xlink\" width=\"445.848625pt\" height=\"322.539375pt\" viewBox=\"0 0 445.848625 322.539375\" xmlns=\"http://www.w3.org/2000/svg\" version=\"1.1\">\n",
       " <metadata>\n",
       "  <rdf:RDF xmlns:dc=\"http://purl.org/dc/elements/1.1/\" xmlns:cc=\"http://creativecommons.org/ns#\" xmlns:rdf=\"http://www.w3.org/1999/02/22-rdf-syntax-ns#\">\n",
       "   <cc:Work>\n",
       "    <dc:type rdf:resource=\"http://purl.org/dc/dcmitype/StillImage\"/>\n",
       "    <dc:date>2023-10-23T15:18:34.169848</dc:date>\n",
       "    <dc:format>image/svg+xml</dc:format>\n",
       "    <dc:creator>\n",
       "     <cc:Agent>\n",
       "      <dc:title>Matplotlib v3.8.0, https://matplotlib.org/</dc:title>\n",
       "     </cc:Agent>\n",
       "    </dc:creator>\n",
       "   </cc:Work>\n",
       "  </rdf:RDF>\n",
       " </metadata>\n",
       " <defs>\n",
       "  <style type=\"text/css\">*{stroke-linejoin: round; stroke-linecap: butt}</style>\n",
       " </defs>\n",
       " <g id=\"figure_1\">\n",
       "  <g id=\"patch_1\">\n",
       "   <path d=\"M 0 322.539375 \n",
       "L 445.848625 322.539375 \n",
       "L 445.848625 0 \n",
       "L 0 0 \n",
       "z\n",
       "\" style=\"fill: #ffffff\"/>\n",
       "  </g>\n",
       "  <g id=\"axes_1\">\n",
       "   <g id=\"patch_2\">\n",
       "    <path d=\"M 43.2065 286.212 \n",
       "L 400.3265 286.212 \n",
       "L 400.3265 20.1 \n",
       "L 43.2065 20.1 \n",
       "z\n",
       "\" style=\"fill: #ffffff\"/>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_1\">\n",
       "    <g id=\"xtick_1\">\n",
       "     <g id=\"line2d_1\">\n",
       "      <defs>\n",
       "       <path id=\"m25197b5681\" d=\"M 0 0 \n",
       "L 0 4.8 \n",
       "\" style=\"stroke: #262626\"/>\n",
       "      </defs>\n",
       "      <g>\n",
       "       <use xlink:href=\"#m25197b5681\" x=\"59.439227\" y=\"286.212\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_1\">\n",
       "      <!-- 0.0 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(53.323227 300.810875) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-30\" d=\"M 266 2259 \n",
       "Q 266 3072 433 3567 \n",
       "Q 600 4063 929 4331 \n",
       "Q 1259 4600 1759 4600 \n",
       "Q 2128 4600 2406 4451 \n",
       "Q 2684 4303 2865 4023 \n",
       "Q 3047 3744 3150 3342 \n",
       "Q 3253 2941 3253 2259 \n",
       "Q 3253 1453 3087 958 \n",
       "Q 2922 463 2592 192 \n",
       "Q 2263 -78 1759 -78 \n",
       "Q 1097 -78 719 397 \n",
       "Q 266 969 266 2259 \n",
       "z\n",
       "M 844 2259 \n",
       "Q 844 1131 1108 757 \n",
       "Q 1372 384 1759 384 \n",
       "Q 2147 384 2411 759 \n",
       "Q 2675 1134 2675 2259 \n",
       "Q 2675 3391 2411 3762 \n",
       "Q 2147 4134 1753 4134 \n",
       "Q 1366 4134 1134 3806 \n",
       "Q 844 3388 844 2259 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "        <path id=\"ArialMT-2e\" d=\"M 581 0 \n",
       "L 581 641 \n",
       "L 1222 641 \n",
       "L 1222 0 \n",
       "L 581 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_2\">\n",
       "     <g id=\"line2d_2\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m25197b5681\" x=\"124.370136\" y=\"286.212\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_2\">\n",
       "      <!-- 0.2 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(118.254136 300.810875) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-32\" d=\"M 3222 541 \n",
       "L 3222 0 \n",
       "L 194 0 \n",
       "Q 188 203 259 391 \n",
       "Q 375 700 629 1000 \n",
       "Q 884 1300 1366 1694 \n",
       "Q 2113 2306 2375 2664 \n",
       "Q 2638 3022 2638 3341 \n",
       "Q 2638 3675 2398 3904 \n",
       "Q 2159 4134 1775 4134 \n",
       "Q 1369 4134 1125 3890 \n",
       "Q 881 3647 878 3216 \n",
       "L 300 3275 \n",
       "Q 359 3922 746 4261 \n",
       "Q 1134 4600 1788 4600 \n",
       "Q 2447 4600 2831 4234 \n",
       "Q 3216 3869 3216 3328 \n",
       "Q 3216 3053 3103 2787 \n",
       "Q 2991 2522 2730 2228 \n",
       "Q 2469 1934 1863 1422 \n",
       "Q 1356 997 1212 845 \n",
       "Q 1069 694 975 541 \n",
       "L 3222 541 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-32\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_3\">\n",
       "     <g id=\"line2d_3\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m25197b5681\" x=\"189.301045\" y=\"286.212\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_3\">\n",
       "      <!-- 0.4 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(183.185045 300.810875) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-34\" d=\"M 2069 0 \n",
       "L 2069 1097 \n",
       "L 81 1097 \n",
       "L 81 1613 \n",
       "L 2172 4581 \n",
       "L 2631 4581 \n",
       "L 2631 1613 \n",
       "L 3250 1613 \n",
       "L 3250 1097 \n",
       "L 2631 1097 \n",
       "L 2631 0 \n",
       "L 2069 0 \n",
       "z\n",
       "M 2069 1613 \n",
       "L 2069 3678 \n",
       "L 634 1613 \n",
       "L 2069 1613 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-34\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_4\">\n",
       "     <g id=\"line2d_4\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m25197b5681\" x=\"254.231955\" y=\"286.212\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_4\">\n",
       "      <!-- 0.6 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(248.115955 300.810875) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-36\" d=\"M 3184 3459 \n",
       "L 2625 3416 \n",
       "Q 2550 3747 2413 3897 \n",
       "Q 2184 4138 1850 4138 \n",
       "Q 1581 4138 1378 3988 \n",
       "Q 1113 3794 959 3422 \n",
       "Q 806 3050 800 2363 \n",
       "Q 1003 2672 1297 2822 \n",
       "Q 1591 2972 1913 2972 \n",
       "Q 2475 2972 2870 2558 \n",
       "Q 3266 2144 3266 1488 \n",
       "Q 3266 1056 3080 686 \n",
       "Q 2894 316 2569 119 \n",
       "Q 2244 -78 1831 -78 \n",
       "Q 1128 -78 684 439 \n",
       "Q 241 956 241 2144 \n",
       "Q 241 3472 731 4075 \n",
       "Q 1159 4600 1884 4600 \n",
       "Q 2425 4600 2770 4297 \n",
       "Q 3116 3994 3184 3459 \n",
       "z\n",
       "M 888 1484 \n",
       "Q 888 1194 1011 928 \n",
       "Q 1134 663 1356 523 \n",
       "Q 1578 384 1822 384 \n",
       "Q 2178 384 2434 671 \n",
       "Q 2691 959 2691 1453 \n",
       "Q 2691 1928 2437 2201 \n",
       "Q 2184 2475 1800 2475 \n",
       "Q 1419 2475 1153 2201 \n",
       "Q 888 1928 888 1484 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-36\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_5\">\n",
       "     <g id=\"line2d_5\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m25197b5681\" x=\"319.162864\" y=\"286.212\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_5\">\n",
       "      <!-- 0.8 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(313.046864 300.810875) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-38\" d=\"M 1131 2484 \n",
       "Q 781 2613 612 2850 \n",
       "Q 444 3088 444 3419 \n",
       "Q 444 3919 803 4259 \n",
       "Q 1163 4600 1759 4600 \n",
       "Q 2359 4600 2725 4251 \n",
       "Q 3091 3903 3091 3403 \n",
       "Q 3091 3084 2923 2848 \n",
       "Q 2756 2613 2416 2484 \n",
       "Q 2838 2347 3058 2040 \n",
       "Q 3278 1734 3278 1309 \n",
       "Q 3278 722 2862 322 \n",
       "Q 2447 -78 1769 -78 \n",
       "Q 1091 -78 675 323 \n",
       "Q 259 725 259 1325 \n",
       "Q 259 1772 486 2073 \n",
       "Q 713 2375 1131 2484 \n",
       "z\n",
       "M 1019 3438 \n",
       "Q 1019 3113 1228 2906 \n",
       "Q 1438 2700 1772 2700 \n",
       "Q 2097 2700 2305 2904 \n",
       "Q 2513 3109 2513 3406 \n",
       "Q 2513 3716 2298 3927 \n",
       "Q 2084 4138 1766 4138 \n",
       "Q 1444 4138 1231 3931 \n",
       "Q 1019 3725 1019 3438 \n",
       "z\n",
       "M 838 1322 \n",
       "Q 838 1081 952 856 \n",
       "Q 1066 631 1291 507 \n",
       "Q 1516 384 1775 384 \n",
       "Q 2178 384 2440 643 \n",
       "Q 2703 903 2703 1303 \n",
       "Q 2703 1709 2433 1975 \n",
       "Q 2163 2241 1756 2241 \n",
       "Q 1359 2241 1098 1978 \n",
       "Q 838 1716 838 1322 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-38\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_6\">\n",
       "     <g id=\"line2d_6\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m25197b5681\" x=\"384.093773\" y=\"286.212\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_6\">\n",
       "      <!-- 1.0 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(377.977773 300.810875) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-31\" d=\"M 2384 0 \n",
       "L 1822 0 \n",
       "L 1822 3584 \n",
       "Q 1619 3391 1289 3197 \n",
       "Q 959 3003 697 2906 \n",
       "L 697 3450 \n",
       "Q 1169 3672 1522 3987 \n",
       "Q 1875 4303 2022 4600 \n",
       "L 2384 4600 \n",
       "L 2384 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-31\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"text_7\">\n",
       "     <!-- $x$ -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(218.8865 313.431375) scale(0.096 -0.096)\">\n",
       "      <defs>\n",
       "       <path id=\"DejaVuSans-Oblique-78\" d=\"M 3841 3500 \n",
       "L 2234 1784 \n",
       "L 3219 0 \n",
       "L 2559 0 \n",
       "L 1819 1388 \n",
       "L 531 0 \n",
       "L -166 0 \n",
       "L 1556 1844 \n",
       "L 641 3500 \n",
       "L 1300 3500 \n",
       "L 1972 2234 \n",
       "L 3144 3500 \n",
       "L 3841 3500 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-78\" transform=\"translate(0 0.3125)\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_2\">\n",
       "    <g id=\"ytick_1\">\n",
       "     <g id=\"line2d_7\">\n",
       "      <defs>\n",
       "       <path id=\"mb6dc1e0ef1\" d=\"M 0 0 \n",
       "L -4.8 0 \n",
       "\" style=\"stroke: #262626\"/>\n",
       "      </defs>\n",
       "      <g>\n",
       "       <use xlink:href=\"#mb6dc1e0ef1\" x=\"43.2065\" y=\"250.415383\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_8\">\n",
       "      <!-- −10 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(19.9795 253.564821) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-2212\" d=\"M 3381 1997 \n",
       "L 356 1997 \n",
       "L 356 2522 \n",
       "L 3381 2522 \n",
       "L 3381 1997 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-31\" x=\"58.398438\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"114.013672\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_2\">\n",
       "     <g id=\"line2d_8\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mb6dc1e0ef1\" x=\"43.2065\" y=\"214.205704\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_9\">\n",
       "      <!-- −8 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(24.873125 217.355142) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-38\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_3\">\n",
       "     <g id=\"line2d_9\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mb6dc1e0ef1\" x=\"43.2065\" y=\"177.996025\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_10\">\n",
       "      <!-- −6 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(24.873125 181.145463) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-36\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_4\">\n",
       "     <g id=\"line2d_10\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mb6dc1e0ef1\" x=\"43.2065\" y=\"141.786346\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_11\">\n",
       "      <!-- −4 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(24.873125 144.935783) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-34\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_5\">\n",
       "     <g id=\"line2d_11\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mb6dc1e0ef1\" x=\"43.2065\" y=\"105.576667\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_12\">\n",
       "      <!-- −2 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(24.873125 108.726104) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-32\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_6\">\n",
       "     <g id=\"line2d_12\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mb6dc1e0ef1\" x=\"43.2065\" y=\"69.366988\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_13\">\n",
       "      <!-- 0 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(30.012875 72.516425) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_7\">\n",
       "     <g id=\"line2d_13\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mb6dc1e0ef1\" x=\"43.2065\" y=\"33.157309\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_14\">\n",
       "      <!-- 2 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(30.012875 36.306746) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-32\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"text_15\">\n",
       "     <!-- $y$ -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(13.9635 156.036) rotate(-90) scale(0.096 -0.096)\">\n",
       "      <defs>\n",
       "       <path id=\"DejaVuSans-Oblique-79\" d=\"M 1588 -325 \n",
       "Q 1188 -997 936 -1164 \n",
       "Q 684 -1331 294 -1331 \n",
       "L -159 -1331 \n",
       "L -63 -850 \n",
       "L 269 -850 \n",
       "Q 509 -850 678 -719 \n",
       "Q 847 -588 1056 -206 \n",
       "L 1234 128 \n",
       "L 459 3500 \n",
       "L 1069 3500 \n",
       "L 1650 819 \n",
       "L 3256 3500 \n",
       "L 3859 3500 \n",
       "L 1588 -325 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-79\" transform=\"translate(0 0.3125)\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"PolyCollection_1\">\n",
       "    <defs>\n",
       "     <path id=\"m9e01f8f8fd\" d=\"M 59.439227 -290.220941 \n",
       "L 59.439227 -183.252093 \n",
       "L 62.718566 -185.300114 \n",
       "L 65.997905 -187.635926 \n",
       "L 69.277244 -190.255896 \n",
       "L 72.556583 -193.150082 \n",
       "L 75.835921 -196.301948 \n",
       "L 79.115261 -199.688352 \n",
       "L 82.394598 -203.279696 \n",
       "L 85.673938 -207.040279 \n",
       "L 88.953278 -210.929041 \n",
       "L 92.232615 -214.899476 \n",
       "L 95.511955 -218.90102 \n",
       "L 98.791295 -222.879074 \n",
       "L 102.070632 -226.774732 \n",
       "L 105.349969 -230.524939 \n",
       "L 108.629311 -234.057976 \n",
       "L 111.908649 -237.287017 \n",
       "L 115.187986 -240.098848 \n",
       "L 118.467328 -242.35586 \n",
       "L 121.746666 -243.98497 \n",
       "L 125.026003 -245.105458 \n",
       "L 128.305345 -245.944541 \n",
       "L 131.584682 -246.657394 \n",
       "L 134.86402 -247.304276 \n",
       "L 138.143362 -247.888897 \n",
       "L 141.422694 -248.390188 \n",
       "L 144.702037 -248.768726 \n",
       "L 147.981379 -248.970442 \n",
       "L 151.260711 -248.911522 \n",
       "L 154.540053 -248.456041 \n",
       "L 157.819395 -247.417515 \n",
       "L 161.098728 -245.673 \n",
       "L 164.37807 -243.261053 \n",
       "L 167.657412 -240.294451 \n",
       "L 170.936745 -236.870821 \n",
       "L 174.216087 -233.064643 \n",
       "L 177.495429 -228.937738 \n",
       "L 180.774762 -224.548546 \n",
       "L 184.054104 -219.955018 \n",
       "L 187.333446 -215.215053 \n",
       "L 190.612778 -210.386846 \n",
       "L 193.892121 -205.52658 \n",
       "L 197.171463 -200.687654 \n",
       "L 200.450795 -195.918523 \n",
       "L 203.730137 -191.261155 \n",
       "L 207.00948 -186.749626 \n",
       "L 210.288812 -182.408979 \n",
       "L 213.568154 -178.254285 \n",
       "L 216.847496 -174.290277 \n",
       "L 220.126829 -170.510991 \n",
       "L 223.406181 -166.899851 \n",
       "L 226.685504 -163.429352 \n",
       "L 229.964846 -160.058815 \n",
       "L 233.244188 -156.727542 \n",
       "L 236.523511 -153.325667 \n",
       "L 239.802872 -149.565469 \n",
       "L 243.082195 -144.463011 \n",
       "L 246.361537 -136.791751 \n",
       "L 249.640879 -127.679823 \n",
       "L 252.920222 -118.157739 \n",
       "L 256.199564 -108.598671 \n",
       "L 259.478887 -99.211668 \n",
       "L 262.758248 -90.167502 \n",
       "L 266.037571 -81.628128 \n",
       "L 269.316913 -73.752066 \n",
       "L 272.596255 -66.695299 \n",
       "L 275.875578 -60.608715 \n",
       "L 279.15494 -55.636159 \n",
       "L 282.434262 -51.909163 \n",
       "L 285.713605 -49.543894 \n",
       "L 288.992947 -48.638597 \n",
       "L 292.272289 -49.266911 \n",
       "L 295.551631 -51.476129 \n",
       "L 298.830954 -55.285294 \n",
       "L 302.110315 -60.679057 \n",
       "L 305.389638 -67.609246 \n",
       "L 308.66898 -75.992069 \n",
       "L 311.948322 -85.709545 \n",
       "L 315.227645 -96.608162 \n",
       "L 318.507007 -108.504441 \n",
       "L 321.78633 -121.185172 \n",
       "L 325.065672 -134.412074 \n",
       "L 328.345014 -147.928977 \n",
       "L 331.624356 -161.461092 \n",
       "L 334.903698 -174.726022 \n",
       "L 338.183021 -187.432544 \n",
       "L 341.462363 -199.283612 \n",
       "L 344.741705 -209.976784 \n",
       "L 348.021048 -219.221104 \n",
       "L 351.30039 -226.817038 \n",
       "L 354.579713 -232.719101 \n",
       "L 357.859055 -236.953974 \n",
       "L 361.138397 -239.541002 \n",
       "L 364.417739 -240.495242 \n",
       "L 367.697081 -239.827703 \n",
       "L 370.976423 -237.580675 \n",
       "L 374.255766 -233.796886 \n",
       "L 377.535088 -228.514095 \n",
       "L 380.814431 -221.738241 \n",
       "L 384.093773 -213.46195 \n",
       "L 384.093773 -220.570656 \n",
       "L 384.093773 -220.570656 \n",
       "L 380.814431 -228.067862 \n",
       "L 377.535088 -234.776987 \n",
       "L 374.255766 -240.319915 \n",
       "L 370.976423 -244.386548 \n",
       "L 367.697081 -246.77789 \n",
       "L 364.417739 -247.384729 \n",
       "L 361.138397 -246.170344 \n",
       "L 357.859055 -243.171437 \n",
       "L 354.579713 -238.504451 \n",
       "L 351.30039 -232.383493 \n",
       "L 348.021048 -225.109015 \n",
       "L 344.741705 -216.968974 \n",
       "L 341.462363 -208.161653 \n",
       "L 338.183021 -198.845838 \n",
       "L 334.903698 -189.19204 \n",
       "L 331.624356 -179.398001 \n",
       "L 328.345014 -169.671685 \n",
       "L 325.065672 -160.212769 \n",
       "L 321.78633 -151.215272 \n",
       "L 318.507007 -142.844597 \n",
       "L 315.227645 -135.245078 \n",
       "L 311.948322 -128.530318 \n",
       "L 308.66898 -122.780665 \n",
       "L 305.389638 -118.047866 \n",
       "L 302.110315 -114.350145 \n",
       "L 298.830954 -111.678412 \n",
       "L 295.551631 -109.995008 \n",
       "L 292.272289 -109.24262 \n",
       "L 288.992947 -109.341339 \n",
       "L 285.713605 -110.200087 \n",
       "L 282.434262 -111.718236 \n",
       "L 279.15494 -113.788729 \n",
       "L 275.875578 -116.305939 \n",
       "L 272.596255 -119.168179 \n",
       "L 269.316913 -122.280328 \n",
       "L 266.037571 -125.559423 \n",
       "L 262.758248 -128.935986 \n",
       "L 259.478887 -132.357621 \n",
       "L 256.199564 -135.792915 \n",
       "L 252.920222 -139.241157 \n",
       "L 249.640879 -142.762021 \n",
       "L 246.361537 -146.603224 \n",
       "L 243.082195 -151.692991 \n",
       "L 239.802872 -159.079843 \n",
       "L 236.523511 -167.478758 \n",
       "L 233.244188 -175.865586 \n",
       "L 229.964846 -183.929261 \n",
       "L 226.685504 -191.549767 \n",
       "L 223.406181 -198.667056 \n",
       "L 220.126829 -205.249135 \n",
       "L 216.847496 -211.281835 \n",
       "L 213.568154 -216.764873 \n",
       "L 210.288812 -221.708515 \n",
       "L 207.00948 -226.132024 \n",
       "L 203.730137 -230.061771 \n",
       "L 200.450795 -233.529452 \n",
       "L 197.171463 -236.570321 \n",
       "L 193.892121 -239.221896 \n",
       "L 190.612778 -241.5222 \n",
       "L 187.333446 -243.508726 \n",
       "L 184.054104 -245.216967 \n",
       "L 180.774762 -246.680246 \n",
       "L 177.495429 -247.928909 \n",
       "L 174.216087 -248.991845 \n",
       "L 170.936745 -249.898316 \n",
       "L 167.657412 -250.682302 \n",
       "L 164.37807 -251.3936 \n",
       "L 161.098728 -252.109082 \n",
       "L 157.819395 -252.926713 \n",
       "L 154.540053 -253.876744 \n",
       "L 151.260711 -254.835703 \n",
       "L 147.981379 -255.624791 \n",
       "L 144.702037 -256.124503 \n",
       "L 141.422694 -256.276181 \n",
       "L 138.143362 -256.059323 \n",
       "L 134.86402 -255.476374 \n",
       "L 131.584682 -254.555199 \n",
       "L 128.305345 -253.354551 \n",
       "L 125.026003 -251.995242 \n",
       "L 121.746666 -250.696195 \n",
       "L 118.467328 -249.750616 \n",
       "L 115.187986 -249.344207 \n",
       "L 111.908649 -249.469879 \n",
       "L 108.629311 -250.052835 \n",
       "L 105.349969 -251.039179 \n",
       "L 102.070632 -252.396208 \n",
       "L 98.791295 -254.100043 \n",
       "L 95.511955 -256.128503 \n",
       "L 92.232615 -258.455665 \n",
       "L 88.953278 -261.05201 \n",
       "L 85.673938 -263.883947 \n",
       "L 82.394598 -266.913593 \n",
       "L 79.115261 -270.100901 \n",
       "L 75.835921 -273.404059 \n",
       "L 72.556583 -276.780626 \n",
       "L 69.277244 -280.188893 \n",
       "L 65.997905 -283.589154 \n",
       "L 62.718566 -286.944317 \n",
       "L 59.439227 -290.220941 \n",
       "z\n",
       "\" style=\"stroke: #1f77b4; stroke-opacity: 0.5; stroke-width: 0.8\"/>\n",
       "    </defs>\n",
       "    <g clip-path=\"url(#p2a8fe0773f)\">\n",
       "     <use xlink:href=\"#m9e01f8f8fd\" x=\"0\" y=\"322.539375\" style=\"fill: #1f77b4; fill-opacity: 0.5; stroke: #1f77b4; stroke-opacity: 0.5; stroke-width: 0.8\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"PolyCollection_2\">\n",
       "    <defs>\n",
       "     <path id=\"m32c2fc02be\" d=\"M 59.439227 -183.252093 \n",
       "L 59.439227 -183.129659 \n",
       "L 62.718566 -185.171291 \n",
       "L 65.997905 -187.499476 \n",
       "L 69.277244 -190.110343 \n",
       "L 72.556583 -192.993595 \n",
       "L 75.835921 -196.132269 \n",
       "L 79.115261 -199.502637 \n",
       "L 82.394598 -203.074316 \n",
       "L 85.673938 -206.810549 \n",
       "L 88.953278 -210.66881 \n",
       "L 92.232615 -214.600504 \n",
       "L 95.511955 -218.552093 \n",
       "L 98.791295 -222.464622 \n",
       "L 102.070632 -226.272829 \n",
       "L 105.349969 -229.904563 \n",
       "L 108.629311 -233.276438 \n",
       "L 111.908649 -236.292057 \n",
       "L 115.187986 -238.849511 \n",
       "L 118.467328 -240.878102 \n",
       "L 121.746666 -242.403827 \n",
       "L 125.026003 -243.552482 \n",
       "L 128.305345 -244.46896 \n",
       "L 131.584682 -245.248569 \n",
       "L 134.86402 -245.930727 \n",
       "L 138.143362 -246.515138 \n",
       "L 141.422694 -246.979809 \n",
       "L 144.702037 -247.285386 \n",
       "L 147.981379 -247.380147 \n",
       "L 151.260711 -247.195429 \n",
       "L 154.540053 -246.643405 \n",
       "L 157.819395 -245.622473 \n",
       "L 161.098728 -244.046746 \n",
       "L 164.37807 -241.882514 \n",
       "L 167.657412 -239.156847 \n",
       "L 170.936745 -235.932031 \n",
       "L 174.216087 -232.280082 \n",
       "L 177.495429 -228.270765 \n",
       "L 180.774762 -223.971182 \n",
       "L 184.054104 -219.446245 \n",
       "L 187.333446 -214.758999 \n",
       "L 190.612778 -209.97128 \n",
       "L 193.892121 -205.141856 \n",
       "L 197.171463 -200.325903 \n",
       "L 200.450795 -195.573088 \n",
       "L 203.730137 -190.926132 \n",
       "L 207.00948 -186.419468 \n",
       "L 210.288812 -182.078139 \n",
       "L 213.568154 -177.916775 \n",
       "L 216.847496 -173.939162 \n",
       "L 220.126829 -170.137568 \n",
       "L 223.406181 -166.492353 \n",
       "L 226.685504 -162.970574 \n",
       "L 229.964846 -159.521632 \n",
       "L 233.244188 -156.06536 \n",
       "L 236.523511 -152.453063 \n",
       "L 239.802872 -148.344176 \n",
       "L 243.082195 -142.961411 \n",
       "L 246.361537 -135.600138 \n",
       "L 249.640879 -126.855539 \n",
       "L 252.920222 -117.553192 \n",
       "L 256.199564 -108.124785 \n",
       "L 259.478887 -98.820712 \n",
       "L 262.758248 -89.832211 \n",
       "L 266.037571 -81.331686 \n",
       "L 269.316913 -73.483371 \n",
       "L 272.596255 -66.446615 \n",
       "L 275.875578 -60.374293 \n",
       "L 279.15494 -55.411561 \n",
       "L 282.434262 -51.690747 \n",
       "L 285.713605 -49.3285 \n",
       "L 288.992947 -48.423375 \n",
       "L 292.272289 -49.049082 \n",
       "L 295.551631 -51.25293 \n",
       "L 298.830954 -55.053738 \n",
       "L 302.110315 -60.435864 \n",
       "L 305.389638 -67.350617 \n",
       "L 308.66898 -75.713497 \n",
       "L 311.948322 -85.405506 \n",
       "L 315.227645 -96.271732 \n",
       "L 318.507007 -108.126788 \n",
       "L 321.78633 -120.754728 \n",
       "L 325.065672 -133.913523 \n",
       "L 328.345014 -147.341808 \n",
       "L 331.624356 -160.757696 \n",
       "L 334.903698 -173.870287 \n",
       "L 338.183021 -186.380697 \n",
       "L 341.462363 -197.994079 \n",
       "L 344.741705 -208.439581 \n",
       "L 348.021048 -217.498338 \n",
       "L 351.30039 -225.033234 \n",
       "L 354.579713 -230.977234 \n",
       "L 357.859055 -235.290324 \n",
       "L 361.138397 -237.946656 \n",
       "L 364.417739 -238.94222 \n",
       "L 367.697081 -238.284063 \n",
       "L 370.976423 -236.014569 \n",
       "L 374.255766 -232.185118 \n",
       "L 377.535088 -226.858332 \n",
       "L 380.814431 -220.093952 \n",
       "L 384.093773 -211.942363 \n",
       "L 384.093773 -213.46195 \n",
       "L 384.093773 -213.46195 \n",
       "L 380.814431 -221.738241 \n",
       "L 377.535088 -228.514095 \n",
       "L 374.255766 -233.796886 \n",
       "L 370.976423 -237.580675 \n",
       "L 367.697081 -239.827703 \n",
       "L 364.417739 -240.495242 \n",
       "L 361.138397 -239.541002 \n",
       "L 357.859055 -236.953974 \n",
       "L 354.579713 -232.719101 \n",
       "L 351.30039 -226.817038 \n",
       "L 348.021048 -219.221104 \n",
       "L 344.741705 -209.976784 \n",
       "L 341.462363 -199.283612 \n",
       "L 338.183021 -187.432544 \n",
       "L 334.903698 -174.726022 \n",
       "L 331.624356 -161.461092 \n",
       "L 328.345014 -147.928977 \n",
       "L 325.065672 -134.412074 \n",
       "L 321.78633 -121.185172 \n",
       "L 318.507007 -108.504441 \n",
       "L 315.227645 -96.608162 \n",
       "L 311.948322 -85.709545 \n",
       "L 308.66898 -75.992069 \n",
       "L 305.389638 -67.609246 \n",
       "L 302.110315 -60.679057 \n",
       "L 298.830954 -55.285294 \n",
       "L 295.551631 -51.476129 \n",
       "L 292.272289 -49.266911 \n",
       "L 288.992947 -48.638597 \n",
       "L 285.713605 -49.543894 \n",
       "L 282.434262 -51.909163 \n",
       "L 279.15494 -55.636159 \n",
       "L 275.875578 -60.608715 \n",
       "L 272.596255 -66.695299 \n",
       "L 269.316913 -73.752066 \n",
       "L 266.037571 -81.628128 \n",
       "L 262.758248 -90.167502 \n",
       "L 259.478887 -99.211668 \n",
       "L 256.199564 -108.598671 \n",
       "L 252.920222 -118.157739 \n",
       "L 249.640879 -127.679823 \n",
       "L 246.361537 -136.791751 \n",
       "L 243.082195 -144.463011 \n",
       "L 239.802872 -149.565469 \n",
       "L 236.523511 -153.325667 \n",
       "L 233.244188 -156.727542 \n",
       "L 229.964846 -160.058815 \n",
       "L 226.685504 -163.429352 \n",
       "L 223.406181 -166.899851 \n",
       "L 220.126829 -170.510991 \n",
       "L 216.847496 -174.290277 \n",
       "L 213.568154 -178.254285 \n",
       "L 210.288812 -182.408979 \n",
       "L 207.00948 -186.749626 \n",
       "L 203.730137 -191.261155 \n",
       "L 200.450795 -195.918523 \n",
       "L 197.171463 -200.687654 \n",
       "L 193.892121 -205.52658 \n",
       "L 190.612778 -210.386846 \n",
       "L 187.333446 -215.215053 \n",
       "L 184.054104 -219.955018 \n",
       "L 180.774762 -224.548546 \n",
       "L 177.495429 -228.937738 \n",
       "L 174.216087 -233.064643 \n",
       "L 170.936745 -236.870821 \n",
       "L 167.657412 -240.294451 \n",
       "L 164.37807 -243.261053 \n",
       "L 161.098728 -245.673 \n",
       "L 157.819395 -247.417515 \n",
       "L 154.540053 -248.456041 \n",
       "L 151.260711 -248.911522 \n",
       "L 147.981379 -248.970442 \n",
       "L 144.702037 -248.768726 \n",
       "L 141.422694 -248.390188 \n",
       "L 138.143362 -247.888897 \n",
       "L 134.86402 -247.304276 \n",
       "L 131.584682 -246.657394 \n",
       "L 128.305345 -245.944541 \n",
       "L 125.026003 -245.105458 \n",
       "L 121.746666 -243.98497 \n",
       "L 118.467328 -242.35586 \n",
       "L 115.187986 -240.098848 \n",
       "L 111.908649 -237.287017 \n",
       "L 108.629311 -234.057976 \n",
       "L 105.349969 -230.524939 \n",
       "L 102.070632 -226.774732 \n",
       "L 98.791295 -222.879074 \n",
       "L 95.511955 -218.90102 \n",
       "L 92.232615 -214.899476 \n",
       "L 88.953278 -210.929041 \n",
       "L 85.673938 -207.040279 \n",
       "L 82.394598 -203.279696 \n",
       "L 79.115261 -199.688352 \n",
       "L 75.835921 -196.301948 \n",
       "L 72.556583 -193.150082 \n",
       "L 69.277244 -190.255896 \n",
       "L 65.997905 -187.635926 \n",
       "L 62.718566 -185.300114 \n",
       "L 59.439227 -183.252093 \n",
       "z\n",
       "\" style=\"stroke: #ff7f0e; stroke-opacity: 0.5; stroke-width: 0.8\"/>\n",
       "    </defs>\n",
       "    <g clip-path=\"url(#p2a8fe0773f)\">\n",
       "     <use xlink:href=\"#m32c2fc02be\" x=\"0\" y=\"322.539375\" style=\"fill: #ff7f0e; fill-opacity: 0.5; stroke: #ff7f0e; stroke-opacity: 0.5; stroke-width: 0.8\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"PolyCollection_3\">\n",
       "    <defs>\n",
       "     <path id=\"m51b025431f\" d=\"M 59.439227 -290.343375 \n",
       "L 59.439227 -290.220941 \n",
       "L 62.718566 -286.944317 \n",
       "L 65.997905 -283.589154 \n",
       "L 69.277244 -280.188893 \n",
       "L 72.556583 -276.780626 \n",
       "L 75.835921 -273.404059 \n",
       "L 79.115261 -270.100901 \n",
       "L 82.394598 -266.913593 \n",
       "L 85.673938 -263.883947 \n",
       "L 88.953278 -261.05201 \n",
       "L 92.232615 -258.455665 \n",
       "L 95.511955 -256.128503 \n",
       "L 98.791295 -254.100043 \n",
       "L 102.070632 -252.396208 \n",
       "L 105.349969 -251.039179 \n",
       "L 108.629311 -250.052835 \n",
       "L 111.908649 -249.469879 \n",
       "L 115.187986 -249.344207 \n",
       "L 118.467328 -249.750616 \n",
       "L 121.746666 -250.696195 \n",
       "L 125.026003 -251.995242 \n",
       "L 128.305345 -253.354551 \n",
       "L 131.584682 -254.555199 \n",
       "L 134.86402 -255.476374 \n",
       "L 138.143362 -256.059323 \n",
       "L 141.422694 -256.276181 \n",
       "L 144.702037 -256.124503 \n",
       "L 147.981379 -255.624791 \n",
       "L 151.260711 -254.835703 \n",
       "L 154.540053 -253.876744 \n",
       "L 157.819395 -252.926713 \n",
       "L 161.098728 -252.109082 \n",
       "L 164.37807 -251.3936 \n",
       "L 167.657412 -250.682302 \n",
       "L 170.936745 -249.898316 \n",
       "L 174.216087 -248.991845 \n",
       "L 177.495429 -247.928909 \n",
       "L 180.774762 -246.680246 \n",
       "L 184.054104 -245.216967 \n",
       "L 187.333446 -243.508726 \n",
       "L 190.612778 -241.5222 \n",
       "L 193.892121 -239.221896 \n",
       "L 197.171463 -236.570321 \n",
       "L 200.450795 -233.529452 \n",
       "L 203.730137 -230.061771 \n",
       "L 207.00948 -226.132024 \n",
       "L 210.288812 -221.708515 \n",
       "L 213.568154 -216.764873 \n",
       "L 216.847496 -211.281835 \n",
       "L 220.126829 -205.249135 \n",
       "L 223.406181 -198.667056 \n",
       "L 226.685504 -191.549767 \n",
       "L 229.964846 -183.929261 \n",
       "L 233.244188 -175.865586 \n",
       "L 236.523511 -167.478758 \n",
       "L 239.802872 -159.079843 \n",
       "L 243.082195 -151.692991 \n",
       "L 246.361537 -146.603224 \n",
       "L 249.640879 -142.762021 \n",
       "L 252.920222 -139.241157 \n",
       "L 256.199564 -135.792915 \n",
       "L 259.478887 -132.357621 \n",
       "L 262.758248 -128.935986 \n",
       "L 266.037571 -125.559423 \n",
       "L 269.316913 -122.280328 \n",
       "L 272.596255 -119.168179 \n",
       "L 275.875578 -116.305939 \n",
       "L 279.15494 -113.788729 \n",
       "L 282.434262 -111.718236 \n",
       "L 285.713605 -110.200087 \n",
       "L 288.992947 -109.341339 \n",
       "L 292.272289 -109.24262 \n",
       "L 295.551631 -109.995008 \n",
       "L 298.830954 -111.678412 \n",
       "L 302.110315 -114.350145 \n",
       "L 305.389638 -118.047866 \n",
       "L 308.66898 -122.780665 \n",
       "L 311.948322 -128.530318 \n",
       "L 315.227645 -135.245078 \n",
       "L 318.507007 -142.844597 \n",
       "L 321.78633 -151.215272 \n",
       "L 325.065672 -160.212769 \n",
       "L 328.345014 -169.671685 \n",
       "L 331.624356 -179.398001 \n",
       "L 334.903698 -189.19204 \n",
       "L 338.183021 -198.845838 \n",
       "L 341.462363 -208.161653 \n",
       "L 344.741705 -216.968974 \n",
       "L 348.021048 -225.109015 \n",
       "L 351.30039 -232.383493 \n",
       "L 354.579713 -238.504451 \n",
       "L 357.859055 -243.171437 \n",
       "L 361.138397 -246.170344 \n",
       "L 364.417739 -247.384729 \n",
       "L 367.697081 -246.77789 \n",
       "L 370.976423 -244.386548 \n",
       "L 374.255766 -240.319915 \n",
       "L 377.535088 -234.776987 \n",
       "L 380.814431 -228.067862 \n",
       "L 384.093773 -220.570656 \n",
       "L 384.093773 -222.090241 \n",
       "L 384.093773 -222.090241 \n",
       "L 380.814431 -229.712152 \n",
       "L 377.535088 -236.43275 \n",
       "L 374.255766 -241.931683 \n",
       "L 370.976423 -245.952654 \n",
       "L 367.697081 -248.32153 \n",
       "L 364.417739 -248.937751 \n",
       "L 361.138397 -247.764691 \n",
       "L 357.859055 -244.835087 \n",
       "L 354.579713 -240.246318 \n",
       "L 351.30039 -234.167297 \n",
       "L 348.021048 -226.831781 \n",
       "L 344.741705 -218.506178 \n",
       "L 341.462363 -209.451186 \n",
       "L 338.183021 -199.897686 \n",
       "L 334.903698 -190.047779 \n",
       "L 331.624356 -180.101397 \n",
       "L 328.345014 -170.258854 \n",
       "L 325.065672 -160.711319 \n",
       "L 321.78633 -151.645717 \n",
       "L 318.507007 -143.222259 \n",
       "L 315.227645 -135.5815 \n",
       "L 311.948322 -128.834349 \n",
       "L 308.66898 -123.059237 \n",
       "L 305.389638 -118.306496 \n",
       "L 302.110315 -114.59333 \n",
       "L 298.830954 -111.909959 \n",
       "L 295.551631 -110.218216 \n",
       "L 292.272289 -109.46044 \n",
       "L 288.992947 -109.55657 \n",
       "L 285.713605 -110.415481 \n",
       "L 282.434262 -111.936661 \n",
       "L 279.15494 -114.013327 \n",
       "L 275.875578 -116.540361 \n",
       "L 272.596255 -119.416863 \n",
       "L 269.316913 -122.549014 \n",
       "L 266.037571 -125.855865 \n",
       "L 262.758248 -129.271276 \n",
       "L 259.478887 -132.748569 \n",
       "L 256.199564 -136.2668 \n",
       "L 252.920222 -139.845705 \n",
       "L 249.640879 -143.586306 \n",
       "L 246.361537 -147.794837 \n",
       "L 243.082195 -153.194591 \n",
       "L 239.802872 -160.301137 \n",
       "L 236.523511 -168.351362 \n",
       "L 233.244188 -176.527768 \n",
       "L 229.964846 -184.466445 \n",
       "L 226.685504 -192.008545 \n",
       "L 223.406181 -199.074563 \n",
       "L 220.126829 -205.622553 \n",
       "L 216.847496 -211.632946 \n",
       "L 213.568154 -217.10238 \n",
       "L 210.288812 -222.039358 \n",
       "L 207.00948 -226.462182 \n",
       "L 203.730137 -230.396797 \n",
       "L 200.450795 -233.874886 \n",
       "L 197.171463 -236.932071 \n",
       "L 193.892121 -239.60662 \n",
       "L 190.612778 -241.937763 \n",
       "L 187.333446 -243.96478 \n",
       "L 184.054104 -245.725739 \n",
       "L 180.774762 -247.257611 \n",
       "L 177.495429 -248.59588 \n",
       "L 174.216087 -249.776407 \n",
       "L 170.936745 -250.837107 \n",
       "L 167.657412 -251.819907 \n",
       "L 164.37807 -252.77214 \n",
       "L 161.098728 -253.735337 \n",
       "L 157.819395 -254.721755 \n",
       "L 154.540053 -255.68938 \n",
       "L 151.260711 -256.551796 \n",
       "L 147.981379 -257.215086 \n",
       "L 144.702037 -257.607843 \n",
       "L 141.422694 -257.686561 \n",
       "L 138.143362 -257.433082 \n",
       "L 134.86402 -256.849923 \n",
       "L 131.584682 -255.964024 \n",
       "L 128.305345 -254.830132 \n",
       "L 125.026003 -253.548219 \n",
       "L 121.746666 -252.277337 \n",
       "L 118.467328 -251.228373 \n",
       "L 115.187986 -250.593544 \n",
       "L 111.908649 -250.46484 \n",
       "L 108.629311 -250.834374 \n",
       "L 105.349969 -251.659555 \n",
       "L 102.070632 -252.898112 \n",
       "L 98.791295 -254.514497 \n",
       "L 95.511955 -256.477429 \n",
       "L 92.232615 -258.754634 \n",
       "L 88.953278 -261.312243 \n",
       "L 85.673938 -264.113678 \n",
       "L 82.394598 -267.118975 \n",
       "L 79.115261 -270.28662 \n",
       "L 75.835921 -273.573737 \n",
       "L 72.556583 -276.937113 \n",
       "L 69.277244 -280.334447 \n",
       "L 65.997905 -283.725603 \n",
       "L 62.718566 -287.073144 \n",
       "L 59.439227 -290.343375 \n",
       "z\n",
       "\" style=\"stroke: #ff7f0e; stroke-opacity: 0.5; stroke-width: 0.8\"/>\n",
       "    </defs>\n",
       "    <g clip-path=\"url(#p2a8fe0773f)\">\n",
       "     <use xlink:href=\"#m51b025431f\" x=\"0\" y=\"322.539375\" style=\"fill: #ff7f0e; fill-opacity: 0.5; stroke: #ff7f0e; stroke-opacity: 0.5; stroke-width: 0.8\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"line2d_14\">\n",
       "    <defs>\n",
       "     <path id=\"m0af59e3531\" d=\"M -5 5 \n",
       "L 5 -5 \n",
       "M -5 -5 \n",
       "L 5 5 \n",
       "\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "    </defs>\n",
       "    <g clip-path=\"url(#p2a8fe0773f)\">\n",
       "     <use xlink:href=\"#m0af59e3531\" x=\"361.243318\" y=\"73.683928\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     <use xlink:href=\"#m0af59e3531\" x=\"162.151989\" y=\"74.43002\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     <use xlink:href=\"#m0af59e3531\" x=\"119.149308\" y=\"76.428928\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     <use xlink:href=\"#m0af59e3531\" x=\"243.082195\" y=\"174.559256\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     <use xlink:href=\"#m0af59e3531\" x=\"147.981379\" y=\"69.751081\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     <use xlink:href=\"#m0af59e3531\" x=\"384.093773\" y=\"108.232693\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     <use xlink:href=\"#m0af59e3531\" x=\"344.741705\" y=\"112.807114\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"line2d_15\">\n",
       "    <path d=\"M 59.439227 85.802856 \n",
       "L 62.718566 86.417159 \n",
       "L 65.997905 86.926835 \n",
       "L 69.277244 87.31698 \n",
       "L 72.556583 87.574021 \n",
       "L 75.835921 87.686372 \n",
       "L 79.115261 87.644747 \n",
       "L 82.394598 87.44273 \n",
       "L 85.673938 87.077262 \n",
       "L 88.953278 86.54885 \n",
       "L 92.232615 85.861805 \n",
       "L 95.511955 85.024614 \n",
       "L 98.791295 84.049816 \n",
       "L 102.070632 82.953905 \n",
       "L 105.349969 81.757315 \n",
       "L 108.629311 80.483969 \n",
       "L 111.908649 79.160927 \n",
       "L 115.187986 77.817847 \n",
       "L 118.467328 76.486137 \n",
       "L 121.746666 75.198793 \n",
       "L 125.026003 73.989025 \n",
       "L 128.305345 72.889829 \n",
       "L 131.584682 71.933079 \n",
       "L 134.86402 71.14905 \n",
       "L 138.143362 70.565265 \n",
       "L 141.422694 70.20619 \n",
       "L 144.702037 70.09276 \n",
       "L 147.981379 70.241758 \n",
       "L 151.260711 70.665763 \n",
       "L 154.540053 71.372983 \n",
       "L 157.819395 72.367261 \n",
       "L 161.098728 73.648334 \n",
       "L 164.37807 75.212049 \n",
       "L 167.657412 77.050998 \n",
       "L 170.936745 79.154806 \n",
       "L 174.216087 81.511131 \n",
       "L 177.495429 84.106052 \n",
       "L 180.774762 86.924979 \n",
       "L 184.054104 89.953383 \n",
       "L 187.333446 93.177486 \n",
       "L 190.612778 96.584853 \n",
       "L 193.892121 100.165137 \n",
       "L 197.171463 103.910387 \n",
       "L 200.450795 107.815388 \n",
       "L 203.730137 111.877912 \n",
       "L 207.00948 116.09855 \n",
       "L 210.288812 120.480627 \n",
       "L 213.568154 125.029796 \n",
       "L 216.847496 129.753319 \n",
       "L 220.126829 134.659314 \n",
       "L 223.406181 139.755919 \n",
       "L 226.685504 145.049815 \n",
       "L 229.964846 150.545337 \n",
       "L 233.244188 156.242811 \n",
       "L 236.523511 162.137163 \n",
       "L 239.802872 168.216719 \n",
       "L 243.082195 174.461374 \n",
       "L 246.361537 180.841888 \n",
       "L 249.640879 187.318453 \n",
       "L 252.920222 193.839927 \n",
       "L 256.199564 200.343582 \n",
       "L 259.478887 206.754734 \n",
       "L 262.758248 212.987631 \n",
       "L 266.037571 218.9456 \n",
       "L 269.316913 224.523178 \n",
       "L 272.596255 229.607636 \n",
       "L 275.875578 234.082048 \n",
       "L 279.15494 237.826931 \n",
       "L 282.434262 240.725671 \n",
       "L 285.713605 242.667385 \n",
       "L 288.992947 243.549407 \n",
       "L 292.272289 243.284614 \n",
       "L 295.551631 241.803802 \n",
       "L 298.830954 239.057522 \n",
       "L 302.110315 235.024778 \n",
       "L 305.389638 229.710819 \n",
       "L 308.66898 223.153008 \n",
       "L 311.948322 215.419443 \n",
       "L 315.227645 206.612755 \n",
       "L 318.507007 196.864856 \n",
       "L 321.78633 186.339153 \n",
       "L 325.065672 175.226954 \n",
       "L 328.345014 163.739044 \n",
       "L 331.624356 152.109828 \n",
       "L 334.903698 140.580342 \n",
       "L 338.183021 129.400184 \n",
       "L 341.462363 118.816742 \n",
       "L 344.741705 109.066495 \n",
       "L 348.021048 100.374316 \n",
       "L 351.30039 92.93911 \n",
       "L 354.579713 86.927599 \n",
       "L 357.859055 82.47667 \n",
       "L 361.138397 79.683702 \n",
       "L 364.417739 78.59939 \n",
       "L 367.697081 79.236578 \n",
       "L 370.976423 81.555764 \n",
       "L 374.255766 85.480974 \n",
       "L 377.535088 90.893834 \n",
       "L 380.814431 97.636323 \n",
       "L 384.093773 105.523073 \n",
       "\" clip-path=\"url(#p2a8fe0773f)\" style=\"fill: none; stroke: #1f77b4; stroke-width: 2; stroke-linecap: round\"/>\n",
       "   </g>\n",
       "   <g id=\"line2d_16\">\n",
       "    <path d=\"M 59.439227 141.258046 \n",
       "L 62.718566 136.839836 \n",
       "L 65.997905 132.438019 \n",
       "L 69.277244 128.068923 \n",
       "L 72.556583 123.74881 \n",
       "L 75.835921 119.493764 \n",
       "L 79.115261 115.319714 \n",
       "L 82.394598 111.242307 \n",
       "L 85.673938 107.276879 \n",
       "L 88.953278 103.43843 \n",
       "L 92.232615 99.741525 \n",
       "L 95.511955 96.200274 \n",
       "L 98.791295 92.828274 \n",
       "L 102.070632 89.638566 \n",
       "L 105.349969 86.643571 \n",
       "L 108.629311 83.855093 \n",
       "L 111.908649 81.284228 \n",
       "L 115.187986 78.941354 \n",
       "L 118.467328 76.836074 \n",
       "L 121.746666 74.977212 \n",
       "L 125.026003 73.372766 \n",
       "L 128.305345 72.029868 \n",
       "L 131.584682 70.954776 \n",
       "L 134.86402 70.152847 \n",
       "L 138.143362 69.628505 \n",
       "L 141.422694 69.385238 \n",
       "L 144.702037 69.42558 \n",
       "L 147.981379 69.751081 \n",
       "L 151.260711 70.362315 \n",
       "L 154.540053 71.258871 \n",
       "L 157.819395 72.439334 \n",
       "L 161.098728 73.901278 \n",
       "L 164.37807 75.641302 \n",
       "L 167.657412 77.654963 \n",
       "L 170.936745 79.936845 \n",
       "L 174.216087 82.480516 \n",
       "L 177.495429 85.278546 \n",
       "L 180.774762 88.322516 \n",
       "L 184.054104 91.603001 \n",
       "L 187.333446 95.109634 \n",
       "L 190.612778 98.831009 \n",
       "L 193.892121 102.754804 \n",
       "L 197.171463 106.867681 \n",
       "L 200.450795 111.155394 \n",
       "L 203.730137 115.602697 \n",
       "L 207.00948 120.193383 \n",
       "L 210.288812 124.910302 \n",
       "L 213.568154 129.735362 \n",
       "L 216.847496 134.649473 \n",
       "L 220.126829 139.632618 \n",
       "L 223.406181 144.663805 \n",
       "L 226.685504 149.721026 \n",
       "L 229.964846 154.781355 \n",
       "L 233.244188 159.820852 \n",
       "L 236.523511 164.814456 \n",
       "L 239.802872 169.73631 \n",
       "L 243.082195 174.559256 \n",
       "L 246.361537 179.255312 \n",
       "L 249.640879 183.795318 \n",
       "L 252.920222 188.149091 \n",
       "L 256.199564 192.285441 \n",
       "L 259.478887 196.172053 \n",
       "L 262.758248 199.775691 \n",
       "L 266.037571 203.06209 \n",
       "L 269.316913 205.99613 \n",
       "L 272.596255 208.541864 \n",
       "L 275.875578 210.66274 \n",
       "L 279.15494 212.321668 \n",
       "L 282.434262 213.481356 \n",
       "L 285.713605 214.104568 \n",
       "L 288.992947 214.154527 \n",
       "L 292.272289 213.595399 \n",
       "L 295.551631 212.392934 \n",
       "L 298.830954 210.515183 \n",
       "L 302.110315 207.93332 \n",
       "L 305.389638 204.623059 \n",
       "L 308.66898 200.565435 \n",
       "L 311.948322 195.748791 \n",
       "L 315.227645 190.17047 \n",
       "L 318.507007 183.838639 \n",
       "L 321.78633 176.77506 \n",
       "L 325.065672 169.017418 \n",
       "L 328.345014 160.622388 \n",
       "L 331.624356 151.668852 \n",
       "L 334.903698 142.261112 \n",
       "L 338.183021 132.532305 \n",
       "L 341.462363 122.647663 \n",
       "L 344.741705 112.807114 \n",
       "L 348.021048 103.247454 \n",
       "L 351.30039 94.243164 \n",
       "L 354.579713 86.104963 \n",
       "L 357.859055 79.175992 \n",
       "L 361.138397 73.824832 \n",
       "L 364.417739 70.432912 \n",
       "L 367.697081 69.377024 \n",
       "L 370.976423 71.004558 \n",
       "L 374.255766 75.601085 \n",
       "L 377.535088 83.349955 \n",
       "L 380.814431 94.284158 \n",
       "L 384.093773 108.232693 \n",
       "\" clip-path=\"url(#p2a8fe0773f)\" style=\"fill: none; stroke-dasharray: 7.68,1.92,1.2,1.92; stroke-dashoffset: 0; stroke: #bf00bf; stroke-width: 1.2\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_3\">\n",
       "    <path d=\"M 43.2065 250.415383 \n",
       "L 43.2065 33.157309 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_4\">\n",
       "    <path d=\"M 59.439227 286.212 \n",
       "L 384.093773 286.212 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"text_16\">\n",
       "    <!-- N=3, psi=0.10 -->\n",
       "    <g style=\"fill: #262626\" transform=\"translate(191.87975 14.1) scale(0.096 -0.096)\">\n",
       "     <defs>\n",
       "      <path id=\"ArialMT-4e\" d=\"M 488 0 \n",
       "L 488 4581 \n",
       "L 1109 4581 \n",
       "L 3516 984 \n",
       "L 3516 4581 \n",
       "L 4097 4581 \n",
       "L 4097 0 \n",
       "L 3475 0 \n",
       "L 1069 3600 \n",
       "L 1069 0 \n",
       "L 488 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-3d\" d=\"M 3381 2694 \n",
       "L 356 2694 \n",
       "L 356 3219 \n",
       "L 3381 3219 \n",
       "L 3381 2694 \n",
       "z\n",
       "M 3381 1303 \n",
       "L 356 1303 \n",
       "L 356 1828 \n",
       "L 3381 1828 \n",
       "L 3381 1303 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-33\" d=\"M 269 1209 \n",
       "L 831 1284 \n",
       "Q 928 806 1161 595 \n",
       "Q 1394 384 1728 384 \n",
       "Q 2125 384 2398 659 \n",
       "Q 2672 934 2672 1341 \n",
       "Q 2672 1728 2419 1979 \n",
       "Q 2166 2231 1775 2231 \n",
       "Q 1616 2231 1378 2169 \n",
       "L 1441 2663 \n",
       "Q 1497 2656 1531 2656 \n",
       "Q 1891 2656 2178 2843 \n",
       "Q 2466 3031 2466 3422 \n",
       "Q 2466 3731 2256 3934 \n",
       "Q 2047 4138 1716 4138 \n",
       "Q 1388 4138 1169 3931 \n",
       "Q 950 3725 888 3313 \n",
       "L 325 3413 \n",
       "Q 428 3978 793 4289 \n",
       "Q 1159 4600 1703 4600 \n",
       "Q 2078 4600 2393 4439 \n",
       "Q 2709 4278 2876 4000 \n",
       "Q 3044 3722 3044 3409 \n",
       "Q 3044 3113 2884 2869 \n",
       "Q 2725 2625 2413 2481 \n",
       "Q 2819 2388 3044 2092 \n",
       "Q 3269 1797 3269 1353 \n",
       "Q 3269 753 2831 336 \n",
       "Q 2394 -81 1725 -81 \n",
       "Q 1122 -81 723 278 \n",
       "Q 325 638 269 1209 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-2c\" d=\"M 569 0 \n",
       "L 569 641 \n",
       "L 1209 641 \n",
       "L 1209 0 \n",
       "Q 1209 -353 1084 -570 \n",
       "Q 959 -788 688 -906 \n",
       "L 531 -666 \n",
       "Q 709 -588 793 -436 \n",
       "Q 878 -284 888 0 \n",
       "L 569 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-20\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-70\" d=\"M 422 -1272 \n",
       "L 422 3319 \n",
       "L 934 3319 \n",
       "L 934 2888 \n",
       "Q 1116 3141 1344 3267 \n",
       "Q 1572 3394 1897 3394 \n",
       "Q 2322 3394 2647 3175 \n",
       "Q 2972 2956 3137 2557 \n",
       "Q 3303 2159 3303 1684 \n",
       "Q 3303 1175 3120 767 \n",
       "Q 2938 359 2589 142 \n",
       "Q 2241 -75 1856 -75 \n",
       "Q 1575 -75 1351 44 \n",
       "Q 1128 163 984 344 \n",
       "L 984 -1272 \n",
       "L 422 -1272 \n",
       "z\n",
       "M 931 1641 \n",
       "Q 931 1000 1190 694 \n",
       "Q 1450 388 1819 388 \n",
       "Q 2194 388 2461 705 \n",
       "Q 2728 1022 2728 1688 \n",
       "Q 2728 2322 2467 2637 \n",
       "Q 2206 2953 1844 2953 \n",
       "Q 1484 2953 1207 2617 \n",
       "Q 931 2281 931 1641 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-73\" d=\"M 197 991 \n",
       "L 753 1078 \n",
       "Q 800 744 1014 566 \n",
       "Q 1228 388 1613 388 \n",
       "Q 2000 388 2187 545 \n",
       "Q 2375 703 2375 916 \n",
       "Q 2375 1106 2209 1216 \n",
       "Q 2094 1291 1634 1406 \n",
       "Q 1016 1563 777 1677 \n",
       "Q 538 1791 414 1992 \n",
       "Q 291 2194 291 2438 \n",
       "Q 291 2659 392 2848 \n",
       "Q 494 3038 669 3163 \n",
       "Q 800 3259 1026 3326 \n",
       "Q 1253 3394 1513 3394 \n",
       "Q 1903 3394 2198 3281 \n",
       "Q 2494 3169 2634 2976 \n",
       "Q 2775 2784 2828 2463 \n",
       "L 2278 2388 \n",
       "Q 2241 2644 2061 2787 \n",
       "Q 1881 2931 1553 2931 \n",
       "Q 1166 2931 1000 2803 \n",
       "Q 834 2675 834 2503 \n",
       "Q 834 2394 903 2306 \n",
       "Q 972 2216 1119 2156 \n",
       "Q 1203 2125 1616 2013 \n",
       "Q 2213 1853 2448 1751 \n",
       "Q 2684 1650 2818 1456 \n",
       "Q 2953 1263 2953 975 \n",
       "Q 2953 694 2789 445 \n",
       "Q 2625 197 2315 61 \n",
       "Q 2006 -75 1616 -75 \n",
       "Q 969 -75 630 194 \n",
       "Q 291 463 197 991 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-69\" d=\"M 425 3934 \n",
       "L 425 4581 \n",
       "L 988 4581 \n",
       "L 988 3934 \n",
       "L 425 3934 \n",
       "z\n",
       "M 425 0 \n",
       "L 425 3319 \n",
       "L 988 3319 \n",
       "L 988 0 \n",
       "L 425 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "     </defs>\n",
       "     <use xlink:href=\"#ArialMT-4e\"/>\n",
       "     <use xlink:href=\"#ArialMT-3d\" x=\"72.216797\"/>\n",
       "     <use xlink:href=\"#ArialMT-33\" x=\"130.615234\"/>\n",
       "     <use xlink:href=\"#ArialMT-2c\" x=\"186.230469\"/>\n",
       "     <use xlink:href=\"#ArialMT-20\" x=\"214.013672\"/>\n",
       "     <use xlink:href=\"#ArialMT-70\" x=\"241.796875\"/>\n",
       "     <use xlink:href=\"#ArialMT-73\" x=\"297.412109\"/>\n",
       "     <use xlink:href=\"#ArialMT-69\" x=\"347.412109\"/>\n",
       "     <use xlink:href=\"#ArialMT-3d\" x=\"369.628906\"/>\n",
       "     <use xlink:href=\"#ArialMT-30\" x=\"428.027344\"/>\n",
       "     <use xlink:href=\"#ArialMT-2e\" x=\"483.642578\"/>\n",
       "     <use xlink:href=\"#ArialMT-31\" x=\"511.425781\"/>\n",
       "     <use xlink:href=\"#ArialMT-30\" x=\"567.041016\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"legend_1\">\n",
       "    <g id=\"line2d_17\">\n",
       "     <g>\n",
       "      <use xlink:href=\"#m0af59e3531\" x=\"59.9265\" y=\"220.007125\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"text_17\">\n",
       "     <!-- Observations -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(75.7665 223.087125) scale(0.088 -0.088)\">\n",
       "      <defs>\n",
       "       <path id=\"ArialMT-4f\" d=\"M 309 2231 \n",
       "Q 309 3372 921 4017 \n",
       "Q 1534 4663 2503 4663 \n",
       "Q 3138 4663 3647 4359 \n",
       "Q 4156 4056 4423 3514 \n",
       "Q 4691 2972 4691 2284 \n",
       "Q 4691 1588 4409 1038 \n",
       "Q 4128 488 3612 205 \n",
       "Q 3097 -78 2500 -78 \n",
       "Q 1853 -78 1343 234 \n",
       "Q 834 547 571 1087 \n",
       "Q 309 1628 309 2231 \n",
       "z\n",
       "M 934 2222 \n",
       "Q 934 1394 1379 917 \n",
       "Q 1825 441 2497 441 \n",
       "Q 3181 441 3623 922 \n",
       "Q 4066 1403 4066 2288 \n",
       "Q 4066 2847 3877 3264 \n",
       "Q 3688 3681 3323 3911 \n",
       "Q 2959 4141 2506 4141 \n",
       "Q 1863 4141 1398 3698 \n",
       "Q 934 3256 934 2222 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-62\" d=\"M 941 0 \n",
       "L 419 0 \n",
       "L 419 4581 \n",
       "L 981 4581 \n",
       "L 981 2947 \n",
       "Q 1338 3394 1891 3394 \n",
       "Q 2197 3394 2470 3270 \n",
       "Q 2744 3147 2920 2923 \n",
       "Q 3097 2700 3197 2384 \n",
       "Q 3297 2069 3297 1709 \n",
       "Q 3297 856 2875 390 \n",
       "Q 2453 -75 1863 -75 \n",
       "Q 1275 -75 941 416 \n",
       "L 941 0 \n",
       "z\n",
       "M 934 1684 \n",
       "Q 934 1088 1097 822 \n",
       "Q 1363 388 1816 388 \n",
       "Q 2184 388 2453 708 \n",
       "Q 2722 1028 2722 1663 \n",
       "Q 2722 2313 2464 2622 \n",
       "Q 2206 2931 1841 2931 \n",
       "Q 1472 2931 1203 2611 \n",
       "Q 934 2291 934 1684 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-65\" d=\"M 2694 1069 \n",
       "L 3275 997 \n",
       "Q 3138 488 2766 206 \n",
       "Q 2394 -75 1816 -75 \n",
       "Q 1088 -75 661 373 \n",
       "Q 234 822 234 1631 \n",
       "Q 234 2469 665 2931 \n",
       "Q 1097 3394 1784 3394 \n",
       "Q 2450 3394 2872 2941 \n",
       "Q 3294 2488 3294 1666 \n",
       "Q 3294 1616 3291 1516 \n",
       "L 816 1516 \n",
       "Q 847 969 1125 678 \n",
       "Q 1403 388 1819 388 \n",
       "Q 2128 388 2347 550 \n",
       "Q 2566 713 2694 1069 \n",
       "z\n",
       "M 847 1978 \n",
       "L 2700 1978 \n",
       "Q 2663 2397 2488 2606 \n",
       "Q 2219 2931 1791 2931 \n",
       "Q 1403 2931 1139 2672 \n",
       "Q 875 2413 847 1978 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-72\" d=\"M 416 0 \n",
       "L 416 3319 \n",
       "L 922 3319 \n",
       "L 922 2816 \n",
       "Q 1116 3169 1280 3281 \n",
       "Q 1444 3394 1641 3394 \n",
       "Q 1925 3394 2219 3213 \n",
       "L 2025 2691 \n",
       "Q 1819 2813 1613 2813 \n",
       "Q 1428 2813 1281 2702 \n",
       "Q 1134 2591 1072 2394 \n",
       "Q 978 2094 978 1738 \n",
       "L 978 0 \n",
       "L 416 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-76\" d=\"M 1344 0 \n",
       "L 81 3319 \n",
       "L 675 3319 \n",
       "L 1388 1331 \n",
       "Q 1503 1009 1600 663 \n",
       "Q 1675 925 1809 1294 \n",
       "L 2547 3319 \n",
       "L 3125 3319 \n",
       "L 1869 0 \n",
       "L 1344 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-61\" d=\"M 2588 409 \n",
       "Q 2275 144 1986 34 \n",
       "Q 1697 -75 1366 -75 \n",
       "Q 819 -75 525 192 \n",
       "Q 231 459 231 875 \n",
       "Q 231 1119 342 1320 \n",
       "Q 453 1522 633 1644 \n",
       "Q 813 1766 1038 1828 \n",
       "Q 1203 1872 1538 1913 \n",
       "Q 2219 1994 2541 2106 \n",
       "Q 2544 2222 2544 2253 \n",
       "Q 2544 2597 2384 2738 \n",
       "Q 2169 2928 1744 2928 \n",
       "Q 1347 2928 1158 2789 \n",
       "Q 969 2650 878 2297 \n",
       "L 328 2372 \n",
       "Q 403 2725 575 2942 \n",
       "Q 747 3159 1072 3276 \n",
       "Q 1397 3394 1825 3394 \n",
       "Q 2250 3394 2515 3294 \n",
       "Q 2781 3194 2906 3042 \n",
       "Q 3031 2891 3081 2659 \n",
       "Q 3109 2516 3109 2141 \n",
       "L 3109 1391 \n",
       "Q 3109 606 3145 398 \n",
       "Q 3181 191 3288 0 \n",
       "L 2700 0 \n",
       "Q 2613 175 2588 409 \n",
       "z\n",
       "M 2541 1666 \n",
       "Q 2234 1541 1622 1453 \n",
       "Q 1275 1403 1131 1340 \n",
       "Q 988 1278 909 1158 \n",
       "Q 831 1038 831 891 \n",
       "Q 831 666 1001 516 \n",
       "Q 1172 366 1500 366 \n",
       "Q 1825 366 2078 508 \n",
       "Q 2331 650 2450 897 \n",
       "Q 2541 1088 2541 1459 \n",
       "L 2541 1666 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-74\" d=\"M 1650 503 \n",
       "L 1731 6 \n",
       "Q 1494 -44 1306 -44 \n",
       "Q 1000 -44 831 53 \n",
       "Q 663 150 594 308 \n",
       "Q 525 466 525 972 \n",
       "L 525 2881 \n",
       "L 113 2881 \n",
       "L 113 3319 \n",
       "L 525 3319 \n",
       "L 525 4141 \n",
       "L 1084 4478 \n",
       "L 1084 3319 \n",
       "L 1650 3319 \n",
       "L 1650 2881 \n",
       "L 1084 2881 \n",
       "L 1084 941 \n",
       "Q 1084 700 1114 631 \n",
       "Q 1144 563 1211 522 \n",
       "Q 1278 481 1403 481 \n",
       "Q 1497 481 1650 503 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-6f\" d=\"M 213 1659 \n",
       "Q 213 2581 725 3025 \n",
       "Q 1153 3394 1769 3394 \n",
       "Q 2453 3394 2887 2945 \n",
       "Q 3322 2497 3322 1706 \n",
       "Q 3322 1066 3130 698 \n",
       "Q 2938 331 2570 128 \n",
       "Q 2203 -75 1769 -75 \n",
       "Q 1072 -75 642 372 \n",
       "Q 213 819 213 1659 \n",
       "z\n",
       "M 791 1659 \n",
       "Q 791 1022 1069 705 \n",
       "Q 1347 388 1769 388 \n",
       "Q 2188 388 2466 706 \n",
       "Q 2744 1025 2744 1678 \n",
       "Q 2744 2294 2464 2611 \n",
       "Q 2184 2928 1769 2928 \n",
       "Q 1347 2928 1069 2612 \n",
       "Q 791 2297 791 1659 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-6e\" d=\"M 422 0 \n",
       "L 422 3319 \n",
       "L 928 3319 \n",
       "L 928 2847 \n",
       "Q 1294 3394 1984 3394 \n",
       "Q 2284 3394 2536 3286 \n",
       "Q 2788 3178 2913 3003 \n",
       "Q 3038 2828 3088 2588 \n",
       "Q 3119 2431 3119 2041 \n",
       "L 3119 0 \n",
       "L 2556 0 \n",
       "L 2556 2019 \n",
       "Q 2556 2363 2490 2533 \n",
       "Q 2425 2703 2258 2804 \n",
       "Q 2091 2906 1866 2906 \n",
       "Q 1506 2906 1245 2678 \n",
       "Q 984 2450 984 1813 \n",
       "L 984 0 \n",
       "L 422 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#ArialMT-4f\"/>\n",
       "      <use xlink:href=\"#ArialMT-62\" x=\"77.783203\"/>\n",
       "      <use xlink:href=\"#ArialMT-73\" x=\"133.398438\"/>\n",
       "      <use xlink:href=\"#ArialMT-65\" x=\"183.398438\"/>\n",
       "      <use xlink:href=\"#ArialMT-72\" x=\"239.013672\"/>\n",
       "      <use xlink:href=\"#ArialMT-76\" x=\"272.314453\"/>\n",
       "      <use xlink:href=\"#ArialMT-61\" x=\"322.314453\"/>\n",
       "      <use xlink:href=\"#ArialMT-74\" x=\"377.929688\"/>\n",
       "      <use xlink:href=\"#ArialMT-69\" x=\"405.712891\"/>\n",
       "      <use xlink:href=\"#ArialMT-6f\" x=\"427.929688\"/>\n",
       "      <use xlink:href=\"#ArialMT-6e\" x=\"483.544922\"/>\n",
       "      <use xlink:href=\"#ArialMT-73\" x=\"539.160156\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"line2d_18\">\n",
       "     <path d=\"M 51.1265 232.591125 \n",
       "L 59.9265 232.591125 \n",
       "L 68.7265 232.591125 \n",
       "\" style=\"fill: none; stroke: #1f77b4; stroke-width: 2; stroke-linecap: round\"/>\n",
       "    </g>\n",
       "    <g id=\"text_18\">\n",
       "     <!-- $m_n(x)$ -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(75.7665 235.671125) scale(0.088 -0.088)\">\n",
       "      <defs>\n",
       "       <path id=\"DejaVuSans-Oblique-6d\" d=\"M 5747 2113 \n",
       "L 5338 0 \n",
       "L 4763 0 \n",
       "L 5166 2094 \n",
       "Q 5191 2228 5203 2325 \n",
       "Q 5216 2422 5216 2491 \n",
       "Q 5216 2772 5059 2928 \n",
       "Q 4903 3084 4622 3084 \n",
       "Q 4203 3084 3875 2770 \n",
       "Q 3547 2456 3450 1953 \n",
       "L 3066 0 \n",
       "L 2491 0 \n",
       "L 2900 2094 \n",
       "Q 2925 2209 2937 2307 \n",
       "Q 2950 2406 2950 2484 \n",
       "Q 2950 2769 2794 2926 \n",
       "Q 2638 3084 2363 3084 \n",
       "Q 1938 3084 1609 2770 \n",
       "Q 1281 2456 1184 1953 \n",
       "L 800 0 \n",
       "L 225 0 \n",
       "L 909 3500 \n",
       "L 1484 3500 \n",
       "L 1375 2956 \n",
       "Q 1609 3263 1923 3423 \n",
       "Q 2238 3584 2597 3584 \n",
       "Q 2978 3584 3223 3384 \n",
       "Q 3469 3184 3519 2828 \n",
       "Q 3781 3197 4126 3390 \n",
       "Q 4472 3584 4856 3584 \n",
       "Q 5306 3584 5551 3325 \n",
       "Q 5797 3066 5797 2591 \n",
       "Q 5797 2488 5784 2364 \n",
       "Q 5772 2241 5747 2113 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-Oblique-6e\" d=\"M 3566 2113 \n",
       "L 3156 0 \n",
       "L 2578 0 \n",
       "L 2988 2091 \n",
       "Q 3016 2238 3031 2350 \n",
       "Q 3047 2463 3047 2528 \n",
       "Q 3047 2791 2881 2937 \n",
       "Q 2716 3084 2419 3084 \n",
       "Q 1956 3084 1622 2776 \n",
       "Q 1288 2469 1184 1941 \n",
       "L 800 0 \n",
       "L 225 0 \n",
       "L 903 3500 \n",
       "L 1478 3500 \n",
       "L 1363 2950 \n",
       "Q 1603 3253 1940 3418 \n",
       "Q 2278 3584 2650 3584 \n",
       "Q 3113 3584 3367 3334 \n",
       "Q 3622 3084 3622 2631 \n",
       "Q 3622 2519 3608 2391 \n",
       "Q 3594 2263 3566 2113 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-28\" d=\"M 1984 4856 \n",
       "Q 1566 4138 1362 3434 \n",
       "Q 1159 2731 1159 2009 \n",
       "Q 1159 1288 1364 580 \n",
       "Q 1569 -128 1984 -844 \n",
       "L 1484 -844 \n",
       "Q 1016 -109 783 600 \n",
       "Q 550 1309 550 2009 \n",
       "Q 550 2706 781 3412 \n",
       "Q 1013 4119 1484 4856 \n",
       "L 1984 4856 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-29\" d=\"M 513 4856 \n",
       "L 1013 4856 \n",
       "Q 1481 4119 1714 3412 \n",
       "Q 1947 2706 1947 2009 \n",
       "Q 1947 1309 1714 600 \n",
       "Q 1481 -109 1013 -844 \n",
       "L 513 -844 \n",
       "Q 928 -128 1133 580 \n",
       "Q 1338 1288 1338 2009 \n",
       "Q 1338 2731 1133 3434 \n",
       "Q 928 4138 513 4856 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-6d\" transform=\"translate(0 0.125)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-6e\" transform=\"translate(97.412109 -16.28125) scale(0.7)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-28\" transform=\"translate(144.511719 0.125)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-78\" transform=\"translate(183.525391 0.125)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-29\" transform=\"translate(242.705078 0.125)\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"patch_5\">\n",
       "     <path d=\"M 51.1265 249.828125 \n",
       "L 68.7265 249.828125 \n",
       "L 68.7265 243.668125 \n",
       "L 51.1265 243.668125 \n",
       "z\n",
       "\" style=\"fill: #1f77b4; fill-opacity: 0.5; stroke: #1f77b4; stroke-opacity: 0.5; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "    </g>\n",
       "    <g id=\"text_19\">\n",
       "     <!-- $f(\\mathbf{x}^*)$ 95% pred. -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(75.7665 249.828125) scale(0.088 -0.088)\">\n",
       "      <defs>\n",
       "       <path id=\"DejaVuSans-Oblique-66\" d=\"M 3059 4863 \n",
       "L 2969 4384 \n",
       "L 2419 4384 \n",
       "Q 2106 4384 1964 4261 \n",
       "Q 1822 4138 1753 3809 \n",
       "L 1691 3500 \n",
       "L 2638 3500 \n",
       "L 2553 3053 \n",
       "L 1606 3053 \n",
       "L 1013 0 \n",
       "L 434 0 \n",
       "L 1031 3053 \n",
       "L 481 3053 \n",
       "L 563 3500 \n",
       "L 1113 3500 \n",
       "L 1159 3744 \n",
       "Q 1278 4363 1576 4613 \n",
       "Q 1875 4863 2516 4863 \n",
       "L 3059 4863 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-Bold-78\" d=\"M 1422 1791 \n",
       "L 159 3500 \n",
       "L 1344 3500 \n",
       "L 2059 2463 \n",
       "L 2784 3500 \n",
       "L 3969 3500 \n",
       "L 2706 1797 \n",
       "L 4031 0 \n",
       "L 2847 0 \n",
       "L 2059 1106 \n",
       "L 1281 0 \n",
       "L 97 0 \n",
       "L 1422 1791 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-2a\" d=\"M 3009 3897 \n",
       "L 1888 3291 \n",
       "L 3009 2681 \n",
       "L 2828 2375 \n",
       "L 1778 3009 \n",
       "L 1778 1831 \n",
       "L 1422 1831 \n",
       "L 1422 3009 \n",
       "L 372 2375 \n",
       "L 191 2681 \n",
       "L 1313 3291 \n",
       "L 191 3897 \n",
       "L 372 4206 \n",
       "L 1422 3572 \n",
       "L 1422 4750 \n",
       "L 1778 4750 \n",
       "L 1778 3572 \n",
       "L 2828 4206 \n",
       "L 3009 3897 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-39\" d=\"M 350 1059 \n",
       "L 891 1109 \n",
       "Q 959 728 1153 556 \n",
       "Q 1347 384 1650 384 \n",
       "Q 1909 384 2104 503 \n",
       "Q 2300 622 2425 820 \n",
       "Q 2550 1019 2634 1356 \n",
       "Q 2719 1694 2719 2044 \n",
       "Q 2719 2081 2716 2156 \n",
       "Q 2547 1888 2255 1720 \n",
       "Q 1963 1553 1622 1553 \n",
       "Q 1053 1553 659 1965 \n",
       "Q 266 2378 266 3053 \n",
       "Q 266 3750 677 4175 \n",
       "Q 1088 4600 1706 4600 \n",
       "Q 2153 4600 2523 4359 \n",
       "Q 2894 4119 3086 3673 \n",
       "Q 3278 3228 3278 2384 \n",
       "Q 3278 1506 3087 986 \n",
       "Q 2897 466 2520 194 \n",
       "Q 2144 -78 1638 -78 \n",
       "Q 1100 -78 759 220 \n",
       "Q 419 519 350 1059 \n",
       "z\n",
       "M 2653 3081 \n",
       "Q 2653 3566 2395 3850 \n",
       "Q 2138 4134 1775 4134 \n",
       "Q 1400 4134 1122 3828 \n",
       "Q 844 3522 844 3034 \n",
       "Q 844 2597 1108 2323 \n",
       "Q 1372 2050 1759 2050 \n",
       "Q 2150 2050 2401 2323 \n",
       "Q 2653 2597 2653 3081 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-35\" d=\"M 266 1200 \n",
       "L 856 1250 \n",
       "Q 922 819 1161 601 \n",
       "Q 1400 384 1738 384 \n",
       "Q 2144 384 2425 690 \n",
       "Q 2706 997 2706 1503 \n",
       "Q 2706 1984 2436 2262 \n",
       "Q 2166 2541 1728 2541 \n",
       "Q 1456 2541 1237 2417 \n",
       "Q 1019 2294 894 2097 \n",
       "L 366 2166 \n",
       "L 809 4519 \n",
       "L 3088 4519 \n",
       "L 3088 3981 \n",
       "L 1259 3981 \n",
       "L 1013 2750 \n",
       "Q 1425 3038 1878 3038 \n",
       "Q 2478 3038 2890 2622 \n",
       "Q 3303 2206 3303 1553 \n",
       "Q 3303 931 2941 478 \n",
       "Q 2500 -78 1738 -78 \n",
       "Q 1113 -78 717 272 \n",
       "Q 322 622 266 1200 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-25\" d=\"M 372 3481 \n",
       "Q 372 3972 619 4315 \n",
       "Q 866 4659 1334 4659 \n",
       "Q 1766 4659 2048 4351 \n",
       "Q 2331 4044 2331 3447 \n",
       "Q 2331 2866 2045 2552 \n",
       "Q 1759 2238 1341 2238 \n",
       "Q 925 2238 648 2547 \n",
       "Q 372 2856 372 3481 \n",
       "z\n",
       "M 1350 4272 \n",
       "Q 1141 4272 1002 4090 \n",
       "Q 863 3909 863 3425 \n",
       "Q 863 2984 1003 2804 \n",
       "Q 1144 2625 1350 2625 \n",
       "Q 1563 2625 1702 2806 \n",
       "Q 1841 2988 1841 3469 \n",
       "Q 1841 3913 1700 4092 \n",
       "Q 1559 4272 1350 4272 \n",
       "z\n",
       "M 1353 -169 \n",
       "L 3859 4659 \n",
       "L 4316 4659 \n",
       "L 1819 -169 \n",
       "L 1353 -169 \n",
       "z\n",
       "M 3334 1075 \n",
       "Q 3334 1569 3581 1911 \n",
       "Q 3828 2253 4300 2253 \n",
       "Q 4731 2253 5014 1945 \n",
       "Q 5297 1638 5297 1041 \n",
       "Q 5297 459 5011 145 \n",
       "Q 4725 -169 4303 -169 \n",
       "Q 3888 -169 3611 142 \n",
       "Q 3334 453 3334 1075 \n",
       "z\n",
       "M 4316 1866 \n",
       "Q 4103 1866 3964 1684 \n",
       "Q 3825 1503 3825 1019 \n",
       "Q 3825 581 3965 400 \n",
       "Q 4106 219 4313 219 \n",
       "Q 4528 219 4667 400 \n",
       "Q 4806 581 4806 1063 \n",
       "Q 4806 1506 4665 1686 \n",
       "Q 4525 1866 4316 1866 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-64\" d=\"M 2575 0 \n",
       "L 2575 419 \n",
       "Q 2259 -75 1647 -75 \n",
       "Q 1250 -75 917 144 \n",
       "Q 584 363 401 755 \n",
       "Q 219 1147 219 1656 \n",
       "Q 219 2153 384 2558 \n",
       "Q 550 2963 881 3178 \n",
       "Q 1213 3394 1622 3394 \n",
       "Q 1922 3394 2156 3267 \n",
       "Q 2391 3141 2538 2938 \n",
       "L 2538 4581 \n",
       "L 3097 4581 \n",
       "L 3097 0 \n",
       "L 2575 0 \n",
       "z\n",
       "M 797 1656 \n",
       "Q 797 1019 1065 703 \n",
       "Q 1334 388 1700 388 \n",
       "Q 2069 388 2326 689 \n",
       "Q 2584 991 2584 1609 \n",
       "Q 2584 2291 2321 2609 \n",
       "Q 2059 2928 1675 2928 \n",
       "Q 1300 2928 1048 2622 \n",
       "Q 797 2316 797 1656 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-66\" transform=\"translate(0 0.765625)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-28\" transform=\"translate(35.205078 0.765625)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-Bold-78\" transform=\"translate(74.21875 0.765625)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-2a\" transform=\"translate(153.31543 39.046875) scale(0.7)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-29\" transform=\"translate(204.6875 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" transform=\"translate(243.701172 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-39\" transform=\"translate(271.484375 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-35\" transform=\"translate(327.099609 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-25\" transform=\"translate(382.714844 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" transform=\"translate(471.630859 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-70\" transform=\"translate(499.414062 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-72\" transform=\"translate(555.029297 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-65\" transform=\"translate(588.330078 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-64\" transform=\"translate(643.945312 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-2e\" transform=\"translate(699.560547 0.765625)\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"patch_6\">\n",
       "     <path d=\"M 51.1265 263.996125 \n",
       "L 68.7265 263.996125 \n",
       "L 68.7265 257.836125 \n",
       "L 51.1265 257.836125 \n",
       "z\n",
       "\" style=\"fill: #ff7f0e; fill-opacity: 0.5; stroke: #ff7f0e; stroke-opacity: 0.5; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "    </g>\n",
       "    <g id=\"text_20\">\n",
       "     <!-- $y^*$ 95% pred. -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(75.7665 263.996125) scale(0.088 -0.088)\">\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-79\" transform=\"translate(0 0.765625)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-2a\" transform=\"translate(77.283529 39.046875) scale(0.7)\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" transform=\"translate(128.655599 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-39\" transform=\"translate(156.438802 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-35\" transform=\"translate(212.054036 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-25\" transform=\"translate(267.669271 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" transform=\"translate(356.585286 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-70\" transform=\"translate(384.36849 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-72\" transform=\"translate(439.983724 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-65\" transform=\"translate(473.284505 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-64\" transform=\"translate(528.89974 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-2e\" transform=\"translate(584.514974 0.765625)\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"line2d_19\">\n",
       "     <path d=\"M 51.1265 273.463 \n",
       "L 59.9265 273.463 \n",
       "L 68.7265 273.463 \n",
       "\" style=\"fill: none; stroke-dasharray: 7.68,1.92,1.2,1.92; stroke-dashoffset: 0; stroke: #bf00bf; stroke-width: 1.2\"/>\n",
       "    </g>\n",
       "    <g id=\"text_21\">\n",
       "     <!-- True function -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(75.7665 276.543) scale(0.088 -0.088)\">\n",
       "      <defs>\n",
       "       <path id=\"ArialMT-54\" d=\"M 1659 0 \n",
       "L 1659 4041 \n",
       "L 150 4041 \n",
       "L 150 4581 \n",
       "L 3781 4581 \n",
       "L 3781 4041 \n",
       "L 2266 4041 \n",
       "L 2266 0 \n",
       "L 1659 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-75\" d=\"M 2597 0 \n",
       "L 2597 488 \n",
       "Q 2209 -75 1544 -75 \n",
       "Q 1250 -75 995 37 \n",
       "Q 741 150 617 320 \n",
       "Q 494 491 444 738 \n",
       "Q 409 903 409 1263 \n",
       "L 409 3319 \n",
       "L 972 3319 \n",
       "L 972 1478 \n",
       "Q 972 1038 1006 884 \n",
       "Q 1059 663 1231 536 \n",
       "Q 1403 409 1656 409 \n",
       "Q 1909 409 2131 539 \n",
       "Q 2353 669 2445 892 \n",
       "Q 2538 1116 2538 1541 \n",
       "L 2538 3319 \n",
       "L 3100 3319 \n",
       "L 3100 0 \n",
       "L 2597 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-66\" d=\"M 556 0 \n",
       "L 556 2881 \n",
       "L 59 2881 \n",
       "L 59 3319 \n",
       "L 556 3319 \n",
       "L 556 3672 \n",
       "Q 556 4006 616 4169 \n",
       "Q 697 4388 901 4523 \n",
       "Q 1106 4659 1475 4659 \n",
       "Q 1713 4659 2000 4603 \n",
       "L 1916 4113 \n",
       "Q 1741 4144 1584 4144 \n",
       "Q 1328 4144 1222 4034 \n",
       "Q 1116 3925 1116 3625 \n",
       "L 1116 3319 \n",
       "L 1763 3319 \n",
       "L 1763 2881 \n",
       "L 1116 2881 \n",
       "L 1116 0 \n",
       "L 556 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-63\" d=\"M 2588 1216 \n",
       "L 3141 1144 \n",
       "Q 3050 572 2676 248 \n",
       "Q 2303 -75 1759 -75 \n",
       "Q 1078 -75 664 370 \n",
       "Q 250 816 250 1647 \n",
       "Q 250 2184 428 2587 \n",
       "Q 606 2991 970 3192 \n",
       "Q 1334 3394 1763 3394 \n",
       "Q 2303 3394 2647 3120 \n",
       "Q 2991 2847 3088 2344 \n",
       "L 2541 2259 \n",
       "Q 2463 2594 2264 2762 \n",
       "Q 2066 2931 1784 2931 \n",
       "Q 1359 2931 1093 2626 \n",
       "Q 828 2322 828 1663 \n",
       "Q 828 994 1084 691 \n",
       "Q 1341 388 1753 388 \n",
       "Q 2084 388 2306 591 \n",
       "Q 2528 794 2588 1216 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#ArialMT-54\"/>\n",
       "      <use xlink:href=\"#ArialMT-72\" x=\"57.333984\"/>\n",
       "      <use xlink:href=\"#ArialMT-75\" x=\"90.634766\"/>\n",
       "      <use xlink:href=\"#ArialMT-65\" x=\"146.25\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" x=\"201.865234\"/>\n",
       "      <use xlink:href=\"#ArialMT-66\" x=\"229.648438\"/>\n",
       "      <use xlink:href=\"#ArialMT-75\" x=\"257.431641\"/>\n",
       "      <use xlink:href=\"#ArialMT-6e\" x=\"313.046875\"/>\n",
       "      <use xlink:href=\"#ArialMT-63\" x=\"368.662109\"/>\n",
       "      <use xlink:href=\"#ArialMT-74\" x=\"418.662109\"/>\n",
       "      <use xlink:href=\"#ArialMT-69\" x=\"446.445312\"/>\n",
       "      <use xlink:href=\"#ArialMT-6f\" x=\"468.662109\"/>\n",
       "      <use xlink:href=\"#ArialMT-6e\" x=\"524.277344\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "  </g>\n",
       "  <g id=\"axes_2\">\n",
       "   <g id=\"matplotlib.axis_3\">\n",
       "    <g id=\"ytick_8\">\n",
       "     <g id=\"line2d_20\">\n",
       "      <defs>\n",
       "       <path id=\"me060e3c065\" d=\"M 0 0 \n",
       "L 4.8 0 \n",
       "\" style=\"stroke: #262626\"/>\n",
       "      </defs>\n",
       "      <g>\n",
       "       <use xlink:href=\"#me060e3c065\" x=\"400.3265\" y=\"274.116\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_22\">\n",
       "      <!-- 0.00 -->\n",
       "      <g style=\"fill: #ff7f0e\" transform=\"translate(408.6265 277.265437) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"83.398438\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"139.013672\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_9\">\n",
       "     <g id=\"line2d_21\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#me060e3c065\" x=\"400.3265\" y=\"226.132213\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_23\">\n",
       "      <!-- 0.05 -->\n",
       "      <g style=\"fill: #ff7f0e\" transform=\"translate(408.6265 229.281651) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"83.398438\"/>\n",
       "       <use xlink:href=\"#ArialMT-35\" x=\"139.013672\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_10\">\n",
       "     <g id=\"line2d_22\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#me060e3c065\" x=\"400.3265\" y=\"178.148427\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_24\">\n",
       "      <!-- 0.10 -->\n",
       "      <g style=\"fill: #ff7f0e\" transform=\"translate(408.6265 181.297864) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-31\" x=\"83.398438\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"139.013672\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_11\">\n",
       "     <g id=\"line2d_23\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#me060e3c065\" x=\"400.3265\" y=\"130.16464\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_25\">\n",
       "      <!-- 0.15 -->\n",
       "      <g style=\"fill: #ff7f0e\" transform=\"translate(408.6265 133.314078) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-31\" x=\"83.398438\"/>\n",
       "       <use xlink:href=\"#ArialMT-35\" x=\"139.013672\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_12\">\n",
       "     <g id=\"line2d_24\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#me060e3c065\" x=\"400.3265\" y=\"82.180854\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_26\">\n",
       "      <!-- 0.20 -->\n",
       "      <g style=\"fill: #ff7f0e\" transform=\"translate(408.6265 85.330291) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-32\" x=\"83.398438\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"139.013672\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_13\">\n",
       "     <g id=\"line2d_25\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#me060e3c065\" x=\"400.3265\" y=\"34.197067\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_27\">\n",
       "      <!-- 0.25 -->\n",
       "      <g style=\"fill: #ff7f0e\" transform=\"translate(408.6265 37.346505) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-32\" x=\"83.398438\"/>\n",
       "       <use xlink:href=\"#ArialMT-35\" x=\"139.013672\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"text_28\">\n",
       "     <!-- Information Acquisition Function -->\n",
       "     <g style=\"fill: #ff7f0e\" transform=\"translate(436.740625 221.18925) rotate(-90) scale(0.096 -0.096)\">\n",
       "      <defs>\n",
       "       <path id=\"ArialMT-49\" d=\"M 597 0 \n",
       "L 597 4581 \n",
       "L 1203 4581 \n",
       "L 1203 0 \n",
       "L 597 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-6d\" d=\"M 422 0 \n",
       "L 422 3319 \n",
       "L 925 3319 \n",
       "L 925 2853 \n",
       "Q 1081 3097 1340 3245 \n",
       "Q 1600 3394 1931 3394 \n",
       "Q 2300 3394 2536 3241 \n",
       "Q 2772 3088 2869 2813 \n",
       "Q 3263 3394 3894 3394 \n",
       "Q 4388 3394 4653 3120 \n",
       "Q 4919 2847 4919 2278 \n",
       "L 4919 0 \n",
       "L 4359 0 \n",
       "L 4359 2091 \n",
       "Q 4359 2428 4304 2576 \n",
       "Q 4250 2725 4106 2815 \n",
       "Q 3963 2906 3769 2906 \n",
       "Q 3419 2906 3187 2673 \n",
       "Q 2956 2441 2956 1928 \n",
       "L 2956 0 \n",
       "L 2394 0 \n",
       "L 2394 2156 \n",
       "Q 2394 2531 2256 2718 \n",
       "Q 2119 2906 1806 2906 \n",
       "Q 1569 2906 1367 2781 \n",
       "Q 1166 2656 1075 2415 \n",
       "Q 984 2175 984 1722 \n",
       "L 984 0 \n",
       "L 422 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-41\" d=\"M -9 0 \n",
       "L 1750 4581 \n",
       "L 2403 4581 \n",
       "L 4278 0 \n",
       "L 3588 0 \n",
       "L 3053 1388 \n",
       "L 1138 1388 \n",
       "L 634 0 \n",
       "L -9 0 \n",
       "z\n",
       "M 1313 1881 \n",
       "L 2866 1881 \n",
       "L 2388 3150 \n",
       "Q 2169 3728 2063 4100 \n",
       "Q 1975 3659 1816 3225 \n",
       "L 1313 1881 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-71\" d=\"M 2538 -1272 \n",
       "L 2538 353 \n",
       "Q 2406 169 2170 47 \n",
       "Q 1934 -75 1669 -75 \n",
       "Q 1078 -75 651 397 \n",
       "Q 225 869 225 1691 \n",
       "Q 225 2191 398 2587 \n",
       "Q 572 2984 901 3189 \n",
       "Q 1231 3394 1625 3394 \n",
       "Q 2241 3394 2594 2875 \n",
       "L 2594 3319 \n",
       "L 3100 3319 \n",
       "L 3100 -1272 \n",
       "L 2538 -1272 \n",
       "z\n",
       "M 803 1669 \n",
       "Q 803 1028 1072 708 \n",
       "Q 1341 388 1716 388 \n",
       "Q 2075 388 2334 692 \n",
       "Q 2594 997 2594 1619 \n",
       "Q 2594 2281 2320 2615 \n",
       "Q 2047 2950 1678 2950 \n",
       "Q 1313 2950 1058 2639 \n",
       "Q 803 2328 803 1669 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-46\" d=\"M 525 0 \n",
       "L 525 4581 \n",
       "L 3616 4581 \n",
       "L 3616 4041 \n",
       "L 1131 4041 \n",
       "L 1131 2622 \n",
       "L 3281 2622 \n",
       "L 3281 2081 \n",
       "L 1131 2081 \n",
       "L 1131 0 \n",
       "L 525 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#ArialMT-49\"/>\n",
       "      <use xlink:href=\"#ArialMT-6e\" x=\"27.783203\"/>\n",
       "      <use xlink:href=\"#ArialMT-66\" x=\"83.398438\"/>\n",
       "      <use xlink:href=\"#ArialMT-6f\" x=\"111.181641\"/>\n",
       "      <use xlink:href=\"#ArialMT-72\" x=\"166.796875\"/>\n",
       "      <use xlink:href=\"#ArialMT-6d\" x=\"200.097656\"/>\n",
       "      <use xlink:href=\"#ArialMT-61\" x=\"283.398438\"/>\n",
       "      <use xlink:href=\"#ArialMT-74\" x=\"339.013672\"/>\n",
       "      <use xlink:href=\"#ArialMT-69\" x=\"366.796875\"/>\n",
       "      <use xlink:href=\"#ArialMT-6f\" x=\"389.013672\"/>\n",
       "      <use xlink:href=\"#ArialMT-6e\" x=\"444.628906\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" x=\"500.244141\"/>\n",
       "      <use xlink:href=\"#ArialMT-41\" x=\"522.527344\"/>\n",
       "      <use xlink:href=\"#ArialMT-63\" x=\"589.226562\"/>\n",
       "      <use xlink:href=\"#ArialMT-71\" x=\"639.226562\"/>\n",
       "      <use xlink:href=\"#ArialMT-75\" x=\"694.841797\"/>\n",
       "      <use xlink:href=\"#ArialMT-69\" x=\"750.457031\"/>\n",
       "      <use xlink:href=\"#ArialMT-73\" x=\"772.673828\"/>\n",
       "      <use xlink:href=\"#ArialMT-69\" x=\"822.673828\"/>\n",
       "      <use xlink:href=\"#ArialMT-74\" x=\"844.890625\"/>\n",
       "      <use xlink:href=\"#ArialMT-69\" x=\"872.673828\"/>\n",
       "      <use xlink:href=\"#ArialMT-6f\" x=\"894.890625\"/>\n",
       "      <use xlink:href=\"#ArialMT-6e\" x=\"950.505859\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" x=\"1006.121094\"/>\n",
       "      <use xlink:href=\"#ArialMT-46\" x=\"1033.904297\"/>\n",
       "      <use xlink:href=\"#ArialMT-75\" x=\"1094.988281\"/>\n",
       "      <use xlink:href=\"#ArialMT-6e\" x=\"1150.603516\"/>\n",
       "      <use xlink:href=\"#ArialMT-63\" x=\"1206.21875\"/>\n",
       "      <use xlink:href=\"#ArialMT-74\" x=\"1256.21875\"/>\n",
       "      <use xlink:href=\"#ArialMT-69\" x=\"1284.001953\"/>\n",
       "      <use xlink:href=\"#ArialMT-6f\" x=\"1306.21875\"/>\n",
       "      <use xlink:href=\"#ArialMT-6e\" x=\"1361.833984\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"line2d_26\">\n",
       "    <path d=\"M 59.439227 32.196 \n",
       "L 62.718566 49.954892 \n",
       "L 65.997905 68.426567 \n",
       "L 69.277244 87.559974 \n",
       "L 72.556583 107.27523 \n",
       "L 75.835921 127.454359 \n",
       "L 79.115261 147.923898 \n",
       "L 82.394598 168.437454 \n",
       "L 85.673938 188.655108 \n",
       "L 88.953278 208.11825 \n",
       "L 92.232615 226.225955 \n",
       "L 95.511955 242.249221 \n",
       "L 98.791295 255.389208 \n",
       "L 102.070632 264.958242 \n",
       "L 105.349969 270.729035 \n",
       "L 108.629311 273.296508 \n",
       "L 111.908649 274.005773 \n",
       "L 115.187986 274.106762 \n",
       "L 118.467328 274.11417 \n",
       "L 121.746666 274.108707 \n",
       "L 125.026003 273.902182 \n",
       "L 128.305345 270.494139 \n",
       "L 131.584682 253.401955 \n",
       "L 134.86402 218.304971 \n",
       "L 138.143362 178.721159 \n",
       "L 141.422694 153.923954 \n",
       "L 144.702037 158.057536 \n",
       "L 147.981379 194.180966 \n",
       "L 151.260711 242.559938 \n",
       "L 154.540053 268.686297 \n",
       "L 157.819395 273.487874 \n",
       "L 161.098728 273.929238 \n",
       "L 164.37807 273.948858 \n",
       "L 167.657412 273.899408 \n",
       "L 170.936745 273.840148 \n",
       "L 174.216087 273.802109 \n",
       "L 177.495429 273.798276 \n",
       "L 180.774762 273.827563 \n",
       "L 184.054104 273.880274 \n",
       "L 187.333446 273.943253 \n",
       "L 190.612778 274.004029 \n",
       "L 193.892121 274.053336 \n",
       "L 197.171463 274.086827 \n",
       "L 200.450795 274.105303 \n",
       "L 203.730137 274.113169 \n",
       "L 207.00948 274.115514 \n",
       "L 210.288812 274.115971 \n",
       "L 213.568154 274.116 \n",
       "L 216.847496 274.116 \n",
       "L 220.126829 274.116 \n",
       "L 223.406181 274.116 \n",
       "L 226.685504 274.116 \n",
       "L 229.964846 274.116 \n",
       "L 233.244188 274.116 \n",
       "L 236.523511 274.116 \n",
       "L 239.802872 274.116 \n",
       "L 243.082195 274.116 \n",
       "L 246.361537 274.116 \n",
       "L 249.640879 274.116 \n",
       "L 252.920222 274.116 \n",
       "L 256.199564 274.116 \n",
       "L 259.478887 274.116 \n",
       "L 262.758248 274.116 \n",
       "L 266.037571 274.116 \n",
       "L 269.316913 274.116 \n",
       "L 272.596255 274.116 \n",
       "L 275.875578 274.116 \n",
       "L 279.15494 274.116 \n",
       "L 282.434262 274.116 \n",
       "L 285.713605 274.116 \n",
       "L 288.992947 274.116 \n",
       "L 292.272289 274.116 \n",
       "L 295.551631 274.116 \n",
       "L 298.830954 274.116 \n",
       "L 302.110315 274.116 \n",
       "L 305.389638 274.116 \n",
       "L 308.66898 274.116 \n",
       "L 311.948322 274.116 \n",
       "L 315.227645 274.116 \n",
       "L 318.507007 274.116 \n",
       "L 321.78633 274.116 \n",
       "L 325.065672 274.116 \n",
       "L 328.345014 274.116 \n",
       "L 331.624356 274.116 \n",
       "L 334.903698 274.116 \n",
       "L 338.183021 274.116 \n",
       "L 341.462363 274.116 \n",
       "L 344.741705 274.116 \n",
       "L 348.021048 274.116 \n",
       "L 351.30039 274.116 \n",
       "L 354.579713 274.116 \n",
       "L 357.859055 274.116 \n",
       "L 361.138397 274.116 \n",
       "L 364.417739 274.116 \n",
       "L 367.697081 274.116 \n",
       "L 370.976423 274.116 \n",
       "L 374.255766 274.116 \n",
       "L 377.535088 274.116 \n",
       "L 380.814431 274.116 \n",
       "L 384.093773 274.116 \n",
       "\" clip-path=\"url(#p2a8fe0773f)\" style=\"fill: none; stroke: #ff7f0e; stroke-width: 1.2; stroke-linecap: round\"/>\n",
       "   </g>\n",
       "   <g id=\"line2d_27\">\n",
       "    <path d=\"M 59.439227 274.116 \n",
       "L 59.439227 271.672364 \n",
       "L 59.439227 269.228727 \n",
       "L 59.439227 266.785091 \n",
       "L 59.439227 264.341455 \n",
       "L 59.439227 261.897819 \n",
       "L 59.439227 259.454182 \n",
       "L 59.439227 257.010545 \n",
       "L 59.439227 254.566909 \n",
       "L 59.439227 252.123273 \n",
       "L 59.439227 249.679637 \n",
       "L 59.439227 247.236 \n",
       "L 59.439227 244.792364 \n",
       "L 59.439227 242.348726 \n",
       "L 59.439227 239.90509 \n",
       "L 59.439227 237.461454 \n",
       "L 59.439227 235.017819 \n",
       "L 59.439227 232.574183 \n",
       "L 59.439227 230.130547 \n",
       "L 59.439227 227.686911 \n",
       "L 59.439227 225.243275 \n",
       "L 59.439227 222.799635 \n",
       "L 59.439227 220.356 \n",
       "L 59.439227 217.912364 \n",
       "L 59.439227 215.468728 \n",
       "L 59.439227 213.025092 \n",
       "L 59.439227 210.581452 \n",
       "L 59.439227 208.13782 \n",
       "L 59.439227 205.694181 \n",
       "L 59.439227 203.250548 \n",
       "L 59.439227 200.806909 \n",
       "L 59.439227 198.363277 \n",
       "L 59.439227 195.919637 \n",
       "L 59.439227 193.475998 \n",
       "L 59.439227 191.032365 \n",
       "L 59.439227 188.588726 \n",
       "L 59.439227 186.145094 \n",
       "L 59.439227 183.701454 \n",
       "L 59.439227 181.257822 \n",
       "L 59.439227 178.814182 \n",
       "L 59.439227 176.37055 \n",
       "L 59.439227 173.92691 \n",
       "L 59.439227 171.483271 \n",
       "L 59.439227 169.039639 \n",
       "L 59.439227 166.595999 \n",
       "L 59.439227 164.152367 \n",
       "L 59.439227 161.708727 \n",
       "L 59.439227 159.265095 \n",
       "L 59.439227 156.821456 \n",
       "L 59.439227 154.377816 \n",
       "L 59.439227 151.934184 \n",
       "L 59.439227 149.490552 \n",
       "L 59.439227 147.046905 \n",
       "L 59.439227 144.603273 \n",
       "L 59.439227 142.159626 \n",
       "L 59.439227 139.715994 \n",
       "L 59.439227 137.272361 \n",
       "L 59.439227 134.828729 \n",
       "L 59.439227 132.385097 \n",
       "L 59.439227 129.94145 \n",
       "L 59.439227 127.497818 \n",
       "L 59.439227 125.054171 \n",
       "L 59.439227 122.610539 \n",
       "L 59.439227 120.166906 \n",
       "L 59.439227 117.723274 \n",
       "L 59.439227 115.279642 \n",
       "L 59.439227 112.83601 \n",
       "L 59.439227 110.392363 \n",
       "L 59.439227 107.948716 \n",
       "L 59.439227 105.505084 \n",
       "L 59.439227 103.061452 \n",
       "L 59.439227 100.617819 \n",
       "L 59.439227 98.174187 \n",
       "L 59.439227 95.730555 \n",
       "L 59.439227 93.286908 \n",
       "L 59.439227 90.843276 \n",
       "L 59.439227 88.399629 \n",
       "L 59.439227 85.955997 \n",
       "L 59.439227 83.512365 \n",
       "L 59.439227 81.068732 \n",
       "L 59.439227 78.625086 \n",
       "L 59.439227 76.181453 \n",
       "L 59.439227 73.737821 \n",
       "L 59.439227 71.294174 \n",
       "L 59.439227 68.850542 \n",
       "L 59.439227 66.40691 \n",
       "L 59.439227 63.963277 \n",
       "L 59.439227 61.519631 \n",
       "L 59.439227 59.075998 \n",
       "L 59.439227 56.632366 \n",
       "L 59.439227 54.188719 \n",
       "L 59.439227 51.745087 \n",
       "L 59.439227 49.301455 \n",
       "L 59.439227 46.857823 \n",
       "L 59.439227 44.414176 \n",
       "L 59.439227 41.970544 \n",
       "L 59.439227 39.526911 \n",
       "L 59.439227 37.083279 \n",
       "L 59.439227 34.639632 \n",
       "L 59.439227 32.196 \n",
       "\" clip-path=\"url(#p2a8fe0773f)\" style=\"fill: none; stroke: #ff7f0e; stroke-linecap: round\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_7\">\n",
       "    <path d=\"M 43.2065 286.212 \n",
       "L 43.2065 20.1 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_8\">\n",
       "    <path d=\"M 400.3265 286.212 \n",
       "L 400.3265 20.1 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_9\">\n",
       "    <path d=\"M 43.2065 286.212 \n",
       "L 400.3265 286.212 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_10\">\n",
       "    <path d=\"M 43.2065 20.1 \n",
       "L 400.3265 20.1 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "  </g>\n",
       " </g>\n",
       " <defs>\n",
       "  <clipPath id=\"p2a8fe0773f\">\n",
       "   <rect x=\"43.2065\" y=\"20.1\" width=\"357.12\" height=\"266.112\"/>\n",
       "  </clipPath>\n",
       " </defs>\n",
       "</svg>\n"
      ],
      "text/plain": [
       "<Figure size 640x480 with 2 Axes>"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "image/svg+xml": [
       "<?xml version=\"1.0\" encoding=\"utf-8\" standalone=\"no\"?>\n",
       "<!DOCTYPE svg PUBLIC \"-//W3C//DTD SVG 1.1//EN\"\n",
       "  \"http://www.w3.org/Graphics/SVG/1.1/DTD/svg11.dtd\">\n",
       "<svg xmlns:xlink=\"http://www.w3.org/1999/xlink\" width=\"445.848625pt\" height=\"322.539375pt\" viewBox=\"0 0 445.848625 322.539375\" xmlns=\"http://www.w3.org/2000/svg\" version=\"1.1\">\n",
       " <metadata>\n",
       "  <rdf:RDF xmlns:dc=\"http://purl.org/dc/elements/1.1/\" xmlns:cc=\"http://creativecommons.org/ns#\" xmlns:rdf=\"http://www.w3.org/1999/02/22-rdf-syntax-ns#\">\n",
       "   <cc:Work>\n",
       "    <dc:type rdf:resource=\"http://purl.org/dc/dcmitype/StillImage\"/>\n",
       "    <dc:date>2023-10-23T15:18:34.245906</dc:date>\n",
       "    <dc:format>image/svg+xml</dc:format>\n",
       "    <dc:creator>\n",
       "     <cc:Agent>\n",
       "      <dc:title>Matplotlib v3.8.0, https://matplotlib.org/</dc:title>\n",
       "     </cc:Agent>\n",
       "    </dc:creator>\n",
       "   </cc:Work>\n",
       "  </rdf:RDF>\n",
       " </metadata>\n",
       " <defs>\n",
       "  <style type=\"text/css\">*{stroke-linejoin: round; stroke-linecap: butt}</style>\n",
       " </defs>\n",
       " <g id=\"figure_1\">\n",
       "  <g id=\"patch_1\">\n",
       "   <path d=\"M 0 322.539375 \n",
       "L 445.848625 322.539375 \n",
       "L 445.848625 0 \n",
       "L 0 0 \n",
       "z\n",
       "\" style=\"fill: #ffffff\"/>\n",
       "  </g>\n",
       "  <g id=\"axes_1\">\n",
       "   <g id=\"patch_2\">\n",
       "    <path d=\"M 43.2065 286.212 \n",
       "L 400.3265 286.212 \n",
       "L 400.3265 20.1 \n",
       "L 43.2065 20.1 \n",
       "z\n",
       "\" style=\"fill: #ffffff\"/>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_1\">\n",
       "    <g id=\"xtick_1\">\n",
       "     <g id=\"line2d_1\">\n",
       "      <defs>\n",
       "       <path id=\"m0507b08f5e\" d=\"M 0 0 \n",
       "L 0 4.8 \n",
       "\" style=\"stroke: #262626\"/>\n",
       "      </defs>\n",
       "      <g>\n",
       "       <use xlink:href=\"#m0507b08f5e\" x=\"59.439227\" y=\"286.212\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_1\">\n",
       "      <!-- 0.0 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(53.323227 300.810875) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-30\" d=\"M 266 2259 \n",
       "Q 266 3072 433 3567 \n",
       "Q 600 4063 929 4331 \n",
       "Q 1259 4600 1759 4600 \n",
       "Q 2128 4600 2406 4451 \n",
       "Q 2684 4303 2865 4023 \n",
       "Q 3047 3744 3150 3342 \n",
       "Q 3253 2941 3253 2259 \n",
       "Q 3253 1453 3087 958 \n",
       "Q 2922 463 2592 192 \n",
       "Q 2263 -78 1759 -78 \n",
       "Q 1097 -78 719 397 \n",
       "Q 266 969 266 2259 \n",
       "z\n",
       "M 844 2259 \n",
       "Q 844 1131 1108 757 \n",
       "Q 1372 384 1759 384 \n",
       "Q 2147 384 2411 759 \n",
       "Q 2675 1134 2675 2259 \n",
       "Q 2675 3391 2411 3762 \n",
       "Q 2147 4134 1753 4134 \n",
       "Q 1366 4134 1134 3806 \n",
       "Q 844 3388 844 2259 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "        <path id=\"ArialMT-2e\" d=\"M 581 0 \n",
       "L 581 641 \n",
       "L 1222 641 \n",
       "L 1222 0 \n",
       "L 581 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_2\">\n",
       "     <g id=\"line2d_2\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m0507b08f5e\" x=\"124.370136\" y=\"286.212\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_2\">\n",
       "      <!-- 0.2 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(118.254136 300.810875) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-32\" d=\"M 3222 541 \n",
       "L 3222 0 \n",
       "L 194 0 \n",
       "Q 188 203 259 391 \n",
       "Q 375 700 629 1000 \n",
       "Q 884 1300 1366 1694 \n",
       "Q 2113 2306 2375 2664 \n",
       "Q 2638 3022 2638 3341 \n",
       "Q 2638 3675 2398 3904 \n",
       "Q 2159 4134 1775 4134 \n",
       "Q 1369 4134 1125 3890 \n",
       "Q 881 3647 878 3216 \n",
       "L 300 3275 \n",
       "Q 359 3922 746 4261 \n",
       "Q 1134 4600 1788 4600 \n",
       "Q 2447 4600 2831 4234 \n",
       "Q 3216 3869 3216 3328 \n",
       "Q 3216 3053 3103 2787 \n",
       "Q 2991 2522 2730 2228 \n",
       "Q 2469 1934 1863 1422 \n",
       "Q 1356 997 1212 845 \n",
       "Q 1069 694 975 541 \n",
       "L 3222 541 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-32\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_3\">\n",
       "     <g id=\"line2d_3\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m0507b08f5e\" x=\"189.301045\" y=\"286.212\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_3\">\n",
       "      <!-- 0.4 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(183.185045 300.810875) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-34\" d=\"M 2069 0 \n",
       "L 2069 1097 \n",
       "L 81 1097 \n",
       "L 81 1613 \n",
       "L 2172 4581 \n",
       "L 2631 4581 \n",
       "L 2631 1613 \n",
       "L 3250 1613 \n",
       "L 3250 1097 \n",
       "L 2631 1097 \n",
       "L 2631 0 \n",
       "L 2069 0 \n",
       "z\n",
       "M 2069 1613 \n",
       "L 2069 3678 \n",
       "L 634 1613 \n",
       "L 2069 1613 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-34\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_4\">\n",
       "     <g id=\"line2d_4\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m0507b08f5e\" x=\"254.231955\" y=\"286.212\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_4\">\n",
       "      <!-- 0.6 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(248.115955 300.810875) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-36\" d=\"M 3184 3459 \n",
       "L 2625 3416 \n",
       "Q 2550 3747 2413 3897 \n",
       "Q 2184 4138 1850 4138 \n",
       "Q 1581 4138 1378 3988 \n",
       "Q 1113 3794 959 3422 \n",
       "Q 806 3050 800 2363 \n",
       "Q 1003 2672 1297 2822 \n",
       "Q 1591 2972 1913 2972 \n",
       "Q 2475 2972 2870 2558 \n",
       "Q 3266 2144 3266 1488 \n",
       "Q 3266 1056 3080 686 \n",
       "Q 2894 316 2569 119 \n",
       "Q 2244 -78 1831 -78 \n",
       "Q 1128 -78 684 439 \n",
       "Q 241 956 241 2144 \n",
       "Q 241 3472 731 4075 \n",
       "Q 1159 4600 1884 4600 \n",
       "Q 2425 4600 2770 4297 \n",
       "Q 3116 3994 3184 3459 \n",
       "z\n",
       "M 888 1484 \n",
       "Q 888 1194 1011 928 \n",
       "Q 1134 663 1356 523 \n",
       "Q 1578 384 1822 384 \n",
       "Q 2178 384 2434 671 \n",
       "Q 2691 959 2691 1453 \n",
       "Q 2691 1928 2437 2201 \n",
       "Q 2184 2475 1800 2475 \n",
       "Q 1419 2475 1153 2201 \n",
       "Q 888 1928 888 1484 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-36\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_5\">\n",
       "     <g id=\"line2d_5\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m0507b08f5e\" x=\"319.162864\" y=\"286.212\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_5\">\n",
       "      <!-- 0.8 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(313.046864 300.810875) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-38\" d=\"M 1131 2484 \n",
       "Q 781 2613 612 2850 \n",
       "Q 444 3088 444 3419 \n",
       "Q 444 3919 803 4259 \n",
       "Q 1163 4600 1759 4600 \n",
       "Q 2359 4600 2725 4251 \n",
       "Q 3091 3903 3091 3403 \n",
       "Q 3091 3084 2923 2848 \n",
       "Q 2756 2613 2416 2484 \n",
       "Q 2838 2347 3058 2040 \n",
       "Q 3278 1734 3278 1309 \n",
       "Q 3278 722 2862 322 \n",
       "Q 2447 -78 1769 -78 \n",
       "Q 1091 -78 675 323 \n",
       "Q 259 725 259 1325 \n",
       "Q 259 1772 486 2073 \n",
       "Q 713 2375 1131 2484 \n",
       "z\n",
       "M 1019 3438 \n",
       "Q 1019 3113 1228 2906 \n",
       "Q 1438 2700 1772 2700 \n",
       "Q 2097 2700 2305 2904 \n",
       "Q 2513 3109 2513 3406 \n",
       "Q 2513 3716 2298 3927 \n",
       "Q 2084 4138 1766 4138 \n",
       "Q 1444 4138 1231 3931 \n",
       "Q 1019 3725 1019 3438 \n",
       "z\n",
       "M 838 1322 \n",
       "Q 838 1081 952 856 \n",
       "Q 1066 631 1291 507 \n",
       "Q 1516 384 1775 384 \n",
       "Q 2178 384 2440 643 \n",
       "Q 2703 903 2703 1303 \n",
       "Q 2703 1709 2433 1975 \n",
       "Q 2163 2241 1756 2241 \n",
       "Q 1359 2241 1098 1978 \n",
       "Q 838 1716 838 1322 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-38\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_6\">\n",
       "     <g id=\"line2d_6\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m0507b08f5e\" x=\"384.093773\" y=\"286.212\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_6\">\n",
       "      <!-- 1.0 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(377.977773 300.810875) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-31\" d=\"M 2384 0 \n",
       "L 1822 0 \n",
       "L 1822 3584 \n",
       "Q 1619 3391 1289 3197 \n",
       "Q 959 3003 697 2906 \n",
       "L 697 3450 \n",
       "Q 1169 3672 1522 3987 \n",
       "Q 1875 4303 2022 4600 \n",
       "L 2384 4600 \n",
       "L 2384 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-31\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"text_7\">\n",
       "     <!-- $x$ -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(218.8865 313.431375) scale(0.096 -0.096)\">\n",
       "      <defs>\n",
       "       <path id=\"DejaVuSans-Oblique-78\" d=\"M 3841 3500 \n",
       "L 2234 1784 \n",
       "L 3219 0 \n",
       "L 2559 0 \n",
       "L 1819 1388 \n",
       "L 531 0 \n",
       "L -166 0 \n",
       "L 1556 1844 \n",
       "L 641 3500 \n",
       "L 1300 3500 \n",
       "L 1972 2234 \n",
       "L 3144 3500 \n",
       "L 3841 3500 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-78\" transform=\"translate(0 0.3125)\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_2\">\n",
       "    <g id=\"ytick_1\">\n",
       "     <g id=\"line2d_7\">\n",
       "      <defs>\n",
       "       <path id=\"m937ecbb040\" d=\"M 0 0 \n",
       "L -4.8 0 \n",
       "\" style=\"stroke: #262626\"/>\n",
       "      </defs>\n",
       "      <g>\n",
       "       <use xlink:href=\"#m937ecbb040\" x=\"43.2065\" y=\"286.137272\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_8\">\n",
       "      <!-- −12 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(19.9795 289.286709) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-2212\" d=\"M 3381 1997 \n",
       "L 356 1997 \n",
       "L 356 2522 \n",
       "L 3381 2522 \n",
       "L 3381 1997 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-31\" x=\"58.398438\"/>\n",
       "       <use xlink:href=\"#ArialMT-32\" x=\"114.013672\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_2\">\n",
       "     <g id=\"line2d_8\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m937ecbb040\" x=\"43.2065\" y=\"244.901438\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_9\">\n",
       "      <!-- −10 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(19.9795 248.050875) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-31\" x=\"58.398438\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"114.013672\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_3\">\n",
       "     <g id=\"line2d_9\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m937ecbb040\" x=\"43.2065\" y=\"203.665604\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_10\">\n",
       "      <!-- −8 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(24.873125 206.815041) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-38\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_4\">\n",
       "     <g id=\"line2d_10\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m937ecbb040\" x=\"43.2065\" y=\"162.42977\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_11\">\n",
       "      <!-- −6 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(24.873125 165.579207) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-36\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_5\">\n",
       "     <g id=\"line2d_11\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m937ecbb040\" x=\"43.2065\" y=\"121.193936\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_12\">\n",
       "      <!-- −4 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(24.873125 124.343373) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-34\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_6\">\n",
       "     <g id=\"line2d_12\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m937ecbb040\" x=\"43.2065\" y=\"79.958102\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_13\">\n",
       "      <!-- −2 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(24.873125 83.107539) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-32\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_7\">\n",
       "     <g id=\"line2d_13\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m937ecbb040\" x=\"43.2065\" y=\"38.722268\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_14\">\n",
       "      <!-- 0 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(30.012875 41.871705) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"text_15\">\n",
       "     <!-- $y$ -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(13.9635 156.036) rotate(-90) scale(0.096 -0.096)\">\n",
       "      <defs>\n",
       "       <path id=\"DejaVuSans-Oblique-79\" d=\"M 1588 -325 \n",
       "Q 1188 -997 936 -1164 \n",
       "Q 684 -1331 294 -1331 \n",
       "L -159 -1331 \n",
       "L -63 -850 \n",
       "L 269 -850 \n",
       "Q 509 -850 678 -719 \n",
       "Q 847 -588 1056 -206 \n",
       "L 1234 128 \n",
       "L 459 3500 \n",
       "L 1069 3500 \n",
       "L 1650 819 \n",
       "L 3256 3500 \n",
       "L 3859 3500 \n",
       "L 1588 -325 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-79\" transform=\"translate(0 0.3125)\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"PolyCollection_1\">\n",
       "    <defs>\n",
       "     <path id=\"mffd141c1dc\" d=\"M 59.439227 -206.349538 \n",
       "L 59.439227 -198.120881 \n",
       "L 62.718566 -199.838022 \n",
       "L 65.997905 -201.057222 \n",
       "L 69.277244 -202.658166 \n",
       "L 72.556583 -204.891528 \n",
       "L 75.835921 -207.800926 \n",
       "L 79.115261 -211.359328 \n",
       "L 82.394598 -215.505943 \n",
       "L 85.673938 -220.160073 \n",
       "L 88.953278 -225.227417 \n",
       "L 92.232615 -230.602512 \n",
       "L 95.511955 -236.17425 \n",
       "L 98.791295 -241.826926 \n",
       "L 102.070632 -247.44247 \n",
       "L 105.349969 -252.903504 \n",
       "L 108.629311 -258.090776 \n",
       "L 111.908649 -262.883652 \n",
       "L 115.187986 -267.158347 \n",
       "L 118.467328 -270.79469 \n",
       "L 121.746666 -273.714939 \n",
       "L 125.026003 -275.931387 \n",
       "L 128.305345 -277.549427 \n",
       "L 131.584682 -278.699425 \n",
       "L 134.86402 -279.485981 \n",
       "L 138.143362 -279.977724 \n",
       "L 141.422694 -280.218334 \n",
       "L 144.702037 -280.225937 \n",
       "L 147.981379 -279.994624 \n",
       "L 151.260711 -279.478064 \n",
       "L 154.540053 -278.563024 \n",
       "L 157.819395 -277.065035 \n",
       "L 161.098728 -274.845803 \n",
       "L 164.37807 -271.939194 \n",
       "L 167.657412 -268.475038 \n",
       "L 170.936745 -264.570452 \n",
       "L 174.216087 -260.312186 \n",
       "L 177.495429 -255.767049 \n",
       "L 180.774762 -250.99299 \n",
       "L 184.054104 -246.04266 \n",
       "L 187.333446 -240.96601 \n",
       "L 190.612778 -235.811241 \n",
       "L 193.892121 -230.623709 \n",
       "L 197.171463 -225.44591 \n",
       "L 200.450795 -220.31592 \n",
       "L 203.730137 -215.266548 \n",
       "L 207.00948 -210.324584 \n",
       "L 210.288812 -205.509357 \n",
       "L 213.568154 -200.832329 \n",
       "L 216.847496 -196.296411 \n",
       "L 220.126829 -191.895724 \n",
       "L 223.406181 -187.615118 \n",
       "L 226.685504 -183.42967 \n",
       "L 229.964846 -179.301705 \n",
       "L 233.244188 -175.171981 \n",
       "L 236.523511 -170.926729 \n",
       "L 239.802872 -166.250251 \n",
       "L 243.082195 -160.041523 \n",
       "L 246.361537 -150.933026 \n",
       "L 249.640879 -140.202291 \n",
       "L 252.920222 -129.023324 \n",
       "L 256.199564 -117.828341 \n",
       "L 259.478887 -106.862016 \n",
       "L 262.758248 -96.324556 \n",
       "L 266.037571 -86.403899 \n",
       "L 269.316913 -77.282847 \n",
       "L 272.596255 -69.140196 \n",
       "L 275.875578 -62.147207 \n",
       "L 279.15494 -56.465962 \n",
       "L 282.434262 -52.243518 \n",
       "L 285.713605 -49.608864 \n",
       "L 288.992947 -48.668983 \n",
       "L 292.272289 -49.503255 \n",
       "L 295.551631 -52.160129 \n",
       "L 298.830954 -56.656062 \n",
       "L 302.110315 -62.968345 \n",
       "L 305.389638 -71.036926 \n",
       "L 308.66898 -80.761782 \n",
       "L 311.948322 -92.003484 \n",
       "L 315.227645 -104.584575 \n",
       "L 318.507007 -118.292323 \n",
       "L 321.78633 -132.880816 \n",
       "L 325.065672 -148.078001 \n",
       "L 328.345014 -163.589062 \n",
       "L 331.624356 -179.101971 \n",
       "L 334.903698 -194.293758 \n",
       "L 338.183021 -208.833895 \n",
       "L 341.462363 -222.385025 \n",
       "L 344.741705 -234.603317 \n",
       "L 348.021048 -245.158899 \n",
       "L 351.30039 -253.82704 \n",
       "L 354.579713 -260.556803 \n",
       "L 357.859055 -265.380918 \n",
       "L 361.138397 -268.323256 \n",
       "L 364.417739 -269.402505 \n",
       "L 367.697081 -268.633178 \n",
       "L 370.976423 -266.065173 \n",
       "L 374.255766 -261.748534 \n",
       "L 377.535088 -255.72687 \n",
       "L 380.814431 -248.008043 \n",
       "L 384.093773 -238.584253 \n",
       "L 384.093773 -246.679596 \n",
       "L 384.093773 -246.679596 \n",
       "L 380.814431 -255.21626 \n",
       "L 377.535088 -262.859096 \n",
       "L 374.255766 -269.177004 \n",
       "L 370.976423 -273.815739 \n",
       "L 367.697081 -276.548189 \n",
       "L 364.417739 -277.248064 \n",
       "L 361.138397 -275.872613 \n",
       "L 357.859055 -272.461042 \n",
       "L 354.579713 -267.14467 \n",
       "L 351.30039 -260.165543 \n",
       "L 348.021048 -251.864235 \n",
       "L 344.741705 -242.566074 \n",
       "L 341.462363 -232.494484 \n",
       "L 338.183021 -221.829409 \n",
       "L 334.903698 -210.764048 \n",
       "L 331.624356 -199.521982 \n",
       "L 328.345014 -188.33921 \n",
       "L 325.065672 -177.444261 \n",
       "L 321.78633 -167.05734 \n",
       "L 318.507007 -157.369617 \n",
       "L 315.227645 -148.546181 \n",
       "L 311.948322 -140.719589 \n",
       "L 308.66898 -133.98495 \n",
       "L 305.389638 -128.404221 \n",
       "L 302.110315 -124.003298 \n",
       "L 298.830954 -120.776804 \n",
       "L 295.551631 -118.687329 \n",
       "L 292.272289 -117.675286 \n",
       "L 288.992947 -117.65521 \n",
       "L 285.713605 -118.529574 \n",
       "L 282.434262 -120.188769 \n",
       "L 279.15494 -122.516291 \n",
       "L 275.875578 -125.395954 \n",
       "L 272.596255 -128.715227 \n",
       "L 269.316913 -132.368001 \n",
       "L 266.037571 -136.261035 \n",
       "L 262.758248 -140.31433 \n",
       "L 259.478887 -144.466263 \n",
       "L 256.199564 -148.67742 \n",
       "L 252.920222 -152.9415 \n",
       "L 249.640879 -157.319565 \n",
       "L 246.361537 -162.084417 \n",
       "L 243.082195 -168.27478 \n",
       "L 239.802872 -177.056423 \n",
       "L 236.523511 -186.973443 \n",
       "L 233.244188 -196.856152 \n",
       "L 229.964846 -206.340134 \n",
       "L 226.685504 -215.278862 \n",
       "L 223.406181 -223.5949 \n",
       "L 220.126829 -231.244576 \n",
       "L 216.847496 -238.206227 \n",
       "L 213.568154 -244.475991 \n",
       "L 210.288812 -250.064573 \n",
       "L 207.00948 -254.995341 \n",
       "L 203.730137 -259.302522 \n",
       "L 200.450795 -263.028923 \n",
       "L 197.171463 -266.224263 \n",
       "L 193.892121 -268.942809 \n",
       "L 190.612778 -271.241493 \n",
       "L 187.333446 -273.178388 \n",
       "L 184.054104 -274.810293 \n",
       "L 180.774762 -276.192166 \n",
       "L 177.495429 -277.375573 \n",
       "L 174.216087 -278.409261 \n",
       "L 170.936745 -279.341334 \n",
       "L 167.657412 -280.223155 \n",
       "L 164.37807 -281.119898 \n",
       "L 161.098728 -282.121847 \n",
       "L 157.819395 -283.326798 \n",
       "L 154.540053 -284.732314 \n",
       "L 151.260711 -286.160427 \n",
       "L 147.981379 -287.384549 \n",
       "L 144.702037 -288.24865 \n",
       "L 141.422694 -288.66398 \n",
       "L 138.143362 -288.5848 \n",
       "L 134.86402 -287.993389 \n",
       "L 131.584682 -286.903595 \n",
       "L 128.305345 -285.362054 \n",
       "L 125.026003 -283.46081 \n",
       "L 121.746666 -281.328914 \n",
       "L 118.467328 -279.083023 \n",
       "L 115.187986 -276.760296 \n",
       "L 111.908649 -274.322037 \n",
       "L 108.629311 -271.701974 \n",
       "L 105.349969 -268.84513 \n",
       "L 102.070632 -265.713177 \n",
       "L 98.791295 -262.283067 \n",
       "L 95.511955 -258.54476 \n",
       "L 92.232615 -254.497988 \n",
       "L 88.953278 -250.152541 \n",
       "L 85.673938 -245.52776 \n",
       "L 82.394598 -240.651932 \n",
       "L 79.115261 -235.563913 \n",
       "L 75.835921 -230.313666 \n",
       "L 72.556583 -224.964717 \n",
       "L 69.277244 -219.606261 \n",
       "L 65.997905 -214.386954 \n",
       "L 62.718566 -209.649256 \n",
       "L 59.439227 -206.349538 \n",
       "z\n",
       "\" style=\"stroke: #1f77b4; stroke-opacity: 0.5; stroke-width: 0.8\"/>\n",
       "    </defs>\n",
       "    <g clip-path=\"url(#p0efaf9abe6)\">\n",
       "     <use xlink:href=\"#mffd141c1dc\" x=\"0\" y=\"322.539375\" style=\"fill: #1f77b4; fill-opacity: 0.5; stroke: #1f77b4; stroke-opacity: 0.5; stroke-width: 0.8\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"PolyCollection_2\">\n",
       "    <defs>\n",
       "     <path id=\"m66f6d8ec50\" d=\"M 59.439227 -198.120881 \n",
       "L 59.439227 -196.410121 \n",
       "L 62.718566 -198.335127 \n",
       "L 65.997905 -199.884711 \n",
       "L 69.277244 -201.708124 \n",
       "L 72.556583 -204.077445 \n",
       "L 75.835921 -207.069397 \n",
       "L 79.115261 -210.676106 \n",
       "L 82.394598 -214.847004 \n",
       "L 85.673938 -219.506605 \n",
       "L 88.953278 -224.562933 \n",
       "L 92.232615 -229.910933 \n",
       "L 95.511955 -235.438356 \n",
       "L 98.791295 -241.02697 \n",
       "L 102.070632 -246.554919 \n",
       "L 105.349969 -251.900034 \n",
       "L 108.629311 -256.938982 \n",
       "L 111.908649 -261.552091 \n",
       "L 115.187986 -265.630554 \n",
       "L 118.467328 -269.092656 \n",
       "L 121.746666 -271.909698 \n",
       "L 125.026003 -274.112462 \n",
       "L 128.305345 -275.775667 \n",
       "L 131.584682 -276.985064 \n",
       "L 134.86402 -277.815334 \n",
       "L 138.143362 -278.321028 \n",
       "L 141.422694 -278.538939 \n",
       "L 144.702037 -278.484475 \n",
       "L 147.981379 -278.152738 \n",
       "L 151.260711 -277.511946 \n",
       "L 154.540053 -276.498011 \n",
       "L 157.819395 -275.018431 \n",
       "L 161.098728 -272.984812 \n",
       "L 164.37807 -270.35903 \n",
       "L 167.657412 -267.172153 \n",
       "L 170.936745 -263.497247 \n",
       "L 174.216087 -259.416883 \n",
       "L 177.495429 -255.006881 \n",
       "L 180.774762 -250.335371 \n",
       "L 184.054104 -245.463249 \n",
       "L 187.333446 -240.44652 \n",
       "L 190.612778 -235.337644 \n",
       "L 193.892121 -230.184988 \n",
       "L 197.171463 -225.033109 \n",
       "L 200.450795 -219.921465 \n",
       "L 203.730137 -214.883734 \n",
       "L 207.00948 -209.947123 \n",
       "L 210.288812 -205.130937 \n",
       "L 213.568154 -200.446142 \n",
       "L 216.847496 -195.894544 \n",
       "L 220.126829 -191.468236 \n",
       "L 223.406181 -187.148569 \n",
       "L 226.685504 -182.904447 \n",
       "L 229.964846 -178.686801 \n",
       "L 233.244188 -174.414296 \n",
       "L 236.523511 -169.929098 \n",
       "L 239.802872 -164.856475 \n",
       "L 243.082195 -158.331441 \n",
       "L 246.361537 -149.573856 \n",
       "L 249.640879 -139.26071 \n",
       "L 252.920222 -128.332364 \n",
       "L 256.199564 -117.286651 \n",
       "L 259.478887 -106.41516 \n",
       "L 262.758248 -95.941349 \n",
       "L 266.037571 -86.065148 \n",
       "L 269.316913 -76.975872 \n",
       "L 272.596255 -68.856128 \n",
       "L 275.875578 -61.879499 \n",
       "L 279.15494 -56.20952 \n",
       "L 282.434262 -51.994175 \n",
       "L 285.713605 -49.36302 \n",
       "L 288.992947 -48.423375 \n",
       "L 292.272289 -49.254737 \n",
       "L 295.551631 -51.905515 \n",
       "L 298.830954 -56.391971 \n",
       "L 302.110315 -62.691001 \n",
       "L 305.389638 -70.742044 \n",
       "L 308.66898 -80.444189 \n",
       "L 311.948322 -91.656908 \n",
       "L 315.227645 -104.201131 \n",
       "L 318.507007 -117.861925 \n",
       "L 321.78633 -132.390319 \n",
       "L 325.065672 -147.509963 \n",
       "L 328.345014 -162.920124 \n",
       "L 331.624356 -178.300703 \n",
       "L 334.903698 -193.319044 \n",
       "L 338.183021 -207.635886 \n",
       "L 341.462363 -220.916392 \n",
       "L 344.741705 -232.85274 \n",
       "L 348.021048 -243.197028 \n",
       "L 351.30039 -251.795512 \n",
       "L 354.579713 -258.573052 \n",
       "L 357.859055 -263.486279 \n",
       "L 361.138397 -266.507573 \n",
       "L 364.417739 -267.633875 \n",
       "L 367.697081 -266.875284 \n",
       "L 370.976423 -264.281678 \n",
       "L 374.255766 -259.913041 \n",
       "L 377.535088 -253.841276 \n",
       "L 380.814431 -246.135515 \n",
       "L 384.093773 -236.853722 \n",
       "L 384.093773 -238.584253 \n",
       "L 384.093773 -238.584253 \n",
       "L 380.814431 -248.008043 \n",
       "L 377.535088 -255.72687 \n",
       "L 374.255766 -261.748534 \n",
       "L 370.976423 -266.065173 \n",
       "L 367.697081 -268.633178 \n",
       "L 364.417739 -269.402505 \n",
       "L 361.138397 -268.323256 \n",
       "L 357.859055 -265.380918 \n",
       "L 354.579713 -260.556803 \n",
       "L 351.30039 -253.82704 \n",
       "L 348.021048 -245.158899 \n",
       "L 344.741705 -234.603317 \n",
       "L 341.462363 -222.385025 \n",
       "L 338.183021 -208.833895 \n",
       "L 334.903698 -194.293758 \n",
       "L 331.624356 -179.101971 \n",
       "L 328.345014 -163.589062 \n",
       "L 325.065672 -148.078001 \n",
       "L 321.78633 -132.880816 \n",
       "L 318.507007 -118.292323 \n",
       "L 315.227645 -104.584575 \n",
       "L 311.948322 -92.003484 \n",
       "L 308.66898 -80.761782 \n",
       "L 305.389638 -71.036926 \n",
       "L 302.110315 -62.968345 \n",
       "L 298.830954 -56.656062 \n",
       "L 295.551631 -52.160129 \n",
       "L 292.272289 -49.503255 \n",
       "L 288.992947 -48.668983 \n",
       "L 285.713605 -49.608864 \n",
       "L 282.434262 -52.243518 \n",
       "L 279.15494 -56.465962 \n",
       "L 275.875578 -62.147207 \n",
       "L 272.596255 -69.140196 \n",
       "L 269.316913 -77.282847 \n",
       "L 266.037571 -86.403899 \n",
       "L 262.758248 -96.324556 \n",
       "L 259.478887 -106.862016 \n",
       "L 256.199564 -117.828341 \n",
       "L 252.920222 -129.023324 \n",
       "L 249.640879 -140.202291 \n",
       "L 246.361537 -150.933026 \n",
       "L 243.082195 -160.041523 \n",
       "L 239.802872 -166.250251 \n",
       "L 236.523511 -170.926729 \n",
       "L 233.244188 -175.171981 \n",
       "L 229.964846 -179.301705 \n",
       "L 226.685504 -183.42967 \n",
       "L 223.406181 -187.615118 \n",
       "L 220.126829 -191.895724 \n",
       "L 216.847496 -196.296411 \n",
       "L 213.568154 -200.832329 \n",
       "L 210.288812 -205.509357 \n",
       "L 207.00948 -210.324584 \n",
       "L 203.730137 -215.266548 \n",
       "L 200.450795 -220.31592 \n",
       "L 197.171463 -225.44591 \n",
       "L 193.892121 -230.623709 \n",
       "L 190.612778 -235.811241 \n",
       "L 187.333446 -240.96601 \n",
       "L 184.054104 -246.04266 \n",
       "L 180.774762 -250.99299 \n",
       "L 177.495429 -255.767049 \n",
       "L 174.216087 -260.312186 \n",
       "L 170.936745 -264.570452 \n",
       "L 167.657412 -268.475038 \n",
       "L 164.37807 -271.939194 \n",
       "L 161.098728 -274.845803 \n",
       "L 157.819395 -277.065035 \n",
       "L 154.540053 -278.563024 \n",
       "L 151.260711 -279.478064 \n",
       "L 147.981379 -279.994624 \n",
       "L 144.702037 -280.225937 \n",
       "L 141.422694 -280.218334 \n",
       "L 138.143362 -279.977724 \n",
       "L 134.86402 -279.485981 \n",
       "L 131.584682 -278.699425 \n",
       "L 128.305345 -277.549427 \n",
       "L 125.026003 -275.931387 \n",
       "L 121.746666 -273.714939 \n",
       "L 118.467328 -270.79469 \n",
       "L 115.187986 -267.158347 \n",
       "L 111.908649 -262.883652 \n",
       "L 108.629311 -258.090776 \n",
       "L 105.349969 -252.903504 \n",
       "L 102.070632 -247.44247 \n",
       "L 98.791295 -241.826926 \n",
       "L 95.511955 -236.17425 \n",
       "L 92.232615 -230.602512 \n",
       "L 88.953278 -225.227417 \n",
       "L 85.673938 -220.160073 \n",
       "L 82.394598 -215.505943 \n",
       "L 79.115261 -211.359328 \n",
       "L 75.835921 -207.800926 \n",
       "L 72.556583 -204.891528 \n",
       "L 69.277244 -202.658166 \n",
       "L 65.997905 -201.057222 \n",
       "L 62.718566 -199.838022 \n",
       "L 59.439227 -198.120881 \n",
       "z\n",
       "\" style=\"stroke: #ff7f0e; stroke-opacity: 0.5; stroke-width: 0.8\"/>\n",
       "    </defs>\n",
       "    <g clip-path=\"url(#p0efaf9abe6)\">\n",
       "     <use xlink:href=\"#m66f6d8ec50\" x=\"0\" y=\"322.539375\" style=\"fill: #ff7f0e; fill-opacity: 0.5; stroke: #ff7f0e; stroke-opacity: 0.5; stroke-width: 0.8\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"PolyCollection_3\">\n",
       "    <defs>\n",
       "     <path id=\"m8ebe3a1865\" d=\"M 59.439227 -208.060298 \n",
       "L 59.439227 -206.349538 \n",
       "L 62.718566 -209.649256 \n",
       "L 65.997905 -214.386954 \n",
       "L 69.277244 -219.606261 \n",
       "L 72.556583 -224.964717 \n",
       "L 75.835921 -230.313666 \n",
       "L 79.115261 -235.563913 \n",
       "L 82.394598 -240.651932 \n",
       "L 85.673938 -245.52776 \n",
       "L 88.953278 -250.152541 \n",
       "L 92.232615 -254.497988 \n",
       "L 95.511955 -258.54476 \n",
       "L 98.791295 -262.283067 \n",
       "L 102.070632 -265.713177 \n",
       "L 105.349969 -268.84513 \n",
       "L 108.629311 -271.701974 \n",
       "L 111.908649 -274.322037 \n",
       "L 115.187986 -276.760296 \n",
       "L 118.467328 -279.083023 \n",
       "L 121.746666 -281.328914 \n",
       "L 125.026003 -283.46081 \n",
       "L 128.305345 -285.362054 \n",
       "L 131.584682 -286.903595 \n",
       "L 134.86402 -287.993389 \n",
       "L 138.143362 -288.5848 \n",
       "L 141.422694 -288.66398 \n",
       "L 144.702037 -288.24865 \n",
       "L 147.981379 -287.384549 \n",
       "L 151.260711 -286.160427 \n",
       "L 154.540053 -284.732314 \n",
       "L 157.819395 -283.326798 \n",
       "L 161.098728 -282.121847 \n",
       "L 164.37807 -281.119898 \n",
       "L 167.657412 -280.223155 \n",
       "L 170.936745 -279.341334 \n",
       "L 174.216087 -278.409261 \n",
       "L 177.495429 -277.375573 \n",
       "L 180.774762 -276.192166 \n",
       "L 184.054104 -274.810293 \n",
       "L 187.333446 -273.178388 \n",
       "L 190.612778 -271.241493 \n",
       "L 193.892121 -268.942809 \n",
       "L 197.171463 -266.224263 \n",
       "L 200.450795 -263.028923 \n",
       "L 203.730137 -259.302522 \n",
       "L 207.00948 -254.995341 \n",
       "L 210.288812 -250.064573 \n",
       "L 213.568154 -244.475991 \n",
       "L 216.847496 -238.206227 \n",
       "L 220.126829 -231.244576 \n",
       "L 223.406181 -223.5949 \n",
       "L 226.685504 -215.278862 \n",
       "L 229.964846 -206.340134 \n",
       "L 233.244188 -196.856152 \n",
       "L 236.523511 -186.973443 \n",
       "L 239.802872 -177.056423 \n",
       "L 243.082195 -168.27478 \n",
       "L 246.361537 -162.084417 \n",
       "L 249.640879 -157.319565 \n",
       "L 252.920222 -152.9415 \n",
       "L 256.199564 -148.67742 \n",
       "L 259.478887 -144.466263 \n",
       "L 262.758248 -140.31433 \n",
       "L 266.037571 -136.261035 \n",
       "L 269.316913 -132.368001 \n",
       "L 272.596255 -128.715227 \n",
       "L 275.875578 -125.395954 \n",
       "L 279.15494 -122.516291 \n",
       "L 282.434262 -120.188769 \n",
       "L 285.713605 -118.529574 \n",
       "L 288.992947 -117.65521 \n",
       "L 292.272289 -117.675286 \n",
       "L 295.551631 -118.687329 \n",
       "L 298.830954 -120.776804 \n",
       "L 302.110315 -124.003298 \n",
       "L 305.389638 -128.404221 \n",
       "L 308.66898 -133.98495 \n",
       "L 311.948322 -140.719589 \n",
       "L 315.227645 -148.546181 \n",
       "L 318.507007 -157.369617 \n",
       "L 321.78633 -167.05734 \n",
       "L 325.065672 -177.444261 \n",
       "L 328.345014 -188.33921 \n",
       "L 331.624356 -199.521982 \n",
       "L 334.903698 -210.764048 \n",
       "L 338.183021 -221.829409 \n",
       "L 341.462363 -232.494484 \n",
       "L 344.741705 -242.566074 \n",
       "L 348.021048 -251.864235 \n",
       "L 351.30039 -260.165543 \n",
       "L 354.579713 -267.14467 \n",
       "L 357.859055 -272.461042 \n",
       "L 361.138397 -275.872613 \n",
       "L 364.417739 -277.248064 \n",
       "L 367.697081 -276.548189 \n",
       "L 370.976423 -273.815739 \n",
       "L 374.255766 -269.177004 \n",
       "L 377.535088 -262.859096 \n",
       "L 380.814431 -255.21626 \n",
       "L 384.093773 -246.679596 \n",
       "L 384.093773 -248.410124 \n",
       "L 384.093773 -248.410124 \n",
       "L 380.814431 -257.088788 \n",
       "L 377.535088 -264.74469 \n",
       "L 374.255766 -271.012497 \n",
       "L 370.976423 -275.599233 \n",
       "L 367.697081 -278.306083 \n",
       "L 364.417739 -279.016694 \n",
       "L 361.138397 -277.688296 \n",
       "L 357.859055 -274.355681 \n",
       "L 354.579713 -269.12842 \n",
       "L 351.30039 -262.197072 \n",
       "L 348.021048 -253.826106 \n",
       "L 344.741705 -244.316651 \n",
       "L 341.462363 -233.963117 \n",
       "L 338.183021 -223.027417 \n",
       "L 334.903698 -211.738761 \n",
       "L 331.624356 -200.32325 \n",
       "L 328.345014 -189.008147 \n",
       "L 325.065672 -178.012299 \n",
       "L 321.78633 -167.547837 \n",
       "L 318.507007 -157.800015 \n",
       "L 315.227645 -148.929635 \n",
       "L 311.948322 -141.066165 \n",
       "L 308.66898 -134.302543 \n",
       "L 305.389638 -128.699114 \n",
       "L 302.110315 -124.280632 \n",
       "L 298.830954 -121.040904 \n",
       "L 295.551631 -118.941952 \n",
       "L 292.272289 -117.923803 \n",
       "L 288.992947 -117.900818 \n",
       "L 285.713605 -118.775418 \n",
       "L 282.434262 -120.438112 \n",
       "L 279.15494 -122.772733 \n",
       "L 275.875578 -125.663663 \n",
       "L 272.596255 -128.999296 \n",
       "L 269.316913 -132.674977 \n",
       "L 266.037571 -136.599785 \n",
       "L 262.758248 -140.697528 \n",
       "L 259.478887 -144.913139 \n",
       "L 256.199564 -149.2191 \n",
       "L 252.920222 -153.63246 \n",
       "L 249.640879 -158.261147 \n",
       "L 246.361537 -163.443587 \n",
       "L 243.082195 -169.984862 \n",
       "L 239.802872 -178.450199 \n",
       "L 236.523511 -187.971073 \n",
       "L 233.244188 -197.613837 \n",
       "L 229.964846 -206.955033 \n",
       "L 226.685504 -215.804089 \n",
       "L 223.406181 -224.061443 \n",
       "L 220.126829 -231.672064 \n",
       "L 216.847496 -238.608099 \n",
       "L 213.568154 -244.86218 \n",
       "L 210.288812 -250.442995 \n",
       "L 207.00948 -255.3728 \n",
       "L 203.730137 -259.685331 \n",
       "L 200.450795 -263.423375 \n",
       "L 197.171463 -266.637067 \n",
       "L 193.892121 -269.381533 \n",
       "L 190.612778 -271.715089 \n",
       "L 187.333446 -273.697881 \n",
       "L 184.054104 -275.389702 \n",
       "L 180.774762 -276.849786 \n",
       "L 177.495429 -278.135739 \n",
       "L 174.216087 -279.304565 \n",
       "L 170.936745 -280.414539 \n",
       "L 167.657412 -281.526039 \n",
       "L 164.37807 -282.700062 \n",
       "L 161.098728 -283.982838 \n",
       "L 157.819395 -285.373403 \n",
       "L 154.540053 -286.797327 \n",
       "L 151.260711 -288.126546 \n",
       "L 147.981379 -289.226435 \n",
       "L 144.702037 -289.990112 \n",
       "L 141.422694 -290.343375 \n",
       "L 138.143362 -290.241495 \n",
       "L 134.86402 -289.664036 \n",
       "L 131.584682 -288.617956 \n",
       "L 128.305345 -287.135814 \n",
       "L 125.026003 -285.279735 \n",
       "L 121.746666 -283.134155 \n",
       "L 118.467328 -280.785057 \n",
       "L 115.187986 -278.288089 \n",
       "L 111.908649 -275.653596 \n",
       "L 108.629311 -272.853769 \n",
       "L 105.349969 -269.848602 \n",
       "L 102.070632 -266.600729 \n",
       "L 98.791295 -263.083023 \n",
       "L 95.511955 -259.280657 \n",
       "L 92.232615 -255.189568 \n",
       "L 88.953278 -250.817028 \n",
       "L 85.673938 -246.181228 \n",
       "L 82.394598 -241.310871 \n",
       "L 79.115261 -236.247135 \n",
       "L 75.835921 -231.045195 \n",
       "L 72.556583 -225.7788 \n",
       "L 69.277244 -220.556303 \n",
       "L 65.997905 -215.55946 \n",
       "L 62.718566 -211.152151 \n",
       "L 59.439227 -208.060298 \n",
       "z\n",
       "\" style=\"stroke: #ff7f0e; stroke-opacity: 0.5; stroke-width: 0.8\"/>\n",
       "    </defs>\n",
       "    <g clip-path=\"url(#p0efaf9abe6)\">\n",
       "     <use xlink:href=\"#m8ebe3a1865\" x=\"0\" y=\"322.539375\" style=\"fill: #ff7f0e; fill-opacity: 0.5; stroke: #ff7f0e; stroke-opacity: 0.5; stroke-width: 0.8\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"line2d_14\">\n",
       "    <defs>\n",
       "     <path id=\"mc4ba532ef3\" d=\"M -5 5 \n",
       "L 5 -5 \n",
       "M -5 -5 \n",
       "L 5 5 \n",
       "\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "    </defs>\n",
       "    <g clip-path=\"url(#p0efaf9abe6)\">\n",
       "     <use xlink:href=\"#mc4ba532ef3\" x=\"361.243318\" y=\"43.638429\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     <use xlink:href=\"#mc4ba532ef3\" x=\"162.151989\" y=\"44.488084\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     <use xlink:href=\"#mc4ba532ef3\" x=\"119.149308\" y=\"46.764454\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     <use xlink:href=\"#mc4ba532ef3\" x=\"243.082195\" y=\"158.515953\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     <use xlink:href=\"#mc4ba532ef3\" x=\"147.981379\" y=\"39.159676\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     <use xlink:href=\"#mc4ba532ef3\" x=\"384.093773\" y=\"82.982802\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     <use xlink:href=\"#mc4ba532ef3\" x=\"344.741705\" y=\"88.192185\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     <use xlink:href=\"#mc4ba532ef3\" x=\"59.439227\" y=\"120.592304\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"line2d_15\">\n",
       "    <path d=\"M 59.439227 120.304166 \n",
       "L 62.718566 117.795736 \n",
       "L 65.997905 114.817287 \n",
       "L 69.277244 111.407162 \n",
       "L 72.556583 107.611253 \n",
       "L 75.835921 103.482079 \n",
       "L 79.115261 99.077754 \n",
       "L 82.394598 94.460438 \n",
       "L 85.673938 89.695458 \n",
       "L 88.953278 84.849395 \n",
       "L 92.232615 79.989125 \n",
       "L 95.511955 75.17987 \n",
       "L 98.791295 70.484379 \n",
       "L 102.070632 65.961551 \n",
       "L 105.349969 61.665058 \n",
       "L 108.629311 57.642999 \n",
       "L 111.908649 53.936531 \n",
       "L 115.187986 50.580053 \n",
       "L 118.467328 47.600518 \n",
       "L 121.746666 45.017449 \n",
       "L 125.026003 42.843276 \n",
       "L 128.305345 41.083635 \n",
       "L 131.584682 39.737865 \n",
       "L 134.86402 38.79969 \n",
       "L 138.143362 38.258113 \n",
       "L 141.422694 38.098218 \n",
       "L 144.702037 38.302082 \n",
       "L 147.981379 38.849788 \n",
       "L 151.260711 39.720129 \n",
       "L 154.540053 40.891706 \n",
       "L 157.819395 42.343458 \n",
       "L 161.098728 44.05555 \n",
       "L 164.37807 46.009829 \n",
       "L 167.657412 48.190279 \n",
       "L 170.936745 50.583482 \n",
       "L 174.216087 53.178652 \n",
       "L 177.495429 55.968065 \n",
       "L 180.774762 58.946796 \n",
       "L 184.054104 62.112899 \n",
       "L 187.333446 65.467175 \n",
       "L 190.612778 69.013008 \n",
       "L 193.892121 72.756115 \n",
       "L 197.171463 76.704288 \n",
       "L 200.450795 80.866955 \n",
       "L 203.730137 85.254841 \n",
       "L 207.00948 89.879413 \n",
       "L 210.288812 94.75241 \n",
       "L 213.568154 99.885216 \n",
       "L 216.847496 105.288056 \n",
       "L 220.126829 110.969227 \n",
       "L 223.406181 116.934369 \n",
       "L 226.685504 123.185107 \n",
       "L 229.964846 129.718458 \n",
       "L 233.244188 136.525308 \n",
       "L 236.523511 143.589289 \n",
       "L 239.802872 150.886038 \n",
       "L 243.082195 158.381223 \n",
       "L 246.361537 166.030654 \n",
       "L 249.640879 173.778447 \n",
       "L 252.920222 181.556963 \n",
       "L 256.199564 189.286499 \n",
       "L 259.478887 196.875231 \n",
       "L 262.758248 204.219937 \n",
       "L 266.037571 211.206908 \n",
       "L 269.316913 217.713951 \n",
       "L 272.596255 223.611663 \n",
       "L 275.875578 228.767794 \n",
       "L 279.15494 233.048243 \n",
       "L 282.434262 236.323236 \n",
       "L 285.713605 238.470156 \n",
       "L 288.992947 239.377279 \n",
       "L 292.272289 238.950105 \n",
       "L 295.551631 237.115646 \n",
       "L 298.830954 233.822937 \n",
       "L 302.110315 229.053553 \n",
       "L 305.389638 222.818801 \n",
       "L 308.66898 215.166009 \n",
       "L 311.948322 206.177838 \n",
       "L 315.227645 195.973997 \n",
       "L 318.507007 184.708405 \n",
       "L 321.78633 172.570297 \n",
       "L 325.065672 159.778244 \n",
       "L 328.345014 146.575239 \n",
       "L 331.624356 133.227399 \n",
       "L 334.903698 120.010472 \n",
       "L 338.183021 107.207723 \n",
       "L 341.462363 95.09962 \n",
       "L 344.741705 83.954679 \n",
       "L 348.021048 74.027808 \n",
       "L 351.30039 65.543083 \n",
       "L 354.579713 58.688639 \n",
       "L 357.859055 53.618395 \n",
       "L 361.138397 50.441441 \n",
       "L 364.417739 49.21409 \n",
       "L 367.697081 49.948691 \n",
       "L 370.976423 52.598919 \n",
       "L 374.255766 57.076606 \n",
       "L 377.535088 63.246392 \n",
       "L 380.814431 70.927224 \n",
       "L 384.093773 79.90745 \n",
       "\" clip-path=\"url(#p0efaf9abe6)\" style=\"fill: none; stroke: #1f77b4; stroke-width: 2; stroke-linecap: round\"/>\n",
       "   </g>\n",
       "   <g id=\"line2d_16\">\n",
       "    <path d=\"M 59.439227 120.592304 \n",
       "L 62.718566 115.560815 \n",
       "L 65.997905 110.547997 \n",
       "L 69.277244 105.572439 \n",
       "L 72.556583 100.652664 \n",
       "L 75.835921 95.806989 \n",
       "L 79.115261 91.053552 \n",
       "L 82.394598 86.410172 \n",
       "L 85.673938 81.894315 \n",
       "L 88.953278 77.523063 \n",
       "L 92.232615 73.313002 \n",
       "L 95.511955 69.280201 \n",
       "L 98.791295 65.440144 \n",
       "L 102.070632 61.807681 \n",
       "L 105.349969 58.396961 \n",
       "L 108.629311 55.221423 \n",
       "L 111.908649 52.293704 \n",
       "L 115.187986 49.625622 \n",
       "L 118.467328 47.228115 \n",
       "L 121.746666 45.11123 \n",
       "L 125.026003 43.284076 \n",
       "L 128.305345 41.754774 \n",
       "L 131.584682 40.530452 \n",
       "L 134.86402 39.617209 \n",
       "L 138.143362 39.020085 \n",
       "L 141.422694 38.743051 \n",
       "L 144.702037 38.788993 \n",
       "L 147.981379 39.159676 \n",
       "L 151.260711 39.855753 \n",
       "L 154.540053 40.876758 \n",
       "L 157.819395 42.221077 \n",
       "L 161.098728 43.885949 \n",
       "L 164.37807 45.8675 \n",
       "L 167.657412 48.160671 \n",
       "L 170.936745 50.759294 \n",
       "L 174.216087 53.656044 \n",
       "L 177.495429 56.842461 \n",
       "L 180.774762 60.308955 \n",
       "L 184.054104 64.044794 \n",
       "L 187.333446 68.038172 \n",
       "L 190.612778 72.2761 \n",
       "L 193.892121 76.744545 \n",
       "L 197.171463 81.428317 \n",
       "L 200.450795 86.311194 \n",
       "L 203.730137 91.375815 \n",
       "L 207.00948 96.60372 \n",
       "L 210.288812 101.975379 \n",
       "L 213.568154 107.470192 \n",
       "L 216.847496 113.066415 \n",
       "L 220.126829 118.741255 \n",
       "L 223.406181 124.470807 \n",
       "L 226.685504 130.230005 \n",
       "L 229.964846 135.992742 \n",
       "L 233.244188 141.731756 \n",
       "L 236.523511 147.418507 \n",
       "L 239.802872 153.023549 \n",
       "L 243.082195 158.515953 \n",
       "L 246.361537 163.863855 \n",
       "L 249.640879 169.034045 \n",
       "L 252.920222 173.992152 \n",
       "L 256.199564 178.702655 \n",
       "L 259.478887 183.128756 \n",
       "L 262.758248 187.232604 \n",
       "L 266.037571 190.975178 \n",
       "L 269.316913 194.316484 \n",
       "L 272.596255 197.215583 \n",
       "L 275.875578 199.630851 \n",
       "L 279.15494 201.520051 \n",
       "L 282.434262 202.840711 \n",
       "L 285.713605 203.550429 \n",
       "L 288.992947 203.607323 \n",
       "L 292.272289 202.970584 \n",
       "L 295.551631 201.601209 \n",
       "L 298.830954 199.462813 \n",
       "L 302.110315 196.522569 \n",
       "L 305.389638 192.752821 \n",
       "L 308.66898 188.13197 \n",
       "L 311.948322 182.646743 \n",
       "L 315.227645 176.294112 \n",
       "L 318.507007 169.083379 \n",
       "L 321.78633 161.039326 \n",
       "L 325.065672 152.20487 \n",
       "L 328.345014 142.644552 \n",
       "L 331.624356 132.448202 \n",
       "L 334.903698 121.734603 \n",
       "L 338.183021 110.65537 \n",
       "L 341.462363 99.398671 \n",
       "L 344.741705 88.192185 \n",
       "L 348.021048 77.305578 \n",
       "L 351.30039 67.05143 \n",
       "L 354.579713 57.783591 \n",
       "L 357.859055 49.892829 \n",
       "L 361.138397 43.798892 \n",
       "L 364.417739 39.936149 \n",
       "L 367.697081 38.733697 \n",
       "L 370.976423 40.587145 \n",
       "L 374.255766 45.8217 \n",
       "L 377.535088 54.646168 \n",
       "L 380.814431 67.098114 \n",
       "L 384.093773 82.982802 \n",
       "\" clip-path=\"url(#p0efaf9abe6)\" style=\"fill: none; stroke-dasharray: 7.68,1.92,1.2,1.92; stroke-dashoffset: 0; stroke: #bf00bf; stroke-width: 1.2\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_3\">\n",
       "    <path d=\"M 43.2065 286.137272 \n",
       "L 43.2065 38.722268 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_4\">\n",
       "    <path d=\"M 59.439227 286.212 \n",
       "L 384.093773 286.212 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"text_16\">\n",
       "    <!-- N=4, psi=0.10 -->\n",
       "    <g style=\"fill: #262626\" transform=\"translate(191.87975 14.1) scale(0.096 -0.096)\">\n",
       "     <defs>\n",
       "      <path id=\"ArialMT-4e\" d=\"M 488 0 \n",
       "L 488 4581 \n",
       "L 1109 4581 \n",
       "L 3516 984 \n",
       "L 3516 4581 \n",
       "L 4097 4581 \n",
       "L 4097 0 \n",
       "L 3475 0 \n",
       "L 1069 3600 \n",
       "L 1069 0 \n",
       "L 488 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-3d\" d=\"M 3381 2694 \n",
       "L 356 2694 \n",
       "L 356 3219 \n",
       "L 3381 3219 \n",
       "L 3381 2694 \n",
       "z\n",
       "M 3381 1303 \n",
       "L 356 1303 \n",
       "L 356 1828 \n",
       "L 3381 1828 \n",
       "L 3381 1303 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-2c\" d=\"M 569 0 \n",
       "L 569 641 \n",
       "L 1209 641 \n",
       "L 1209 0 \n",
       "Q 1209 -353 1084 -570 \n",
       "Q 959 -788 688 -906 \n",
       "L 531 -666 \n",
       "Q 709 -588 793 -436 \n",
       "Q 878 -284 888 0 \n",
       "L 569 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-20\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-70\" d=\"M 422 -1272 \n",
       "L 422 3319 \n",
       "L 934 3319 \n",
       "L 934 2888 \n",
       "Q 1116 3141 1344 3267 \n",
       "Q 1572 3394 1897 3394 \n",
       "Q 2322 3394 2647 3175 \n",
       "Q 2972 2956 3137 2557 \n",
       "Q 3303 2159 3303 1684 \n",
       "Q 3303 1175 3120 767 \n",
       "Q 2938 359 2589 142 \n",
       "Q 2241 -75 1856 -75 \n",
       "Q 1575 -75 1351 44 \n",
       "Q 1128 163 984 344 \n",
       "L 984 -1272 \n",
       "L 422 -1272 \n",
       "z\n",
       "M 931 1641 \n",
       "Q 931 1000 1190 694 \n",
       "Q 1450 388 1819 388 \n",
       "Q 2194 388 2461 705 \n",
       "Q 2728 1022 2728 1688 \n",
       "Q 2728 2322 2467 2637 \n",
       "Q 2206 2953 1844 2953 \n",
       "Q 1484 2953 1207 2617 \n",
       "Q 931 2281 931 1641 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-73\" d=\"M 197 991 \n",
       "L 753 1078 \n",
       "Q 800 744 1014 566 \n",
       "Q 1228 388 1613 388 \n",
       "Q 2000 388 2187 545 \n",
       "Q 2375 703 2375 916 \n",
       "Q 2375 1106 2209 1216 \n",
       "Q 2094 1291 1634 1406 \n",
       "Q 1016 1563 777 1677 \n",
       "Q 538 1791 414 1992 \n",
       "Q 291 2194 291 2438 \n",
       "Q 291 2659 392 2848 \n",
       "Q 494 3038 669 3163 \n",
       "Q 800 3259 1026 3326 \n",
       "Q 1253 3394 1513 3394 \n",
       "Q 1903 3394 2198 3281 \n",
       "Q 2494 3169 2634 2976 \n",
       "Q 2775 2784 2828 2463 \n",
       "L 2278 2388 \n",
       "Q 2241 2644 2061 2787 \n",
       "Q 1881 2931 1553 2931 \n",
       "Q 1166 2931 1000 2803 \n",
       "Q 834 2675 834 2503 \n",
       "Q 834 2394 903 2306 \n",
       "Q 972 2216 1119 2156 \n",
       "Q 1203 2125 1616 2013 \n",
       "Q 2213 1853 2448 1751 \n",
       "Q 2684 1650 2818 1456 \n",
       "Q 2953 1263 2953 975 \n",
       "Q 2953 694 2789 445 \n",
       "Q 2625 197 2315 61 \n",
       "Q 2006 -75 1616 -75 \n",
       "Q 969 -75 630 194 \n",
       "Q 291 463 197 991 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-69\" d=\"M 425 3934 \n",
       "L 425 4581 \n",
       "L 988 4581 \n",
       "L 988 3934 \n",
       "L 425 3934 \n",
       "z\n",
       "M 425 0 \n",
       "L 425 3319 \n",
       "L 988 3319 \n",
       "L 988 0 \n",
       "L 425 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "     </defs>\n",
       "     <use xlink:href=\"#ArialMT-4e\"/>\n",
       "     <use xlink:href=\"#ArialMT-3d\" x=\"72.216797\"/>\n",
       "     <use xlink:href=\"#ArialMT-34\" x=\"130.615234\"/>\n",
       "     <use xlink:href=\"#ArialMT-2c\" x=\"186.230469\"/>\n",
       "     <use xlink:href=\"#ArialMT-20\" x=\"214.013672\"/>\n",
       "     <use xlink:href=\"#ArialMT-70\" x=\"241.796875\"/>\n",
       "     <use xlink:href=\"#ArialMT-73\" x=\"297.412109\"/>\n",
       "     <use xlink:href=\"#ArialMT-69\" x=\"347.412109\"/>\n",
       "     <use xlink:href=\"#ArialMT-3d\" x=\"369.628906\"/>\n",
       "     <use xlink:href=\"#ArialMT-30\" x=\"428.027344\"/>\n",
       "     <use xlink:href=\"#ArialMT-2e\" x=\"483.642578\"/>\n",
       "     <use xlink:href=\"#ArialMT-31\" x=\"511.425781\"/>\n",
       "     <use xlink:href=\"#ArialMT-30\" x=\"567.041016\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"legend_1\">\n",
       "    <g id=\"line2d_17\">\n",
       "     <g>\n",
       "      <use xlink:href=\"#mc4ba532ef3\" x=\"59.9265\" y=\"220.007125\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"text_17\">\n",
       "     <!-- Observations -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(75.7665 223.087125) scale(0.088 -0.088)\">\n",
       "      <defs>\n",
       "       <path id=\"ArialMT-4f\" d=\"M 309 2231 \n",
       "Q 309 3372 921 4017 \n",
       "Q 1534 4663 2503 4663 \n",
       "Q 3138 4663 3647 4359 \n",
       "Q 4156 4056 4423 3514 \n",
       "Q 4691 2972 4691 2284 \n",
       "Q 4691 1588 4409 1038 \n",
       "Q 4128 488 3612 205 \n",
       "Q 3097 -78 2500 -78 \n",
       "Q 1853 -78 1343 234 \n",
       "Q 834 547 571 1087 \n",
       "Q 309 1628 309 2231 \n",
       "z\n",
       "M 934 2222 \n",
       "Q 934 1394 1379 917 \n",
       "Q 1825 441 2497 441 \n",
       "Q 3181 441 3623 922 \n",
       "Q 4066 1403 4066 2288 \n",
       "Q 4066 2847 3877 3264 \n",
       "Q 3688 3681 3323 3911 \n",
       "Q 2959 4141 2506 4141 \n",
       "Q 1863 4141 1398 3698 \n",
       "Q 934 3256 934 2222 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-62\" d=\"M 941 0 \n",
       "L 419 0 \n",
       "L 419 4581 \n",
       "L 981 4581 \n",
       "L 981 2947 \n",
       "Q 1338 3394 1891 3394 \n",
       "Q 2197 3394 2470 3270 \n",
       "Q 2744 3147 2920 2923 \n",
       "Q 3097 2700 3197 2384 \n",
       "Q 3297 2069 3297 1709 \n",
       "Q 3297 856 2875 390 \n",
       "Q 2453 -75 1863 -75 \n",
       "Q 1275 -75 941 416 \n",
       "L 941 0 \n",
       "z\n",
       "M 934 1684 \n",
       "Q 934 1088 1097 822 \n",
       "Q 1363 388 1816 388 \n",
       "Q 2184 388 2453 708 \n",
       "Q 2722 1028 2722 1663 \n",
       "Q 2722 2313 2464 2622 \n",
       "Q 2206 2931 1841 2931 \n",
       "Q 1472 2931 1203 2611 \n",
       "Q 934 2291 934 1684 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-65\" d=\"M 2694 1069 \n",
       "L 3275 997 \n",
       "Q 3138 488 2766 206 \n",
       "Q 2394 -75 1816 -75 \n",
       "Q 1088 -75 661 373 \n",
       "Q 234 822 234 1631 \n",
       "Q 234 2469 665 2931 \n",
       "Q 1097 3394 1784 3394 \n",
       "Q 2450 3394 2872 2941 \n",
       "Q 3294 2488 3294 1666 \n",
       "Q 3294 1616 3291 1516 \n",
       "L 816 1516 \n",
       "Q 847 969 1125 678 \n",
       "Q 1403 388 1819 388 \n",
       "Q 2128 388 2347 550 \n",
       "Q 2566 713 2694 1069 \n",
       "z\n",
       "M 847 1978 \n",
       "L 2700 1978 \n",
       "Q 2663 2397 2488 2606 \n",
       "Q 2219 2931 1791 2931 \n",
       "Q 1403 2931 1139 2672 \n",
       "Q 875 2413 847 1978 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-72\" d=\"M 416 0 \n",
       "L 416 3319 \n",
       "L 922 3319 \n",
       "L 922 2816 \n",
       "Q 1116 3169 1280 3281 \n",
       "Q 1444 3394 1641 3394 \n",
       "Q 1925 3394 2219 3213 \n",
       "L 2025 2691 \n",
       "Q 1819 2813 1613 2813 \n",
       "Q 1428 2813 1281 2702 \n",
       "Q 1134 2591 1072 2394 \n",
       "Q 978 2094 978 1738 \n",
       "L 978 0 \n",
       "L 416 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-76\" d=\"M 1344 0 \n",
       "L 81 3319 \n",
       "L 675 3319 \n",
       "L 1388 1331 \n",
       "Q 1503 1009 1600 663 \n",
       "Q 1675 925 1809 1294 \n",
       "L 2547 3319 \n",
       "L 3125 3319 \n",
       "L 1869 0 \n",
       "L 1344 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-61\" d=\"M 2588 409 \n",
       "Q 2275 144 1986 34 \n",
       "Q 1697 -75 1366 -75 \n",
       "Q 819 -75 525 192 \n",
       "Q 231 459 231 875 \n",
       "Q 231 1119 342 1320 \n",
       "Q 453 1522 633 1644 \n",
       "Q 813 1766 1038 1828 \n",
       "Q 1203 1872 1538 1913 \n",
       "Q 2219 1994 2541 2106 \n",
       "Q 2544 2222 2544 2253 \n",
       "Q 2544 2597 2384 2738 \n",
       "Q 2169 2928 1744 2928 \n",
       "Q 1347 2928 1158 2789 \n",
       "Q 969 2650 878 2297 \n",
       "L 328 2372 \n",
       "Q 403 2725 575 2942 \n",
       "Q 747 3159 1072 3276 \n",
       "Q 1397 3394 1825 3394 \n",
       "Q 2250 3394 2515 3294 \n",
       "Q 2781 3194 2906 3042 \n",
       "Q 3031 2891 3081 2659 \n",
       "Q 3109 2516 3109 2141 \n",
       "L 3109 1391 \n",
       "Q 3109 606 3145 398 \n",
       "Q 3181 191 3288 0 \n",
       "L 2700 0 \n",
       "Q 2613 175 2588 409 \n",
       "z\n",
       "M 2541 1666 \n",
       "Q 2234 1541 1622 1453 \n",
       "Q 1275 1403 1131 1340 \n",
       "Q 988 1278 909 1158 \n",
       "Q 831 1038 831 891 \n",
       "Q 831 666 1001 516 \n",
       "Q 1172 366 1500 366 \n",
       "Q 1825 366 2078 508 \n",
       "Q 2331 650 2450 897 \n",
       "Q 2541 1088 2541 1459 \n",
       "L 2541 1666 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-74\" d=\"M 1650 503 \n",
       "L 1731 6 \n",
       "Q 1494 -44 1306 -44 \n",
       "Q 1000 -44 831 53 \n",
       "Q 663 150 594 308 \n",
       "Q 525 466 525 972 \n",
       "L 525 2881 \n",
       "L 113 2881 \n",
       "L 113 3319 \n",
       "L 525 3319 \n",
       "L 525 4141 \n",
       "L 1084 4478 \n",
       "L 1084 3319 \n",
       "L 1650 3319 \n",
       "L 1650 2881 \n",
       "L 1084 2881 \n",
       "L 1084 941 \n",
       "Q 1084 700 1114 631 \n",
       "Q 1144 563 1211 522 \n",
       "Q 1278 481 1403 481 \n",
       "Q 1497 481 1650 503 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-6f\" d=\"M 213 1659 \n",
       "Q 213 2581 725 3025 \n",
       "Q 1153 3394 1769 3394 \n",
       "Q 2453 3394 2887 2945 \n",
       "Q 3322 2497 3322 1706 \n",
       "Q 3322 1066 3130 698 \n",
       "Q 2938 331 2570 128 \n",
       "Q 2203 -75 1769 -75 \n",
       "Q 1072 -75 642 372 \n",
       "Q 213 819 213 1659 \n",
       "z\n",
       "M 791 1659 \n",
       "Q 791 1022 1069 705 \n",
       "Q 1347 388 1769 388 \n",
       "Q 2188 388 2466 706 \n",
       "Q 2744 1025 2744 1678 \n",
       "Q 2744 2294 2464 2611 \n",
       "Q 2184 2928 1769 2928 \n",
       "Q 1347 2928 1069 2612 \n",
       "Q 791 2297 791 1659 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-6e\" d=\"M 422 0 \n",
       "L 422 3319 \n",
       "L 928 3319 \n",
       "L 928 2847 \n",
       "Q 1294 3394 1984 3394 \n",
       "Q 2284 3394 2536 3286 \n",
       "Q 2788 3178 2913 3003 \n",
       "Q 3038 2828 3088 2588 \n",
       "Q 3119 2431 3119 2041 \n",
       "L 3119 0 \n",
       "L 2556 0 \n",
       "L 2556 2019 \n",
       "Q 2556 2363 2490 2533 \n",
       "Q 2425 2703 2258 2804 \n",
       "Q 2091 2906 1866 2906 \n",
       "Q 1506 2906 1245 2678 \n",
       "Q 984 2450 984 1813 \n",
       "L 984 0 \n",
       "L 422 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#ArialMT-4f\"/>\n",
       "      <use xlink:href=\"#ArialMT-62\" x=\"77.783203\"/>\n",
       "      <use xlink:href=\"#ArialMT-73\" x=\"133.398438\"/>\n",
       "      <use xlink:href=\"#ArialMT-65\" x=\"183.398438\"/>\n",
       "      <use xlink:href=\"#ArialMT-72\" x=\"239.013672\"/>\n",
       "      <use xlink:href=\"#ArialMT-76\" x=\"272.314453\"/>\n",
       "      <use xlink:href=\"#ArialMT-61\" x=\"322.314453\"/>\n",
       "      <use xlink:href=\"#ArialMT-74\" x=\"377.929688\"/>\n",
       "      <use xlink:href=\"#ArialMT-69\" x=\"405.712891\"/>\n",
       "      <use xlink:href=\"#ArialMT-6f\" x=\"427.929688\"/>\n",
       "      <use xlink:href=\"#ArialMT-6e\" x=\"483.544922\"/>\n",
       "      <use xlink:href=\"#ArialMT-73\" x=\"539.160156\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"line2d_18\">\n",
       "     <path d=\"M 51.1265 232.591125 \n",
       "L 59.9265 232.591125 \n",
       "L 68.7265 232.591125 \n",
       "\" style=\"fill: none; stroke: #1f77b4; stroke-width: 2; stroke-linecap: round\"/>\n",
       "    </g>\n",
       "    <g id=\"text_18\">\n",
       "     <!-- $m_n(x)$ -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(75.7665 235.671125) scale(0.088 -0.088)\">\n",
       "      <defs>\n",
       "       <path id=\"DejaVuSans-Oblique-6d\" d=\"M 5747 2113 \n",
       "L 5338 0 \n",
       "L 4763 0 \n",
       "L 5166 2094 \n",
       "Q 5191 2228 5203 2325 \n",
       "Q 5216 2422 5216 2491 \n",
       "Q 5216 2772 5059 2928 \n",
       "Q 4903 3084 4622 3084 \n",
       "Q 4203 3084 3875 2770 \n",
       "Q 3547 2456 3450 1953 \n",
       "L 3066 0 \n",
       "L 2491 0 \n",
       "L 2900 2094 \n",
       "Q 2925 2209 2937 2307 \n",
       "Q 2950 2406 2950 2484 \n",
       "Q 2950 2769 2794 2926 \n",
       "Q 2638 3084 2363 3084 \n",
       "Q 1938 3084 1609 2770 \n",
       "Q 1281 2456 1184 1953 \n",
       "L 800 0 \n",
       "L 225 0 \n",
       "L 909 3500 \n",
       "L 1484 3500 \n",
       "L 1375 2956 \n",
       "Q 1609 3263 1923 3423 \n",
       "Q 2238 3584 2597 3584 \n",
       "Q 2978 3584 3223 3384 \n",
       "Q 3469 3184 3519 2828 \n",
       "Q 3781 3197 4126 3390 \n",
       "Q 4472 3584 4856 3584 \n",
       "Q 5306 3584 5551 3325 \n",
       "Q 5797 3066 5797 2591 \n",
       "Q 5797 2488 5784 2364 \n",
       "Q 5772 2241 5747 2113 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-Oblique-6e\" d=\"M 3566 2113 \n",
       "L 3156 0 \n",
       "L 2578 0 \n",
       "L 2988 2091 \n",
       "Q 3016 2238 3031 2350 \n",
       "Q 3047 2463 3047 2528 \n",
       "Q 3047 2791 2881 2937 \n",
       "Q 2716 3084 2419 3084 \n",
       "Q 1956 3084 1622 2776 \n",
       "Q 1288 2469 1184 1941 \n",
       "L 800 0 \n",
       "L 225 0 \n",
       "L 903 3500 \n",
       "L 1478 3500 \n",
       "L 1363 2950 \n",
       "Q 1603 3253 1940 3418 \n",
       "Q 2278 3584 2650 3584 \n",
       "Q 3113 3584 3367 3334 \n",
       "Q 3622 3084 3622 2631 \n",
       "Q 3622 2519 3608 2391 \n",
       "Q 3594 2263 3566 2113 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-28\" d=\"M 1984 4856 \n",
       "Q 1566 4138 1362 3434 \n",
       "Q 1159 2731 1159 2009 \n",
       "Q 1159 1288 1364 580 \n",
       "Q 1569 -128 1984 -844 \n",
       "L 1484 -844 \n",
       "Q 1016 -109 783 600 \n",
       "Q 550 1309 550 2009 \n",
       "Q 550 2706 781 3412 \n",
       "Q 1013 4119 1484 4856 \n",
       "L 1984 4856 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-29\" d=\"M 513 4856 \n",
       "L 1013 4856 \n",
       "Q 1481 4119 1714 3412 \n",
       "Q 1947 2706 1947 2009 \n",
       "Q 1947 1309 1714 600 \n",
       "Q 1481 -109 1013 -844 \n",
       "L 513 -844 \n",
       "Q 928 -128 1133 580 \n",
       "Q 1338 1288 1338 2009 \n",
       "Q 1338 2731 1133 3434 \n",
       "Q 928 4138 513 4856 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-6d\" transform=\"translate(0 0.125)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-6e\" transform=\"translate(97.412109 -16.28125) scale(0.7)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-28\" transform=\"translate(144.511719 0.125)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-78\" transform=\"translate(183.525391 0.125)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-29\" transform=\"translate(242.705078 0.125)\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"patch_5\">\n",
       "     <path d=\"M 51.1265 249.828125 \n",
       "L 68.7265 249.828125 \n",
       "L 68.7265 243.668125 \n",
       "L 51.1265 243.668125 \n",
       "z\n",
       "\" style=\"fill: #1f77b4; fill-opacity: 0.5; stroke: #1f77b4; stroke-opacity: 0.5; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "    </g>\n",
       "    <g id=\"text_19\">\n",
       "     <!-- $f(\\mathbf{x}^*)$ 95% pred. -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(75.7665 249.828125) scale(0.088 -0.088)\">\n",
       "      <defs>\n",
       "       <path id=\"DejaVuSans-Oblique-66\" d=\"M 3059 4863 \n",
       "L 2969 4384 \n",
       "L 2419 4384 \n",
       "Q 2106 4384 1964 4261 \n",
       "Q 1822 4138 1753 3809 \n",
       "L 1691 3500 \n",
       "L 2638 3500 \n",
       "L 2553 3053 \n",
       "L 1606 3053 \n",
       "L 1013 0 \n",
       "L 434 0 \n",
       "L 1031 3053 \n",
       "L 481 3053 \n",
       "L 563 3500 \n",
       "L 1113 3500 \n",
       "L 1159 3744 \n",
       "Q 1278 4363 1576 4613 \n",
       "Q 1875 4863 2516 4863 \n",
       "L 3059 4863 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-Bold-78\" d=\"M 1422 1791 \n",
       "L 159 3500 \n",
       "L 1344 3500 \n",
       "L 2059 2463 \n",
       "L 2784 3500 \n",
       "L 3969 3500 \n",
       "L 2706 1797 \n",
       "L 4031 0 \n",
       "L 2847 0 \n",
       "L 2059 1106 \n",
       "L 1281 0 \n",
       "L 97 0 \n",
       "L 1422 1791 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-2a\" d=\"M 3009 3897 \n",
       "L 1888 3291 \n",
       "L 3009 2681 \n",
       "L 2828 2375 \n",
       "L 1778 3009 \n",
       "L 1778 1831 \n",
       "L 1422 1831 \n",
       "L 1422 3009 \n",
       "L 372 2375 \n",
       "L 191 2681 \n",
       "L 1313 3291 \n",
       "L 191 3897 \n",
       "L 372 4206 \n",
       "L 1422 3572 \n",
       "L 1422 4750 \n",
       "L 1778 4750 \n",
       "L 1778 3572 \n",
       "L 2828 4206 \n",
       "L 3009 3897 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-39\" d=\"M 350 1059 \n",
       "L 891 1109 \n",
       "Q 959 728 1153 556 \n",
       "Q 1347 384 1650 384 \n",
       "Q 1909 384 2104 503 \n",
       "Q 2300 622 2425 820 \n",
       "Q 2550 1019 2634 1356 \n",
       "Q 2719 1694 2719 2044 \n",
       "Q 2719 2081 2716 2156 \n",
       "Q 2547 1888 2255 1720 \n",
       "Q 1963 1553 1622 1553 \n",
       "Q 1053 1553 659 1965 \n",
       "Q 266 2378 266 3053 \n",
       "Q 266 3750 677 4175 \n",
       "Q 1088 4600 1706 4600 \n",
       "Q 2153 4600 2523 4359 \n",
       "Q 2894 4119 3086 3673 \n",
       "Q 3278 3228 3278 2384 \n",
       "Q 3278 1506 3087 986 \n",
       "Q 2897 466 2520 194 \n",
       "Q 2144 -78 1638 -78 \n",
       "Q 1100 -78 759 220 \n",
       "Q 419 519 350 1059 \n",
       "z\n",
       "M 2653 3081 \n",
       "Q 2653 3566 2395 3850 \n",
       "Q 2138 4134 1775 4134 \n",
       "Q 1400 4134 1122 3828 \n",
       "Q 844 3522 844 3034 \n",
       "Q 844 2597 1108 2323 \n",
       "Q 1372 2050 1759 2050 \n",
       "Q 2150 2050 2401 2323 \n",
       "Q 2653 2597 2653 3081 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-35\" d=\"M 266 1200 \n",
       "L 856 1250 \n",
       "Q 922 819 1161 601 \n",
       "Q 1400 384 1738 384 \n",
       "Q 2144 384 2425 690 \n",
       "Q 2706 997 2706 1503 \n",
       "Q 2706 1984 2436 2262 \n",
       "Q 2166 2541 1728 2541 \n",
       "Q 1456 2541 1237 2417 \n",
       "Q 1019 2294 894 2097 \n",
       "L 366 2166 \n",
       "L 809 4519 \n",
       "L 3088 4519 \n",
       "L 3088 3981 \n",
       "L 1259 3981 \n",
       "L 1013 2750 \n",
       "Q 1425 3038 1878 3038 \n",
       "Q 2478 3038 2890 2622 \n",
       "Q 3303 2206 3303 1553 \n",
       "Q 3303 931 2941 478 \n",
       "Q 2500 -78 1738 -78 \n",
       "Q 1113 -78 717 272 \n",
       "Q 322 622 266 1200 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-25\" d=\"M 372 3481 \n",
       "Q 372 3972 619 4315 \n",
       "Q 866 4659 1334 4659 \n",
       "Q 1766 4659 2048 4351 \n",
       "Q 2331 4044 2331 3447 \n",
       "Q 2331 2866 2045 2552 \n",
       "Q 1759 2238 1341 2238 \n",
       "Q 925 2238 648 2547 \n",
       "Q 372 2856 372 3481 \n",
       "z\n",
       "M 1350 4272 \n",
       "Q 1141 4272 1002 4090 \n",
       "Q 863 3909 863 3425 \n",
       "Q 863 2984 1003 2804 \n",
       "Q 1144 2625 1350 2625 \n",
       "Q 1563 2625 1702 2806 \n",
       "Q 1841 2988 1841 3469 \n",
       "Q 1841 3913 1700 4092 \n",
       "Q 1559 4272 1350 4272 \n",
       "z\n",
       "M 1353 -169 \n",
       "L 3859 4659 \n",
       "L 4316 4659 \n",
       "L 1819 -169 \n",
       "L 1353 -169 \n",
       "z\n",
       "M 3334 1075 \n",
       "Q 3334 1569 3581 1911 \n",
       "Q 3828 2253 4300 2253 \n",
       "Q 4731 2253 5014 1945 \n",
       "Q 5297 1638 5297 1041 \n",
       "Q 5297 459 5011 145 \n",
       "Q 4725 -169 4303 -169 \n",
       "Q 3888 -169 3611 142 \n",
       "Q 3334 453 3334 1075 \n",
       "z\n",
       "M 4316 1866 \n",
       "Q 4103 1866 3964 1684 \n",
       "Q 3825 1503 3825 1019 \n",
       "Q 3825 581 3965 400 \n",
       "Q 4106 219 4313 219 \n",
       "Q 4528 219 4667 400 \n",
       "Q 4806 581 4806 1063 \n",
       "Q 4806 1506 4665 1686 \n",
       "Q 4525 1866 4316 1866 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-64\" d=\"M 2575 0 \n",
       "L 2575 419 \n",
       "Q 2259 -75 1647 -75 \n",
       "Q 1250 -75 917 144 \n",
       "Q 584 363 401 755 \n",
       "Q 219 1147 219 1656 \n",
       "Q 219 2153 384 2558 \n",
       "Q 550 2963 881 3178 \n",
       "Q 1213 3394 1622 3394 \n",
       "Q 1922 3394 2156 3267 \n",
       "Q 2391 3141 2538 2938 \n",
       "L 2538 4581 \n",
       "L 3097 4581 \n",
       "L 3097 0 \n",
       "L 2575 0 \n",
       "z\n",
       "M 797 1656 \n",
       "Q 797 1019 1065 703 \n",
       "Q 1334 388 1700 388 \n",
       "Q 2069 388 2326 689 \n",
       "Q 2584 991 2584 1609 \n",
       "Q 2584 2291 2321 2609 \n",
       "Q 2059 2928 1675 2928 \n",
       "Q 1300 2928 1048 2622 \n",
       "Q 797 2316 797 1656 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-66\" transform=\"translate(0 0.765625)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-28\" transform=\"translate(35.205078 0.765625)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-Bold-78\" transform=\"translate(74.21875 0.765625)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-2a\" transform=\"translate(153.31543 39.046875) scale(0.7)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-29\" transform=\"translate(204.6875 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" transform=\"translate(243.701172 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-39\" transform=\"translate(271.484375 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-35\" transform=\"translate(327.099609 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-25\" transform=\"translate(382.714844 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" transform=\"translate(471.630859 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-70\" transform=\"translate(499.414062 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-72\" transform=\"translate(555.029297 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-65\" transform=\"translate(588.330078 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-64\" transform=\"translate(643.945312 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-2e\" transform=\"translate(699.560547 0.765625)\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"patch_6\">\n",
       "     <path d=\"M 51.1265 263.996125 \n",
       "L 68.7265 263.996125 \n",
       "L 68.7265 257.836125 \n",
       "L 51.1265 257.836125 \n",
       "z\n",
       "\" style=\"fill: #ff7f0e; fill-opacity: 0.5; stroke: #ff7f0e; stroke-opacity: 0.5; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "    </g>\n",
       "    <g id=\"text_20\">\n",
       "     <!-- $y^*$ 95% pred. -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(75.7665 263.996125) scale(0.088 -0.088)\">\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-79\" transform=\"translate(0 0.765625)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-2a\" transform=\"translate(77.283529 39.046875) scale(0.7)\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" transform=\"translate(128.655599 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-39\" transform=\"translate(156.438802 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-35\" transform=\"translate(212.054036 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-25\" transform=\"translate(267.669271 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" transform=\"translate(356.585286 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-70\" transform=\"translate(384.36849 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-72\" transform=\"translate(439.983724 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-65\" transform=\"translate(473.284505 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-64\" transform=\"translate(528.89974 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-2e\" transform=\"translate(584.514974 0.765625)\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"line2d_19\">\n",
       "     <path d=\"M 51.1265 273.463 \n",
       "L 59.9265 273.463 \n",
       "L 68.7265 273.463 \n",
       "\" style=\"fill: none; stroke-dasharray: 7.68,1.92,1.2,1.92; stroke-dashoffset: 0; stroke: #bf00bf; stroke-width: 1.2\"/>\n",
       "    </g>\n",
       "    <g id=\"text_21\">\n",
       "     <!-- True function -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(75.7665 276.543) scale(0.088 -0.088)\">\n",
       "      <defs>\n",
       "       <path id=\"ArialMT-54\" d=\"M 1659 0 \n",
       "L 1659 4041 \n",
       "L 150 4041 \n",
       "L 150 4581 \n",
       "L 3781 4581 \n",
       "L 3781 4041 \n",
       "L 2266 4041 \n",
       "L 2266 0 \n",
       "L 1659 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-75\" d=\"M 2597 0 \n",
       "L 2597 488 \n",
       "Q 2209 -75 1544 -75 \n",
       "Q 1250 -75 995 37 \n",
       "Q 741 150 617 320 \n",
       "Q 494 491 444 738 \n",
       "Q 409 903 409 1263 \n",
       "L 409 3319 \n",
       "L 972 3319 \n",
       "L 972 1478 \n",
       "Q 972 1038 1006 884 \n",
       "Q 1059 663 1231 536 \n",
       "Q 1403 409 1656 409 \n",
       "Q 1909 409 2131 539 \n",
       "Q 2353 669 2445 892 \n",
       "Q 2538 1116 2538 1541 \n",
       "L 2538 3319 \n",
       "L 3100 3319 \n",
       "L 3100 0 \n",
       "L 2597 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-66\" d=\"M 556 0 \n",
       "L 556 2881 \n",
       "L 59 2881 \n",
       "L 59 3319 \n",
       "L 556 3319 \n",
       "L 556 3672 \n",
       "Q 556 4006 616 4169 \n",
       "Q 697 4388 901 4523 \n",
       "Q 1106 4659 1475 4659 \n",
       "Q 1713 4659 2000 4603 \n",
       "L 1916 4113 \n",
       "Q 1741 4144 1584 4144 \n",
       "Q 1328 4144 1222 4034 \n",
       "Q 1116 3925 1116 3625 \n",
       "L 1116 3319 \n",
       "L 1763 3319 \n",
       "L 1763 2881 \n",
       "L 1116 2881 \n",
       "L 1116 0 \n",
       "L 556 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-63\" d=\"M 2588 1216 \n",
       "L 3141 1144 \n",
       "Q 3050 572 2676 248 \n",
       "Q 2303 -75 1759 -75 \n",
       "Q 1078 -75 664 370 \n",
       "Q 250 816 250 1647 \n",
       "Q 250 2184 428 2587 \n",
       "Q 606 2991 970 3192 \n",
       "Q 1334 3394 1763 3394 \n",
       "Q 2303 3394 2647 3120 \n",
       "Q 2991 2847 3088 2344 \n",
       "L 2541 2259 \n",
       "Q 2463 2594 2264 2762 \n",
       "Q 2066 2931 1784 2931 \n",
       "Q 1359 2931 1093 2626 \n",
       "Q 828 2322 828 1663 \n",
       "Q 828 994 1084 691 \n",
       "Q 1341 388 1753 388 \n",
       "Q 2084 388 2306 591 \n",
       "Q 2528 794 2588 1216 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#ArialMT-54\"/>\n",
       "      <use xlink:href=\"#ArialMT-72\" x=\"57.333984\"/>\n",
       "      <use xlink:href=\"#ArialMT-75\" x=\"90.634766\"/>\n",
       "      <use xlink:href=\"#ArialMT-65\" x=\"146.25\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" x=\"201.865234\"/>\n",
       "      <use xlink:href=\"#ArialMT-66\" x=\"229.648438\"/>\n",
       "      <use xlink:href=\"#ArialMT-75\" x=\"257.431641\"/>\n",
       "      <use xlink:href=\"#ArialMT-6e\" x=\"313.046875\"/>\n",
       "      <use xlink:href=\"#ArialMT-63\" x=\"368.662109\"/>\n",
       "      <use xlink:href=\"#ArialMT-74\" x=\"418.662109\"/>\n",
       "      <use xlink:href=\"#ArialMT-69\" x=\"446.445312\"/>\n",
       "      <use xlink:href=\"#ArialMT-6f\" x=\"468.662109\"/>\n",
       "      <use xlink:href=\"#ArialMT-6e\" x=\"524.277344\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "  </g>\n",
       "  <g id=\"axes_2\">\n",
       "   <g id=\"matplotlib.axis_3\">\n",
       "    <g id=\"ytick_8\">\n",
       "     <g id=\"line2d_20\">\n",
       "      <defs>\n",
       "       <path id=\"mcd4ab9e934\" d=\"M 0 0 \n",
       "L 4.8 0 \n",
       "\" style=\"stroke: #262626\"/>\n",
       "      </defs>\n",
       "      <g>\n",
       "       <use xlink:href=\"#mcd4ab9e934\" x=\"400.3265\" y=\"274.116\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_22\">\n",
       "      <!-- 0.00 -->\n",
       "      <g style=\"fill: #ff7f0e\" transform=\"translate(408.6265 277.265437) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"83.398438\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"139.013672\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_9\">\n",
       "     <g id=\"line2d_21\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mcd4ab9e934\" x=\"400.3265\" y=\"236.05795\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_23\">\n",
       "      <!-- 0.05 -->\n",
       "      <g style=\"fill: #ff7f0e\" transform=\"translate(408.6265 239.207388) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"83.398438\"/>\n",
       "       <use xlink:href=\"#ArialMT-35\" x=\"139.013672\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_10\">\n",
       "     <g id=\"line2d_22\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mcd4ab9e934\" x=\"400.3265\" y=\"197.999901\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_24\">\n",
       "      <!-- 0.10 -->\n",
       "      <g style=\"fill: #ff7f0e\" transform=\"translate(408.6265 201.149338) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-31\" x=\"83.398438\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"139.013672\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_11\">\n",
       "     <g id=\"line2d_23\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mcd4ab9e934\" x=\"400.3265\" y=\"159.941851\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_25\">\n",
       "      <!-- 0.15 -->\n",
       "      <g style=\"fill: #ff7f0e\" transform=\"translate(408.6265 163.091288) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-31\" x=\"83.398438\"/>\n",
       "       <use xlink:href=\"#ArialMT-35\" x=\"139.013672\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_12\">\n",
       "     <g id=\"line2d_24\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mcd4ab9e934\" x=\"400.3265\" y=\"121.883801\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_26\">\n",
       "      <!-- 0.20 -->\n",
       "      <g style=\"fill: #ff7f0e\" transform=\"translate(408.6265 125.033239) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-32\" x=\"83.398438\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"139.013672\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_13\">\n",
       "     <g id=\"line2d_25\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mcd4ab9e934\" x=\"400.3265\" y=\"83.825752\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_27\">\n",
       "      <!-- 0.25 -->\n",
       "      <g style=\"fill: #ff7f0e\" transform=\"translate(408.6265 86.975189) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-32\" x=\"83.398438\"/>\n",
       "       <use xlink:href=\"#ArialMT-35\" x=\"139.013672\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_14\">\n",
       "     <g id=\"line2d_26\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mcd4ab9e934\" x=\"400.3265\" y=\"45.767702\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_28\">\n",
       "      <!-- 0.30 -->\n",
       "      <g style=\"fill: #ff7f0e\" transform=\"translate(408.6265 48.917139) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-33\" d=\"M 269 1209 \n",
       "L 831 1284 \n",
       "Q 928 806 1161 595 \n",
       "Q 1394 384 1728 384 \n",
       "Q 2125 384 2398 659 \n",
       "Q 2672 934 2672 1341 \n",
       "Q 2672 1728 2419 1979 \n",
       "Q 2166 2231 1775 2231 \n",
       "Q 1616 2231 1378 2169 \n",
       "L 1441 2663 \n",
       "Q 1497 2656 1531 2656 \n",
       "Q 1891 2656 2178 2843 \n",
       "Q 2466 3031 2466 3422 \n",
       "Q 2466 3731 2256 3934 \n",
       "Q 2047 4138 1716 4138 \n",
       "Q 1388 4138 1169 3931 \n",
       "Q 950 3725 888 3313 \n",
       "L 325 3413 \n",
       "Q 428 3978 793 4289 \n",
       "Q 1159 4600 1703 4600 \n",
       "Q 2078 4600 2393 4439 \n",
       "Q 2709 4278 2876 4000 \n",
       "Q 3044 3722 3044 3409 \n",
       "Q 3044 3113 2884 2869 \n",
       "Q 2725 2625 2413 2481 \n",
       "Q 2819 2388 3044 2092 \n",
       "Q 3269 1797 3269 1353 \n",
       "Q 3269 753 2831 336 \n",
       "Q 2394 -81 1725 -81 \n",
       "Q 1122 -81 723 278 \n",
       "Q 325 638 269 1209 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-33\" x=\"83.398438\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"139.013672\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"text_29\">\n",
       "     <!-- Information Acquisition Function -->\n",
       "     <g style=\"fill: #ff7f0e\" transform=\"translate(436.740625 221.18925) rotate(-90) scale(0.096 -0.096)\">\n",
       "      <defs>\n",
       "       <path id=\"ArialMT-49\" d=\"M 597 0 \n",
       "L 597 4581 \n",
       "L 1203 4581 \n",
       "L 1203 0 \n",
       "L 597 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-6d\" d=\"M 422 0 \n",
       "L 422 3319 \n",
       "L 925 3319 \n",
       "L 925 2853 \n",
       "Q 1081 3097 1340 3245 \n",
       "Q 1600 3394 1931 3394 \n",
       "Q 2300 3394 2536 3241 \n",
       "Q 2772 3088 2869 2813 \n",
       "Q 3263 3394 3894 3394 \n",
       "Q 4388 3394 4653 3120 \n",
       "Q 4919 2847 4919 2278 \n",
       "L 4919 0 \n",
       "L 4359 0 \n",
       "L 4359 2091 \n",
       "Q 4359 2428 4304 2576 \n",
       "Q 4250 2725 4106 2815 \n",
       "Q 3963 2906 3769 2906 \n",
       "Q 3419 2906 3187 2673 \n",
       "Q 2956 2441 2956 1928 \n",
       "L 2956 0 \n",
       "L 2394 0 \n",
       "L 2394 2156 \n",
       "Q 2394 2531 2256 2718 \n",
       "Q 2119 2906 1806 2906 \n",
       "Q 1569 2906 1367 2781 \n",
       "Q 1166 2656 1075 2415 \n",
       "Q 984 2175 984 1722 \n",
       "L 984 0 \n",
       "L 422 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-41\" d=\"M -9 0 \n",
       "L 1750 4581 \n",
       "L 2403 4581 \n",
       "L 4278 0 \n",
       "L 3588 0 \n",
       "L 3053 1388 \n",
       "L 1138 1388 \n",
       "L 634 0 \n",
       "L -9 0 \n",
       "z\n",
       "M 1313 1881 \n",
       "L 2866 1881 \n",
       "L 2388 3150 \n",
       "Q 2169 3728 2063 4100 \n",
       "Q 1975 3659 1816 3225 \n",
       "L 1313 1881 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-71\" d=\"M 2538 -1272 \n",
       "L 2538 353 \n",
       "Q 2406 169 2170 47 \n",
       "Q 1934 -75 1669 -75 \n",
       "Q 1078 -75 651 397 \n",
       "Q 225 869 225 1691 \n",
       "Q 225 2191 398 2587 \n",
       "Q 572 2984 901 3189 \n",
       "Q 1231 3394 1625 3394 \n",
       "Q 2241 3394 2594 2875 \n",
       "L 2594 3319 \n",
       "L 3100 3319 \n",
       "L 3100 -1272 \n",
       "L 2538 -1272 \n",
       "z\n",
       "M 803 1669 \n",
       "Q 803 1028 1072 708 \n",
       "Q 1341 388 1716 388 \n",
       "Q 2075 388 2334 692 \n",
       "Q 2594 997 2594 1619 \n",
       "Q 2594 2281 2320 2615 \n",
       "Q 2047 2950 1678 2950 \n",
       "Q 1313 2950 1058 2639 \n",
       "Q 803 2328 803 1669 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-46\" d=\"M 525 0 \n",
       "L 525 4581 \n",
       "L 3616 4581 \n",
       "L 3616 4041 \n",
       "L 1131 4041 \n",
       "L 1131 2622 \n",
       "L 3281 2622 \n",
       "L 3281 2081 \n",
       "L 1131 2081 \n",
       "L 1131 0 \n",
       "L 525 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#ArialMT-49\"/>\n",
       "      <use xlink:href=\"#ArialMT-6e\" x=\"27.783203\"/>\n",
       "      <use xlink:href=\"#ArialMT-66\" x=\"83.398438\"/>\n",
       "      <use xlink:href=\"#ArialMT-6f\" x=\"111.181641\"/>\n",
       "      <use xlink:href=\"#ArialMT-72\" x=\"166.796875\"/>\n",
       "      <use xlink:href=\"#ArialMT-6d\" x=\"200.097656\"/>\n",
       "      <use xlink:href=\"#ArialMT-61\" x=\"283.398438\"/>\n",
       "      <use xlink:href=\"#ArialMT-74\" x=\"339.013672\"/>\n",
       "      <use xlink:href=\"#ArialMT-69\" x=\"366.796875\"/>\n",
       "      <use xlink:href=\"#ArialMT-6f\" x=\"389.013672\"/>\n",
       "      <use xlink:href=\"#ArialMT-6e\" x=\"444.628906\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" x=\"500.244141\"/>\n",
       "      <use xlink:href=\"#ArialMT-41\" x=\"522.527344\"/>\n",
       "      <use xlink:href=\"#ArialMT-63\" x=\"589.226562\"/>\n",
       "      <use xlink:href=\"#ArialMT-71\" x=\"639.226562\"/>\n",
       "      <use xlink:href=\"#ArialMT-75\" x=\"694.841797\"/>\n",
       "      <use xlink:href=\"#ArialMT-69\" x=\"750.457031\"/>\n",
       "      <use xlink:href=\"#ArialMT-73\" x=\"772.673828\"/>\n",
       "      <use xlink:href=\"#ArialMT-69\" x=\"822.673828\"/>\n",
       "      <use xlink:href=\"#ArialMT-74\" x=\"844.890625\"/>\n",
       "      <use xlink:href=\"#ArialMT-69\" x=\"872.673828\"/>\n",
       "      <use xlink:href=\"#ArialMT-6f\" x=\"894.890625\"/>\n",
       "      <use xlink:href=\"#ArialMT-6e\" x=\"950.505859\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" x=\"1006.121094\"/>\n",
       "      <use xlink:href=\"#ArialMT-46\" x=\"1033.904297\"/>\n",
       "      <use xlink:href=\"#ArialMT-75\" x=\"1094.988281\"/>\n",
       "      <use xlink:href=\"#ArialMT-6e\" x=\"1150.603516\"/>\n",
       "      <use xlink:href=\"#ArialMT-63\" x=\"1206.21875\"/>\n",
       "      <use xlink:href=\"#ArialMT-74\" x=\"1256.21875\"/>\n",
       "      <use xlink:href=\"#ArialMT-69\" x=\"1284.001953\"/>\n",
       "      <use xlink:href=\"#ArialMT-6f\" x=\"1306.21875\"/>\n",
       "      <use xlink:href=\"#ArialMT-6e\" x=\"1361.833984\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"line2d_27\">\n",
       "    <path d=\"M 59.439227 274.116 \n",
       "L 62.718566 274.116 \n",
       "L 65.997905 274.116 \n",
       "L 69.277244 274.116 \n",
       "L 72.556583 274.116 \n",
       "L 75.835921 274.116 \n",
       "L 79.115261 274.116 \n",
       "L 82.394598 274.116 \n",
       "L 85.673938 274.116 \n",
       "L 88.953278 274.116 \n",
       "L 92.232615 274.116 \n",
       "L 95.511955 274.116 \n",
       "L 98.791295 274.116 \n",
       "L 102.070632 274.116 \n",
       "L 105.349969 274.116 \n",
       "L 108.629311 274.116 \n",
       "L 111.908649 274.116 \n",
       "L 115.187986 274.116 \n",
       "L 118.467328 274.115841 \n",
       "L 121.746666 274.103909 \n",
       "L 125.026003 273.251476 \n",
       "L 128.305345 258.404332 \n",
       "L 131.584682 198.743771 \n",
       "L 134.86402 112.893543 \n",
       "L 138.143362 49.668519 \n",
       "L 141.422694 32.196 \n",
       "L 144.702037 65.465117 \n",
       "L 147.981379 143.57916 \n",
       "L 151.260711 229.779771 \n",
       "L 154.540053 268.82553 \n",
       "L 157.819395 273.809353 \n",
       "L 161.098728 274.066208 \n",
       "L 164.37807 274.076711 \n",
       "L 167.657412 274.055501 \n",
       "L 170.936745 274.016915 \n",
       "L 174.216087 273.97175 \n",
       "L 177.495429 273.934253 \n",
       "L 180.774762 273.916559 \n",
       "L 184.054104 273.923863 \n",
       "L 187.333446 273.953444 \n",
       "L 190.612778 273.996317 \n",
       "L 193.892121 274.040824 \n",
       "L 197.171463 274.077051 \n",
       "L 200.450795 274.100189 \n",
       "L 203.730137 274.11135 \n",
       "L 207.00948 274.115138 \n",
       "L 210.288812 274.115909 \n",
       "L 213.568154 274.116 \n",
       "L 216.847496 274.116 \n",
       "L 220.126829 274.116 \n",
       "L 223.406181 274.116 \n",
       "L 226.685504 274.116 \n",
       "L 229.964846 274.116 \n",
       "L 233.244188 274.116 \n",
       "L 236.523511 274.116 \n",
       "L 239.802872 274.116 \n",
       "L 243.082195 274.116 \n",
       "L 246.361537 274.116 \n",
       "L 249.640879 274.116 \n",
       "L 252.920222 274.116 \n",
       "L 256.199564 274.116 \n",
       "L 259.478887 274.116 \n",
       "L 262.758248 274.116 \n",
       "L 266.037571 274.116 \n",
       "L 269.316913 274.116 \n",
       "L 272.596255 274.116 \n",
       "L 275.875578 274.116 \n",
       "L 279.15494 274.116 \n",
       "L 282.434262 274.116 \n",
       "L 285.713605 274.116 \n",
       "L 288.992947 274.116 \n",
       "L 292.272289 274.116 \n",
       "L 295.551631 274.116 \n",
       "L 298.830954 274.116 \n",
       "L 302.110315 274.116 \n",
       "L 305.389638 274.116 \n",
       "L 308.66898 274.116 \n",
       "L 311.948322 274.116 \n",
       "L 315.227645 274.116 \n",
       "L 318.507007 274.116 \n",
       "L 321.78633 274.116 \n",
       "L 325.065672 274.116 \n",
       "L 328.345014 274.116 \n",
       "L 331.624356 274.116 \n",
       "L 334.903698 274.116 \n",
       "L 338.183021 274.116 \n",
       "L 341.462363 274.116 \n",
       "L 344.741705 274.116 \n",
       "L 348.021048 274.116 \n",
       "L 351.30039 274.116 \n",
       "L 354.579713 274.116 \n",
       "L 357.859055 274.116 \n",
       "L 361.138397 274.116 \n",
       "L 364.417739 274.116 \n",
       "L 367.697081 274.116 \n",
       "L 370.976423 274.116 \n",
       "L 374.255766 274.116 \n",
       "L 377.535088 274.116 \n",
       "L 380.814431 274.116 \n",
       "L 384.093773 274.116 \n",
       "\" clip-path=\"url(#p0efaf9abe6)\" style=\"fill: none; stroke: #ff7f0e; stroke-width: 1.2; stroke-linecap: round\"/>\n",
       "   </g>\n",
       "   <g id=\"line2d_28\">\n",
       "    <path d=\"M 141.422694 274.116 \n",
       "L 141.422694 271.672364 \n",
       "L 141.422694 269.228727 \n",
       "L 141.422694 266.785091 \n",
       "L 141.422694 264.341454 \n",
       "L 141.422694 261.897818 \n",
       "L 141.422694 259.454182 \n",
       "L 141.422694 257.010545 \n",
       "L 141.422694 254.566909 \n",
       "L 141.422694 252.123272 \n",
       "L 141.422694 249.679636 \n",
       "L 141.422694 247.236 \n",
       "L 141.422694 244.792363 \n",
       "L 141.422694 242.348727 \n",
       "L 141.422694 239.905091 \n",
       "L 141.422694 237.461454 \n",
       "L 141.422694 235.017818 \n",
       "L 141.422694 232.574181 \n",
       "L 141.422694 230.130545 \n",
       "L 141.422694 227.686909 \n",
       "L 141.422694 225.243272 \n",
       "L 141.422694 222.799633 \n",
       "L 141.422694 220.355999 \n",
       "L 141.422694 217.912366 \n",
       "L 141.422694 215.468727 \n",
       "L 141.422694 213.025087 \n",
       "L 141.422694 210.581454 \n",
       "L 141.422694 208.13782 \n",
       "L 141.422694 205.694181 \n",
       "L 141.422694 203.250542 \n",
       "L 141.422694 200.806908 \n",
       "L 141.422694 198.363275 \n",
       "L 141.422694 195.919635 \n",
       "L 141.422694 193.475996 \n",
       "L 141.422694 191.032363 \n",
       "L 141.422694 188.588729 \n",
       "L 141.422694 186.14509 \n",
       "L 141.422694 183.701451 \n",
       "L 141.422694 181.257817 \n",
       "L 141.422694 178.814184 \n",
       "L 141.422694 176.370544 \n",
       "L 141.422694 173.926905 \n",
       "L 141.422694 171.483266 \n",
       "L 141.422694 169.039638 \n",
       "L 141.422694 166.595999 \n",
       "L 141.422694 164.15236 \n",
       "L 141.422694 161.708732 \n",
       "L 141.422694 159.265092 \n",
       "L 141.422694 156.821453 \n",
       "L 141.422694 154.377814 \n",
       "L 141.422694 151.934186 \n",
       "L 141.422694 149.490547 \n",
       "L 141.422694 147.046908 \n",
       "L 141.422694 144.603268 \n",
       "L 141.422694 142.15964 \n",
       "L 141.422694 139.716001 \n",
       "L 141.422694 137.272362 \n",
       "L 141.422694 134.828734 \n",
       "L 141.422694 132.385095 \n",
       "L 141.422694 129.941456 \n",
       "L 141.422694 127.497816 \n",
       "L 141.422694 125.054177 \n",
       "L 141.422694 122.610549 \n",
       "L 141.422694 120.16691 \n",
       "L 141.422694 117.723271 \n",
       "L 141.422694 115.279643 \n",
       "L 141.422694 112.836004 \n",
       "L 141.422694 110.392365 \n",
       "L 141.422694 107.948725 \n",
       "L 141.422694 105.505086 \n",
       "L 141.422694 103.061458 \n",
       "L 141.422694 100.617819 \n",
       "L 141.422694 98.17418 \n",
       "L 141.422694 95.730552 \n",
       "L 141.422694 93.286913 \n",
       "L 141.422694 90.843273 \n",
       "L 141.422694 88.399634 \n",
       "L 141.422694 85.955995 \n",
       "L 141.422694 83.512367 \n",
       "L 141.422694 81.068739 \n",
       "L 141.422694 78.625089 \n",
       "L 141.422694 76.181461 \n",
       "L 141.422694 73.73781 \n",
       "L 141.422694 71.294182 \n",
       "L 141.422694 68.850554 \n",
       "L 141.422694 66.406904 \n",
       "L 141.422694 63.963276 \n",
       "L 141.422694 61.519625 \n",
       "L 141.422694 59.075997 \n",
       "L 141.422694 56.63237 \n",
       "L 141.422694 54.188719 \n",
       "L 141.422694 51.745091 \n",
       "L 141.422694 49.301463 \n",
       "L 141.422694 46.857813 \n",
       "L 141.422694 44.414185 \n",
       "L 141.422694 41.970557 \n",
       "L 141.422694 39.526906 \n",
       "L 141.422694 37.083278 \n",
       "L 141.422694 34.639628 \n",
       "L 141.422694 32.196 \n",
       "\" clip-path=\"url(#p0efaf9abe6)\" style=\"fill: none; stroke: #ff7f0e; stroke-linecap: round\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_7\">\n",
       "    <path d=\"M 43.2065 286.212 \n",
       "L 43.2065 20.1 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_8\">\n",
       "    <path d=\"M 400.3265 286.212 \n",
       "L 400.3265 20.1 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_9\">\n",
       "    <path d=\"M 43.2065 286.212 \n",
       "L 400.3265 286.212 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_10\">\n",
       "    <path d=\"M 43.2065 20.1 \n",
       "L 400.3265 20.1 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "  </g>\n",
       " </g>\n",
       " <defs>\n",
       "  <clipPath id=\"p0efaf9abe6\">\n",
       "   <rect x=\"43.2065\" y=\"20.1\" width=\"357.12\" height=\"266.112\"/>\n",
       "  </clipPath>\n",
       " </defs>\n",
       "</svg>\n"
      ],
      "text/plain": [
       "<Figure size 640x480 with 2 Axes>"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "image/svg+xml": [
       "<?xml version=\"1.0\" encoding=\"utf-8\" standalone=\"no\"?>\n",
       "<!DOCTYPE svg PUBLIC \"-//W3C//DTD SVG 1.1//EN\"\n",
       "  \"http://www.w3.org/Graphics/SVG/1.1/DTD/svg11.dtd\">\n",
       "<svg xmlns:xlink=\"http://www.w3.org/1999/xlink\" width=\"445.848625pt\" height=\"322.539375pt\" viewBox=\"0 0 445.848625 322.539375\" xmlns=\"http://www.w3.org/2000/svg\" version=\"1.1\">\n",
       " <metadata>\n",
       "  <rdf:RDF xmlns:dc=\"http://purl.org/dc/elements/1.1/\" xmlns:cc=\"http://creativecommons.org/ns#\" xmlns:rdf=\"http://www.w3.org/1999/02/22-rdf-syntax-ns#\">\n",
       "   <cc:Work>\n",
       "    <dc:type rdf:resource=\"http://purl.org/dc/dcmitype/StillImage\"/>\n",
       "    <dc:date>2023-10-23T15:18:34.324095</dc:date>\n",
       "    <dc:format>image/svg+xml</dc:format>\n",
       "    <dc:creator>\n",
       "     <cc:Agent>\n",
       "      <dc:title>Matplotlib v3.8.0, https://matplotlib.org/</dc:title>\n",
       "     </cc:Agent>\n",
       "    </dc:creator>\n",
       "   </cc:Work>\n",
       "  </rdf:RDF>\n",
       " </metadata>\n",
       " <defs>\n",
       "  <style type=\"text/css\">*{stroke-linejoin: round; stroke-linecap: butt}</style>\n",
       " </defs>\n",
       " <g id=\"figure_1\">\n",
       "  <g id=\"patch_1\">\n",
       "   <path d=\"M 0 322.539375 \n",
       "L 445.848625 322.539375 \n",
       "L 445.848625 0 \n",
       "L 0 0 \n",
       "z\n",
       "\" style=\"fill: #ffffff\"/>\n",
       "  </g>\n",
       "  <g id=\"axes_1\">\n",
       "   <g id=\"patch_2\">\n",
       "    <path d=\"M 43.2065 286.212 \n",
       "L 400.3265 286.212 \n",
       "L 400.3265 20.1 \n",
       "L 43.2065 20.1 \n",
       "z\n",
       "\" style=\"fill: #ffffff\"/>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_1\">\n",
       "    <g id=\"xtick_1\">\n",
       "     <g id=\"line2d_1\">\n",
       "      <defs>\n",
       "       <path id=\"m7fc0dadb6b\" d=\"M 0 0 \n",
       "L 0 4.8 \n",
       "\" style=\"stroke: #262626\"/>\n",
       "      </defs>\n",
       "      <g>\n",
       "       <use xlink:href=\"#m7fc0dadb6b\" x=\"59.439227\" y=\"286.212\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_1\">\n",
       "      <!-- 0.0 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(53.323227 300.810875) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-30\" d=\"M 266 2259 \n",
       "Q 266 3072 433 3567 \n",
       "Q 600 4063 929 4331 \n",
       "Q 1259 4600 1759 4600 \n",
       "Q 2128 4600 2406 4451 \n",
       "Q 2684 4303 2865 4023 \n",
       "Q 3047 3744 3150 3342 \n",
       "Q 3253 2941 3253 2259 \n",
       "Q 3253 1453 3087 958 \n",
       "Q 2922 463 2592 192 \n",
       "Q 2263 -78 1759 -78 \n",
       "Q 1097 -78 719 397 \n",
       "Q 266 969 266 2259 \n",
       "z\n",
       "M 844 2259 \n",
       "Q 844 1131 1108 757 \n",
       "Q 1372 384 1759 384 \n",
       "Q 2147 384 2411 759 \n",
       "Q 2675 1134 2675 2259 \n",
       "Q 2675 3391 2411 3762 \n",
       "Q 2147 4134 1753 4134 \n",
       "Q 1366 4134 1134 3806 \n",
       "Q 844 3388 844 2259 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "        <path id=\"ArialMT-2e\" d=\"M 581 0 \n",
       "L 581 641 \n",
       "L 1222 641 \n",
       "L 1222 0 \n",
       "L 581 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_2\">\n",
       "     <g id=\"line2d_2\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m7fc0dadb6b\" x=\"124.370136\" y=\"286.212\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_2\">\n",
       "      <!-- 0.2 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(118.254136 300.810875) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-32\" d=\"M 3222 541 \n",
       "L 3222 0 \n",
       "L 194 0 \n",
       "Q 188 203 259 391 \n",
       "Q 375 700 629 1000 \n",
       "Q 884 1300 1366 1694 \n",
       "Q 2113 2306 2375 2664 \n",
       "Q 2638 3022 2638 3341 \n",
       "Q 2638 3675 2398 3904 \n",
       "Q 2159 4134 1775 4134 \n",
       "Q 1369 4134 1125 3890 \n",
       "Q 881 3647 878 3216 \n",
       "L 300 3275 \n",
       "Q 359 3922 746 4261 \n",
       "Q 1134 4600 1788 4600 \n",
       "Q 2447 4600 2831 4234 \n",
       "Q 3216 3869 3216 3328 \n",
       "Q 3216 3053 3103 2787 \n",
       "Q 2991 2522 2730 2228 \n",
       "Q 2469 1934 1863 1422 \n",
       "Q 1356 997 1212 845 \n",
       "Q 1069 694 975 541 \n",
       "L 3222 541 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-32\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_3\">\n",
       "     <g id=\"line2d_3\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m7fc0dadb6b\" x=\"189.301045\" y=\"286.212\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_3\">\n",
       "      <!-- 0.4 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(183.185045 300.810875) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-34\" d=\"M 2069 0 \n",
       "L 2069 1097 \n",
       "L 81 1097 \n",
       "L 81 1613 \n",
       "L 2172 4581 \n",
       "L 2631 4581 \n",
       "L 2631 1613 \n",
       "L 3250 1613 \n",
       "L 3250 1097 \n",
       "L 2631 1097 \n",
       "L 2631 0 \n",
       "L 2069 0 \n",
       "z\n",
       "M 2069 1613 \n",
       "L 2069 3678 \n",
       "L 634 1613 \n",
       "L 2069 1613 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-34\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_4\">\n",
       "     <g id=\"line2d_4\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m7fc0dadb6b\" x=\"254.231955\" y=\"286.212\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_4\">\n",
       "      <!-- 0.6 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(248.115955 300.810875) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-36\" d=\"M 3184 3459 \n",
       "L 2625 3416 \n",
       "Q 2550 3747 2413 3897 \n",
       "Q 2184 4138 1850 4138 \n",
       "Q 1581 4138 1378 3988 \n",
       "Q 1113 3794 959 3422 \n",
       "Q 806 3050 800 2363 \n",
       "Q 1003 2672 1297 2822 \n",
       "Q 1591 2972 1913 2972 \n",
       "Q 2475 2972 2870 2558 \n",
       "Q 3266 2144 3266 1488 \n",
       "Q 3266 1056 3080 686 \n",
       "Q 2894 316 2569 119 \n",
       "Q 2244 -78 1831 -78 \n",
       "Q 1128 -78 684 439 \n",
       "Q 241 956 241 2144 \n",
       "Q 241 3472 731 4075 \n",
       "Q 1159 4600 1884 4600 \n",
       "Q 2425 4600 2770 4297 \n",
       "Q 3116 3994 3184 3459 \n",
       "z\n",
       "M 888 1484 \n",
       "Q 888 1194 1011 928 \n",
       "Q 1134 663 1356 523 \n",
       "Q 1578 384 1822 384 \n",
       "Q 2178 384 2434 671 \n",
       "Q 2691 959 2691 1453 \n",
       "Q 2691 1928 2437 2201 \n",
       "Q 2184 2475 1800 2475 \n",
       "Q 1419 2475 1153 2201 \n",
       "Q 888 1928 888 1484 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-36\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_5\">\n",
       "     <g id=\"line2d_5\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m7fc0dadb6b\" x=\"319.162864\" y=\"286.212\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_5\">\n",
       "      <!-- 0.8 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(313.046864 300.810875) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-38\" d=\"M 1131 2484 \n",
       "Q 781 2613 612 2850 \n",
       "Q 444 3088 444 3419 \n",
       "Q 444 3919 803 4259 \n",
       "Q 1163 4600 1759 4600 \n",
       "Q 2359 4600 2725 4251 \n",
       "Q 3091 3903 3091 3403 \n",
       "Q 3091 3084 2923 2848 \n",
       "Q 2756 2613 2416 2484 \n",
       "Q 2838 2347 3058 2040 \n",
       "Q 3278 1734 3278 1309 \n",
       "Q 3278 722 2862 322 \n",
       "Q 2447 -78 1769 -78 \n",
       "Q 1091 -78 675 323 \n",
       "Q 259 725 259 1325 \n",
       "Q 259 1772 486 2073 \n",
       "Q 713 2375 1131 2484 \n",
       "z\n",
       "M 1019 3438 \n",
       "Q 1019 3113 1228 2906 \n",
       "Q 1438 2700 1772 2700 \n",
       "Q 2097 2700 2305 2904 \n",
       "Q 2513 3109 2513 3406 \n",
       "Q 2513 3716 2298 3927 \n",
       "Q 2084 4138 1766 4138 \n",
       "Q 1444 4138 1231 3931 \n",
       "Q 1019 3725 1019 3438 \n",
       "z\n",
       "M 838 1322 \n",
       "Q 838 1081 952 856 \n",
       "Q 1066 631 1291 507 \n",
       "Q 1516 384 1775 384 \n",
       "Q 2178 384 2440 643 \n",
       "Q 2703 903 2703 1303 \n",
       "Q 2703 1709 2433 1975 \n",
       "Q 2163 2241 1756 2241 \n",
       "Q 1359 2241 1098 1978 \n",
       "Q 838 1716 838 1322 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-38\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_6\">\n",
       "     <g id=\"line2d_6\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m7fc0dadb6b\" x=\"384.093773\" y=\"286.212\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_6\">\n",
       "      <!-- 1.0 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(377.977773 300.810875) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-31\" d=\"M 2384 0 \n",
       "L 1822 0 \n",
       "L 1822 3584 \n",
       "Q 1619 3391 1289 3197 \n",
       "Q 959 3003 697 2906 \n",
       "L 697 3450 \n",
       "Q 1169 3672 1522 3987 \n",
       "Q 1875 4303 2022 4600 \n",
       "L 2384 4600 \n",
       "L 2384 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-31\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"text_7\">\n",
       "     <!-- $x$ -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(218.8865 313.431375) scale(0.096 -0.096)\">\n",
       "      <defs>\n",
       "       <path id=\"DejaVuSans-Oblique-78\" d=\"M 3841 3500 \n",
       "L 2234 1784 \n",
       "L 3219 0 \n",
       "L 2559 0 \n",
       "L 1819 1388 \n",
       "L 531 0 \n",
       "L -166 0 \n",
       "L 1556 1844 \n",
       "L 641 3500 \n",
       "L 1300 3500 \n",
       "L 1972 2234 \n",
       "L 3144 3500 \n",
       "L 3841 3500 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-78\" transform=\"translate(0 0.3125)\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_2\">\n",
       "    <g id=\"ytick_1\">\n",
       "     <g id=\"line2d_7\">\n",
       "      <defs>\n",
       "       <path id=\"m9702af1612\" d=\"M 0 0 \n",
       "L -4.8 0 \n",
       "\" style=\"stroke: #262626\"/>\n",
       "      </defs>\n",
       "      <g>\n",
       "       <use xlink:href=\"#m9702af1612\" x=\"43.2065\" y=\"285.988927\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_8\">\n",
       "      <!-- −12 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(19.9795 289.138364) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-2212\" d=\"M 3381 1997 \n",
       "L 356 1997 \n",
       "L 356 2522 \n",
       "L 3381 2522 \n",
       "L 3381 1997 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-31\" x=\"58.398438\"/>\n",
       "       <use xlink:href=\"#ArialMT-32\" x=\"114.013672\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_2\">\n",
       "     <g id=\"line2d_8\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m9702af1612\" x=\"43.2065\" y=\"244.587747\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_9\">\n",
       "      <!-- −10 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(19.9795 247.737184) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-31\" x=\"58.398438\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"114.013672\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_3\">\n",
       "     <g id=\"line2d_9\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m9702af1612\" x=\"43.2065\" y=\"203.186567\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_10\">\n",
       "      <!-- −8 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(24.873125 206.336005) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-38\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_4\">\n",
       "     <g id=\"line2d_10\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m9702af1612\" x=\"43.2065\" y=\"161.785388\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_11\">\n",
       "      <!-- −6 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(24.873125 164.934825) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-36\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_5\">\n",
       "     <g id=\"line2d_11\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m9702af1612\" x=\"43.2065\" y=\"120.384208\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_12\">\n",
       "      <!-- −4 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(24.873125 123.533645) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-34\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_6\">\n",
       "     <g id=\"line2d_12\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m9702af1612\" x=\"43.2065\" y=\"78.983028\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_13\">\n",
       "      <!-- −2 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(24.873125 82.132466) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-32\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_7\">\n",
       "     <g id=\"line2d_13\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m9702af1612\" x=\"43.2065\" y=\"37.581849\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_14\">\n",
       "      <!-- 0 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(30.012875 40.731286) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"text_15\">\n",
       "     <!-- $y$ -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(13.9635 156.036) rotate(-90) scale(0.096 -0.096)\">\n",
       "      <defs>\n",
       "       <path id=\"DejaVuSans-Oblique-79\" d=\"M 1588 -325 \n",
       "Q 1188 -997 936 -1164 \n",
       "Q 684 -1331 294 -1331 \n",
       "L -159 -1331 \n",
       "L -63 -850 \n",
       "L 269 -850 \n",
       "Q 509 -850 678 -719 \n",
       "Q 847 -588 1056 -206 \n",
       "L 1234 128 \n",
       "L 459 3500 \n",
       "L 1069 3500 \n",
       "L 1650 819 \n",
       "L 3256 3500 \n",
       "L 3859 3500 \n",
       "L 1588 -325 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-79\" transform=\"translate(0 0.3125)\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"PolyCollection_1\">\n",
       "    <defs>\n",
       "     <path id=\"mf337a4a624\" d=\"M 59.439227 -207.186526 \n",
       "L 59.439227 -198.926346 \n",
       "L 62.718566 -200.843218 \n",
       "L 65.997905 -202.30966 \n",
       "L 69.277244 -204.144673 \n",
       "L 72.556583 -206.589678 \n",
       "L 75.835921 -209.682494 \n",
       "L 79.115261 -213.390745 \n",
       "L 82.394598 -217.647917 \n",
       "L 85.673938 -222.368514 \n",
       "L 88.953278 -227.455027 \n",
       "L 92.232615 -232.80008 \n",
       "L 95.511955 -238.292806 \n",
       "L 98.791295 -243.820095 \n",
       "L 102.070632 -249.270596 \n",
       "L 105.349969 -254.537552 \n",
       "L 108.629311 -259.519076 \n",
       "L 111.908649 -264.120769 \n",
       "L 115.187986 -268.258325 \n",
       "L 118.467328 -271.858751 \n",
       "L 121.746666 -274.87556 \n",
       "L 125.026003 -277.297236 \n",
       "L 128.305345 -279.158122 \n",
       "L 131.584682 -280.524641 \n",
       "L 134.86402 -281.467506 \n",
       "L 138.143362 -282.043168 \n",
       "L 141.422694 -282.290427 \n",
       "L 144.702037 -282.225063 \n",
       "L 147.981379 -281.838601 \n",
       "L 151.260711 -281.08933 \n",
       "L 154.540053 -279.901039 \n",
       "L 157.819395 -278.195461 \n",
       "L 161.098728 -275.946006 \n",
       "L 164.37807 -273.183998 \n",
       "L 167.657412 -269.964491 \n",
       "L 170.936745 -266.340517 \n",
       "L 174.216087 -262.360685 \n",
       "L 177.495429 -258.069567 \n",
       "L 180.774762 -253.511977 \n",
       "L 184.054104 -248.733251 \n",
       "L 187.333446 -243.779565 \n",
       "L 190.612778 -238.698427 \n",
       "L 193.892121 -233.53623 \n",
       "L 197.171463 -228.338642 \n",
       "L 200.450795 -223.147617 \n",
       "L 203.730137 -218.001258 \n",
       "L 207.00948 -212.93156 \n",
       "L 210.288812 -207.963631 \n",
       "L 213.568154 -203.114709 \n",
       "L 216.847496 -198.393243 \n",
       "L 220.126829 -193.798608 \n",
       "L 223.406181 -189.320409 \n",
       "L 226.685504 -184.937907 \n",
       "L 229.964846 -180.61699 \n",
       "L 233.244188 -176.301195 \n",
       "L 236.523511 -171.878371 \n",
       "L 239.802872 -167.034478 \n",
       "L 243.082195 -160.687991 \n",
       "L 246.361537 -151.506992 \n",
       "L 249.640879 -140.717377 \n",
       "L 252.920222 -129.474574 \n",
       "L 256.199564 -118.213499 \n",
       "L 259.478887 -107.181467 \n",
       "L 262.758248 -96.58069 \n",
       "L 266.037571 -86.601064 \n",
       "L 269.316913 -77.426915 \n",
       "L 272.596255 -69.23817 \n",
       "L 275.875578 -62.207192 \n",
       "L 279.15494 -56.49679 \n",
       "L 282.434262 -52.254849 \n",
       "L 285.713605 -49.61036 \n",
       "L 288.992947 -48.670738 \n",
       "L 292.272289 -49.515541 \n",
       "L 295.551631 -52.192564 \n",
       "L 298.830954 -56.718251 \n",
       "L 302.110315 -63.069111 \n",
       "L 305.389638 -71.184635 \n",
       "L 308.66898 -80.963311 \n",
       "L 311.948322 -92.265784 \n",
       "L 315.227645 -104.912602 \n",
       "L 318.507007 -118.689864 \n",
       "L 321.78633 -133.351354 \n",
       "L 325.065672 -148.622001 \n",
       "L 328.345014 -164.207132 \n",
       "L 331.624356 -179.792185 \n",
       "L 334.903698 -195.054136 \n",
       "L 338.183021 -209.659643 \n",
       "L 341.462363 -223.271283 \n",
       "L 344.741705 -235.543252 \n",
       "L 348.021048 -246.14472 \n",
       "L 351.30039 -254.849519 \n",
       "L 354.579713 -261.608023 \n",
       "L 357.859055 -266.452143 \n",
       "L 361.138397 -269.40555 \n",
       "L 364.417739 -270.488398 \n",
       "L 367.697081 -269.715019 \n",
       "L 370.976423 -267.135454 \n",
       "L 374.255766 -262.800353 \n",
       "L 377.535088 -256.75403 \n",
       "L 380.814431 -249.003556 \n",
       "L 384.093773 -239.541434 \n",
       "L 384.093773 -247.669338 \n",
       "L 384.093773 -247.669338 \n",
       "L 380.814431 -256.24079 \n",
       "L 377.535088 -263.915313 \n",
       "L 374.255766 -270.25883 \n",
       "L 370.976423 -274.917381 \n",
       "L 367.697081 -277.661737 \n",
       "L 364.417739 -278.365346 \n",
       "L 361.138397 -276.985072 \n",
       "L 357.859055 -273.560514 \n",
       "L 354.579713 -268.222378 \n",
       "L 351.30039 -261.213867 \n",
       "L 348.021048 -252.877067 \n",
       "L 344.741705 -243.537602 \n",
       "L 341.462363 -233.420362 \n",
       "L 338.183021 -222.70464 \n",
       "L 334.903698 -211.584762 \n",
       "L 331.624356 -200.284915 \n",
       "L 328.345014 -189.042526 \n",
       "L 325.065672 -178.085443 \n",
       "L 321.78633 -167.63639 \n",
       "L 318.507007 -157.885865 \n",
       "L 315.227645 -149.000695 \n",
       "L 311.948322 -141.1137 \n",
       "L 308.66898 -134.32052 \n",
       "L 305.389638 -128.684642 \n",
       "L 302.110315 -124.231535 \n",
       "L 298.830954 -120.957012 \n",
       "L 295.551631 -118.82393 \n",
       "L 292.272289 -117.773577 \n",
       "L 288.992947 -117.721005 \n",
       "L 285.713605 -118.569421 \n",
       "L 282.434262 -120.210058 \n",
       "L 279.15494 -122.526974 \n",
       "L 275.875578 -125.404977 \n",
       "L 272.596255 -128.732427 \n",
       "L 269.316913 -132.40421 \n",
       "L 266.037571 -136.327986 \n",
       "L 262.758248 -140.424945 \n",
       "L 259.478887 -144.634312 \n",
       "L 256.199564 -148.917681 \n",
       "L 252.920222 -153.270057 \n",
       "L 249.640879 -157.753626 \n",
       "L 246.361537 -162.642273 \n",
       "L 243.082195 -168.953926 \n",
       "L 239.802872 -177.80063 \n",
       "L 236.523511 -187.759222 \n",
       "L 233.244188 -197.676455 \n",
       "L 229.964846 -207.186354 \n",
       "L 226.685504 -216.140442 \n",
       "L 223.406181 -224.460455 \n",
       "L 220.126829 -232.102515 \n",
       "L 216.847496 -239.045421 \n",
       "L 213.568154 -245.286525 \n",
       "L 210.288812 -250.838443 \n",
       "L 207.00948 -255.72714 \n",
       "L 203.730137 -259.990155 \n",
       "L 200.450795 -263.674115 \n",
       "L 197.171463 -266.83282 \n",
       "L 193.892121 -269.525373 \n",
       "L 190.612778 -271.812952 \n",
       "L 187.333446 -273.758027 \n",
       "L 184.054104 -275.420578 \n",
       "L 180.774762 -276.857748 \n",
       "L 177.495429 -278.121042 \n",
       "L 174.216087 -279.256185 \n",
       "L 170.936745 -280.303222 \n",
       "L 167.657412 -281.296368 \n",
       "L 164.37807 -282.268216 \n",
       "L 161.098728 -283.250708 \n",
       "L 157.819395 -284.272065 \n",
       "L 154.540053 -285.332348 \n",
       "L 151.260711 -286.369786 \n",
       "L 147.981379 -287.267815 \n",
       "L 144.702037 -287.910252 \n",
       "L 141.422694 -288.214891 \n",
       "L 138.143362 -288.134202 \n",
       "L 134.86402 -287.647913 \n",
       "L 131.584682 -286.763439 \n",
       "L 128.305345 -285.512885 \n",
       "L 125.026003 -283.950831 \n",
       "L 121.746666 -282.138127 \n",
       "L 118.467328 -280.115215 \n",
       "L 115.187986 -277.890146 \n",
       "L 111.908649 -275.449551 \n",
       "L 108.629311 -272.768508 \n",
       "L 105.349969 -269.825586 \n",
       "L 102.070632 -266.603596 \n",
       "L 98.791295 -263.091747 \n",
       "L 95.511955 -259.286682 \n",
       "L 92.232615 -255.191392 \n",
       "L 88.953278 -250.816086 \n",
       "L 85.673938 -246.17908 \n",
       "L 82.394598 -241.306523 \n",
       "L 79.115261 -236.234861 \n",
       "L 75.835921 -231.011025 \n",
       "L 72.556583 -225.695579 \n",
       "L 69.277244 -220.37579 \n",
       "L 65.997905 -215.198718 \n",
       "L 62.718566 -210.502058 \n",
       "L 59.439227 -207.186526 \n",
       "z\n",
       "\" style=\"stroke: #1f77b4; stroke-opacity: 0.5; stroke-width: 0.8\"/>\n",
       "    </defs>\n",
       "    <g clip-path=\"url(#pcb736d303a)\">\n",
       "     <use xlink:href=\"#mf337a4a624\" x=\"0\" y=\"322.539375\" style=\"fill: #1f77b4; fill-opacity: 0.5; stroke: #1f77b4; stroke-opacity: 0.5; stroke-width: 0.8\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"PolyCollection_2\">\n",
       "    <defs>\n",
       "     <path id=\"m4d45b50ea5\" d=\"M 59.439227 -198.926346 \n",
       "L 59.439227 -197.208509 \n",
       "L 62.718566 -199.311525 \n",
       "L 65.997905 -201.094391 \n",
       "L 69.277244 -203.149641 \n",
       "L 72.556583 -205.731125 \n",
       "L 75.835921 -208.907043 \n",
       "L 79.115261 -212.663563 \n",
       "L 82.394598 -216.944341 \n",
       "L 85.673938 -221.669177 \n",
       "L 88.953278 -226.743001 \n",
       "L 92.232615 -232.059103 \n",
       "L 95.511955 -237.505851 \n",
       "L 98.791295 -242.968323 \n",
       "L 102.070632 -248.332472 \n",
       "L 105.349969 -253.488376 \n",
       "L 108.629311 -258.331785 \n",
       "L 111.908649 -262.769043 \n",
       "L 115.187986 -266.723363 \n",
       "L 118.467328 -270.140371 \n",
       "L 121.746666 -272.999866 \n",
       "L 125.026003 -275.312898 \n",
       "L 128.305345 -277.11666 \n",
       "L 131.584682 -278.460293 \n",
       "L 134.86402 -279.391479 \n",
       "L 138.143362 -279.949059 \n",
       "L 141.422694 -280.161942 \n",
       "L 144.702037 -280.045614 \n",
       "L 147.981379 -279.602484 \n",
       "L 151.260711 -278.819224 \n",
       "L 154.540053 -277.665395 \n",
       "L 157.819395 -276.098409 \n",
       "L 161.098728 -274.077465 \n",
       "L 164.37807 -271.580269 \n",
       "L 167.657412 -268.613063 \n",
       "L 170.936745 -265.205228 \n",
       "L 174.216087 -261.400724 \n",
       "L 177.495429 -257.24837 \n",
       "L 180.774762 -252.799512 \n",
       "L 184.054104 -248.105732 \n",
       "L 187.333446 -243.218311 \n",
       "L 190.612778 -238.188659 \n",
       "L 193.892121 -233.066099 \n",
       "L 197.171463 -227.898399 \n",
       "L 200.450795 -222.728991 \n",
       "L 203.730137 -217.596935 \n",
       "L 207.00948 -212.534719 \n",
       "L 210.288812 -207.56751 \n",
       "L 213.568154 -202.712108 \n",
       "L 216.847496 -197.975896 \n",
       "L 220.126829 -193.356228 \n",
       "L 223.406181 -188.839217 \n",
       "L 226.685504 -184.397925 \n",
       "L 229.964846 -179.986807 \n",
       "L 233.244188 -175.527323 \n",
       "L 236.523511 -170.863859 \n",
       "L 239.802872 -165.626525 \n",
       "L 243.082195 -158.971003 \n",
       "L 246.361537 -150.136391 \n",
       "L 249.640879 -139.764538 \n",
       "L 252.920222 -128.774822 \n",
       "L 256.199564 -117.665037 \n",
       "L 259.478887 -106.729265 \n",
       "L 262.758248 -96.193162 \n",
       "L 266.037571 -86.258744 \n",
       "L 269.316913 -77.116893 \n",
       "L 272.596255 -68.951463 \n",
       "L 275.875578 -61.937126 \n",
       "L 279.15494 -56.238214 \n",
       "L 282.434262 -52.003538 \n",
       "L 285.713605 -49.362681 \n",
       "L 288.992947 -48.423375 \n",
       "L 292.272289 -49.265335 \n",
       "L 295.551631 -51.936298 \n",
       "L 298.830954 -56.452529 \n",
       "L 302.110315 -62.790142 \n",
       "L 305.389638 -70.888056 \n",
       "L 308.66898 -80.64399 \n",
       "L 311.948322 -91.917364 \n",
       "L 315.227645 -104.527206 \n",
       "L 318.507007 -118.257325 \n",
       "L 321.78633 -132.858505 \n",
       "L 325.065672 -148.051301 \n",
       "L 328.345014 -163.535147 \n",
       "L 331.624356 -178.987368 \n",
       "L 334.903698 -194.075208 \n",
       "L 338.183021 -208.456628 \n",
       "L 341.462363 -221.796663 \n",
       "L 344.741705 -233.785607 \n",
       "L 348.021048 -244.175005 \n",
       "L 351.30039 -252.809928 \n",
       "L 354.579713 -259.616333 \n",
       "L 357.859055 -264.549883 \n",
       "L 361.138397 -267.582569 \n",
       "L 364.417739 -268.712665 \n",
       "L 367.697081 -267.950071 \n",
       "L 370.976423 -265.344853 \n",
       "L 374.255766 -260.957537 \n",
       "L 377.535088 -254.860957 \n",
       "L 380.814431 -247.123539 \n",
       "L 384.093773 -237.803979 \n",
       "L 384.093773 -239.541434 \n",
       "L 384.093773 -239.541434 \n",
       "L 380.814431 -249.003556 \n",
       "L 377.535088 -256.75403 \n",
       "L 374.255766 -262.800353 \n",
       "L 370.976423 -267.135454 \n",
       "L 367.697081 -269.715019 \n",
       "L 364.417739 -270.488398 \n",
       "L 361.138397 -269.40555 \n",
       "L 357.859055 -266.452143 \n",
       "L 354.579713 -261.608023 \n",
       "L 351.30039 -254.849519 \n",
       "L 348.021048 -246.14472 \n",
       "L 344.741705 -235.543252 \n",
       "L 341.462363 -223.271283 \n",
       "L 338.183021 -209.659643 \n",
       "L 334.903698 -195.054136 \n",
       "L 331.624356 -179.792185 \n",
       "L 328.345014 -164.207132 \n",
       "L 325.065672 -148.622001 \n",
       "L 321.78633 -133.351354 \n",
       "L 318.507007 -118.689864 \n",
       "L 315.227645 -104.912602 \n",
       "L 311.948322 -92.265784 \n",
       "L 308.66898 -80.963311 \n",
       "L 305.389638 -71.184635 \n",
       "L 302.110315 -63.069111 \n",
       "L 298.830954 -56.718251 \n",
       "L 295.551631 -52.192564 \n",
       "L 292.272289 -49.515541 \n",
       "L 288.992947 -48.670738 \n",
       "L 285.713605 -49.61036 \n",
       "L 282.434262 -52.254849 \n",
       "L 279.15494 -56.49679 \n",
       "L 275.875578 -62.207192 \n",
       "L 272.596255 -69.23817 \n",
       "L 269.316913 -77.426915 \n",
       "L 266.037571 -86.601064 \n",
       "L 262.758248 -96.58069 \n",
       "L 259.478887 -107.181467 \n",
       "L 256.199564 -118.213499 \n",
       "L 252.920222 -129.474574 \n",
       "L 249.640879 -140.717377 \n",
       "L 246.361537 -151.506992 \n",
       "L 243.082195 -160.687991 \n",
       "L 239.802872 -167.034478 \n",
       "L 236.523511 -171.878371 \n",
       "L 233.244188 -176.301195 \n",
       "L 229.964846 -180.61699 \n",
       "L 226.685504 -184.937907 \n",
       "L 223.406181 -189.320409 \n",
       "L 220.126829 -193.798608 \n",
       "L 216.847496 -198.393243 \n",
       "L 213.568154 -203.114709 \n",
       "L 210.288812 -207.963631 \n",
       "L 207.00948 -212.93156 \n",
       "L 203.730137 -218.001258 \n",
       "L 200.450795 -223.147617 \n",
       "L 197.171463 -228.338642 \n",
       "L 193.892121 -233.53623 \n",
       "L 190.612778 -238.698427 \n",
       "L 187.333446 -243.779565 \n",
       "L 184.054104 -248.733251 \n",
       "L 180.774762 -253.511977 \n",
       "L 177.495429 -258.069567 \n",
       "L 174.216087 -262.360685 \n",
       "L 170.936745 -266.340517 \n",
       "L 167.657412 -269.964491 \n",
       "L 164.37807 -273.183998 \n",
       "L 161.098728 -275.946006 \n",
       "L 157.819395 -278.195461 \n",
       "L 154.540053 -279.901039 \n",
       "L 151.260711 -281.08933 \n",
       "L 147.981379 -281.838601 \n",
       "L 144.702037 -282.225063 \n",
       "L 141.422694 -282.290427 \n",
       "L 138.143362 -282.043168 \n",
       "L 134.86402 -281.467506 \n",
       "L 131.584682 -280.524641 \n",
       "L 128.305345 -279.158122 \n",
       "L 125.026003 -277.297236 \n",
       "L 121.746666 -274.87556 \n",
       "L 118.467328 -271.858751 \n",
       "L 115.187986 -268.258325 \n",
       "L 111.908649 -264.120769 \n",
       "L 108.629311 -259.519076 \n",
       "L 105.349969 -254.537552 \n",
       "L 102.070632 -249.270596 \n",
       "L 98.791295 -243.820095 \n",
       "L 95.511955 -238.292806 \n",
       "L 92.232615 -232.80008 \n",
       "L 88.953278 -227.455027 \n",
       "L 85.673938 -222.368514 \n",
       "L 82.394598 -217.647917 \n",
       "L 79.115261 -213.390745 \n",
       "L 75.835921 -209.682494 \n",
       "L 72.556583 -206.589678 \n",
       "L 69.277244 -204.144673 \n",
       "L 65.997905 -202.30966 \n",
       "L 62.718566 -200.843218 \n",
       "L 59.439227 -198.926346 \n",
       "z\n",
       "\" style=\"stroke: #ff7f0e; stroke-opacity: 0.5; stroke-width: 0.8\"/>\n",
       "    </defs>\n",
       "    <g clip-path=\"url(#pcb736d303a)\">\n",
       "     <use xlink:href=\"#m4d45b50ea5\" x=\"0\" y=\"322.539375\" style=\"fill: #ff7f0e; fill-opacity: 0.5; stroke: #ff7f0e; stroke-opacity: 0.5; stroke-width: 0.8\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"PolyCollection_3\">\n",
       "    <defs>\n",
       "     <path id=\"mb158a296d6\" d=\"M 59.439227 -208.904363 \n",
       "L 59.439227 -207.186526 \n",
       "L 62.718566 -210.502058 \n",
       "L 65.997905 -215.198718 \n",
       "L 69.277244 -220.37579 \n",
       "L 72.556583 -225.695579 \n",
       "L 75.835921 -231.011025 \n",
       "L 79.115261 -236.234861 \n",
       "L 82.394598 -241.306523 \n",
       "L 85.673938 -246.17908 \n",
       "L 88.953278 -250.816086 \n",
       "L 92.232615 -255.191392 \n",
       "L 95.511955 -259.286682 \n",
       "L 98.791295 -263.091747 \n",
       "L 102.070632 -266.603596 \n",
       "L 105.349969 -269.825586 \n",
       "L 108.629311 -272.768508 \n",
       "L 111.908649 -275.449551 \n",
       "L 115.187986 -277.890146 \n",
       "L 118.467328 -280.115215 \n",
       "L 121.746666 -282.138127 \n",
       "L 125.026003 -283.950831 \n",
       "L 128.305345 -285.512885 \n",
       "L 131.584682 -286.763439 \n",
       "L 134.86402 -287.647913 \n",
       "L 138.143362 -288.134202 \n",
       "L 141.422694 -288.214891 \n",
       "L 144.702037 -287.910252 \n",
       "L 147.981379 -287.267815 \n",
       "L 151.260711 -286.369786 \n",
       "L 154.540053 -285.332348 \n",
       "L 157.819395 -284.272065 \n",
       "L 161.098728 -283.250708 \n",
       "L 164.37807 -282.268216 \n",
       "L 167.657412 -281.296368 \n",
       "L 170.936745 -280.303222 \n",
       "L 174.216087 -279.256185 \n",
       "L 177.495429 -278.121042 \n",
       "L 180.774762 -276.857748 \n",
       "L 184.054104 -275.420578 \n",
       "L 187.333446 -273.758027 \n",
       "L 190.612778 -271.812952 \n",
       "L 193.892121 -269.525373 \n",
       "L 197.171463 -266.83282 \n",
       "L 200.450795 -263.674115 \n",
       "L 203.730137 -259.990155 \n",
       "L 207.00948 -255.72714 \n",
       "L 210.288812 -250.838443 \n",
       "L 213.568154 -245.286525 \n",
       "L 216.847496 -239.045421 \n",
       "L 220.126829 -232.102515 \n",
       "L 223.406181 -224.460455 \n",
       "L 226.685504 -216.140442 \n",
       "L 229.964846 -207.186354 \n",
       "L 233.244188 -197.676455 \n",
       "L 236.523511 -187.759222 \n",
       "L 239.802872 -177.80063 \n",
       "L 243.082195 -168.953926 \n",
       "L 246.361537 -162.642273 \n",
       "L 249.640879 -157.753626 \n",
       "L 252.920222 -153.270057 \n",
       "L 256.199564 -148.917681 \n",
       "L 259.478887 -144.634312 \n",
       "L 262.758248 -140.424945 \n",
       "L 266.037571 -136.327986 \n",
       "L 269.316913 -132.40421 \n",
       "L 272.596255 -128.732427 \n",
       "L 275.875578 -125.404977 \n",
       "L 279.15494 -122.526974 \n",
       "L 282.434262 -120.210058 \n",
       "L 285.713605 -118.569421 \n",
       "L 288.992947 -117.721005 \n",
       "L 292.272289 -117.773577 \n",
       "L 295.551631 -118.82393 \n",
       "L 298.830954 -120.957012 \n",
       "L 302.110315 -124.231535 \n",
       "L 305.389638 -128.684642 \n",
       "L 308.66898 -134.32052 \n",
       "L 311.948322 -141.1137 \n",
       "L 315.227645 -149.000695 \n",
       "L 318.507007 -157.885865 \n",
       "L 321.78633 -167.63639 \n",
       "L 325.065672 -178.085443 \n",
       "L 328.345014 -189.042526 \n",
       "L 331.624356 -200.284915 \n",
       "L 334.903698 -211.584762 \n",
       "L 338.183021 -222.70464 \n",
       "L 341.462363 -233.420362 \n",
       "L 344.741705 -243.537602 \n",
       "L 348.021048 -252.877067 \n",
       "L 351.30039 -261.213867 \n",
       "L 354.579713 -268.222378 \n",
       "L 357.859055 -273.560514 \n",
       "L 361.138397 -276.985072 \n",
       "L 364.417739 -278.365346 \n",
       "L 367.697081 -277.661737 \n",
       "L 370.976423 -274.917381 \n",
       "L 374.255766 -270.25883 \n",
       "L 377.535088 -263.915313 \n",
       "L 380.814431 -256.24079 \n",
       "L 384.093773 -247.669338 \n",
       "L 384.093773 -249.406791 \n",
       "L 384.093773 -249.406791 \n",
       "L 380.814431 -258.120807 \n",
       "L 377.535088 -265.808387 \n",
       "L 374.255766 -272.101647 \n",
       "L 370.976423 -276.707982 \n",
       "L 367.697081 -279.426684 \n",
       "L 364.417739 -280.141079 \n",
       "L 361.138397 -278.808052 \n",
       "L 357.859055 -275.462775 \n",
       "L 354.579713 -270.214069 \n",
       "L 351.30039 -263.253458 \n",
       "L 348.021048 -254.846782 \n",
       "L 344.741705 -245.29525 \n",
       "L 341.462363 -234.894982 \n",
       "L 338.183021 -223.907655 \n",
       "L 334.903698 -212.56369 \n",
       "L 331.624356 -201.089732 \n",
       "L 328.345014 -189.714511 \n",
       "L 325.065672 -178.656143 \n",
       "L 321.78633 -168.12924 \n",
       "L 318.507007 -158.318404 \n",
       "L 315.227645 -149.386101 \n",
       "L 311.948322 -141.46211 \n",
       "L 308.66898 -134.63985 \n",
       "L 305.389638 -128.981211 \n",
       "L 302.110315 -124.510513 \n",
       "L 298.830954 -121.222744 \n",
       "L 295.551631 -119.080196 \n",
       "L 292.272289 -118.023782 \n",
       "L 288.992947 -117.968367 \n",
       "L 285.713605 -118.817099 \n",
       "L 282.434262 -120.461359 \n",
       "L 279.15494 -122.78555 \n",
       "L 275.875578 -125.675042 \n",
       "L 272.596255 -129.019144 \n",
       "L 269.316913 -132.714233 \n",
       "L 266.037571 -136.670325 \n",
       "L 262.758248 -140.812463 \n",
       "L 259.478887 -145.086514 \n",
       "L 256.199564 -149.466143 \n",
       "L 252.920222 -153.969809 \n",
       "L 249.640879 -158.706465 \n",
       "L 246.361537 -164.012875 \n",
       "L 243.082195 -170.670914 \n",
       "L 239.802872 -179.208583 \n",
       "L 236.523511 -188.773734 \n",
       "L 233.244188 -198.450326 \n",
       "L 229.964846 -207.816531 \n",
       "L 226.685504 -216.68043 \n",
       "L 223.406181 -224.941647 \n",
       "L 220.126829 -232.544895 \n",
       "L 216.847496 -239.462774 \n",
       "L 213.568154 -245.689125 \n",
       "L 210.288812 -251.234566 \n",
       "L 207.00948 -256.123981 \n",
       "L 203.730137 -260.394479 \n",
       "L 200.450795 -264.092741 \n",
       "L 197.171463 -267.273063 \n",
       "L 193.892121 -269.995504 \n",
       "L 190.612778 -272.322719 \n",
       "L 187.333446 -274.319283 \n",
       "L 184.054104 -276.048096 \n",
       "L 180.774762 -277.570211 \n",
       "L 177.495429 -278.942239 \n",
       "L 174.216087 -280.216147 \n",
       "L 170.936745 -281.438511 \n",
       "L 167.657412 -282.647797 \n",
       "L 164.37807 -283.871945 \n",
       "L 161.098728 -285.119249 \n",
       "L 157.819395 -286.369117 \n",
       "L 154.540053 -287.567992 \n",
       "L 151.260711 -288.639892 \n",
       "L 147.981379 -289.503932 \n",
       "L 144.702037 -290.089701 \n",
       "L 141.422694 -290.343375 \n",
       "L 138.143362 -290.228311 \n",
       "L 134.86402 -289.72394 \n",
       "L 131.584682 -288.827787 \n",
       "L 128.305345 -287.554347 \n",
       "L 125.026003 -285.935169 \n",
       "L 121.746666 -284.013821 \n",
       "L 118.467328 -281.833596 \n",
       "L 115.187986 -279.425107 \n",
       "L 111.908649 -276.801278 \n",
       "L 108.629311 -273.955798 \n",
       "L 105.349969 -270.874761 \n",
       "L 102.070632 -267.54172 \n",
       "L 98.791295 -263.943519 \n",
       "L 95.511955 -260.073638 \n",
       "L 92.232615 -255.932371 \n",
       "L 88.953278 -251.52811 \n",
       "L 85.673938 -246.878415 \n",
       "L 82.394598 -242.010099 \n",
       "L 79.115261 -236.962043 \n",
       "L 75.835921 -231.786476 \n",
       "L 72.556583 -226.554132 \n",
       "L 69.277244 -221.370822 \n",
       "L 65.997905 -216.413992 \n",
       "L 62.718566 -212.033761 \n",
       "L 59.439227 -208.904363 \n",
       "z\n",
       "\" style=\"stroke: #ff7f0e; stroke-opacity: 0.5; stroke-width: 0.8\"/>\n",
       "    </defs>\n",
       "    <g clip-path=\"url(#pcb736d303a)\">\n",
       "     <use xlink:href=\"#mb158a296d6\" x=\"0\" y=\"322.539375\" style=\"fill: #ff7f0e; fill-opacity: 0.5; stroke: #ff7f0e; stroke-opacity: 0.5; stroke-width: 0.8\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"line2d_14\">\n",
       "    <defs>\n",
       "     <path id=\"m48e2645bf6\" d=\"M -5 5 \n",
       "L 5 -5 \n",
       "M -5 -5 \n",
       "L 5 5 \n",
       "\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "    </defs>\n",
       "    <g clip-path=\"url(#pcb736d303a)\">\n",
       "     <use xlink:href=\"#m48e2645bf6\" x=\"361.243318\" y=\"42.517723\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     <use xlink:href=\"#m48e2645bf6\" x=\"162.151989\" y=\"43.370784\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     <use xlink:href=\"#m48e2645bf6\" x=\"119.149308\" y=\"45.656283\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     <use xlink:href=\"#m48e2645bf6\" x=\"243.082195\" y=\"157.855877\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     <use xlink:href=\"#m48e2645bf6\" x=\"147.981379\" y=\"38.021011\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     <use xlink:href=\"#m48e2645bf6\" x=\"384.093773\" y=\"82.019857\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     <use xlink:href=\"#m48e2645bf6\" x=\"344.741705\" y=\"87.250128\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     <use xlink:href=\"#m48e2645bf6\" x=\"59.439227\" y=\"119.780164\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     <use xlink:href=\"#m48e2645bf6\" x=\"141.422694\" y=\"37.602715\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"line2d_15\">\n",
       "    <path d=\"M 59.439227 119.482939 \n",
       "L 62.718566 116.866735 \n",
       "L 65.997905 113.785186 \n",
       "L 69.277244 110.279143 \n",
       "L 72.556583 106.396746 \n",
       "L 75.835921 102.192615 \n",
       "L 79.115261 97.726572 \n",
       "L 82.394598 93.062155 \n",
       "L 85.673938 88.265578 \n",
       "L 88.953278 83.403819 \n",
       "L 92.232615 78.543639 \n",
       "L 95.511955 73.749631 \n",
       "L 98.791295 69.083454 \n",
       "L 102.070632 64.602279 \n",
       "L 105.349969 60.357806 \n",
       "L 108.629311 56.395584 \n",
       "L 111.908649 52.754215 \n",
       "L 115.187986 49.46514 \n",
       "L 118.467328 46.552392 \n",
       "L 121.746666 44.032532 \n",
       "L 125.026003 41.915342 \n",
       "L 128.305345 40.203871 \n",
       "L 131.584682 38.895335 \n",
       "L 134.86402 37.981666 \n",
       "L 138.143362 37.45069 \n",
       "L 141.422694 37.286716 \n",
       "L 144.702037 37.471717 \n",
       "L 147.981379 37.986167 \n",
       "L 151.260711 38.809817 \n",
       "L 154.540053 39.922682 \n",
       "L 157.819395 41.305612 \n",
       "L 161.098728 42.941018 \n",
       "L 164.37807 44.813268 \n",
       "L 167.657412 46.908945 \n",
       "L 170.936745 49.217506 \n",
       "L 174.216087 51.73094 \n",
       "L 177.495429 54.44407 \n",
       "L 180.774762 57.354513 \n",
       "L 184.054104 60.462461 \n",
       "L 187.333446 63.770579 \n",
       "L 190.612778 67.283685 \n",
       "L 193.892121 71.008573 \n",
       "L 197.171463 74.953645 \n",
       "L 200.450795 79.128509 \n",
       "L 203.730137 83.543668 \n",
       "L 207.00948 88.210025 \n",
       "L 210.288812 93.138338 \n",
       "L 213.568154 98.33876 \n",
       "L 216.847496 103.82004 \n",
       "L 220.126829 109.588813 \n",
       "L 223.406181 115.648943 \n",
       "L 226.685504 122.000198 \n",
       "L 229.964846 128.637706 \n",
       "L 233.244188 135.55055 \n",
       "L 236.523511 142.720579 \n",
       "L 239.802872 150.121821 \n",
       "L 243.082195 157.718416 \n",
       "L 246.361537 165.464742 \n",
       "L 249.640879 173.303873 \n",
       "L 252.920222 181.167059 \n",
       "L 256.199564 188.973785 \n",
       "L 259.478887 196.631481 \n",
       "L 262.758248 204.036563 \n",
       "L 266.037571 211.074845 \n",
       "L 269.316913 217.623812 \n",
       "L 272.596255 223.554077 \n",
       "L 275.875578 228.733291 \n",
       "L 279.15494 233.027488 \n",
       "L 282.434262 236.306927 \n",
       "L 285.713605 238.449485 \n",
       "L 288.992947 239.343504 \n",
       "L 292.272289 238.894816 \n",
       "L 295.551631 237.031128 \n",
       "L 298.830954 233.701743 \n",
       "L 302.110315 228.889052 \n",
       "L 305.389638 222.604741 \n",
       "L 308.66898 214.897455 \n",
       "L 311.948322 205.849633 \n",
       "L 315.227645 195.582727 \n",
       "L 318.507007 184.25151 \n",
       "L 321.78633 172.045503 \n",
       "L 325.065672 159.185653 \n",
       "L 328.345014 145.914546 \n",
       "L 331.624356 132.500825 \n",
       "L 334.903698 119.219926 \n",
       "L 338.183021 106.357234 \n",
       "L 341.462363 94.193552 \n",
       "L 344.741705 82.998948 \n",
       "L 348.021048 73.028482 \n",
       "L 351.30039 64.507682 \n",
       "L 354.579713 57.624174 \n",
       "L 357.859055 52.533047 \n",
       "L 361.138397 49.344064 \n",
       "L 364.417739 48.112503 \n",
       "L 367.697081 48.850997 \n",
       "L 370.976423 51.512958 \n",
       "L 374.255766 56.009783 \n",
       "L 377.535088 62.204704 \n",
       "L 380.814431 69.917202 \n",
       "L 384.093773 78.93399 \n",
       "\" clip-path=\"url(#pcb736d303a)\" style=\"fill: none; stroke: #1f77b4; stroke-width: 2; stroke-linecap: round\"/>\n",
       "   </g>\n",
       "   <g id=\"line2d_16\">\n",
       "    <path d=\"M 59.439227 119.780164 \n",
       "L 62.718566 114.7285 \n",
       "L 65.997905 109.695581 \n",
       "L 69.277244 104.700073 \n",
       "L 72.556583 99.760571 \n",
       "L 75.835921 94.895466 \n",
       "L 79.115261 90.122968 \n",
       "L 82.394598 85.46097 \n",
       "L 85.673938 80.927005 \n",
       "L 88.953278 76.538226 \n",
       "L 92.232615 72.311283 \n",
       "L 95.511955 68.262311 \n",
       "L 98.791295 64.406857 \n",
       "L 102.070632 60.759829 \n",
       "L 105.349969 57.335433 \n",
       "L 108.629311 54.147161 \n",
       "L 111.908649 51.207703 \n",
       "L 115.187986 48.528923 \n",
       "L 118.467328 46.121802 \n",
       "L 121.746666 43.996429 \n",
       "L 125.026003 42.161949 \n",
       "L 128.305345 40.626515 \n",
       "L 131.584682 39.397283 \n",
       "L 134.86402 38.480379 \n",
       "L 138.143362 37.88086 \n",
       "L 141.422694 37.602715 \n",
       "L 144.702037 37.648842 \n",
       "L 147.981379 38.021011 \n",
       "L 151.260711 38.719879 \n",
       "L 154.540053 39.744977 \n",
       "L 157.819395 41.094687 \n",
       "L 161.098728 42.766235 \n",
       "L 164.37807 44.755731 \n",
       "L 167.657412 47.058098 \n",
       "L 170.936745 49.667141 \n",
       "L 174.216087 52.575506 \n",
       "L 177.495429 55.7747 \n",
       "L 180.774762 59.255093 \n",
       "L 184.054104 63.005912 \n",
       "L 187.333446 67.015302 \n",
       "L 190.612778 71.270224 \n",
       "L 193.892121 75.756586 \n",
       "L 197.171463 80.459139 \n",
       "L 200.450795 85.361595 \n",
       "L 203.730137 90.446524 \n",
       "L 207.00948 95.695391 \n",
       "L 210.288812 101.08859 \n",
       "L 213.568154 106.605435 \n",
       "L 216.847496 112.224098 \n",
       "L 220.126829 117.921692 \n",
       "L 223.406181 123.674218 \n",
       "L 226.685504 129.456509 \n",
       "L 229.964846 135.242354 \n",
       "L 233.244188 141.00438 \n",
       "L 236.523511 146.713933 \n",
       "L 239.802872 152.34145 \n",
       "L 243.082195 157.855877 \n",
       "L 246.361537 163.225223 \n",
       "L 249.640879 168.416144 \n",
       "L 252.920222 173.394132 \n",
       "L 256.199564 178.123523 \n",
       "L 259.478887 182.567372 \n",
       "L 262.758248 186.687675 \n",
       "L 266.037571 190.445256 \n",
       "L 269.316913 193.79996 \n",
       "L 272.596255 196.710684 \n",
       "L 275.875578 199.135636 \n",
       "L 279.15494 201.032411 \n",
       "L 282.434262 202.358367 \n",
       "L 285.713605 203.070931 \n",
       "L 288.992947 203.128053 \n",
       "L 292.272289 202.48876 \n",
       "L 295.551631 201.113895 \n",
       "L 298.830954 198.966924 \n",
       "L 302.110315 196.01489 \n",
       "L 305.389638 192.230027 \n",
       "L 308.66898 187.590647 \n",
       "L 311.948322 182.083426 \n",
       "L 315.227645 175.705323 \n",
       "L 318.507007 168.465676 \n",
       "L 321.78633 160.389369 \n",
       "L 325.065672 151.519488 \n",
       "L 328.345014 141.920836 \n",
       "L 331.624356 131.683601 \n",
       "L 334.903698 120.927043 \n",
       "L 338.183021 109.803385 \n",
       "L 341.462363 98.501549 \n",
       "L 344.741705 87.250128 \n",
       "L 348.021048 76.319869 \n",
       "L 351.30039 66.024604 \n",
       "L 354.579713 56.719603 \n",
       "L 357.859055 48.797202 \n",
       "L 361.138397 42.678829 \n",
       "L 364.417739 38.800598 \n",
       "L 367.697081 37.593323 \n",
       "L 370.976423 39.454203 \n",
       "L 374.255766 44.709748 \n",
       "L 377.535088 53.5696 \n",
       "L 380.814431 66.071475 \n",
       "L 384.093773 82.019857 \n",
       "\" clip-path=\"url(#pcb736d303a)\" style=\"fill: none; stroke-dasharray: 7.68,1.92,1.2,1.92; stroke-dashoffset: 0; stroke: #bf00bf; stroke-width: 1.2\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_3\">\n",
       "    <path d=\"M 43.2065 285.988927 \n",
       "L 43.2065 37.581849 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_4\">\n",
       "    <path d=\"M 59.439227 286.212 \n",
       "L 384.093773 286.212 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"text_16\">\n",
       "    <!-- N=5, psi=0.10 -->\n",
       "    <g style=\"fill: #262626\" transform=\"translate(191.87975 14.1) scale(0.096 -0.096)\">\n",
       "     <defs>\n",
       "      <path id=\"ArialMT-4e\" d=\"M 488 0 \n",
       "L 488 4581 \n",
       "L 1109 4581 \n",
       "L 3516 984 \n",
       "L 3516 4581 \n",
       "L 4097 4581 \n",
       "L 4097 0 \n",
       "L 3475 0 \n",
       "L 1069 3600 \n",
       "L 1069 0 \n",
       "L 488 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-3d\" d=\"M 3381 2694 \n",
       "L 356 2694 \n",
       "L 356 3219 \n",
       "L 3381 3219 \n",
       "L 3381 2694 \n",
       "z\n",
       "M 3381 1303 \n",
       "L 356 1303 \n",
       "L 356 1828 \n",
       "L 3381 1828 \n",
       "L 3381 1303 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-35\" d=\"M 266 1200 \n",
       "L 856 1250 \n",
       "Q 922 819 1161 601 \n",
       "Q 1400 384 1738 384 \n",
       "Q 2144 384 2425 690 \n",
       "Q 2706 997 2706 1503 \n",
       "Q 2706 1984 2436 2262 \n",
       "Q 2166 2541 1728 2541 \n",
       "Q 1456 2541 1237 2417 \n",
       "Q 1019 2294 894 2097 \n",
       "L 366 2166 \n",
       "L 809 4519 \n",
       "L 3088 4519 \n",
       "L 3088 3981 \n",
       "L 1259 3981 \n",
       "L 1013 2750 \n",
       "Q 1425 3038 1878 3038 \n",
       "Q 2478 3038 2890 2622 \n",
       "Q 3303 2206 3303 1553 \n",
       "Q 3303 931 2941 478 \n",
       "Q 2500 -78 1738 -78 \n",
       "Q 1113 -78 717 272 \n",
       "Q 322 622 266 1200 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-2c\" d=\"M 569 0 \n",
       "L 569 641 \n",
       "L 1209 641 \n",
       "L 1209 0 \n",
       "Q 1209 -353 1084 -570 \n",
       "Q 959 -788 688 -906 \n",
       "L 531 -666 \n",
       "Q 709 -588 793 -436 \n",
       "Q 878 -284 888 0 \n",
       "L 569 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-20\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-70\" d=\"M 422 -1272 \n",
       "L 422 3319 \n",
       "L 934 3319 \n",
       "L 934 2888 \n",
       "Q 1116 3141 1344 3267 \n",
       "Q 1572 3394 1897 3394 \n",
       "Q 2322 3394 2647 3175 \n",
       "Q 2972 2956 3137 2557 \n",
       "Q 3303 2159 3303 1684 \n",
       "Q 3303 1175 3120 767 \n",
       "Q 2938 359 2589 142 \n",
       "Q 2241 -75 1856 -75 \n",
       "Q 1575 -75 1351 44 \n",
       "Q 1128 163 984 344 \n",
       "L 984 -1272 \n",
       "L 422 -1272 \n",
       "z\n",
       "M 931 1641 \n",
       "Q 931 1000 1190 694 \n",
       "Q 1450 388 1819 388 \n",
       "Q 2194 388 2461 705 \n",
       "Q 2728 1022 2728 1688 \n",
       "Q 2728 2322 2467 2637 \n",
       "Q 2206 2953 1844 2953 \n",
       "Q 1484 2953 1207 2617 \n",
       "Q 931 2281 931 1641 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-73\" d=\"M 197 991 \n",
       "L 753 1078 \n",
       "Q 800 744 1014 566 \n",
       "Q 1228 388 1613 388 \n",
       "Q 2000 388 2187 545 \n",
       "Q 2375 703 2375 916 \n",
       "Q 2375 1106 2209 1216 \n",
       "Q 2094 1291 1634 1406 \n",
       "Q 1016 1563 777 1677 \n",
       "Q 538 1791 414 1992 \n",
       "Q 291 2194 291 2438 \n",
       "Q 291 2659 392 2848 \n",
       "Q 494 3038 669 3163 \n",
       "Q 800 3259 1026 3326 \n",
       "Q 1253 3394 1513 3394 \n",
       "Q 1903 3394 2198 3281 \n",
       "Q 2494 3169 2634 2976 \n",
       "Q 2775 2784 2828 2463 \n",
       "L 2278 2388 \n",
       "Q 2241 2644 2061 2787 \n",
       "Q 1881 2931 1553 2931 \n",
       "Q 1166 2931 1000 2803 \n",
       "Q 834 2675 834 2503 \n",
       "Q 834 2394 903 2306 \n",
       "Q 972 2216 1119 2156 \n",
       "Q 1203 2125 1616 2013 \n",
       "Q 2213 1853 2448 1751 \n",
       "Q 2684 1650 2818 1456 \n",
       "Q 2953 1263 2953 975 \n",
       "Q 2953 694 2789 445 \n",
       "Q 2625 197 2315 61 \n",
       "Q 2006 -75 1616 -75 \n",
       "Q 969 -75 630 194 \n",
       "Q 291 463 197 991 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-69\" d=\"M 425 3934 \n",
       "L 425 4581 \n",
       "L 988 4581 \n",
       "L 988 3934 \n",
       "L 425 3934 \n",
       "z\n",
       "M 425 0 \n",
       "L 425 3319 \n",
       "L 988 3319 \n",
       "L 988 0 \n",
       "L 425 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "     </defs>\n",
       "     <use xlink:href=\"#ArialMT-4e\"/>\n",
       "     <use xlink:href=\"#ArialMT-3d\" x=\"72.216797\"/>\n",
       "     <use xlink:href=\"#ArialMT-35\" x=\"130.615234\"/>\n",
       "     <use xlink:href=\"#ArialMT-2c\" x=\"186.230469\"/>\n",
       "     <use xlink:href=\"#ArialMT-20\" x=\"214.013672\"/>\n",
       "     <use xlink:href=\"#ArialMT-70\" x=\"241.796875\"/>\n",
       "     <use xlink:href=\"#ArialMT-73\" x=\"297.412109\"/>\n",
       "     <use xlink:href=\"#ArialMT-69\" x=\"347.412109\"/>\n",
       "     <use xlink:href=\"#ArialMT-3d\" x=\"369.628906\"/>\n",
       "     <use xlink:href=\"#ArialMT-30\" x=\"428.027344\"/>\n",
       "     <use xlink:href=\"#ArialMT-2e\" x=\"483.642578\"/>\n",
       "     <use xlink:href=\"#ArialMT-31\" x=\"511.425781\"/>\n",
       "     <use xlink:href=\"#ArialMT-30\" x=\"567.041016\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"legend_1\">\n",
       "    <g id=\"line2d_17\">\n",
       "     <g>\n",
       "      <use xlink:href=\"#m48e2645bf6\" x=\"59.9265\" y=\"220.007125\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"text_17\">\n",
       "     <!-- Observations -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(75.7665 223.087125) scale(0.088 -0.088)\">\n",
       "      <defs>\n",
       "       <path id=\"ArialMT-4f\" d=\"M 309 2231 \n",
       "Q 309 3372 921 4017 \n",
       "Q 1534 4663 2503 4663 \n",
       "Q 3138 4663 3647 4359 \n",
       "Q 4156 4056 4423 3514 \n",
       "Q 4691 2972 4691 2284 \n",
       "Q 4691 1588 4409 1038 \n",
       "Q 4128 488 3612 205 \n",
       "Q 3097 -78 2500 -78 \n",
       "Q 1853 -78 1343 234 \n",
       "Q 834 547 571 1087 \n",
       "Q 309 1628 309 2231 \n",
       "z\n",
       "M 934 2222 \n",
       "Q 934 1394 1379 917 \n",
       "Q 1825 441 2497 441 \n",
       "Q 3181 441 3623 922 \n",
       "Q 4066 1403 4066 2288 \n",
       "Q 4066 2847 3877 3264 \n",
       "Q 3688 3681 3323 3911 \n",
       "Q 2959 4141 2506 4141 \n",
       "Q 1863 4141 1398 3698 \n",
       "Q 934 3256 934 2222 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-62\" d=\"M 941 0 \n",
       "L 419 0 \n",
       "L 419 4581 \n",
       "L 981 4581 \n",
       "L 981 2947 \n",
       "Q 1338 3394 1891 3394 \n",
       "Q 2197 3394 2470 3270 \n",
       "Q 2744 3147 2920 2923 \n",
       "Q 3097 2700 3197 2384 \n",
       "Q 3297 2069 3297 1709 \n",
       "Q 3297 856 2875 390 \n",
       "Q 2453 -75 1863 -75 \n",
       "Q 1275 -75 941 416 \n",
       "L 941 0 \n",
       "z\n",
       "M 934 1684 \n",
       "Q 934 1088 1097 822 \n",
       "Q 1363 388 1816 388 \n",
       "Q 2184 388 2453 708 \n",
       "Q 2722 1028 2722 1663 \n",
       "Q 2722 2313 2464 2622 \n",
       "Q 2206 2931 1841 2931 \n",
       "Q 1472 2931 1203 2611 \n",
       "Q 934 2291 934 1684 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-65\" d=\"M 2694 1069 \n",
       "L 3275 997 \n",
       "Q 3138 488 2766 206 \n",
       "Q 2394 -75 1816 -75 \n",
       "Q 1088 -75 661 373 \n",
       "Q 234 822 234 1631 \n",
       "Q 234 2469 665 2931 \n",
       "Q 1097 3394 1784 3394 \n",
       "Q 2450 3394 2872 2941 \n",
       "Q 3294 2488 3294 1666 \n",
       "Q 3294 1616 3291 1516 \n",
       "L 816 1516 \n",
       "Q 847 969 1125 678 \n",
       "Q 1403 388 1819 388 \n",
       "Q 2128 388 2347 550 \n",
       "Q 2566 713 2694 1069 \n",
       "z\n",
       "M 847 1978 \n",
       "L 2700 1978 \n",
       "Q 2663 2397 2488 2606 \n",
       "Q 2219 2931 1791 2931 \n",
       "Q 1403 2931 1139 2672 \n",
       "Q 875 2413 847 1978 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-72\" d=\"M 416 0 \n",
       "L 416 3319 \n",
       "L 922 3319 \n",
       "L 922 2816 \n",
       "Q 1116 3169 1280 3281 \n",
       "Q 1444 3394 1641 3394 \n",
       "Q 1925 3394 2219 3213 \n",
       "L 2025 2691 \n",
       "Q 1819 2813 1613 2813 \n",
       "Q 1428 2813 1281 2702 \n",
       "Q 1134 2591 1072 2394 \n",
       "Q 978 2094 978 1738 \n",
       "L 978 0 \n",
       "L 416 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-76\" d=\"M 1344 0 \n",
       "L 81 3319 \n",
       "L 675 3319 \n",
       "L 1388 1331 \n",
       "Q 1503 1009 1600 663 \n",
       "Q 1675 925 1809 1294 \n",
       "L 2547 3319 \n",
       "L 3125 3319 \n",
       "L 1869 0 \n",
       "L 1344 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-61\" d=\"M 2588 409 \n",
       "Q 2275 144 1986 34 \n",
       "Q 1697 -75 1366 -75 \n",
       "Q 819 -75 525 192 \n",
       "Q 231 459 231 875 \n",
       "Q 231 1119 342 1320 \n",
       "Q 453 1522 633 1644 \n",
       "Q 813 1766 1038 1828 \n",
       "Q 1203 1872 1538 1913 \n",
       "Q 2219 1994 2541 2106 \n",
       "Q 2544 2222 2544 2253 \n",
       "Q 2544 2597 2384 2738 \n",
       "Q 2169 2928 1744 2928 \n",
       "Q 1347 2928 1158 2789 \n",
       "Q 969 2650 878 2297 \n",
       "L 328 2372 \n",
       "Q 403 2725 575 2942 \n",
       "Q 747 3159 1072 3276 \n",
       "Q 1397 3394 1825 3394 \n",
       "Q 2250 3394 2515 3294 \n",
       "Q 2781 3194 2906 3042 \n",
       "Q 3031 2891 3081 2659 \n",
       "Q 3109 2516 3109 2141 \n",
       "L 3109 1391 \n",
       "Q 3109 606 3145 398 \n",
       "Q 3181 191 3288 0 \n",
       "L 2700 0 \n",
       "Q 2613 175 2588 409 \n",
       "z\n",
       "M 2541 1666 \n",
       "Q 2234 1541 1622 1453 \n",
       "Q 1275 1403 1131 1340 \n",
       "Q 988 1278 909 1158 \n",
       "Q 831 1038 831 891 \n",
       "Q 831 666 1001 516 \n",
       "Q 1172 366 1500 366 \n",
       "Q 1825 366 2078 508 \n",
       "Q 2331 650 2450 897 \n",
       "Q 2541 1088 2541 1459 \n",
       "L 2541 1666 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-74\" d=\"M 1650 503 \n",
       "L 1731 6 \n",
       "Q 1494 -44 1306 -44 \n",
       "Q 1000 -44 831 53 \n",
       "Q 663 150 594 308 \n",
       "Q 525 466 525 972 \n",
       "L 525 2881 \n",
       "L 113 2881 \n",
       "L 113 3319 \n",
       "L 525 3319 \n",
       "L 525 4141 \n",
       "L 1084 4478 \n",
       "L 1084 3319 \n",
       "L 1650 3319 \n",
       "L 1650 2881 \n",
       "L 1084 2881 \n",
       "L 1084 941 \n",
       "Q 1084 700 1114 631 \n",
       "Q 1144 563 1211 522 \n",
       "Q 1278 481 1403 481 \n",
       "Q 1497 481 1650 503 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-6f\" d=\"M 213 1659 \n",
       "Q 213 2581 725 3025 \n",
       "Q 1153 3394 1769 3394 \n",
       "Q 2453 3394 2887 2945 \n",
       "Q 3322 2497 3322 1706 \n",
       "Q 3322 1066 3130 698 \n",
       "Q 2938 331 2570 128 \n",
       "Q 2203 -75 1769 -75 \n",
       "Q 1072 -75 642 372 \n",
       "Q 213 819 213 1659 \n",
       "z\n",
       "M 791 1659 \n",
       "Q 791 1022 1069 705 \n",
       "Q 1347 388 1769 388 \n",
       "Q 2188 388 2466 706 \n",
       "Q 2744 1025 2744 1678 \n",
       "Q 2744 2294 2464 2611 \n",
       "Q 2184 2928 1769 2928 \n",
       "Q 1347 2928 1069 2612 \n",
       "Q 791 2297 791 1659 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-6e\" d=\"M 422 0 \n",
       "L 422 3319 \n",
       "L 928 3319 \n",
       "L 928 2847 \n",
       "Q 1294 3394 1984 3394 \n",
       "Q 2284 3394 2536 3286 \n",
       "Q 2788 3178 2913 3003 \n",
       "Q 3038 2828 3088 2588 \n",
       "Q 3119 2431 3119 2041 \n",
       "L 3119 0 \n",
       "L 2556 0 \n",
       "L 2556 2019 \n",
       "Q 2556 2363 2490 2533 \n",
       "Q 2425 2703 2258 2804 \n",
       "Q 2091 2906 1866 2906 \n",
       "Q 1506 2906 1245 2678 \n",
       "Q 984 2450 984 1813 \n",
       "L 984 0 \n",
       "L 422 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#ArialMT-4f\"/>\n",
       "      <use xlink:href=\"#ArialMT-62\" x=\"77.783203\"/>\n",
       "      <use xlink:href=\"#ArialMT-73\" x=\"133.398438\"/>\n",
       "      <use xlink:href=\"#ArialMT-65\" x=\"183.398438\"/>\n",
       "      <use xlink:href=\"#ArialMT-72\" x=\"239.013672\"/>\n",
       "      <use xlink:href=\"#ArialMT-76\" x=\"272.314453\"/>\n",
       "      <use xlink:href=\"#ArialMT-61\" x=\"322.314453\"/>\n",
       "      <use xlink:href=\"#ArialMT-74\" x=\"377.929688\"/>\n",
       "      <use xlink:href=\"#ArialMT-69\" x=\"405.712891\"/>\n",
       "      <use xlink:href=\"#ArialMT-6f\" x=\"427.929688\"/>\n",
       "      <use xlink:href=\"#ArialMT-6e\" x=\"483.544922\"/>\n",
       "      <use xlink:href=\"#ArialMT-73\" x=\"539.160156\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"line2d_18\">\n",
       "     <path d=\"M 51.1265 232.591125 \n",
       "L 59.9265 232.591125 \n",
       "L 68.7265 232.591125 \n",
       "\" style=\"fill: none; stroke: #1f77b4; stroke-width: 2; stroke-linecap: round\"/>\n",
       "    </g>\n",
       "    <g id=\"text_18\">\n",
       "     <!-- $m_n(x)$ -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(75.7665 235.671125) scale(0.088 -0.088)\">\n",
       "      <defs>\n",
       "       <path id=\"DejaVuSans-Oblique-6d\" d=\"M 5747 2113 \n",
       "L 5338 0 \n",
       "L 4763 0 \n",
       "L 5166 2094 \n",
       "Q 5191 2228 5203 2325 \n",
       "Q 5216 2422 5216 2491 \n",
       "Q 5216 2772 5059 2928 \n",
       "Q 4903 3084 4622 3084 \n",
       "Q 4203 3084 3875 2770 \n",
       "Q 3547 2456 3450 1953 \n",
       "L 3066 0 \n",
       "L 2491 0 \n",
       "L 2900 2094 \n",
       "Q 2925 2209 2937 2307 \n",
       "Q 2950 2406 2950 2484 \n",
       "Q 2950 2769 2794 2926 \n",
       "Q 2638 3084 2363 3084 \n",
       "Q 1938 3084 1609 2770 \n",
       "Q 1281 2456 1184 1953 \n",
       "L 800 0 \n",
       "L 225 0 \n",
       "L 909 3500 \n",
       "L 1484 3500 \n",
       "L 1375 2956 \n",
       "Q 1609 3263 1923 3423 \n",
       "Q 2238 3584 2597 3584 \n",
       "Q 2978 3584 3223 3384 \n",
       "Q 3469 3184 3519 2828 \n",
       "Q 3781 3197 4126 3390 \n",
       "Q 4472 3584 4856 3584 \n",
       "Q 5306 3584 5551 3325 \n",
       "Q 5797 3066 5797 2591 \n",
       "Q 5797 2488 5784 2364 \n",
       "Q 5772 2241 5747 2113 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-Oblique-6e\" d=\"M 3566 2113 \n",
       "L 3156 0 \n",
       "L 2578 0 \n",
       "L 2988 2091 \n",
       "Q 3016 2238 3031 2350 \n",
       "Q 3047 2463 3047 2528 \n",
       "Q 3047 2791 2881 2937 \n",
       "Q 2716 3084 2419 3084 \n",
       "Q 1956 3084 1622 2776 \n",
       "Q 1288 2469 1184 1941 \n",
       "L 800 0 \n",
       "L 225 0 \n",
       "L 903 3500 \n",
       "L 1478 3500 \n",
       "L 1363 2950 \n",
       "Q 1603 3253 1940 3418 \n",
       "Q 2278 3584 2650 3584 \n",
       "Q 3113 3584 3367 3334 \n",
       "Q 3622 3084 3622 2631 \n",
       "Q 3622 2519 3608 2391 \n",
       "Q 3594 2263 3566 2113 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-28\" d=\"M 1984 4856 \n",
       "Q 1566 4138 1362 3434 \n",
       "Q 1159 2731 1159 2009 \n",
       "Q 1159 1288 1364 580 \n",
       "Q 1569 -128 1984 -844 \n",
       "L 1484 -844 \n",
       "Q 1016 -109 783 600 \n",
       "Q 550 1309 550 2009 \n",
       "Q 550 2706 781 3412 \n",
       "Q 1013 4119 1484 4856 \n",
       "L 1984 4856 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-29\" d=\"M 513 4856 \n",
       "L 1013 4856 \n",
       "Q 1481 4119 1714 3412 \n",
       "Q 1947 2706 1947 2009 \n",
       "Q 1947 1309 1714 600 \n",
       "Q 1481 -109 1013 -844 \n",
       "L 513 -844 \n",
       "Q 928 -128 1133 580 \n",
       "Q 1338 1288 1338 2009 \n",
       "Q 1338 2731 1133 3434 \n",
       "Q 928 4138 513 4856 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-6d\" transform=\"translate(0 0.125)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-6e\" transform=\"translate(97.412109 -16.28125) scale(0.7)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-28\" transform=\"translate(144.511719 0.125)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-78\" transform=\"translate(183.525391 0.125)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-29\" transform=\"translate(242.705078 0.125)\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"patch_5\">\n",
       "     <path d=\"M 51.1265 249.828125 \n",
       "L 68.7265 249.828125 \n",
       "L 68.7265 243.668125 \n",
       "L 51.1265 243.668125 \n",
       "z\n",
       "\" style=\"fill: #1f77b4; fill-opacity: 0.5; stroke: #1f77b4; stroke-opacity: 0.5; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "    </g>\n",
       "    <g id=\"text_19\">\n",
       "     <!-- $f(\\mathbf{x}^*)$ 95% pred. -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(75.7665 249.828125) scale(0.088 -0.088)\">\n",
       "      <defs>\n",
       "       <path id=\"DejaVuSans-Oblique-66\" d=\"M 3059 4863 \n",
       "L 2969 4384 \n",
       "L 2419 4384 \n",
       "Q 2106 4384 1964 4261 \n",
       "Q 1822 4138 1753 3809 \n",
       "L 1691 3500 \n",
       "L 2638 3500 \n",
       "L 2553 3053 \n",
       "L 1606 3053 \n",
       "L 1013 0 \n",
       "L 434 0 \n",
       "L 1031 3053 \n",
       "L 481 3053 \n",
       "L 563 3500 \n",
       "L 1113 3500 \n",
       "L 1159 3744 \n",
       "Q 1278 4363 1576 4613 \n",
       "Q 1875 4863 2516 4863 \n",
       "L 3059 4863 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-Bold-78\" d=\"M 1422 1791 \n",
       "L 159 3500 \n",
       "L 1344 3500 \n",
       "L 2059 2463 \n",
       "L 2784 3500 \n",
       "L 3969 3500 \n",
       "L 2706 1797 \n",
       "L 4031 0 \n",
       "L 2847 0 \n",
       "L 2059 1106 \n",
       "L 1281 0 \n",
       "L 97 0 \n",
       "L 1422 1791 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-2a\" d=\"M 3009 3897 \n",
       "L 1888 3291 \n",
       "L 3009 2681 \n",
       "L 2828 2375 \n",
       "L 1778 3009 \n",
       "L 1778 1831 \n",
       "L 1422 1831 \n",
       "L 1422 3009 \n",
       "L 372 2375 \n",
       "L 191 2681 \n",
       "L 1313 3291 \n",
       "L 191 3897 \n",
       "L 372 4206 \n",
       "L 1422 3572 \n",
       "L 1422 4750 \n",
       "L 1778 4750 \n",
       "L 1778 3572 \n",
       "L 2828 4206 \n",
       "L 3009 3897 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-39\" d=\"M 350 1059 \n",
       "L 891 1109 \n",
       "Q 959 728 1153 556 \n",
       "Q 1347 384 1650 384 \n",
       "Q 1909 384 2104 503 \n",
       "Q 2300 622 2425 820 \n",
       "Q 2550 1019 2634 1356 \n",
       "Q 2719 1694 2719 2044 \n",
       "Q 2719 2081 2716 2156 \n",
       "Q 2547 1888 2255 1720 \n",
       "Q 1963 1553 1622 1553 \n",
       "Q 1053 1553 659 1965 \n",
       "Q 266 2378 266 3053 \n",
       "Q 266 3750 677 4175 \n",
       "Q 1088 4600 1706 4600 \n",
       "Q 2153 4600 2523 4359 \n",
       "Q 2894 4119 3086 3673 \n",
       "Q 3278 3228 3278 2384 \n",
       "Q 3278 1506 3087 986 \n",
       "Q 2897 466 2520 194 \n",
       "Q 2144 -78 1638 -78 \n",
       "Q 1100 -78 759 220 \n",
       "Q 419 519 350 1059 \n",
       "z\n",
       "M 2653 3081 \n",
       "Q 2653 3566 2395 3850 \n",
       "Q 2138 4134 1775 4134 \n",
       "Q 1400 4134 1122 3828 \n",
       "Q 844 3522 844 3034 \n",
       "Q 844 2597 1108 2323 \n",
       "Q 1372 2050 1759 2050 \n",
       "Q 2150 2050 2401 2323 \n",
       "Q 2653 2597 2653 3081 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-25\" d=\"M 372 3481 \n",
       "Q 372 3972 619 4315 \n",
       "Q 866 4659 1334 4659 \n",
       "Q 1766 4659 2048 4351 \n",
       "Q 2331 4044 2331 3447 \n",
       "Q 2331 2866 2045 2552 \n",
       "Q 1759 2238 1341 2238 \n",
       "Q 925 2238 648 2547 \n",
       "Q 372 2856 372 3481 \n",
       "z\n",
       "M 1350 4272 \n",
       "Q 1141 4272 1002 4090 \n",
       "Q 863 3909 863 3425 \n",
       "Q 863 2984 1003 2804 \n",
       "Q 1144 2625 1350 2625 \n",
       "Q 1563 2625 1702 2806 \n",
       "Q 1841 2988 1841 3469 \n",
       "Q 1841 3913 1700 4092 \n",
       "Q 1559 4272 1350 4272 \n",
       "z\n",
       "M 1353 -169 \n",
       "L 3859 4659 \n",
       "L 4316 4659 \n",
       "L 1819 -169 \n",
       "L 1353 -169 \n",
       "z\n",
       "M 3334 1075 \n",
       "Q 3334 1569 3581 1911 \n",
       "Q 3828 2253 4300 2253 \n",
       "Q 4731 2253 5014 1945 \n",
       "Q 5297 1638 5297 1041 \n",
       "Q 5297 459 5011 145 \n",
       "Q 4725 -169 4303 -169 \n",
       "Q 3888 -169 3611 142 \n",
       "Q 3334 453 3334 1075 \n",
       "z\n",
       "M 4316 1866 \n",
       "Q 4103 1866 3964 1684 \n",
       "Q 3825 1503 3825 1019 \n",
       "Q 3825 581 3965 400 \n",
       "Q 4106 219 4313 219 \n",
       "Q 4528 219 4667 400 \n",
       "Q 4806 581 4806 1063 \n",
       "Q 4806 1506 4665 1686 \n",
       "Q 4525 1866 4316 1866 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-64\" d=\"M 2575 0 \n",
       "L 2575 419 \n",
       "Q 2259 -75 1647 -75 \n",
       "Q 1250 -75 917 144 \n",
       "Q 584 363 401 755 \n",
       "Q 219 1147 219 1656 \n",
       "Q 219 2153 384 2558 \n",
       "Q 550 2963 881 3178 \n",
       "Q 1213 3394 1622 3394 \n",
       "Q 1922 3394 2156 3267 \n",
       "Q 2391 3141 2538 2938 \n",
       "L 2538 4581 \n",
       "L 3097 4581 \n",
       "L 3097 0 \n",
       "L 2575 0 \n",
       "z\n",
       "M 797 1656 \n",
       "Q 797 1019 1065 703 \n",
       "Q 1334 388 1700 388 \n",
       "Q 2069 388 2326 689 \n",
       "Q 2584 991 2584 1609 \n",
       "Q 2584 2291 2321 2609 \n",
       "Q 2059 2928 1675 2928 \n",
       "Q 1300 2928 1048 2622 \n",
       "Q 797 2316 797 1656 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-66\" transform=\"translate(0 0.765625)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-28\" transform=\"translate(35.205078 0.765625)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-Bold-78\" transform=\"translate(74.21875 0.765625)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-2a\" transform=\"translate(153.31543 39.046875) scale(0.7)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-29\" transform=\"translate(204.6875 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" transform=\"translate(243.701172 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-39\" transform=\"translate(271.484375 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-35\" transform=\"translate(327.099609 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-25\" transform=\"translate(382.714844 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" transform=\"translate(471.630859 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-70\" transform=\"translate(499.414062 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-72\" transform=\"translate(555.029297 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-65\" transform=\"translate(588.330078 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-64\" transform=\"translate(643.945312 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-2e\" transform=\"translate(699.560547 0.765625)\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"patch_6\">\n",
       "     <path d=\"M 51.1265 263.996125 \n",
       "L 68.7265 263.996125 \n",
       "L 68.7265 257.836125 \n",
       "L 51.1265 257.836125 \n",
       "z\n",
       "\" style=\"fill: #ff7f0e; fill-opacity: 0.5; stroke: #ff7f0e; stroke-opacity: 0.5; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "    </g>\n",
       "    <g id=\"text_20\">\n",
       "     <!-- $y^*$ 95% pred. -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(75.7665 263.996125) scale(0.088 -0.088)\">\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-79\" transform=\"translate(0 0.765625)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-2a\" transform=\"translate(77.283529 39.046875) scale(0.7)\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" transform=\"translate(128.655599 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-39\" transform=\"translate(156.438802 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-35\" transform=\"translate(212.054036 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-25\" transform=\"translate(267.669271 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" transform=\"translate(356.585286 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-70\" transform=\"translate(384.36849 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-72\" transform=\"translate(439.983724 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-65\" transform=\"translate(473.284505 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-64\" transform=\"translate(528.89974 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-2e\" transform=\"translate(584.514974 0.765625)\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"line2d_19\">\n",
       "     <path d=\"M 51.1265 273.463 \n",
       "L 59.9265 273.463 \n",
       "L 68.7265 273.463 \n",
       "\" style=\"fill: none; stroke-dasharray: 7.68,1.92,1.2,1.92; stroke-dashoffset: 0; stroke: #bf00bf; stroke-width: 1.2\"/>\n",
       "    </g>\n",
       "    <g id=\"text_21\">\n",
       "     <!-- True function -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(75.7665 276.543) scale(0.088 -0.088)\">\n",
       "      <defs>\n",
       "       <path id=\"ArialMT-54\" d=\"M 1659 0 \n",
       "L 1659 4041 \n",
       "L 150 4041 \n",
       "L 150 4581 \n",
       "L 3781 4581 \n",
       "L 3781 4041 \n",
       "L 2266 4041 \n",
       "L 2266 0 \n",
       "L 1659 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-75\" d=\"M 2597 0 \n",
       "L 2597 488 \n",
       "Q 2209 -75 1544 -75 \n",
       "Q 1250 -75 995 37 \n",
       "Q 741 150 617 320 \n",
       "Q 494 491 444 738 \n",
       "Q 409 903 409 1263 \n",
       "L 409 3319 \n",
       "L 972 3319 \n",
       "L 972 1478 \n",
       "Q 972 1038 1006 884 \n",
       "Q 1059 663 1231 536 \n",
       "Q 1403 409 1656 409 \n",
       "Q 1909 409 2131 539 \n",
       "Q 2353 669 2445 892 \n",
       "Q 2538 1116 2538 1541 \n",
       "L 2538 3319 \n",
       "L 3100 3319 \n",
       "L 3100 0 \n",
       "L 2597 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-66\" d=\"M 556 0 \n",
       "L 556 2881 \n",
       "L 59 2881 \n",
       "L 59 3319 \n",
       "L 556 3319 \n",
       "L 556 3672 \n",
       "Q 556 4006 616 4169 \n",
       "Q 697 4388 901 4523 \n",
       "Q 1106 4659 1475 4659 \n",
       "Q 1713 4659 2000 4603 \n",
       "L 1916 4113 \n",
       "Q 1741 4144 1584 4144 \n",
       "Q 1328 4144 1222 4034 \n",
       "Q 1116 3925 1116 3625 \n",
       "L 1116 3319 \n",
       "L 1763 3319 \n",
       "L 1763 2881 \n",
       "L 1116 2881 \n",
       "L 1116 0 \n",
       "L 556 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-63\" d=\"M 2588 1216 \n",
       "L 3141 1144 \n",
       "Q 3050 572 2676 248 \n",
       "Q 2303 -75 1759 -75 \n",
       "Q 1078 -75 664 370 \n",
       "Q 250 816 250 1647 \n",
       "Q 250 2184 428 2587 \n",
       "Q 606 2991 970 3192 \n",
       "Q 1334 3394 1763 3394 \n",
       "Q 2303 3394 2647 3120 \n",
       "Q 2991 2847 3088 2344 \n",
       "L 2541 2259 \n",
       "Q 2463 2594 2264 2762 \n",
       "Q 2066 2931 1784 2931 \n",
       "Q 1359 2931 1093 2626 \n",
       "Q 828 2322 828 1663 \n",
       "Q 828 994 1084 691 \n",
       "Q 1341 388 1753 388 \n",
       "Q 2084 388 2306 591 \n",
       "Q 2528 794 2588 1216 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#ArialMT-54\"/>\n",
       "      <use xlink:href=\"#ArialMT-72\" x=\"57.333984\"/>\n",
       "      <use xlink:href=\"#ArialMT-75\" x=\"90.634766\"/>\n",
       "      <use xlink:href=\"#ArialMT-65\" x=\"146.25\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" x=\"201.865234\"/>\n",
       "      <use xlink:href=\"#ArialMT-66\" x=\"229.648438\"/>\n",
       "      <use xlink:href=\"#ArialMT-75\" x=\"257.431641\"/>\n",
       "      <use xlink:href=\"#ArialMT-6e\" x=\"313.046875\"/>\n",
       "      <use xlink:href=\"#ArialMT-63\" x=\"368.662109\"/>\n",
       "      <use xlink:href=\"#ArialMT-74\" x=\"418.662109\"/>\n",
       "      <use xlink:href=\"#ArialMT-69\" x=\"446.445312\"/>\n",
       "      <use xlink:href=\"#ArialMT-6f\" x=\"468.662109\"/>\n",
       "      <use xlink:href=\"#ArialMT-6e\" x=\"524.277344\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "  </g>\n",
       "  <g id=\"axes_2\">\n",
       "   <g id=\"matplotlib.axis_3\">\n",
       "    <g id=\"ytick_8\">\n",
       "     <g id=\"line2d_20\">\n",
       "      <defs>\n",
       "       <path id=\"m8eb80a6de0\" d=\"M 0 0 \n",
       "L 4.8 0 \n",
       "\" style=\"stroke: #262626\"/>\n",
       "      </defs>\n",
       "      <g>\n",
       "       <use xlink:href=\"#m8eb80a6de0\" x=\"400.3265\" y=\"274.116\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_22\">\n",
       "      <!-- 0.00 -->\n",
       "      <g style=\"fill: #ff7f0e\" transform=\"translate(408.6265 277.265437) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"83.398438\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"139.013672\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_9\">\n",
       "     <g id=\"line2d_21\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m8eb80a6de0\" x=\"400.3265\" y=\"233.164903\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_23\">\n",
       "      <!-- 0.02 -->\n",
       "      <g style=\"fill: #ff7f0e\" transform=\"translate(408.6265 236.314341) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"83.398438\"/>\n",
       "       <use xlink:href=\"#ArialMT-32\" x=\"139.013672\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_10\">\n",
       "     <g id=\"line2d_22\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m8eb80a6de0\" x=\"400.3265\" y=\"192.213806\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_24\">\n",
       "      <!-- 0.04 -->\n",
       "      <g style=\"fill: #ff7f0e\" transform=\"translate(408.6265 195.363244) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"83.398438\"/>\n",
       "       <use xlink:href=\"#ArialMT-34\" x=\"139.013672\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_11\">\n",
       "     <g id=\"line2d_23\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m8eb80a6de0\" x=\"400.3265\" y=\"151.262709\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_25\">\n",
       "      <!-- 0.06 -->\n",
       "      <g style=\"fill: #ff7f0e\" transform=\"translate(408.6265 154.412147) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"83.398438\"/>\n",
       "       <use xlink:href=\"#ArialMT-36\" x=\"139.013672\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_12\">\n",
       "     <g id=\"line2d_24\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m8eb80a6de0\" x=\"400.3265\" y=\"110.311612\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_26\">\n",
       "      <!-- 0.08 -->\n",
       "      <g style=\"fill: #ff7f0e\" transform=\"translate(408.6265 113.46105) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"83.398438\"/>\n",
       "       <use xlink:href=\"#ArialMT-38\" x=\"139.013672\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_13\">\n",
       "     <g id=\"line2d_25\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m8eb80a6de0\" x=\"400.3265\" y=\"69.360515\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_27\">\n",
       "      <!-- 0.10 -->\n",
       "      <g style=\"fill: #ff7f0e\" transform=\"translate(408.6265 72.509953) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-31\" x=\"83.398438\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"139.013672\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_14\">\n",
       "     <g id=\"line2d_26\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m8eb80a6de0\" x=\"400.3265\" y=\"28.409418\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_28\">\n",
       "      <!-- 0.12 -->\n",
       "      <g style=\"fill: #ff7f0e\" transform=\"translate(408.6265 31.558856) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-31\" x=\"83.398438\"/>\n",
       "       <use xlink:href=\"#ArialMT-32\" x=\"139.013672\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"text_29\">\n",
       "     <!-- Information Acquisition Function -->\n",
       "     <g style=\"fill: #ff7f0e\" transform=\"translate(436.740625 221.18925) rotate(-90) scale(0.096 -0.096)\">\n",
       "      <defs>\n",
       "       <path id=\"ArialMT-49\" d=\"M 597 0 \n",
       "L 597 4581 \n",
       "L 1203 4581 \n",
       "L 1203 0 \n",
       "L 597 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-6d\" d=\"M 422 0 \n",
       "L 422 3319 \n",
       "L 925 3319 \n",
       "L 925 2853 \n",
       "Q 1081 3097 1340 3245 \n",
       "Q 1600 3394 1931 3394 \n",
       "Q 2300 3394 2536 3241 \n",
       "Q 2772 3088 2869 2813 \n",
       "Q 3263 3394 3894 3394 \n",
       "Q 4388 3394 4653 3120 \n",
       "Q 4919 2847 4919 2278 \n",
       "L 4919 0 \n",
       "L 4359 0 \n",
       "L 4359 2091 \n",
       "Q 4359 2428 4304 2576 \n",
       "Q 4250 2725 4106 2815 \n",
       "Q 3963 2906 3769 2906 \n",
       "Q 3419 2906 3187 2673 \n",
       "Q 2956 2441 2956 1928 \n",
       "L 2956 0 \n",
       "L 2394 0 \n",
       "L 2394 2156 \n",
       "Q 2394 2531 2256 2718 \n",
       "Q 2119 2906 1806 2906 \n",
       "Q 1569 2906 1367 2781 \n",
       "Q 1166 2656 1075 2415 \n",
       "Q 984 2175 984 1722 \n",
       "L 984 0 \n",
       "L 422 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-41\" d=\"M -9 0 \n",
       "L 1750 4581 \n",
       "L 2403 4581 \n",
       "L 4278 0 \n",
       "L 3588 0 \n",
       "L 3053 1388 \n",
       "L 1138 1388 \n",
       "L 634 0 \n",
       "L -9 0 \n",
       "z\n",
       "M 1313 1881 \n",
       "L 2866 1881 \n",
       "L 2388 3150 \n",
       "Q 2169 3728 2063 4100 \n",
       "Q 1975 3659 1816 3225 \n",
       "L 1313 1881 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-71\" d=\"M 2538 -1272 \n",
       "L 2538 353 \n",
       "Q 2406 169 2170 47 \n",
       "Q 1934 -75 1669 -75 \n",
       "Q 1078 -75 651 397 \n",
       "Q 225 869 225 1691 \n",
       "Q 225 2191 398 2587 \n",
       "Q 572 2984 901 3189 \n",
       "Q 1231 3394 1625 3394 \n",
       "Q 2241 3394 2594 2875 \n",
       "L 2594 3319 \n",
       "L 3100 3319 \n",
       "L 3100 -1272 \n",
       "L 2538 -1272 \n",
       "z\n",
       "M 803 1669 \n",
       "Q 803 1028 1072 708 \n",
       "Q 1341 388 1716 388 \n",
       "Q 2075 388 2334 692 \n",
       "Q 2594 997 2594 1619 \n",
       "Q 2594 2281 2320 2615 \n",
       "Q 2047 2950 1678 2950 \n",
       "Q 1313 2950 1058 2639 \n",
       "Q 803 2328 803 1669 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-46\" d=\"M 525 0 \n",
       "L 525 4581 \n",
       "L 3616 4581 \n",
       "L 3616 4041 \n",
       "L 1131 4041 \n",
       "L 1131 2622 \n",
       "L 3281 2622 \n",
       "L 3281 2081 \n",
       "L 1131 2081 \n",
       "L 1131 0 \n",
       "L 525 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#ArialMT-49\"/>\n",
       "      <use xlink:href=\"#ArialMT-6e\" x=\"27.783203\"/>\n",
       "      <use xlink:href=\"#ArialMT-66\" x=\"83.398438\"/>\n",
       "      <use xlink:href=\"#ArialMT-6f\" x=\"111.181641\"/>\n",
       "      <use xlink:href=\"#ArialMT-72\" x=\"166.796875\"/>\n",
       "      <use xlink:href=\"#ArialMT-6d\" x=\"200.097656\"/>\n",
       "      <use xlink:href=\"#ArialMT-61\" x=\"283.398438\"/>\n",
       "      <use xlink:href=\"#ArialMT-74\" x=\"339.013672\"/>\n",
       "      <use xlink:href=\"#ArialMT-69\" x=\"366.796875\"/>\n",
       "      <use xlink:href=\"#ArialMT-6f\" x=\"389.013672\"/>\n",
       "      <use xlink:href=\"#ArialMT-6e\" x=\"444.628906\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" x=\"500.244141\"/>\n",
       "      <use xlink:href=\"#ArialMT-41\" x=\"522.527344\"/>\n",
       "      <use xlink:href=\"#ArialMT-63\" x=\"589.226562\"/>\n",
       "      <use xlink:href=\"#ArialMT-71\" x=\"639.226562\"/>\n",
       "      <use xlink:href=\"#ArialMT-75\" x=\"694.841797\"/>\n",
       "      <use xlink:href=\"#ArialMT-69\" x=\"750.457031\"/>\n",
       "      <use xlink:href=\"#ArialMT-73\" x=\"772.673828\"/>\n",
       "      <use xlink:href=\"#ArialMT-69\" x=\"822.673828\"/>\n",
       "      <use xlink:href=\"#ArialMT-74\" x=\"844.890625\"/>\n",
       "      <use xlink:href=\"#ArialMT-69\" x=\"872.673828\"/>\n",
       "      <use xlink:href=\"#ArialMT-6f\" x=\"894.890625\"/>\n",
       "      <use xlink:href=\"#ArialMT-6e\" x=\"950.505859\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" x=\"1006.121094\"/>\n",
       "      <use xlink:href=\"#ArialMT-46\" x=\"1033.904297\"/>\n",
       "      <use xlink:href=\"#ArialMT-75\" x=\"1094.988281\"/>\n",
       "      <use xlink:href=\"#ArialMT-6e\" x=\"1150.603516\"/>\n",
       "      <use xlink:href=\"#ArialMT-63\" x=\"1206.21875\"/>\n",
       "      <use xlink:href=\"#ArialMT-74\" x=\"1256.21875\"/>\n",
       "      <use xlink:href=\"#ArialMT-69\" x=\"1284.001953\"/>\n",
       "      <use xlink:href=\"#ArialMT-6f\" x=\"1306.21875\"/>\n",
       "      <use xlink:href=\"#ArialMT-6e\" x=\"1361.833984\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"line2d_27\">\n",
       "    <path d=\"M 59.439227 274.116 \n",
       "L 62.718566 274.116 \n",
       "L 65.997905 274.116 \n",
       "L 69.277244 274.116 \n",
       "L 72.556583 274.116 \n",
       "L 75.835921 274.116 \n",
       "L 79.115261 274.116 \n",
       "L 82.394598 274.116 \n",
       "L 85.673938 274.116 \n",
       "L 88.953278 274.116 \n",
       "L 92.232615 274.116 \n",
       "L 95.511955 274.116 \n",
       "L 98.791295 274.116 \n",
       "L 102.070632 274.116 \n",
       "L 105.349969 274.116 \n",
       "L 108.629311 274.116 \n",
       "L 111.908649 274.116 \n",
       "L 115.187986 274.116 \n",
       "L 118.467328 274.115878 \n",
       "L 121.746666 274.113071 \n",
       "L 125.026003 273.988525 \n",
       "L 128.305345 270.758881 \n",
       "L 131.584682 242.29162 \n",
       "L 134.86402 158.467071 \n",
       "L 138.143362 61.352869 \n",
       "L 141.422694 32.196 \n",
       "L 144.702037 97.538422 \n",
       "L 147.981379 201.772719 \n",
       "L 151.260711 260.758736 \n",
       "L 154.540053 272.862305 \n",
       "L 157.819395 273.9679 \n",
       "L 161.098728 274.065047 \n",
       "L 164.37807 274.071149 \n",
       "L 167.657412 274.055283 \n",
       "L 170.936745 274.025444 \n",
       "L 174.216087 273.987366 \n",
       "L 177.495429 273.950509 \n",
       "L 180.774762 273.92671 \n",
       "L 184.054104 273.92494 \n",
       "L 187.333446 273.947335 \n",
       "L 190.612778 273.987549 \n",
       "L 193.892121 274.033559 \n",
       "L 197.171463 274.07298 \n",
       "L 200.450795 274.098731 \n",
       "L 203.730137 274.111118 \n",
       "L 207.00948 274.115146 \n",
       "L 210.288812 274.115939 \n",
       "L 213.568154 274.116 \n",
       "L 216.847496 274.116 \n",
       "L 220.126829 274.116 \n",
       "L 223.406181 274.116 \n",
       "L 226.685504 274.116 \n",
       "L 229.964846 274.116 \n",
       "L 233.244188 274.116 \n",
       "L 236.523511 274.116 \n",
       "L 239.802872 274.116 \n",
       "L 243.082195 274.116 \n",
       "L 246.361537 274.116 \n",
       "L 249.640879 274.116 \n",
       "L 252.920222 274.116 \n",
       "L 256.199564 274.116 \n",
       "L 259.478887 274.116 \n",
       "L 262.758248 274.116 \n",
       "L 266.037571 274.116 \n",
       "L 269.316913 274.116 \n",
       "L 272.596255 274.116 \n",
       "L 275.875578 274.116 \n",
       "L 279.15494 274.116 \n",
       "L 282.434262 274.116 \n",
       "L 285.713605 274.116 \n",
       "L 288.992947 274.116 \n",
       "L 292.272289 274.116 \n",
       "L 295.551631 274.116 \n",
       "L 298.830954 274.116 \n",
       "L 302.110315 274.116 \n",
       "L 305.389638 274.116 \n",
       "L 308.66898 274.116 \n",
       "L 311.948322 274.116 \n",
       "L 315.227645 274.116 \n",
       "L 318.507007 274.116 \n",
       "L 321.78633 274.116 \n",
       "L 325.065672 274.116 \n",
       "L 328.345014 274.116 \n",
       "L 331.624356 274.116 \n",
       "L 334.903698 274.116 \n",
       "L 338.183021 274.116 \n",
       "L 341.462363 274.116 \n",
       "L 344.741705 274.116 \n",
       "L 348.021048 274.116 \n",
       "L 351.30039 274.116 \n",
       "L 354.579713 274.116 \n",
       "L 357.859055 274.116 \n",
       "L 361.138397 274.116 \n",
       "L 364.417739 274.116 \n",
       "L 367.697081 274.116 \n",
       "L 370.976423 274.116 \n",
       "L 374.255766 274.116 \n",
       "L 377.535088 274.116 \n",
       "L 380.814431 274.116 \n",
       "L 384.093773 274.116 \n",
       "\" clip-path=\"url(#pcb736d303a)\" style=\"fill: none; stroke: #ff7f0e; stroke-width: 1.2; stroke-linecap: round\"/>\n",
       "   </g>\n",
       "   <g id=\"line2d_28\">\n",
       "    <path d=\"M 141.422694 274.116 \n",
       "L 141.422694 271.672364 \n",
       "L 141.422694 269.228727 \n",
       "L 141.422694 266.785091 \n",
       "L 141.422694 264.341455 \n",
       "L 141.422694 261.897818 \n",
       "L 141.422694 259.454182 \n",
       "L 141.422694 257.010546 \n",
       "L 141.422694 254.566909 \n",
       "L 141.422694 252.123272 \n",
       "L 141.422694 249.679636 \n",
       "L 141.422694 247.236001 \n",
       "L 141.422694 244.792364 \n",
       "L 141.422694 242.348727 \n",
       "L 141.422694 239.905092 \n",
       "L 141.422694 237.461455 \n",
       "L 141.422694 235.017818 \n",
       "L 141.422694 232.574182 \n",
       "L 141.422694 230.130545 \n",
       "L 141.422694 227.686908 \n",
       "L 141.422694 225.243271 \n",
       "L 141.422694 222.799638 \n",
       "L 141.422694 220.356001 \n",
       "L 141.422694 217.912364 \n",
       "L 141.422694 215.468728 \n",
       "L 141.422694 213.025091 \n",
       "L 141.422694 210.581454 \n",
       "L 141.422694 208.137821 \n",
       "L 141.422694 205.694184 \n",
       "L 141.422694 203.250547 \n",
       "L 141.422694 200.80691 \n",
       "L 141.422694 198.363274 \n",
       "L 141.422694 195.919637 \n",
       "L 141.422694 193.476 \n",
       "L 141.422694 191.032363 \n",
       "L 141.422694 188.588726 \n",
       "L 141.422694 186.14509 \n",
       "L 141.422694 183.701453 \n",
       "L 141.422694 181.257816 \n",
       "L 141.422694 178.814179 \n",
       "L 141.422694 176.370542 \n",
       "L 141.422694 173.926913 \n",
       "L 141.422694 171.483276 \n",
       "L 141.422694 169.039639 \n",
       "L 141.422694 166.596003 \n",
       "L 141.422694 164.152366 \n",
       "L 141.422694 161.708729 \n",
       "L 141.422694 159.265092 \n",
       "L 141.422694 156.821455 \n",
       "L 141.422694 154.377818 \n",
       "L 141.422694 151.934182 \n",
       "L 141.422694 149.490545 \n",
       "L 141.422694 147.046908 \n",
       "L 141.422694 144.603263 \n",
       "L 141.422694 142.159642 \n",
       "L 141.422694 139.71599 \n",
       "L 141.422694 137.272368 \n",
       "L 141.422694 134.828716 \n",
       "L 141.422694 132.385095 \n",
       "L 141.422694 129.941458 \n",
       "L 141.422694 127.497821 \n",
       "L 141.422694 125.054184 \n",
       "L 141.422694 122.610547 \n",
       "L 141.422694 120.16691 \n",
       "L 141.422694 117.723274 \n",
       "L 141.422694 115.279637 \n",
       "L 141.422694 112.836 \n",
       "L 141.422694 110.392363 \n",
       "L 141.422694 107.948726 \n",
       "L 141.422694 105.50509 \n",
       "L 141.422694 103.061453 \n",
       "L 141.422694 100.617816 \n",
       "L 141.422694 98.174179 \n",
       "L 141.422694 95.730542 \n",
       "L 141.422694 93.286905 \n",
       "L 141.422694 90.843269 \n",
       "L 141.422694 88.399632 \n",
       "L 141.422694 85.955995 \n",
       "L 141.422694 83.512358 \n",
       "L 141.422694 81.068737 \n",
       "L 141.422694 78.625084 \n",
       "L 141.422694 76.181463 \n",
       "L 141.422694 73.737811 \n",
       "L 141.422694 71.294189 \n",
       "L 141.422694 68.850537 \n",
       "L 141.422694 66.406916 \n",
       "L 141.422694 63.963279 \n",
       "L 141.422694 61.519642 \n",
       "L 141.422694 59.076005 \n",
       "L 141.422694 56.632368 \n",
       "L 141.422694 54.188731 \n",
       "L 141.422694 51.745095 \n",
       "L 141.422694 49.301458 \n",
       "L 141.422694 46.857821 \n",
       "L 141.422694 44.414184 \n",
       "L 141.422694 41.970547 \n",
       "L 141.422694 39.52691 \n",
       "L 141.422694 37.083274 \n",
       "L 141.422694 34.639637 \n",
       "L 141.422694 32.196 \n",
       "\" clip-path=\"url(#pcb736d303a)\" style=\"fill: none; stroke: #ff7f0e; stroke-linecap: round\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_7\">\n",
       "    <path d=\"M 43.2065 286.212 \n",
       "L 43.2065 20.1 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_8\">\n",
       "    <path d=\"M 400.3265 286.212 \n",
       "L 400.3265 20.1 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_9\">\n",
       "    <path d=\"M 43.2065 286.212 \n",
       "L 400.3265 286.212 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_10\">\n",
       "    <path d=\"M 43.2065 20.1 \n",
       "L 400.3265 20.1 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "  </g>\n",
       " </g>\n",
       " <defs>\n",
       "  <clipPath id=\"pcb736d303a\">\n",
       "   <rect x=\"43.2065\" y=\"20.1\" width=\"357.12\" height=\"266.112\"/>\n",
       "  </clipPath>\n",
       " </defs>\n",
       "</svg>\n"
      ],
      "text/plain": [
       "<Figure size 640x480 with 2 Axes>"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "image/svg+xml": [
       "<?xml version=\"1.0\" encoding=\"utf-8\" standalone=\"no\"?>\n",
       "<!DOCTYPE svg PUBLIC \"-//W3C//DTD SVG 1.1//EN\"\n",
       "  \"http://www.w3.org/Graphics/SVG/1.1/DTD/svg11.dtd\">\n",
       "<svg xmlns:xlink=\"http://www.w3.org/1999/xlink\" width=\"445.848625pt\" height=\"322.539375pt\" viewBox=\"0 0 445.848625 322.539375\" xmlns=\"http://www.w3.org/2000/svg\" version=\"1.1\">\n",
       " <metadata>\n",
       "  <rdf:RDF xmlns:dc=\"http://purl.org/dc/elements/1.1/\" xmlns:cc=\"http://creativecommons.org/ns#\" xmlns:rdf=\"http://www.w3.org/1999/02/22-rdf-syntax-ns#\">\n",
       "   <cc:Work>\n",
       "    <dc:type rdf:resource=\"http://purl.org/dc/dcmitype/StillImage\"/>\n",
       "    <dc:date>2023-10-23T15:18:34.403866</dc:date>\n",
       "    <dc:format>image/svg+xml</dc:format>\n",
       "    <dc:creator>\n",
       "     <cc:Agent>\n",
       "      <dc:title>Matplotlib v3.8.0, https://matplotlib.org/</dc:title>\n",
       "     </cc:Agent>\n",
       "    </dc:creator>\n",
       "   </cc:Work>\n",
       "  </rdf:RDF>\n",
       " </metadata>\n",
       " <defs>\n",
       "  <style type=\"text/css\">*{stroke-linejoin: round; stroke-linecap: butt}</style>\n",
       " </defs>\n",
       " <g id=\"figure_1\">\n",
       "  <g id=\"patch_1\">\n",
       "   <path d=\"M 0 322.539375 \n",
       "L 445.848625 322.539375 \n",
       "L 445.848625 0 \n",
       "L 0 0 \n",
       "z\n",
       "\" style=\"fill: #ffffff\"/>\n",
       "  </g>\n",
       "  <g id=\"axes_1\">\n",
       "   <g id=\"patch_2\">\n",
       "    <path d=\"M 43.2065 286.212 \n",
       "L 400.3265 286.212 \n",
       "L 400.3265 20.1 \n",
       "L 43.2065 20.1 \n",
       "z\n",
       "\" style=\"fill: #ffffff\"/>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_1\">\n",
       "    <g id=\"xtick_1\">\n",
       "     <g id=\"line2d_1\">\n",
       "      <defs>\n",
       "       <path id=\"m1de9bb41e9\" d=\"M 0 0 \n",
       "L 0 4.8 \n",
       "\" style=\"stroke: #262626\"/>\n",
       "      </defs>\n",
       "      <g>\n",
       "       <use xlink:href=\"#m1de9bb41e9\" x=\"59.439227\" y=\"286.212\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_1\">\n",
       "      <!-- 0.0 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(53.323227 300.810875) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-30\" d=\"M 266 2259 \n",
       "Q 266 3072 433 3567 \n",
       "Q 600 4063 929 4331 \n",
       "Q 1259 4600 1759 4600 \n",
       "Q 2128 4600 2406 4451 \n",
       "Q 2684 4303 2865 4023 \n",
       "Q 3047 3744 3150 3342 \n",
       "Q 3253 2941 3253 2259 \n",
       "Q 3253 1453 3087 958 \n",
       "Q 2922 463 2592 192 \n",
       "Q 2263 -78 1759 -78 \n",
       "Q 1097 -78 719 397 \n",
       "Q 266 969 266 2259 \n",
       "z\n",
       "M 844 2259 \n",
       "Q 844 1131 1108 757 \n",
       "Q 1372 384 1759 384 \n",
       "Q 2147 384 2411 759 \n",
       "Q 2675 1134 2675 2259 \n",
       "Q 2675 3391 2411 3762 \n",
       "Q 2147 4134 1753 4134 \n",
       "Q 1366 4134 1134 3806 \n",
       "Q 844 3388 844 2259 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "        <path id=\"ArialMT-2e\" d=\"M 581 0 \n",
       "L 581 641 \n",
       "L 1222 641 \n",
       "L 1222 0 \n",
       "L 581 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_2\">\n",
       "     <g id=\"line2d_2\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m1de9bb41e9\" x=\"124.370136\" y=\"286.212\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_2\">\n",
       "      <!-- 0.2 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(118.254136 300.810875) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-32\" d=\"M 3222 541 \n",
       "L 3222 0 \n",
       "L 194 0 \n",
       "Q 188 203 259 391 \n",
       "Q 375 700 629 1000 \n",
       "Q 884 1300 1366 1694 \n",
       "Q 2113 2306 2375 2664 \n",
       "Q 2638 3022 2638 3341 \n",
       "Q 2638 3675 2398 3904 \n",
       "Q 2159 4134 1775 4134 \n",
       "Q 1369 4134 1125 3890 \n",
       "Q 881 3647 878 3216 \n",
       "L 300 3275 \n",
       "Q 359 3922 746 4261 \n",
       "Q 1134 4600 1788 4600 \n",
       "Q 2447 4600 2831 4234 \n",
       "Q 3216 3869 3216 3328 \n",
       "Q 3216 3053 3103 2787 \n",
       "Q 2991 2522 2730 2228 \n",
       "Q 2469 1934 1863 1422 \n",
       "Q 1356 997 1212 845 \n",
       "Q 1069 694 975 541 \n",
       "L 3222 541 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-32\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_3\">\n",
       "     <g id=\"line2d_3\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m1de9bb41e9\" x=\"189.301045\" y=\"286.212\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_3\">\n",
       "      <!-- 0.4 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(183.185045 300.810875) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-34\" d=\"M 2069 0 \n",
       "L 2069 1097 \n",
       "L 81 1097 \n",
       "L 81 1613 \n",
       "L 2172 4581 \n",
       "L 2631 4581 \n",
       "L 2631 1613 \n",
       "L 3250 1613 \n",
       "L 3250 1097 \n",
       "L 2631 1097 \n",
       "L 2631 0 \n",
       "L 2069 0 \n",
       "z\n",
       "M 2069 1613 \n",
       "L 2069 3678 \n",
       "L 634 1613 \n",
       "L 2069 1613 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-34\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_4\">\n",
       "     <g id=\"line2d_4\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m1de9bb41e9\" x=\"254.231955\" y=\"286.212\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_4\">\n",
       "      <!-- 0.6 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(248.115955 300.810875) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-36\" d=\"M 3184 3459 \n",
       "L 2625 3416 \n",
       "Q 2550 3747 2413 3897 \n",
       "Q 2184 4138 1850 4138 \n",
       "Q 1581 4138 1378 3988 \n",
       "Q 1113 3794 959 3422 \n",
       "Q 806 3050 800 2363 \n",
       "Q 1003 2672 1297 2822 \n",
       "Q 1591 2972 1913 2972 \n",
       "Q 2475 2972 2870 2558 \n",
       "Q 3266 2144 3266 1488 \n",
       "Q 3266 1056 3080 686 \n",
       "Q 2894 316 2569 119 \n",
       "Q 2244 -78 1831 -78 \n",
       "Q 1128 -78 684 439 \n",
       "Q 241 956 241 2144 \n",
       "Q 241 3472 731 4075 \n",
       "Q 1159 4600 1884 4600 \n",
       "Q 2425 4600 2770 4297 \n",
       "Q 3116 3994 3184 3459 \n",
       "z\n",
       "M 888 1484 \n",
       "Q 888 1194 1011 928 \n",
       "Q 1134 663 1356 523 \n",
       "Q 1578 384 1822 384 \n",
       "Q 2178 384 2434 671 \n",
       "Q 2691 959 2691 1453 \n",
       "Q 2691 1928 2437 2201 \n",
       "Q 2184 2475 1800 2475 \n",
       "Q 1419 2475 1153 2201 \n",
       "Q 888 1928 888 1484 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-36\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_5\">\n",
       "     <g id=\"line2d_5\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m1de9bb41e9\" x=\"319.162864\" y=\"286.212\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_5\">\n",
       "      <!-- 0.8 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(313.046864 300.810875) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-38\" d=\"M 1131 2484 \n",
       "Q 781 2613 612 2850 \n",
       "Q 444 3088 444 3419 \n",
       "Q 444 3919 803 4259 \n",
       "Q 1163 4600 1759 4600 \n",
       "Q 2359 4600 2725 4251 \n",
       "Q 3091 3903 3091 3403 \n",
       "Q 3091 3084 2923 2848 \n",
       "Q 2756 2613 2416 2484 \n",
       "Q 2838 2347 3058 2040 \n",
       "Q 3278 1734 3278 1309 \n",
       "Q 3278 722 2862 322 \n",
       "Q 2447 -78 1769 -78 \n",
       "Q 1091 -78 675 323 \n",
       "Q 259 725 259 1325 \n",
       "Q 259 1772 486 2073 \n",
       "Q 713 2375 1131 2484 \n",
       "z\n",
       "M 1019 3438 \n",
       "Q 1019 3113 1228 2906 \n",
       "Q 1438 2700 1772 2700 \n",
       "Q 2097 2700 2305 2904 \n",
       "Q 2513 3109 2513 3406 \n",
       "Q 2513 3716 2298 3927 \n",
       "Q 2084 4138 1766 4138 \n",
       "Q 1444 4138 1231 3931 \n",
       "Q 1019 3725 1019 3438 \n",
       "z\n",
       "M 838 1322 \n",
       "Q 838 1081 952 856 \n",
       "Q 1066 631 1291 507 \n",
       "Q 1516 384 1775 384 \n",
       "Q 2178 384 2440 643 \n",
       "Q 2703 903 2703 1303 \n",
       "Q 2703 1709 2433 1975 \n",
       "Q 2163 2241 1756 2241 \n",
       "Q 1359 2241 1098 1978 \n",
       "Q 838 1716 838 1322 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-38\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_6\">\n",
       "     <g id=\"line2d_6\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m1de9bb41e9\" x=\"384.093773\" y=\"286.212\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_6\">\n",
       "      <!-- 1.0 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(377.977773 300.810875) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-31\" d=\"M 2384 0 \n",
       "L 1822 0 \n",
       "L 1822 3584 \n",
       "Q 1619 3391 1289 3197 \n",
       "Q 959 3003 697 2906 \n",
       "L 697 3450 \n",
       "Q 1169 3672 1522 3987 \n",
       "Q 1875 4303 2022 4600 \n",
       "L 2384 4600 \n",
       "L 2384 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-31\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"text_7\">\n",
       "     <!-- $x$ -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(218.8865 313.431375) scale(0.096 -0.096)\">\n",
       "      <defs>\n",
       "       <path id=\"DejaVuSans-Oblique-78\" d=\"M 3841 3500 \n",
       "L 2234 1784 \n",
       "L 3219 0 \n",
       "L 2559 0 \n",
       "L 1819 1388 \n",
       "L 531 0 \n",
       "L -166 0 \n",
       "L 1556 1844 \n",
       "L 641 3500 \n",
       "L 1300 3500 \n",
       "L 1972 2234 \n",
       "L 3144 3500 \n",
       "L 3841 3500 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-78\" transform=\"translate(0 0.3125)\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_2\">\n",
       "    <g id=\"ytick_1\">\n",
       "     <g id=\"line2d_7\">\n",
       "      <defs>\n",
       "       <path id=\"me409b25756\" d=\"M 0 0 \n",
       "L -4.8 0 \n",
       "\" style=\"stroke: #262626\"/>\n",
       "      </defs>\n",
       "      <g>\n",
       "       <use xlink:href=\"#me409b25756\" x=\"43.2065\" y=\"285.947783\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_8\">\n",
       "      <!-- −12 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(19.9795 289.097221) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-2212\" d=\"M 3381 1997 \n",
       "L 356 1997 \n",
       "L 356 2522 \n",
       "L 3381 2522 \n",
       "L 3381 1997 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-31\" x=\"58.398438\"/>\n",
       "       <use xlink:href=\"#ArialMT-32\" x=\"114.013672\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_2\">\n",
       "     <g id=\"line2d_8\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#me409b25756\" x=\"43.2065\" y=\"244.486702\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_9\">\n",
       "      <!-- −10 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(19.9795 247.636139) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-31\" x=\"58.398438\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"114.013672\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_3\">\n",
       "     <g id=\"line2d_9\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#me409b25756\" x=\"43.2065\" y=\"203.025621\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_10\">\n",
       "      <!-- −8 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(24.873125 206.175058) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-38\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_4\">\n",
       "     <g id=\"line2d_10\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#me409b25756\" x=\"43.2065\" y=\"161.564539\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_11\">\n",
       "      <!-- −6 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(24.873125 164.713977) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-36\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_5\">\n",
       "     <g id=\"line2d_11\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#me409b25756\" x=\"43.2065\" y=\"120.103458\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_12\">\n",
       "      <!-- −4 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(24.873125 123.252896) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-34\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_6\">\n",
       "     <g id=\"line2d_12\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#me409b25756\" x=\"43.2065\" y=\"78.642377\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_13\">\n",
       "      <!-- −2 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(24.873125 81.791815) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-32\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_7\">\n",
       "     <g id=\"line2d_13\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#me409b25756\" x=\"43.2065\" y=\"37.181296\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_14\">\n",
       "      <!-- 0 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(30.012875 40.330733) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"text_15\">\n",
       "     <!-- $y$ -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(13.9635 156.036) rotate(-90) scale(0.096 -0.096)\">\n",
       "      <defs>\n",
       "       <path id=\"DejaVuSans-Oblique-79\" d=\"M 1588 -325 \n",
       "Q 1188 -997 936 -1164 \n",
       "Q 684 -1331 294 -1331 \n",
       "L -159 -1331 \n",
       "L -63 -850 \n",
       "L 269 -850 \n",
       "Q 509 -850 678 -719 \n",
       "Q 847 -588 1056 -206 \n",
       "L 1234 128 \n",
       "L 459 3500 \n",
       "L 1069 3500 \n",
       "L 1650 819 \n",
       "L 3256 3500 \n",
       "L 3859 3500 \n",
       "L 1588 -325 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-79\" transform=\"translate(0 0.3125)\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"PolyCollection_1\">\n",
       "    <defs>\n",
       "     <path id=\"m6141016692\" d=\"M 59.439227 -207.477007 \n",
       "L 59.439227 -199.205133 \n",
       "L 62.718566 -201.187627 \n",
       "L 65.997905 -202.736171 \n",
       "L 69.277244 -204.649505 \n",
       "L 72.556583 -207.165656 \n",
       "L 75.835921 -210.320503 \n",
       "L 79.115261 -214.079764 \n",
       "L 82.394598 -218.374946 \n",
       "L 85.673938 -223.118821 \n",
       "L 88.953278 -228.212678 \n",
       "L 92.232615 -233.548241 \n",
       "L 95.511955 -239.01483 \n",
       "L 98.791295 -244.500194 \n",
       "L 102.070632 -249.895262 \n",
       "L 105.349969 -255.09717 \n",
       "L 108.629311 -260.0104 \n",
       "L 111.908649 -264.549735 \n",
       "L 115.187986 -268.643084 \n",
       "L 118.467328 -272.232544 \n",
       "L 121.746666 -275.283316 \n",
       "L 125.026003 -277.783575 \n",
       "L 128.305345 -279.750565 \n",
       "L 131.584682 -281.224361 \n",
       "L 134.86402 -282.253339 \n",
       "L 138.143362 -282.879248 \n",
       "L 141.422694 -283.13413 \n",
       "L 144.702037 -283.029284 \n",
       "L 147.981379 -282.557484 \n",
       "L 151.260711 -281.687781 \n",
       "L 154.540053 -280.377045 \n",
       "L 157.819395 -278.592403 \n",
       "L 161.098728 -276.332184 \n",
       "L 164.37807 -273.617003 \n",
       "L 167.657412 -270.477988 \n",
       "L 170.936745 -266.94838 \n",
       "L 174.216087 -263.062891 \n",
       "L 177.495429 -258.85783 \n",
       "L 180.774762 -254.372981 \n",
       "L 184.054104 -249.651031 \n",
       "L 187.333446 -244.737011 \n",
       "L 190.612778 -239.678367 \n",
       "L 193.892121 -234.522352 \n",
       "L 197.171463 -229.315637 \n",
       "L 200.450795 -224.101903 \n",
       "L 203.730137 -218.921151 \n",
       "L 207.00948 -213.807005 \n",
       "L 210.288812 -208.786742 \n",
       "L 213.568154 -203.879466 \n",
       "L 216.847496 -199.095517 \n",
       "L 220.126829 -194.435892 \n",
       "L 223.406181 -189.891844 \n",
       "L 226.685504 -185.443898 \n",
       "L 229.964846 -181.059099 \n",
       "L 233.244188 -176.681792 \n",
       "L 236.523511 -172.200376 \n",
       "L 239.802872 -167.301403 \n",
       "L 243.082195 -160.909416 \n",
       "L 246.361537 -151.703884 \n",
       "L 249.640879 -140.893864 \n",
       "L 252.920222 -129.629218 \n",
       "L 256.199564 -118.345416 \n",
       "L 259.478887 -107.290818 \n",
       "L 262.758248 -96.668397 \n",
       "L 266.037571 -86.668559 \n",
       "L 269.316913 -77.476096 \n",
       "L 272.596255 -69.271607 \n",
       "L 275.875578 -62.227511 \n",
       "L 279.15494 -56.507285 \n",
       "L 282.434262 -52.258534 \n",
       "L 285.713605 -49.610713 \n",
       "L 288.992947 -48.671333 \n",
       "L 292.272289 -49.51975 \n",
       "L 295.551631 -52.20381 \n",
       "L 298.830954 -56.739822 \n",
       "L 302.110315 -63.103943 \n",
       "L 305.389638 -71.235637 \n",
       "L 308.66898 -81.033681 \n",
       "L 311.948322 -92.356876 \n",
       "L 315.227645 -105.026658 \n",
       "L 318.507007 -118.828283 \n",
       "L 321.78633 -133.51493 \n",
       "L 325.065672 -148.811487 \n",
       "L 328.345014 -164.422331 \n",
       "L 331.624356 -180.032898 \n",
       "L 334.903698 -195.319224 \n",
       "L 338.183021 -209.948167 \n",
       "L 341.462363 -223.580366 \n",
       "L 344.741705 -235.87143 \n",
       "L 348.021048 -246.489383 \n",
       "L 351.30039 -255.207209 \n",
       "L 354.579713 -261.975326 \n",
       "L 357.859055 -266.826511 \n",
       "L 361.138397 -269.784479 \n",
       "L 364.417739 -270.868941 \n",
       "L 367.697081 -270.094108 \n",
       "L 370.976423 -267.510449 \n",
       "L 374.255766 -263.169487 \n",
       "L 377.535088 -257.11412 \n",
       "L 380.814431 -249.352677 \n",
       "L 384.093773 -239.877482 \n",
       "L 384.093773 -248.016946 \n",
       "L 384.093773 -248.016946 \n",
       "L 380.814431 -256.600154 \n",
       "L 377.535088 -264.285077 \n",
       "L 374.255766 -270.638426 \n",
       "L 370.976423 -275.303178 \n",
       "L 367.697081 -278.052092 \n",
       "L 364.417739 -278.757018 \n",
       "L 361.138397 -277.374793 \n",
       "L 357.859055 -273.945252 \n",
       "L 354.579713 -268.599134 \n",
       "L 351.30039 -261.580632 \n",
       "L 348.021048 -253.231569 \n",
       "L 344.741705 -243.877524 \n",
       "L 341.462363 -233.744138 \n",
       "L 338.183021 -223.011247 \n",
       "L 334.903698 -211.872522 \n",
       "L 331.624356 -200.552925 \n",
       "L 328.345014 -189.289644 \n",
       "L 325.065672 -178.311962 \n",
       "L 321.78633 -167.841485 \n",
       "L 318.507007 -158.069735 \n",
       "L 315.227645 -149.163475 \n",
       "L 311.948322 -141.256133 \n",
       "L 308.66898 -134.443585 \n",
       "L 305.389638 -128.78862 \n",
       "L 302.110315 -124.318166 \n",
       "L 298.830954 -121.027646 \n",
       "L 295.551631 -118.880061 \n",
       "L 292.272289 -117.816959 \n",
       "L 288.992947 -117.753575 \n",
       "L 285.713605 -118.593432 \n",
       "L 282.434262 -120.227834 \n",
       "L 279.15494 -122.541291 \n",
       "L 275.875578 -125.418624 \n",
       "L 272.596255 -128.748832 \n",
       "L 269.316913 -132.426769 \n",
       "L 266.037571 -136.360679 \n",
       "L 262.758248 -140.47185 \n",
       "L 259.478887 -144.70003 \n",
       "L 256.199564 -149.007034 \n",
       "L 252.920222 -153.388334 \n",
       "L 249.640879 -157.906622 \n",
       "L 246.361537 -162.835744 \n",
       "L 243.082195 -169.187528 \n",
       "L 239.802872 -178.056245 \n",
       "L 236.523511 -188.029334 \n",
       "L 233.244188 -197.958622 \n",
       "L 229.964846 -207.477581 \n",
       "L 226.685504 -216.437176 \n",
       "L 223.406181 -224.758758 \n",
       "L 220.126829 -232.398313 \n",
       "L 216.847496 -239.33484 \n",
       "L 213.568154 -245.566046 \n",
       "L 210.288812 -251.105138 \n",
       "L 207.00948 -255.97902 \n",
       "L 203.730137 -260.226226 \n",
       "L 200.450795 -263.895004 \n",
       "L 197.171463 -267.040329 \n",
       "L 193.892121 -269.723123 \n",
       "L 190.612778 -272.006387 \n",
       "L 187.333446 -273.953937 \n",
       "L 184.054104 -275.627372 \n",
       "L 180.774762 -277.084652 \n",
       "L 177.495429 -278.377402 \n",
       "L 174.216087 -279.550039 \n",
       "L 170.936745 -280.639194 \n",
       "L 167.657412 -281.672524 \n",
       "L 164.37807 -282.670578 \n",
       "L 161.098728 -283.647232 \n",
       "L 157.819395 -284.608535 \n",
       "L 154.540053 -285.545545 \n",
       "L 151.260711 -286.422785 \n",
       "L 147.981379 -287.170284 \n",
       "L 144.702037 -287.705973 \n",
       "L 141.422694 -287.958907 \n",
       "L 138.143362 -287.883153 \n",
       "L 134.86402 -287.453808 \n",
       "L 131.584682 -286.671047 \n",
       "L 128.305345 -285.551518 \n",
       "L 125.026003 -284.1263 \n",
       "L 121.746666 -282.428509 \n",
       "L 118.467328 -280.479857 \n",
       "L 115.187986 -278.2863 \n",
       "L 111.908649 -275.844269 \n",
       "L 108.629311 -273.141954 \n",
       "L 105.349969 -270.168511 \n",
       "L 102.070632 -266.913921 \n",
       "L 98.791295 -263.372362 \n",
       "L 95.511955 -259.543023 \n",
       "L 92.232615 -255.430068 \n",
       "L 88.953278 -251.04388 \n",
       "L 85.673938 -246.402545 \n",
       "L 82.394598 -241.531347 \n",
       "L 79.115261 -236.465692 \n",
       "L 75.835921 -231.251464 \n",
       "L 72.556583 -225.948142 \n",
       "L 69.277244 -220.642161 \n",
       "L 65.997905 -215.480091 \n",
       "L 62.718566 -210.797637 \n",
       "L 59.439227 -207.477007 \n",
       "z\n",
       "\" style=\"stroke: #1f77b4; stroke-opacity: 0.5; stroke-width: 0.8\"/>\n",
       "    </defs>\n",
       "    <g clip-path=\"url(#p21289cda7f)\">\n",
       "     <use xlink:href=\"#m6141016692\" x=\"0\" y=\"322.539375\" style=\"fill: #1f77b4; fill-opacity: 0.5; stroke: #1f77b4; stroke-opacity: 0.5; stroke-width: 0.8\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"PolyCollection_2\">\n",
       "    <defs>\n",
       "     <path id=\"m8c93e967b1\" d=\"M 59.439227 -199.205133 \n",
       "L 59.439227 -197.484781 \n",
       "L 62.718566 -199.646116 \n",
       "L 65.997905 -201.506016 \n",
       "L 69.277244 -203.638532 \n",
       "L 72.556583 -206.291147 \n",
       "L 75.835921 -209.529142 \n",
       "L 79.115261 -213.336539 \n",
       "L 82.394598 -217.654975 \n",
       "L 85.673938 -222.402557 \n",
       "L 88.953278 -227.483069 \n",
       "L 92.232615 -232.788991 \n",
       "L 95.511955 -238.209062 \n",
       "L 98.791295 -243.629487 \n",
       "L 102.070632 -248.938921 \n",
       "L 105.349969 -254.031879 \n",
       "L 108.629311 -258.810893 \n",
       "L 111.908649 -263.19116 \n",
       "L 115.187986 -267.105595 \n",
       "L 118.467328 -270.508571 \n",
       "L 121.746666 -273.382918 \n",
       "L 125.026003 -275.734999 \n",
       "L 128.305345 -277.591103 \n",
       "L 131.584682 -278.987178 \n",
       "L 134.86402 -279.959553 \n",
       "L 138.143362 -280.538682 \n",
       "L 141.422694 -280.749662 \n",
       "L 144.702037 -280.607579 \n",
       "L 147.981379 -280.119445 \n",
       "L 151.260711 -279.280843 \n",
       "L 154.540053 -278.075749 \n",
       "L 157.819395 -276.478099 \n",
       "L 161.098728 -274.460902 \n",
       "L 164.37807 -272.005223 \n",
       "L 167.657412 -269.109653 \n",
       "L 170.936745 -265.790674 \n",
       "L 174.216087 -262.078966 \n",
       "L 177.495429 -258.01367 \n",
       "L 180.774762 -253.639764 \n",
       "L 184.054104 -249.005317 \n",
       "L 187.333446 -244.16004 \n",
       "L 190.612778 -239.15509 \n",
       "L 193.892121 -234.040602 \n",
       "L 197.171463 -228.865341 \n",
       "L 200.450795 -223.674502 \n",
       "L 203.730137 -218.509086 \n",
       "L 207.00948 -213.403248 \n",
       "L 210.288812 -208.38436 \n",
       "L 213.568154 -203.471098 \n",
       "L 216.847496 -198.672761 \n",
       "L 220.126829 -193.988344 \n",
       "L 223.406181 -189.405606 \n",
       "L 226.685504 -184.898844 \n",
       "L 229.964846 -180.423695 \n",
       "L 233.244188 -175.902412 \n",
       "L 236.523511 -171.180145 \n",
       "L 239.802872 -165.888616 \n",
       "L 243.082195 -159.189973 \n",
       "L 246.361537 -150.329372 \n",
       "L 249.640879 -139.937224 \n",
       "L 252.920222 -128.926477 \n",
       "L 256.199564 -117.794678 \n",
       "L 259.478887 -106.836816 \n",
       "L 262.758248 -96.279399 \n",
       "L 266.037571 -86.325012 \n",
       "L 269.316913 -77.165031 \n",
       "L 272.596255 -68.983971 \n",
       "L 275.875578 -61.956639 \n",
       "L 279.15494 -56.247979 \n",
       "L 282.434262 -52.006563 \n",
       "L 285.713605 -49.362419 \n",
       "L 288.992947 -48.423375 \n",
       "L 292.272289 -49.268966 \n",
       "L 295.551631 -51.946975 \n",
       "L 298.830954 -56.473517 \n",
       "L 302.110315 -62.824392 \n",
       "L 305.389638 -70.938491 \n",
       "L 308.66898 -80.71374 \n",
       "L 311.948322 -92.007833 \n",
       "L 315.227645 -104.640566 \n",
       "L 318.507007 -118.394999 \n",
       "L 321.78633 -133.021238 \n",
       "L 325.065672 -148.239852 \n",
       "L 328.345014 -163.749265 \n",
       "L 331.624356 -179.226838 \n",
       "L 334.903698 -194.33881 \n",
       "L 338.183021 -208.743347 \n",
       "L 341.462363 -222.103612 \n",
       "L 344.741705 -234.111266 \n",
       "L 348.021048 -244.516838 \n",
       "L 351.30039 -253.164642 \n",
       "L 354.579713 -259.980732 \n",
       "L 357.859055 -264.921511 \n",
       "L 361.138397 -267.958832 \n",
       "L 364.417739 -269.090597 \n",
       "L 367.697081 -268.326571 \n",
       "L 370.976423 -265.717185 \n",
       "L 374.255766 -261.323951 \n",
       "L 377.535088 -255.218186 \n",
       "L 380.814431 -247.4699 \n",
       "L 384.093773 -238.137489 \n",
       "L 384.093773 -239.877482 \n",
       "L 384.093773 -239.877482 \n",
       "L 380.814431 -249.352677 \n",
       "L 377.535088 -257.11412 \n",
       "L 374.255766 -263.169487 \n",
       "L 370.976423 -267.510449 \n",
       "L 367.697081 -270.094108 \n",
       "L 364.417739 -270.868941 \n",
       "L 361.138397 -269.784479 \n",
       "L 357.859055 -266.826511 \n",
       "L 354.579713 -261.975326 \n",
       "L 351.30039 -255.207209 \n",
       "L 348.021048 -246.489383 \n",
       "L 344.741705 -235.87143 \n",
       "L 341.462363 -223.580366 \n",
       "L 338.183021 -209.948167 \n",
       "L 334.903698 -195.319224 \n",
       "L 331.624356 -180.032898 \n",
       "L 328.345014 -164.422331 \n",
       "L 325.065672 -148.811487 \n",
       "L 321.78633 -133.51493 \n",
       "L 318.507007 -118.828283 \n",
       "L 315.227645 -105.026658 \n",
       "L 311.948322 -92.356876 \n",
       "L 308.66898 -81.033681 \n",
       "L 305.389638 -71.235637 \n",
       "L 302.110315 -63.103943 \n",
       "L 298.830954 -56.739822 \n",
       "L 295.551631 -52.20381 \n",
       "L 292.272289 -49.51975 \n",
       "L 288.992947 -48.671333 \n",
       "L 285.713605 -49.610713 \n",
       "L 282.434262 -52.258534 \n",
       "L 279.15494 -56.507285 \n",
       "L 275.875578 -62.227511 \n",
       "L 272.596255 -69.271607 \n",
       "L 269.316913 -77.476096 \n",
       "L 266.037571 -86.668559 \n",
       "L 262.758248 -96.668397 \n",
       "L 259.478887 -107.290818 \n",
       "L 256.199564 -118.345416 \n",
       "L 252.920222 -129.629218 \n",
       "L 249.640879 -140.893864 \n",
       "L 246.361537 -151.703884 \n",
       "L 243.082195 -160.909416 \n",
       "L 239.802872 -167.301403 \n",
       "L 236.523511 -172.200376 \n",
       "L 233.244188 -176.681792 \n",
       "L 229.964846 -181.059099 \n",
       "L 226.685504 -185.443898 \n",
       "L 223.406181 -189.891844 \n",
       "L 220.126829 -194.435892 \n",
       "L 216.847496 -199.095517 \n",
       "L 213.568154 -203.879466 \n",
       "L 210.288812 -208.786742 \n",
       "L 207.00948 -213.807005 \n",
       "L 203.730137 -218.921151 \n",
       "L 200.450795 -224.101903 \n",
       "L 197.171463 -229.315637 \n",
       "L 193.892121 -234.522352 \n",
       "L 190.612778 -239.678367 \n",
       "L 187.333446 -244.737011 \n",
       "L 184.054104 -249.651031 \n",
       "L 180.774762 -254.372981 \n",
       "L 177.495429 -258.85783 \n",
       "L 174.216087 -263.062891 \n",
       "L 170.936745 -266.94838 \n",
       "L 167.657412 -270.477988 \n",
       "L 164.37807 -273.617003 \n",
       "L 161.098728 -276.332184 \n",
       "L 157.819395 -278.592403 \n",
       "L 154.540053 -280.377045 \n",
       "L 151.260711 -281.687781 \n",
       "L 147.981379 -282.557484 \n",
       "L 144.702037 -283.029284 \n",
       "L 141.422694 -283.13413 \n",
       "L 138.143362 -282.879248 \n",
       "L 134.86402 -282.253339 \n",
       "L 131.584682 -281.224361 \n",
       "L 128.305345 -279.750565 \n",
       "L 125.026003 -277.783575 \n",
       "L 121.746666 -275.283316 \n",
       "L 118.467328 -272.232544 \n",
       "L 115.187986 -268.643084 \n",
       "L 111.908649 -264.549735 \n",
       "L 108.629311 -260.0104 \n",
       "L 105.349969 -255.09717 \n",
       "L 102.070632 -249.895262 \n",
       "L 98.791295 -244.500194 \n",
       "L 95.511955 -239.01483 \n",
       "L 92.232615 -233.548241 \n",
       "L 88.953278 -228.212678 \n",
       "L 85.673938 -223.118821 \n",
       "L 82.394598 -218.374946 \n",
       "L 79.115261 -214.079764 \n",
       "L 75.835921 -210.320503 \n",
       "L 72.556583 -207.165656 \n",
       "L 69.277244 -204.649505 \n",
       "L 65.997905 -202.736171 \n",
       "L 62.718566 -201.187627 \n",
       "L 59.439227 -199.205133 \n",
       "z\n",
       "\" style=\"stroke: #ff7f0e; stroke-opacity: 0.5; stroke-width: 0.8\"/>\n",
       "    </defs>\n",
       "    <g clip-path=\"url(#p21289cda7f)\">\n",
       "     <use xlink:href=\"#m8c93e967b1\" x=\"0\" y=\"322.539375\" style=\"fill: #ff7f0e; fill-opacity: 0.5; stroke: #ff7f0e; stroke-opacity: 0.5; stroke-width: 0.8\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"PolyCollection_3\">\n",
       "    <defs>\n",
       "     <path id=\"mfa9d8a9168\" d=\"M 59.439227 -209.197364 \n",
       "L 59.439227 -207.477007 \n",
       "L 62.718566 -210.797637 \n",
       "L 65.997905 -215.480091 \n",
       "L 69.277244 -220.642161 \n",
       "L 72.556583 -225.948142 \n",
       "L 75.835921 -231.251464 \n",
       "L 79.115261 -236.465692 \n",
       "L 82.394598 -241.531347 \n",
       "L 85.673938 -246.402545 \n",
       "L 88.953278 -251.04388 \n",
       "L 92.232615 -255.430068 \n",
       "L 95.511955 -259.543023 \n",
       "L 98.791295 -263.372362 \n",
       "L 102.070632 -266.913921 \n",
       "L 105.349969 -270.168511 \n",
       "L 108.629311 -273.141954 \n",
       "L 111.908649 -275.844269 \n",
       "L 115.187986 -278.2863 \n",
       "L 118.467328 -280.479857 \n",
       "L 121.746666 -282.428509 \n",
       "L 125.026003 -284.1263 \n",
       "L 128.305345 -285.551518 \n",
       "L 131.584682 -286.671047 \n",
       "L 134.86402 -287.453808 \n",
       "L 138.143362 -287.883153 \n",
       "L 141.422694 -287.958907 \n",
       "L 144.702037 -287.705973 \n",
       "L 147.981379 -287.170284 \n",
       "L 151.260711 -286.422785 \n",
       "L 154.540053 -285.545545 \n",
       "L 157.819395 -284.608535 \n",
       "L 161.098728 -283.647232 \n",
       "L 164.37807 -282.670578 \n",
       "L 167.657412 -281.672524 \n",
       "L 170.936745 -280.639194 \n",
       "L 174.216087 -279.550039 \n",
       "L 177.495429 -278.377402 \n",
       "L 180.774762 -277.084652 \n",
       "L 184.054104 -275.627372 \n",
       "L 187.333446 -273.953937 \n",
       "L 190.612778 -272.006387 \n",
       "L 193.892121 -269.723123 \n",
       "L 197.171463 -267.040329 \n",
       "L 200.450795 -263.895004 \n",
       "L 203.730137 -260.226226 \n",
       "L 207.00948 -255.97902 \n",
       "L 210.288812 -251.105138 \n",
       "L 213.568154 -245.566046 \n",
       "L 216.847496 -239.33484 \n",
       "L 220.126829 -232.398313 \n",
       "L 223.406181 -224.758758 \n",
       "L 226.685504 -216.437176 \n",
       "L 229.964846 -207.477581 \n",
       "L 233.244188 -197.958622 \n",
       "L 236.523511 -188.029334 \n",
       "L 239.802872 -178.056245 \n",
       "L 243.082195 -169.187528 \n",
       "L 246.361537 -162.835744 \n",
       "L 249.640879 -157.906622 \n",
       "L 252.920222 -153.388334 \n",
       "L 256.199564 -149.007034 \n",
       "L 259.478887 -144.70003 \n",
       "L 262.758248 -140.47185 \n",
       "L 266.037571 -136.360679 \n",
       "L 269.316913 -132.426769 \n",
       "L 272.596255 -128.748832 \n",
       "L 275.875578 -125.418624 \n",
       "L 279.15494 -122.541291 \n",
       "L 282.434262 -120.227834 \n",
       "L 285.713605 -118.593432 \n",
       "L 288.992947 -117.753575 \n",
       "L 292.272289 -117.816959 \n",
       "L 295.551631 -118.880061 \n",
       "L 298.830954 -121.027646 \n",
       "L 302.110315 -124.318166 \n",
       "L 305.389638 -128.78862 \n",
       "L 308.66898 -134.443585 \n",
       "L 311.948322 -141.256133 \n",
       "L 315.227645 -149.163475 \n",
       "L 318.507007 -158.069735 \n",
       "L 321.78633 -167.841485 \n",
       "L 325.065672 -178.311962 \n",
       "L 328.345014 -189.289644 \n",
       "L 331.624356 -200.552925 \n",
       "L 334.903698 -211.872522 \n",
       "L 338.183021 -223.011247 \n",
       "L 341.462363 -233.744138 \n",
       "L 344.741705 -243.877524 \n",
       "L 348.021048 -253.231569 \n",
       "L 351.30039 -261.580632 \n",
       "L 354.579713 -268.599134 \n",
       "L 357.859055 -273.945252 \n",
       "L 361.138397 -277.374793 \n",
       "L 364.417739 -278.757018 \n",
       "L 367.697081 -278.052092 \n",
       "L 370.976423 -275.303178 \n",
       "L 374.255766 -270.638426 \n",
       "L 377.535088 -264.285077 \n",
       "L 380.814431 -256.600154 \n",
       "L 384.093773 -248.016946 \n",
       "L 384.093773 -249.756942 \n",
       "L 384.093773 -249.756942 \n",
       "L 380.814431 -258.482931 \n",
       "L 377.535088 -266.18101 \n",
       "L 374.255766 -272.483962 \n",
       "L 370.976423 -277.096442 \n",
       "L 367.697081 -279.819629 \n",
       "L 364.417739 -280.535361 \n",
       "L 361.138397 -279.20044 \n",
       "L 357.859055 -275.850251 \n",
       "L 354.579713 -270.593728 \n",
       "L 351.30039 -263.623198 \n",
       "L 348.021048 -255.204115 \n",
       "L 344.741705 -245.637686 \n",
       "L 341.462363 -235.220892 \n",
       "L 338.183021 -224.216066 \n",
       "L 334.903698 -212.85293 \n",
       "L 331.624356 -201.358985 \n",
       "L 328.345014 -189.96271 \n",
       "L 325.065672 -178.883597 \n",
       "L 321.78633 -168.335176 \n",
       "L 318.507007 -158.503009 \n",
       "L 315.227645 -149.549577 \n",
       "L 311.948322 -141.605176 \n",
       "L 308.66898 -134.763525 \n",
       "L 305.389638 -129.085776 \n",
       "L 302.110315 -124.597707 \n",
       "L 298.830954 -121.293941 \n",
       "L 295.551631 -119.136895 \n",
       "L 292.272289 -118.067743 \n",
       "L 288.992947 -118.001533 \n",
       "L 285.713605 -118.841726 \n",
       "L 282.434262 -120.479805 \n",
       "L 279.15494 -122.800587 \n",
       "L 275.875578 -125.689505 \n",
       "L 272.596255 -129.036459 \n",
       "L 269.316913 -132.737833 \n",
       "L 266.037571 -136.704236 \n",
       "L 262.758248 -140.860838 \n",
       "L 259.478887 -145.154042 \n",
       "L 256.199564 -149.557782 \n",
       "L 252.920222 -154.091075 \n",
       "L 249.640879 -158.863261 \n",
       "L 246.361537 -164.210256 \n",
       "L 243.082195 -170.906971 \n",
       "L 239.802872 -179.469032 \n",
       "L 236.523511 -189.049565 \n",
       "L 233.244188 -198.738003 \n",
       "L 229.964846 -208.112989 \n",
       "L 226.685504 -216.982235 \n",
       "L 223.406181 -225.245001 \n",
       "L 220.126829 -232.84586 \n",
       "L 216.847496 -239.757596 \n",
       "L 213.568154 -245.974414 \n",
       "L 210.288812 -251.507523 \n",
       "L 207.00948 -256.382776 \n",
       "L 203.730137 -260.638293 \n",
       "L 200.450795 -264.322405 \n",
       "L 197.171463 -267.490629 \n",
       "L 193.892121 -270.204878 \n",
       "L 190.612778 -272.52966 \n",
       "L 187.333446 -274.530909 \n",
       "L 184.054104 -276.273085 \n",
       "L 180.774762 -277.81787 \n",
       "L 177.495429 -279.221561 \n",
       "L 174.216087 -280.533963 \n",
       "L 170.936745 -281.796899 \n",
       "L 167.657412 -283.040859 \n",
       "L 164.37807 -284.282359 \n",
       "L 161.098728 -285.518514 \n",
       "L 157.819395 -286.722839 \n",
       "L 154.540053 -287.846841 \n",
       "L 151.260711 -288.829723 \n",
       "L 147.981379 -289.608322 \n",
       "L 144.702037 -290.127677 \n",
       "L 141.422694 -290.343375 \n",
       "L 138.143362 -290.223718 \n",
       "L 134.86402 -289.747594 \n",
       "L 131.584682 -288.908229 \n",
       "L 128.305345 -287.71098 \n",
       "L 125.026003 -286.174876 \n",
       "L 121.746666 -284.328907 \n",
       "L 118.467328 -282.203829 \n",
       "L 115.187986 -279.823789 \n",
       "L 111.908649 -277.202845 \n",
       "L 108.629311 -274.341461 \n",
       "L 105.349969 -271.233802 \n",
       "L 102.070632 -267.870261 \n",
       "L 98.791295 -264.243068 \n",
       "L 95.511955 -260.348791 \n",
       "L 92.232615 -256.189317 \n",
       "L 88.953278 -251.773489 \n",
       "L 85.673938 -247.118804 \n",
       "L 82.394598 -242.251318 \n",
       "L 79.115261 -237.208918 \n",
       "L 75.835921 -232.042825 \n",
       "L 72.556583 -226.822651 \n",
       "L 69.277244 -221.653134 \n",
       "L 65.997905 -216.710242 \n",
       "L 62.718566 -212.339148 \n",
       "L 59.439227 -209.197364 \n",
       "z\n",
       "\" style=\"stroke: #ff7f0e; stroke-opacity: 0.5; stroke-width: 0.8\"/>\n",
       "    </defs>\n",
       "    <g clip-path=\"url(#p21289cda7f)\">\n",
       "     <use xlink:href=\"#mfa9d8a9168\" x=\"0\" y=\"322.539375\" style=\"fill: #ff7f0e; fill-opacity: 0.5; stroke: #ff7f0e; stroke-opacity: 0.5; stroke-width: 0.8\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"line2d_14\">\n",
       "    <defs>\n",
       "     <path id=\"mb1f2adcf12\" d=\"M -5 5 \n",
       "L 5 -5 \n",
       "M -5 -5 \n",
       "L 5 5 \n",
       "\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "    </defs>\n",
       "    <g clip-path=\"url(#p21289cda7f)\">\n",
       "     <use xlink:href=\"#mb1f2adcf12\" x=\"361.243318\" y=\"42.124312\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     <use xlink:href=\"#mb1f2adcf12\" x=\"162.151989\" y=\"42.978607\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     <use xlink:href=\"#mb1f2adcf12\" x=\"119.149308\" y=\"45.267412\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     <use xlink:href=\"#mb1f2adcf12\" x=\"243.082195\" y=\"157.629344\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     <use xlink:href=\"#mb1f2adcf12\" x=\"147.981379\" y=\"37.621094\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     <use xlink:href=\"#mb1f2adcf12\" x=\"384.093773\" y=\"81.6836\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     <use xlink:href=\"#mb1f2adcf12\" x=\"344.741705\" y=\"86.921438\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     <use xlink:href=\"#mb1f2adcf12\" x=\"59.439227\" y=\"119.49854\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     <use xlink:href=\"#mb1f2adcf12\" x=\"141.422694\" y=\"37.202193\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     <use xlink:href=\"#mb1f2adcf12\" x=\"141.422694\" y=\"37.202193\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"line2d_15\">\n",
       "    <path d=\"M 59.439227 119.198305 \n",
       "L 62.718566 116.546743 \n",
       "L 65.997905 113.431244 \n",
       "L 69.277244 109.893542 \n",
       "L 72.556583 105.982476 \n",
       "L 75.835921 101.753391 \n",
       "L 79.115261 97.266647 \n",
       "L 82.394598 92.586229 \n",
       "L 85.673938 87.778693 \n",
       "L 88.953278 82.911096 \n",
       "L 92.232615 78.050221 \n",
       "L 95.511955 73.260449 \n",
       "L 98.791295 68.603097 \n",
       "L 102.070632 64.134784 \n",
       "L 105.349969 59.906534 \n",
       "L 108.629311 55.963198 \n",
       "L 111.908649 52.342373 \n",
       "L 115.187986 49.074683 \n",
       "L 118.467328 46.183175 \n",
       "L 121.746666 43.683462 \n",
       "L 125.026003 41.584437 \n",
       "L 128.305345 39.888333 \n",
       "L 131.584682 38.591671 \n",
       "L 134.86402 37.685801 \n",
       "L 138.143362 37.158175 \n",
       "L 141.422694 36.992856 \n",
       "L 144.702037 37.171747 \n",
       "L 147.981379 37.675491 \n",
       "L 151.260711 38.484092 \n",
       "L 154.540053 39.57808 \n",
       "L 157.819395 40.938906 \n",
       "L 161.098728 42.549667 \n",
       "L 164.37807 44.395584 \n",
       "L 167.657412 46.464119 \n",
       "L 170.936745 48.745588 \n",
       "L 174.216087 51.23291 \n",
       "L 177.495429 53.921759 \n",
       "L 180.774762 56.810558 \n",
       "L 184.054104 59.900173 \n",
       "L 187.333446 63.193901 \n",
       "L 190.612778 66.697 \n",
       "L 193.892121 70.416636 \n",
       "L 197.171463 74.361391 \n",
       "L 200.450795 78.540921 \n",
       "L 203.730137 82.965686 \n",
       "L 207.00948 87.646362 \n",
       "L 210.288812 92.593435 \n",
       "L 213.568154 97.816619 \n",
       "L 216.847496 103.324197 \n",
       "L 220.126829 109.122273 \n",
       "L 223.406181 115.214074 \n",
       "L 226.685504 121.598836 \n",
       "L 229.964846 128.271035 \n",
       "L 233.244188 135.219168 \n",
       "L 236.523511 142.42452 \n",
       "L 239.802872 149.860551 \n",
       "L 243.082195 157.490903 \n",
       "L 246.361537 165.269561 \n",
       "L 249.640879 173.139132 \n",
       "L 252.920222 181.030599 \n",
       "L 256.199564 188.86315 \n",
       "L 259.478887 196.543946 \n",
       "L 262.758248 203.969252 \n",
       "L 266.037571 211.024756 \n",
       "L 269.316913 217.587943 \n",
       "L 272.596255 223.52916 \n",
       "L 275.875578 228.716303 \n",
       "L 279.15494 233.015092 \n",
       "L 282.434262 236.296191 \n",
       "L 285.713605 238.437302 \n",
       "L 288.992947 239.326921 \n",
       "L 292.272289 238.871021 \n",
       "L 295.551631 236.99744 \n",
       "L 298.830954 233.655646 \n",
       "L 302.110315 228.828321 \n",
       "L 305.389638 222.527247 \n",
       "L 308.66898 214.800742 \n",
       "L 311.948322 205.732871 \n",
       "L 315.227645 195.444309 \n",
       "L 318.507007 184.090371 \n",
       "L 321.78633 171.861168 \n",
       "L 325.065672 158.97765 \n",
       "L 328.345014 145.683388 \n",
       "L 331.624356 132.246464 \n",
       "L 334.903698 118.943502 \n",
       "L 338.183021 106.059668 \n",
       "L 341.462363 93.877123 \n",
       "L 344.741705 82.664898 \n",
       "L 348.021048 72.678899 \n",
       "L 351.30039 64.145455 \n",
       "L 354.579713 57.252145 \n",
       "L 357.859055 52.153494 \n",
       "L 361.138397 48.959739 \n",
       "L 364.417739 47.726396 \n",
       "L 367.697081 48.466275 \n",
       "L 370.976423 51.132561 \n",
       "L 374.255766 55.635418 \n",
       "L 377.535088 61.839777 \n",
       "L 380.814431 69.56296 \n",
       "L 384.093773 78.592161 \n",
       "\" clip-path=\"url(#p21289cda7f)\" style=\"fill: none; stroke: #1f77b4; stroke-width: 2; stroke-linecap: round\"/>\n",
       "   </g>\n",
       "   <g id=\"line2d_16\">\n",
       "    <path d=\"M 59.439227 119.49854 \n",
       "L 62.718566 114.439567 \n",
       "L 65.997905 109.399367 \n",
       "L 69.277244 104.39663 \n",
       "L 72.556583 99.449982 \n",
       "L 75.835921 94.577837 \n",
       "L 79.115261 89.798435 \n",
       "L 82.394598 85.129691 \n",
       "L 85.673938 80.589167 \n",
       "L 88.953278 76.194038 \n",
       "L 92.232615 71.960979 \n",
       "L 95.511955 67.906149 \n",
       "L 98.791295 64.045116 \n",
       "L 102.070632 60.392812 \n",
       "L 105.349969 56.963461 \n",
       "L 108.629311 53.770576 \n",
       "L 111.908649 50.826865 \n",
       "L 115.187986 48.144209 \n",
       "L 118.467328 45.733606 \n",
       "L 121.746666 43.605158 \n",
       "L 125.026003 41.768023 \n",
       "L 128.305345 40.230367 \n",
       "L 131.584682 38.999357 \n",
       "L 134.86402 38.081126 \n",
       "L 138.143362 37.48074 \n",
       "L 141.422694 37.202193 \n",
       "L 144.702037 37.248386 \n",
       "L 147.981379 37.621094 \n",
       "L 151.260711 38.320973 \n",
       "L 154.540053 39.347555 \n",
       "L 157.819395 40.699217 \n",
       "L 161.098728 42.373184 \n",
       "L 164.37807 44.365558 \n",
       "L 167.657412 46.671256 \n",
       "L 170.936745 49.284074 \n",
       "L 174.216087 52.196647 \n",
       "L 177.495429 55.40047 \n",
       "L 180.774762 58.885899 \n",
       "L 184.054104 62.642145 \n",
       "L 187.333446 66.657336 \n",
       "L 190.612778 70.918413 \n",
       "L 193.892121 75.411267 \n",
       "L 197.171463 80.120623 \n",
       "L 200.450795 85.030173 \n",
       "L 203.730137 90.122458 \n",
       "L 207.00948 95.37892 \n",
       "L 210.288812 100.779922 \n",
       "L 213.568154 106.30475 \n",
       "L 216.847496 111.931542 \n",
       "L 220.126829 117.63738 \n",
       "L 223.406181 123.398229 \n",
       "L 226.685504 129.188886 \n",
       "L 229.964846 134.983102 \n",
       "L 233.244188 140.753465 \n",
       "L 236.523511 146.471279 \n",
       "L 239.802872 152.106938 \n",
       "L 243.082195 157.629344 \n",
       "L 246.361537 163.006458 \n",
       "L 249.640879 168.20489 \n",
       "L 252.920222 173.19008 \n",
       "L 256.199564 177.926314 \n",
       "L 259.478887 182.376593 \n",
       "L 262.758248 186.502857 \n",
       "L 266.037571 190.265875 \n",
       "L 269.316913 193.625432 \n",
       "L 272.596255 196.540368 \n",
       "L 275.875578 198.968828 \n",
       "L 279.15494 200.868348 \n",
       "L 282.434262 202.196222 \n",
       "L 285.713605 202.909817 \n",
       "L 288.992947 202.967022 \n",
       "L 292.272289 202.326804 \n",
       "L 295.551631 200.949949 \n",
       "L 298.830954 198.799872 \n",
       "L 302.110315 195.843567 \n",
       "L 305.389638 192.053228 \n",
       "L 308.66898 187.407136 \n",
       "L 311.948322 181.891946 \n",
       "L 315.227645 175.504615 \n",
       "L 318.507007 168.254493 \n",
       "L 321.78633 160.166501 \n",
       "L 325.065672 151.283787 \n",
       "L 328.345014 141.671246 \n",
       "L 331.624356 131.4192 \n",
       "L 334.903698 120.647079 \n",
       "L 338.183021 109.507327 \n",
       "L 341.462363 98.189138 \n",
       "L 344.741705 86.921438 \n",
       "L 348.021048 75.975364 \n",
       "L 351.30039 65.665204 \n",
       "L 354.579713 56.34674 \n",
       "L 357.859055 48.412876 \n",
       "L 361.138397 42.285651 \n",
       "L 364.417739 38.401808 \n",
       "L 367.697081 37.192787 \n",
       "L 370.976423 39.05636 \n",
       "L 374.255766 44.319509 \n",
       "L 377.535088 53.19218 \n",
       "L 380.814431 65.712143 \n",
       "L 384.093773 81.6836 \n",
       "\" clip-path=\"url(#p21289cda7f)\" style=\"fill: none; stroke-dasharray: 7.68,1.92,1.2,1.92; stroke-dashoffset: 0; stroke: #bf00bf; stroke-width: 1.2\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_3\">\n",
       "    <path d=\"M 43.2065 285.947783 \n",
       "L 43.2065 37.181296 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_4\">\n",
       "    <path d=\"M 59.439227 286.212 \n",
       "L 384.093773 286.212 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"text_16\">\n",
       "    <!-- N=6, psi=0.10 -->\n",
       "    <g style=\"fill: #262626\" transform=\"translate(191.87975 14.1) scale(0.096 -0.096)\">\n",
       "     <defs>\n",
       "      <path id=\"ArialMT-4e\" d=\"M 488 0 \n",
       "L 488 4581 \n",
       "L 1109 4581 \n",
       "L 3516 984 \n",
       "L 3516 4581 \n",
       "L 4097 4581 \n",
       "L 4097 0 \n",
       "L 3475 0 \n",
       "L 1069 3600 \n",
       "L 1069 0 \n",
       "L 488 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-3d\" d=\"M 3381 2694 \n",
       "L 356 2694 \n",
       "L 356 3219 \n",
       "L 3381 3219 \n",
       "L 3381 2694 \n",
       "z\n",
       "M 3381 1303 \n",
       "L 356 1303 \n",
       "L 356 1828 \n",
       "L 3381 1828 \n",
       "L 3381 1303 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-2c\" d=\"M 569 0 \n",
       "L 569 641 \n",
       "L 1209 641 \n",
       "L 1209 0 \n",
       "Q 1209 -353 1084 -570 \n",
       "Q 959 -788 688 -906 \n",
       "L 531 -666 \n",
       "Q 709 -588 793 -436 \n",
       "Q 878 -284 888 0 \n",
       "L 569 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-20\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-70\" d=\"M 422 -1272 \n",
       "L 422 3319 \n",
       "L 934 3319 \n",
       "L 934 2888 \n",
       "Q 1116 3141 1344 3267 \n",
       "Q 1572 3394 1897 3394 \n",
       "Q 2322 3394 2647 3175 \n",
       "Q 2972 2956 3137 2557 \n",
       "Q 3303 2159 3303 1684 \n",
       "Q 3303 1175 3120 767 \n",
       "Q 2938 359 2589 142 \n",
       "Q 2241 -75 1856 -75 \n",
       "Q 1575 -75 1351 44 \n",
       "Q 1128 163 984 344 \n",
       "L 984 -1272 \n",
       "L 422 -1272 \n",
       "z\n",
       "M 931 1641 \n",
       "Q 931 1000 1190 694 \n",
       "Q 1450 388 1819 388 \n",
       "Q 2194 388 2461 705 \n",
       "Q 2728 1022 2728 1688 \n",
       "Q 2728 2322 2467 2637 \n",
       "Q 2206 2953 1844 2953 \n",
       "Q 1484 2953 1207 2617 \n",
       "Q 931 2281 931 1641 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-73\" d=\"M 197 991 \n",
       "L 753 1078 \n",
       "Q 800 744 1014 566 \n",
       "Q 1228 388 1613 388 \n",
       "Q 2000 388 2187 545 \n",
       "Q 2375 703 2375 916 \n",
       "Q 2375 1106 2209 1216 \n",
       "Q 2094 1291 1634 1406 \n",
       "Q 1016 1563 777 1677 \n",
       "Q 538 1791 414 1992 \n",
       "Q 291 2194 291 2438 \n",
       "Q 291 2659 392 2848 \n",
       "Q 494 3038 669 3163 \n",
       "Q 800 3259 1026 3326 \n",
       "Q 1253 3394 1513 3394 \n",
       "Q 1903 3394 2198 3281 \n",
       "Q 2494 3169 2634 2976 \n",
       "Q 2775 2784 2828 2463 \n",
       "L 2278 2388 \n",
       "Q 2241 2644 2061 2787 \n",
       "Q 1881 2931 1553 2931 \n",
       "Q 1166 2931 1000 2803 \n",
       "Q 834 2675 834 2503 \n",
       "Q 834 2394 903 2306 \n",
       "Q 972 2216 1119 2156 \n",
       "Q 1203 2125 1616 2013 \n",
       "Q 2213 1853 2448 1751 \n",
       "Q 2684 1650 2818 1456 \n",
       "Q 2953 1263 2953 975 \n",
       "Q 2953 694 2789 445 \n",
       "Q 2625 197 2315 61 \n",
       "Q 2006 -75 1616 -75 \n",
       "Q 969 -75 630 194 \n",
       "Q 291 463 197 991 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-69\" d=\"M 425 3934 \n",
       "L 425 4581 \n",
       "L 988 4581 \n",
       "L 988 3934 \n",
       "L 425 3934 \n",
       "z\n",
       "M 425 0 \n",
       "L 425 3319 \n",
       "L 988 3319 \n",
       "L 988 0 \n",
       "L 425 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "     </defs>\n",
       "     <use xlink:href=\"#ArialMT-4e\"/>\n",
       "     <use xlink:href=\"#ArialMT-3d\" x=\"72.216797\"/>\n",
       "     <use xlink:href=\"#ArialMT-36\" x=\"130.615234\"/>\n",
       "     <use xlink:href=\"#ArialMT-2c\" x=\"186.230469\"/>\n",
       "     <use xlink:href=\"#ArialMT-20\" x=\"214.013672\"/>\n",
       "     <use xlink:href=\"#ArialMT-70\" x=\"241.796875\"/>\n",
       "     <use xlink:href=\"#ArialMT-73\" x=\"297.412109\"/>\n",
       "     <use xlink:href=\"#ArialMT-69\" x=\"347.412109\"/>\n",
       "     <use xlink:href=\"#ArialMT-3d\" x=\"369.628906\"/>\n",
       "     <use xlink:href=\"#ArialMT-30\" x=\"428.027344\"/>\n",
       "     <use xlink:href=\"#ArialMT-2e\" x=\"483.642578\"/>\n",
       "     <use xlink:href=\"#ArialMT-31\" x=\"511.425781\"/>\n",
       "     <use xlink:href=\"#ArialMT-30\" x=\"567.041016\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"legend_1\">\n",
       "    <g id=\"line2d_17\">\n",
       "     <g>\n",
       "      <use xlink:href=\"#mb1f2adcf12\" x=\"59.9265\" y=\"220.007125\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"text_17\">\n",
       "     <!-- Observations -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(75.7665 223.087125) scale(0.088 -0.088)\">\n",
       "      <defs>\n",
       "       <path id=\"ArialMT-4f\" d=\"M 309 2231 \n",
       "Q 309 3372 921 4017 \n",
       "Q 1534 4663 2503 4663 \n",
       "Q 3138 4663 3647 4359 \n",
       "Q 4156 4056 4423 3514 \n",
       "Q 4691 2972 4691 2284 \n",
       "Q 4691 1588 4409 1038 \n",
       "Q 4128 488 3612 205 \n",
       "Q 3097 -78 2500 -78 \n",
       "Q 1853 -78 1343 234 \n",
       "Q 834 547 571 1087 \n",
       "Q 309 1628 309 2231 \n",
       "z\n",
       "M 934 2222 \n",
       "Q 934 1394 1379 917 \n",
       "Q 1825 441 2497 441 \n",
       "Q 3181 441 3623 922 \n",
       "Q 4066 1403 4066 2288 \n",
       "Q 4066 2847 3877 3264 \n",
       "Q 3688 3681 3323 3911 \n",
       "Q 2959 4141 2506 4141 \n",
       "Q 1863 4141 1398 3698 \n",
       "Q 934 3256 934 2222 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-62\" d=\"M 941 0 \n",
       "L 419 0 \n",
       "L 419 4581 \n",
       "L 981 4581 \n",
       "L 981 2947 \n",
       "Q 1338 3394 1891 3394 \n",
       "Q 2197 3394 2470 3270 \n",
       "Q 2744 3147 2920 2923 \n",
       "Q 3097 2700 3197 2384 \n",
       "Q 3297 2069 3297 1709 \n",
       "Q 3297 856 2875 390 \n",
       "Q 2453 -75 1863 -75 \n",
       "Q 1275 -75 941 416 \n",
       "L 941 0 \n",
       "z\n",
       "M 934 1684 \n",
       "Q 934 1088 1097 822 \n",
       "Q 1363 388 1816 388 \n",
       "Q 2184 388 2453 708 \n",
       "Q 2722 1028 2722 1663 \n",
       "Q 2722 2313 2464 2622 \n",
       "Q 2206 2931 1841 2931 \n",
       "Q 1472 2931 1203 2611 \n",
       "Q 934 2291 934 1684 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-65\" d=\"M 2694 1069 \n",
       "L 3275 997 \n",
       "Q 3138 488 2766 206 \n",
       "Q 2394 -75 1816 -75 \n",
       "Q 1088 -75 661 373 \n",
       "Q 234 822 234 1631 \n",
       "Q 234 2469 665 2931 \n",
       "Q 1097 3394 1784 3394 \n",
       "Q 2450 3394 2872 2941 \n",
       "Q 3294 2488 3294 1666 \n",
       "Q 3294 1616 3291 1516 \n",
       "L 816 1516 \n",
       "Q 847 969 1125 678 \n",
       "Q 1403 388 1819 388 \n",
       "Q 2128 388 2347 550 \n",
       "Q 2566 713 2694 1069 \n",
       "z\n",
       "M 847 1978 \n",
       "L 2700 1978 \n",
       "Q 2663 2397 2488 2606 \n",
       "Q 2219 2931 1791 2931 \n",
       "Q 1403 2931 1139 2672 \n",
       "Q 875 2413 847 1978 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-72\" d=\"M 416 0 \n",
       "L 416 3319 \n",
       "L 922 3319 \n",
       "L 922 2816 \n",
       "Q 1116 3169 1280 3281 \n",
       "Q 1444 3394 1641 3394 \n",
       "Q 1925 3394 2219 3213 \n",
       "L 2025 2691 \n",
       "Q 1819 2813 1613 2813 \n",
       "Q 1428 2813 1281 2702 \n",
       "Q 1134 2591 1072 2394 \n",
       "Q 978 2094 978 1738 \n",
       "L 978 0 \n",
       "L 416 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-76\" d=\"M 1344 0 \n",
       "L 81 3319 \n",
       "L 675 3319 \n",
       "L 1388 1331 \n",
       "Q 1503 1009 1600 663 \n",
       "Q 1675 925 1809 1294 \n",
       "L 2547 3319 \n",
       "L 3125 3319 \n",
       "L 1869 0 \n",
       "L 1344 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-61\" d=\"M 2588 409 \n",
       "Q 2275 144 1986 34 \n",
       "Q 1697 -75 1366 -75 \n",
       "Q 819 -75 525 192 \n",
       "Q 231 459 231 875 \n",
       "Q 231 1119 342 1320 \n",
       "Q 453 1522 633 1644 \n",
       "Q 813 1766 1038 1828 \n",
       "Q 1203 1872 1538 1913 \n",
       "Q 2219 1994 2541 2106 \n",
       "Q 2544 2222 2544 2253 \n",
       "Q 2544 2597 2384 2738 \n",
       "Q 2169 2928 1744 2928 \n",
       "Q 1347 2928 1158 2789 \n",
       "Q 969 2650 878 2297 \n",
       "L 328 2372 \n",
       "Q 403 2725 575 2942 \n",
       "Q 747 3159 1072 3276 \n",
       "Q 1397 3394 1825 3394 \n",
       "Q 2250 3394 2515 3294 \n",
       "Q 2781 3194 2906 3042 \n",
       "Q 3031 2891 3081 2659 \n",
       "Q 3109 2516 3109 2141 \n",
       "L 3109 1391 \n",
       "Q 3109 606 3145 398 \n",
       "Q 3181 191 3288 0 \n",
       "L 2700 0 \n",
       "Q 2613 175 2588 409 \n",
       "z\n",
       "M 2541 1666 \n",
       "Q 2234 1541 1622 1453 \n",
       "Q 1275 1403 1131 1340 \n",
       "Q 988 1278 909 1158 \n",
       "Q 831 1038 831 891 \n",
       "Q 831 666 1001 516 \n",
       "Q 1172 366 1500 366 \n",
       "Q 1825 366 2078 508 \n",
       "Q 2331 650 2450 897 \n",
       "Q 2541 1088 2541 1459 \n",
       "L 2541 1666 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-74\" d=\"M 1650 503 \n",
       "L 1731 6 \n",
       "Q 1494 -44 1306 -44 \n",
       "Q 1000 -44 831 53 \n",
       "Q 663 150 594 308 \n",
       "Q 525 466 525 972 \n",
       "L 525 2881 \n",
       "L 113 2881 \n",
       "L 113 3319 \n",
       "L 525 3319 \n",
       "L 525 4141 \n",
       "L 1084 4478 \n",
       "L 1084 3319 \n",
       "L 1650 3319 \n",
       "L 1650 2881 \n",
       "L 1084 2881 \n",
       "L 1084 941 \n",
       "Q 1084 700 1114 631 \n",
       "Q 1144 563 1211 522 \n",
       "Q 1278 481 1403 481 \n",
       "Q 1497 481 1650 503 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-6f\" d=\"M 213 1659 \n",
       "Q 213 2581 725 3025 \n",
       "Q 1153 3394 1769 3394 \n",
       "Q 2453 3394 2887 2945 \n",
       "Q 3322 2497 3322 1706 \n",
       "Q 3322 1066 3130 698 \n",
       "Q 2938 331 2570 128 \n",
       "Q 2203 -75 1769 -75 \n",
       "Q 1072 -75 642 372 \n",
       "Q 213 819 213 1659 \n",
       "z\n",
       "M 791 1659 \n",
       "Q 791 1022 1069 705 \n",
       "Q 1347 388 1769 388 \n",
       "Q 2188 388 2466 706 \n",
       "Q 2744 1025 2744 1678 \n",
       "Q 2744 2294 2464 2611 \n",
       "Q 2184 2928 1769 2928 \n",
       "Q 1347 2928 1069 2612 \n",
       "Q 791 2297 791 1659 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-6e\" d=\"M 422 0 \n",
       "L 422 3319 \n",
       "L 928 3319 \n",
       "L 928 2847 \n",
       "Q 1294 3394 1984 3394 \n",
       "Q 2284 3394 2536 3286 \n",
       "Q 2788 3178 2913 3003 \n",
       "Q 3038 2828 3088 2588 \n",
       "Q 3119 2431 3119 2041 \n",
       "L 3119 0 \n",
       "L 2556 0 \n",
       "L 2556 2019 \n",
       "Q 2556 2363 2490 2533 \n",
       "Q 2425 2703 2258 2804 \n",
       "Q 2091 2906 1866 2906 \n",
       "Q 1506 2906 1245 2678 \n",
       "Q 984 2450 984 1813 \n",
       "L 984 0 \n",
       "L 422 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#ArialMT-4f\"/>\n",
       "      <use xlink:href=\"#ArialMT-62\" x=\"77.783203\"/>\n",
       "      <use xlink:href=\"#ArialMT-73\" x=\"133.398438\"/>\n",
       "      <use xlink:href=\"#ArialMT-65\" x=\"183.398438\"/>\n",
       "      <use xlink:href=\"#ArialMT-72\" x=\"239.013672\"/>\n",
       "      <use xlink:href=\"#ArialMT-76\" x=\"272.314453\"/>\n",
       "      <use xlink:href=\"#ArialMT-61\" x=\"322.314453\"/>\n",
       "      <use xlink:href=\"#ArialMT-74\" x=\"377.929688\"/>\n",
       "      <use xlink:href=\"#ArialMT-69\" x=\"405.712891\"/>\n",
       "      <use xlink:href=\"#ArialMT-6f\" x=\"427.929688\"/>\n",
       "      <use xlink:href=\"#ArialMT-6e\" x=\"483.544922\"/>\n",
       "      <use xlink:href=\"#ArialMT-73\" x=\"539.160156\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"line2d_18\">\n",
       "     <path d=\"M 51.1265 232.591125 \n",
       "L 59.9265 232.591125 \n",
       "L 68.7265 232.591125 \n",
       "\" style=\"fill: none; stroke: #1f77b4; stroke-width: 2; stroke-linecap: round\"/>\n",
       "    </g>\n",
       "    <g id=\"text_18\">\n",
       "     <!-- $m_n(x)$ -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(75.7665 235.671125) scale(0.088 -0.088)\">\n",
       "      <defs>\n",
       "       <path id=\"DejaVuSans-Oblique-6d\" d=\"M 5747 2113 \n",
       "L 5338 0 \n",
       "L 4763 0 \n",
       "L 5166 2094 \n",
       "Q 5191 2228 5203 2325 \n",
       "Q 5216 2422 5216 2491 \n",
       "Q 5216 2772 5059 2928 \n",
       "Q 4903 3084 4622 3084 \n",
       "Q 4203 3084 3875 2770 \n",
       "Q 3547 2456 3450 1953 \n",
       "L 3066 0 \n",
       "L 2491 0 \n",
       "L 2900 2094 \n",
       "Q 2925 2209 2937 2307 \n",
       "Q 2950 2406 2950 2484 \n",
       "Q 2950 2769 2794 2926 \n",
       "Q 2638 3084 2363 3084 \n",
       "Q 1938 3084 1609 2770 \n",
       "Q 1281 2456 1184 1953 \n",
       "L 800 0 \n",
       "L 225 0 \n",
       "L 909 3500 \n",
       "L 1484 3500 \n",
       "L 1375 2956 \n",
       "Q 1609 3263 1923 3423 \n",
       "Q 2238 3584 2597 3584 \n",
       "Q 2978 3584 3223 3384 \n",
       "Q 3469 3184 3519 2828 \n",
       "Q 3781 3197 4126 3390 \n",
       "Q 4472 3584 4856 3584 \n",
       "Q 5306 3584 5551 3325 \n",
       "Q 5797 3066 5797 2591 \n",
       "Q 5797 2488 5784 2364 \n",
       "Q 5772 2241 5747 2113 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-Oblique-6e\" d=\"M 3566 2113 \n",
       "L 3156 0 \n",
       "L 2578 0 \n",
       "L 2988 2091 \n",
       "Q 3016 2238 3031 2350 \n",
       "Q 3047 2463 3047 2528 \n",
       "Q 3047 2791 2881 2937 \n",
       "Q 2716 3084 2419 3084 \n",
       "Q 1956 3084 1622 2776 \n",
       "Q 1288 2469 1184 1941 \n",
       "L 800 0 \n",
       "L 225 0 \n",
       "L 903 3500 \n",
       "L 1478 3500 \n",
       "L 1363 2950 \n",
       "Q 1603 3253 1940 3418 \n",
       "Q 2278 3584 2650 3584 \n",
       "Q 3113 3584 3367 3334 \n",
       "Q 3622 3084 3622 2631 \n",
       "Q 3622 2519 3608 2391 \n",
       "Q 3594 2263 3566 2113 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-28\" d=\"M 1984 4856 \n",
       "Q 1566 4138 1362 3434 \n",
       "Q 1159 2731 1159 2009 \n",
       "Q 1159 1288 1364 580 \n",
       "Q 1569 -128 1984 -844 \n",
       "L 1484 -844 \n",
       "Q 1016 -109 783 600 \n",
       "Q 550 1309 550 2009 \n",
       "Q 550 2706 781 3412 \n",
       "Q 1013 4119 1484 4856 \n",
       "L 1984 4856 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-29\" d=\"M 513 4856 \n",
       "L 1013 4856 \n",
       "Q 1481 4119 1714 3412 \n",
       "Q 1947 2706 1947 2009 \n",
       "Q 1947 1309 1714 600 \n",
       "Q 1481 -109 1013 -844 \n",
       "L 513 -844 \n",
       "Q 928 -128 1133 580 \n",
       "Q 1338 1288 1338 2009 \n",
       "Q 1338 2731 1133 3434 \n",
       "Q 928 4138 513 4856 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-6d\" transform=\"translate(0 0.125)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-6e\" transform=\"translate(97.412109 -16.28125) scale(0.7)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-28\" transform=\"translate(144.511719 0.125)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-78\" transform=\"translate(183.525391 0.125)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-29\" transform=\"translate(242.705078 0.125)\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"patch_5\">\n",
       "     <path d=\"M 51.1265 249.828125 \n",
       "L 68.7265 249.828125 \n",
       "L 68.7265 243.668125 \n",
       "L 51.1265 243.668125 \n",
       "z\n",
       "\" style=\"fill: #1f77b4; fill-opacity: 0.5; stroke: #1f77b4; stroke-opacity: 0.5; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "    </g>\n",
       "    <g id=\"text_19\">\n",
       "     <!-- $f(\\mathbf{x}^*)$ 95% pred. -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(75.7665 249.828125) scale(0.088 -0.088)\">\n",
       "      <defs>\n",
       "       <path id=\"DejaVuSans-Oblique-66\" d=\"M 3059 4863 \n",
       "L 2969 4384 \n",
       "L 2419 4384 \n",
       "Q 2106 4384 1964 4261 \n",
       "Q 1822 4138 1753 3809 \n",
       "L 1691 3500 \n",
       "L 2638 3500 \n",
       "L 2553 3053 \n",
       "L 1606 3053 \n",
       "L 1013 0 \n",
       "L 434 0 \n",
       "L 1031 3053 \n",
       "L 481 3053 \n",
       "L 563 3500 \n",
       "L 1113 3500 \n",
       "L 1159 3744 \n",
       "Q 1278 4363 1576 4613 \n",
       "Q 1875 4863 2516 4863 \n",
       "L 3059 4863 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-Bold-78\" d=\"M 1422 1791 \n",
       "L 159 3500 \n",
       "L 1344 3500 \n",
       "L 2059 2463 \n",
       "L 2784 3500 \n",
       "L 3969 3500 \n",
       "L 2706 1797 \n",
       "L 4031 0 \n",
       "L 2847 0 \n",
       "L 2059 1106 \n",
       "L 1281 0 \n",
       "L 97 0 \n",
       "L 1422 1791 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-2a\" d=\"M 3009 3897 \n",
       "L 1888 3291 \n",
       "L 3009 2681 \n",
       "L 2828 2375 \n",
       "L 1778 3009 \n",
       "L 1778 1831 \n",
       "L 1422 1831 \n",
       "L 1422 3009 \n",
       "L 372 2375 \n",
       "L 191 2681 \n",
       "L 1313 3291 \n",
       "L 191 3897 \n",
       "L 372 4206 \n",
       "L 1422 3572 \n",
       "L 1422 4750 \n",
       "L 1778 4750 \n",
       "L 1778 3572 \n",
       "L 2828 4206 \n",
       "L 3009 3897 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-39\" d=\"M 350 1059 \n",
       "L 891 1109 \n",
       "Q 959 728 1153 556 \n",
       "Q 1347 384 1650 384 \n",
       "Q 1909 384 2104 503 \n",
       "Q 2300 622 2425 820 \n",
       "Q 2550 1019 2634 1356 \n",
       "Q 2719 1694 2719 2044 \n",
       "Q 2719 2081 2716 2156 \n",
       "Q 2547 1888 2255 1720 \n",
       "Q 1963 1553 1622 1553 \n",
       "Q 1053 1553 659 1965 \n",
       "Q 266 2378 266 3053 \n",
       "Q 266 3750 677 4175 \n",
       "Q 1088 4600 1706 4600 \n",
       "Q 2153 4600 2523 4359 \n",
       "Q 2894 4119 3086 3673 \n",
       "Q 3278 3228 3278 2384 \n",
       "Q 3278 1506 3087 986 \n",
       "Q 2897 466 2520 194 \n",
       "Q 2144 -78 1638 -78 \n",
       "Q 1100 -78 759 220 \n",
       "Q 419 519 350 1059 \n",
       "z\n",
       "M 2653 3081 \n",
       "Q 2653 3566 2395 3850 \n",
       "Q 2138 4134 1775 4134 \n",
       "Q 1400 4134 1122 3828 \n",
       "Q 844 3522 844 3034 \n",
       "Q 844 2597 1108 2323 \n",
       "Q 1372 2050 1759 2050 \n",
       "Q 2150 2050 2401 2323 \n",
       "Q 2653 2597 2653 3081 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-35\" d=\"M 266 1200 \n",
       "L 856 1250 \n",
       "Q 922 819 1161 601 \n",
       "Q 1400 384 1738 384 \n",
       "Q 2144 384 2425 690 \n",
       "Q 2706 997 2706 1503 \n",
       "Q 2706 1984 2436 2262 \n",
       "Q 2166 2541 1728 2541 \n",
       "Q 1456 2541 1237 2417 \n",
       "Q 1019 2294 894 2097 \n",
       "L 366 2166 \n",
       "L 809 4519 \n",
       "L 3088 4519 \n",
       "L 3088 3981 \n",
       "L 1259 3981 \n",
       "L 1013 2750 \n",
       "Q 1425 3038 1878 3038 \n",
       "Q 2478 3038 2890 2622 \n",
       "Q 3303 2206 3303 1553 \n",
       "Q 3303 931 2941 478 \n",
       "Q 2500 -78 1738 -78 \n",
       "Q 1113 -78 717 272 \n",
       "Q 322 622 266 1200 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-25\" d=\"M 372 3481 \n",
       "Q 372 3972 619 4315 \n",
       "Q 866 4659 1334 4659 \n",
       "Q 1766 4659 2048 4351 \n",
       "Q 2331 4044 2331 3447 \n",
       "Q 2331 2866 2045 2552 \n",
       "Q 1759 2238 1341 2238 \n",
       "Q 925 2238 648 2547 \n",
       "Q 372 2856 372 3481 \n",
       "z\n",
       "M 1350 4272 \n",
       "Q 1141 4272 1002 4090 \n",
       "Q 863 3909 863 3425 \n",
       "Q 863 2984 1003 2804 \n",
       "Q 1144 2625 1350 2625 \n",
       "Q 1563 2625 1702 2806 \n",
       "Q 1841 2988 1841 3469 \n",
       "Q 1841 3913 1700 4092 \n",
       "Q 1559 4272 1350 4272 \n",
       "z\n",
       "M 1353 -169 \n",
       "L 3859 4659 \n",
       "L 4316 4659 \n",
       "L 1819 -169 \n",
       "L 1353 -169 \n",
       "z\n",
       "M 3334 1075 \n",
       "Q 3334 1569 3581 1911 \n",
       "Q 3828 2253 4300 2253 \n",
       "Q 4731 2253 5014 1945 \n",
       "Q 5297 1638 5297 1041 \n",
       "Q 5297 459 5011 145 \n",
       "Q 4725 -169 4303 -169 \n",
       "Q 3888 -169 3611 142 \n",
       "Q 3334 453 3334 1075 \n",
       "z\n",
       "M 4316 1866 \n",
       "Q 4103 1866 3964 1684 \n",
       "Q 3825 1503 3825 1019 \n",
       "Q 3825 581 3965 400 \n",
       "Q 4106 219 4313 219 \n",
       "Q 4528 219 4667 400 \n",
       "Q 4806 581 4806 1063 \n",
       "Q 4806 1506 4665 1686 \n",
       "Q 4525 1866 4316 1866 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-64\" d=\"M 2575 0 \n",
       "L 2575 419 \n",
       "Q 2259 -75 1647 -75 \n",
       "Q 1250 -75 917 144 \n",
       "Q 584 363 401 755 \n",
       "Q 219 1147 219 1656 \n",
       "Q 219 2153 384 2558 \n",
       "Q 550 2963 881 3178 \n",
       "Q 1213 3394 1622 3394 \n",
       "Q 1922 3394 2156 3267 \n",
       "Q 2391 3141 2538 2938 \n",
       "L 2538 4581 \n",
       "L 3097 4581 \n",
       "L 3097 0 \n",
       "L 2575 0 \n",
       "z\n",
       "M 797 1656 \n",
       "Q 797 1019 1065 703 \n",
       "Q 1334 388 1700 388 \n",
       "Q 2069 388 2326 689 \n",
       "Q 2584 991 2584 1609 \n",
       "Q 2584 2291 2321 2609 \n",
       "Q 2059 2928 1675 2928 \n",
       "Q 1300 2928 1048 2622 \n",
       "Q 797 2316 797 1656 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-66\" transform=\"translate(0 0.765625)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-28\" transform=\"translate(35.205078 0.765625)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-Bold-78\" transform=\"translate(74.21875 0.765625)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-2a\" transform=\"translate(153.31543 39.046875) scale(0.7)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-29\" transform=\"translate(204.6875 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" transform=\"translate(243.701172 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-39\" transform=\"translate(271.484375 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-35\" transform=\"translate(327.099609 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-25\" transform=\"translate(382.714844 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" transform=\"translate(471.630859 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-70\" transform=\"translate(499.414062 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-72\" transform=\"translate(555.029297 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-65\" transform=\"translate(588.330078 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-64\" transform=\"translate(643.945312 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-2e\" transform=\"translate(699.560547 0.765625)\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"patch_6\">\n",
       "     <path d=\"M 51.1265 263.996125 \n",
       "L 68.7265 263.996125 \n",
       "L 68.7265 257.836125 \n",
       "L 51.1265 257.836125 \n",
       "z\n",
       "\" style=\"fill: #ff7f0e; fill-opacity: 0.5; stroke: #ff7f0e; stroke-opacity: 0.5; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "    </g>\n",
       "    <g id=\"text_20\">\n",
       "     <!-- $y^*$ 95% pred. -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(75.7665 263.996125) scale(0.088 -0.088)\">\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-79\" transform=\"translate(0 0.765625)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-2a\" transform=\"translate(77.283529 39.046875) scale(0.7)\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" transform=\"translate(128.655599 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-39\" transform=\"translate(156.438802 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-35\" transform=\"translate(212.054036 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-25\" transform=\"translate(267.669271 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" transform=\"translate(356.585286 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-70\" transform=\"translate(384.36849 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-72\" transform=\"translate(439.983724 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-65\" transform=\"translate(473.284505 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-64\" transform=\"translate(528.89974 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-2e\" transform=\"translate(584.514974 0.765625)\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"line2d_19\">\n",
       "     <path d=\"M 51.1265 273.463 \n",
       "L 59.9265 273.463 \n",
       "L 68.7265 273.463 \n",
       "\" style=\"fill: none; stroke-dasharray: 7.68,1.92,1.2,1.92; stroke-dashoffset: 0; stroke: #bf00bf; stroke-width: 1.2\"/>\n",
       "    </g>\n",
       "    <g id=\"text_21\">\n",
       "     <!-- True function -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(75.7665 276.543) scale(0.088 -0.088)\">\n",
       "      <defs>\n",
       "       <path id=\"ArialMT-54\" d=\"M 1659 0 \n",
       "L 1659 4041 \n",
       "L 150 4041 \n",
       "L 150 4581 \n",
       "L 3781 4581 \n",
       "L 3781 4041 \n",
       "L 2266 4041 \n",
       "L 2266 0 \n",
       "L 1659 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-75\" d=\"M 2597 0 \n",
       "L 2597 488 \n",
       "Q 2209 -75 1544 -75 \n",
       "Q 1250 -75 995 37 \n",
       "Q 741 150 617 320 \n",
       "Q 494 491 444 738 \n",
       "Q 409 903 409 1263 \n",
       "L 409 3319 \n",
       "L 972 3319 \n",
       "L 972 1478 \n",
       "Q 972 1038 1006 884 \n",
       "Q 1059 663 1231 536 \n",
       "Q 1403 409 1656 409 \n",
       "Q 1909 409 2131 539 \n",
       "Q 2353 669 2445 892 \n",
       "Q 2538 1116 2538 1541 \n",
       "L 2538 3319 \n",
       "L 3100 3319 \n",
       "L 3100 0 \n",
       "L 2597 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-66\" d=\"M 556 0 \n",
       "L 556 2881 \n",
       "L 59 2881 \n",
       "L 59 3319 \n",
       "L 556 3319 \n",
       "L 556 3672 \n",
       "Q 556 4006 616 4169 \n",
       "Q 697 4388 901 4523 \n",
       "Q 1106 4659 1475 4659 \n",
       "Q 1713 4659 2000 4603 \n",
       "L 1916 4113 \n",
       "Q 1741 4144 1584 4144 \n",
       "Q 1328 4144 1222 4034 \n",
       "Q 1116 3925 1116 3625 \n",
       "L 1116 3319 \n",
       "L 1763 3319 \n",
       "L 1763 2881 \n",
       "L 1116 2881 \n",
       "L 1116 0 \n",
       "L 556 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-63\" d=\"M 2588 1216 \n",
       "L 3141 1144 \n",
       "Q 3050 572 2676 248 \n",
       "Q 2303 -75 1759 -75 \n",
       "Q 1078 -75 664 370 \n",
       "Q 250 816 250 1647 \n",
       "Q 250 2184 428 2587 \n",
       "Q 606 2991 970 3192 \n",
       "Q 1334 3394 1763 3394 \n",
       "Q 2303 3394 2647 3120 \n",
       "Q 2991 2847 3088 2344 \n",
       "L 2541 2259 \n",
       "Q 2463 2594 2264 2762 \n",
       "Q 2066 2931 1784 2931 \n",
       "Q 1359 2931 1093 2626 \n",
       "Q 828 2322 828 1663 \n",
       "Q 828 994 1084 691 \n",
       "Q 1341 388 1753 388 \n",
       "Q 2084 388 2306 591 \n",
       "Q 2528 794 2588 1216 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#ArialMT-54\"/>\n",
       "      <use xlink:href=\"#ArialMT-72\" x=\"57.333984\"/>\n",
       "      <use xlink:href=\"#ArialMT-75\" x=\"90.634766\"/>\n",
       "      <use xlink:href=\"#ArialMT-65\" x=\"146.25\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" x=\"201.865234\"/>\n",
       "      <use xlink:href=\"#ArialMT-66\" x=\"229.648438\"/>\n",
       "      <use xlink:href=\"#ArialMT-75\" x=\"257.431641\"/>\n",
       "      <use xlink:href=\"#ArialMT-6e\" x=\"313.046875\"/>\n",
       "      <use xlink:href=\"#ArialMT-63\" x=\"368.662109\"/>\n",
       "      <use xlink:href=\"#ArialMT-74\" x=\"418.662109\"/>\n",
       "      <use xlink:href=\"#ArialMT-69\" x=\"446.445312\"/>\n",
       "      <use xlink:href=\"#ArialMT-6f\" x=\"468.662109\"/>\n",
       "      <use xlink:href=\"#ArialMT-6e\" x=\"524.277344\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "  </g>\n",
       "  <g id=\"axes_2\">\n",
       "   <g id=\"matplotlib.axis_3\">\n",
       "    <g id=\"ytick_8\">\n",
       "     <g id=\"line2d_20\">\n",
       "      <defs>\n",
       "       <path id=\"mee53ed21aa\" d=\"M 0 0 \n",
       "L 4.8 0 \n",
       "\" style=\"stroke: #262626\"/>\n",
       "      </defs>\n",
       "      <g>\n",
       "       <use xlink:href=\"#mee53ed21aa\" x=\"400.3265\" y=\"274.116\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_22\">\n",
       "      <!-- 0.00 -->\n",
       "      <g style=\"fill: #ff7f0e\" transform=\"translate(408.6265 277.265437) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"83.398438\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"139.013672\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_9\">\n",
       "     <g id=\"line2d_21\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mee53ed21aa\" x=\"400.3265\" y=\"234.559674\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_23\">\n",
       "      <!-- 0.01 -->\n",
       "      <g style=\"fill: #ff7f0e\" transform=\"translate(408.6265 237.709111) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"83.398438\"/>\n",
       "       <use xlink:href=\"#ArialMT-31\" x=\"139.013672\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_10\">\n",
       "     <g id=\"line2d_22\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mee53ed21aa\" x=\"400.3265\" y=\"195.003348\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_24\">\n",
       "      <!-- 0.02 -->\n",
       "      <g style=\"fill: #ff7f0e\" transform=\"translate(408.6265 198.152785) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"83.398438\"/>\n",
       "       <use xlink:href=\"#ArialMT-32\" x=\"139.013672\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_11\">\n",
       "     <g id=\"line2d_23\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mee53ed21aa\" x=\"400.3265\" y=\"155.447021\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_25\">\n",
       "      <!-- 0.03 -->\n",
       "      <g style=\"fill: #ff7f0e\" transform=\"translate(408.6265 158.596459) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-33\" d=\"M 269 1209 \n",
       "L 831 1284 \n",
       "Q 928 806 1161 595 \n",
       "Q 1394 384 1728 384 \n",
       "Q 2125 384 2398 659 \n",
       "Q 2672 934 2672 1341 \n",
       "Q 2672 1728 2419 1979 \n",
       "Q 2166 2231 1775 2231 \n",
       "Q 1616 2231 1378 2169 \n",
       "L 1441 2663 \n",
       "Q 1497 2656 1531 2656 \n",
       "Q 1891 2656 2178 2843 \n",
       "Q 2466 3031 2466 3422 \n",
       "Q 2466 3731 2256 3934 \n",
       "Q 2047 4138 1716 4138 \n",
       "Q 1388 4138 1169 3931 \n",
       "Q 950 3725 888 3313 \n",
       "L 325 3413 \n",
       "Q 428 3978 793 4289 \n",
       "Q 1159 4600 1703 4600 \n",
       "Q 2078 4600 2393 4439 \n",
       "Q 2709 4278 2876 4000 \n",
       "Q 3044 3722 3044 3409 \n",
       "Q 3044 3113 2884 2869 \n",
       "Q 2725 2625 2413 2481 \n",
       "Q 2819 2388 3044 2092 \n",
       "Q 3269 1797 3269 1353 \n",
       "Q 3269 753 2831 336 \n",
       "Q 2394 -81 1725 -81 \n",
       "Q 1122 -81 723 278 \n",
       "Q 325 638 269 1209 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"83.398438\"/>\n",
       "       <use xlink:href=\"#ArialMT-33\" x=\"139.013672\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_12\">\n",
       "     <g id=\"line2d_24\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mee53ed21aa\" x=\"400.3265\" y=\"115.890695\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_26\">\n",
       "      <!-- 0.04 -->\n",
       "      <g style=\"fill: #ff7f0e\" transform=\"translate(408.6265 119.040133) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"83.398438\"/>\n",
       "       <use xlink:href=\"#ArialMT-34\" x=\"139.013672\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_13\">\n",
       "     <g id=\"line2d_25\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mee53ed21aa\" x=\"400.3265\" y=\"76.334369\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_27\">\n",
       "      <!-- 0.05 -->\n",
       "      <g style=\"fill: #ff7f0e\" transform=\"translate(408.6265 79.483807) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"83.398438\"/>\n",
       "       <use xlink:href=\"#ArialMT-35\" x=\"139.013672\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_14\">\n",
       "     <g id=\"line2d_26\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mee53ed21aa\" x=\"400.3265\" y=\"36.778043\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_28\">\n",
       "      <!-- 0.06 -->\n",
       "      <g style=\"fill: #ff7f0e\" transform=\"translate(408.6265 39.92748) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"83.398438\"/>\n",
       "       <use xlink:href=\"#ArialMT-36\" x=\"139.013672\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"text_29\">\n",
       "     <!-- Information Acquisition Function -->\n",
       "     <g style=\"fill: #ff7f0e\" transform=\"translate(436.740625 221.18925) rotate(-90) scale(0.096 -0.096)\">\n",
       "      <defs>\n",
       "       <path id=\"ArialMT-49\" d=\"M 597 0 \n",
       "L 597 4581 \n",
       "L 1203 4581 \n",
       "L 1203 0 \n",
       "L 597 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-6d\" d=\"M 422 0 \n",
       "L 422 3319 \n",
       "L 925 3319 \n",
       "L 925 2853 \n",
       "Q 1081 3097 1340 3245 \n",
       "Q 1600 3394 1931 3394 \n",
       "Q 2300 3394 2536 3241 \n",
       "Q 2772 3088 2869 2813 \n",
       "Q 3263 3394 3894 3394 \n",
       "Q 4388 3394 4653 3120 \n",
       "Q 4919 2847 4919 2278 \n",
       "L 4919 0 \n",
       "L 4359 0 \n",
       "L 4359 2091 \n",
       "Q 4359 2428 4304 2576 \n",
       "Q 4250 2725 4106 2815 \n",
       "Q 3963 2906 3769 2906 \n",
       "Q 3419 2906 3187 2673 \n",
       "Q 2956 2441 2956 1928 \n",
       "L 2956 0 \n",
       "L 2394 0 \n",
       "L 2394 2156 \n",
       "Q 2394 2531 2256 2718 \n",
       "Q 2119 2906 1806 2906 \n",
       "Q 1569 2906 1367 2781 \n",
       "Q 1166 2656 1075 2415 \n",
       "Q 984 2175 984 1722 \n",
       "L 984 0 \n",
       "L 422 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-41\" d=\"M -9 0 \n",
       "L 1750 4581 \n",
       "L 2403 4581 \n",
       "L 4278 0 \n",
       "L 3588 0 \n",
       "L 3053 1388 \n",
       "L 1138 1388 \n",
       "L 634 0 \n",
       "L -9 0 \n",
       "z\n",
       "M 1313 1881 \n",
       "L 2866 1881 \n",
       "L 2388 3150 \n",
       "Q 2169 3728 2063 4100 \n",
       "Q 1975 3659 1816 3225 \n",
       "L 1313 1881 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-71\" d=\"M 2538 -1272 \n",
       "L 2538 353 \n",
       "Q 2406 169 2170 47 \n",
       "Q 1934 -75 1669 -75 \n",
       "Q 1078 -75 651 397 \n",
       "Q 225 869 225 1691 \n",
       "Q 225 2191 398 2587 \n",
       "Q 572 2984 901 3189 \n",
       "Q 1231 3394 1625 3394 \n",
       "Q 2241 3394 2594 2875 \n",
       "L 2594 3319 \n",
       "L 3100 3319 \n",
       "L 3100 -1272 \n",
       "L 2538 -1272 \n",
       "z\n",
       "M 803 1669 \n",
       "Q 803 1028 1072 708 \n",
       "Q 1341 388 1716 388 \n",
       "Q 2075 388 2334 692 \n",
       "Q 2594 997 2594 1619 \n",
       "Q 2594 2281 2320 2615 \n",
       "Q 2047 2950 1678 2950 \n",
       "Q 1313 2950 1058 2639 \n",
       "Q 803 2328 803 1669 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-46\" d=\"M 525 0 \n",
       "L 525 4581 \n",
       "L 3616 4581 \n",
       "L 3616 4041 \n",
       "L 1131 4041 \n",
       "L 1131 2622 \n",
       "L 3281 2622 \n",
       "L 3281 2081 \n",
       "L 1131 2081 \n",
       "L 1131 0 \n",
       "L 525 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#ArialMT-49\"/>\n",
       "      <use xlink:href=\"#ArialMT-6e\" x=\"27.783203\"/>\n",
       "      <use xlink:href=\"#ArialMT-66\" x=\"83.398438\"/>\n",
       "      <use xlink:href=\"#ArialMT-6f\" x=\"111.181641\"/>\n",
       "      <use xlink:href=\"#ArialMT-72\" x=\"166.796875\"/>\n",
       "      <use xlink:href=\"#ArialMT-6d\" x=\"200.097656\"/>\n",
       "      <use xlink:href=\"#ArialMT-61\" x=\"283.398438\"/>\n",
       "      <use xlink:href=\"#ArialMT-74\" x=\"339.013672\"/>\n",
       "      <use xlink:href=\"#ArialMT-69\" x=\"366.796875\"/>\n",
       "      <use xlink:href=\"#ArialMT-6f\" x=\"389.013672\"/>\n",
       "      <use xlink:href=\"#ArialMT-6e\" x=\"444.628906\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" x=\"500.244141\"/>\n",
       "      <use xlink:href=\"#ArialMT-41\" x=\"522.527344\"/>\n",
       "      <use xlink:href=\"#ArialMT-63\" x=\"589.226562\"/>\n",
       "      <use xlink:href=\"#ArialMT-71\" x=\"639.226562\"/>\n",
       "      <use xlink:href=\"#ArialMT-75\" x=\"694.841797\"/>\n",
       "      <use xlink:href=\"#ArialMT-69\" x=\"750.457031\"/>\n",
       "      <use xlink:href=\"#ArialMT-73\" x=\"772.673828\"/>\n",
       "      <use xlink:href=\"#ArialMT-69\" x=\"822.673828\"/>\n",
       "      <use xlink:href=\"#ArialMT-74\" x=\"844.890625\"/>\n",
       "      <use xlink:href=\"#ArialMT-69\" x=\"872.673828\"/>\n",
       "      <use xlink:href=\"#ArialMT-6f\" x=\"894.890625\"/>\n",
       "      <use xlink:href=\"#ArialMT-6e\" x=\"950.505859\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" x=\"1006.121094\"/>\n",
       "      <use xlink:href=\"#ArialMT-46\" x=\"1033.904297\"/>\n",
       "      <use xlink:href=\"#ArialMT-75\" x=\"1094.988281\"/>\n",
       "      <use xlink:href=\"#ArialMT-6e\" x=\"1150.603516\"/>\n",
       "      <use xlink:href=\"#ArialMT-63\" x=\"1206.21875\"/>\n",
       "      <use xlink:href=\"#ArialMT-74\" x=\"1256.21875\"/>\n",
       "      <use xlink:href=\"#ArialMT-69\" x=\"1284.001953\"/>\n",
       "      <use xlink:href=\"#ArialMT-6f\" x=\"1306.21875\"/>\n",
       "      <use xlink:href=\"#ArialMT-6e\" x=\"1361.833984\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"line2d_27\">\n",
       "    <path d=\"M 59.439227 274.116 \n",
       "L 62.718566 274.116 \n",
       "L 65.997905 274.116 \n",
       "L 69.277244 274.116 \n",
       "L 72.556583 274.116 \n",
       "L 75.835921 274.116 \n",
       "L 79.115261 274.116 \n",
       "L 82.394598 274.116 \n",
       "L 85.673938 274.116 \n",
       "L 88.953278 274.116 \n",
       "L 92.232615 274.116 \n",
       "L 95.511955 274.116 \n",
       "L 98.791295 274.116 \n",
       "L 102.070632 274.116 \n",
       "L 105.349969 274.116 \n",
       "L 108.629311 274.116 \n",
       "L 111.908649 274.116 \n",
       "L 115.187986 274.116 \n",
       "L 118.467328 274.115882 \n",
       "L 121.746666 274.112699 \n",
       "L 125.026003 274.023341 \n",
       "L 128.305345 272.074668 \n",
       "L 131.584682 252.369614 \n",
       "L 134.86402 176.723741 \n",
       "L 138.143362 66.818126 \n",
       "L 141.422694 32.196 \n",
       "L 144.702037 114.649142 \n",
       "L 147.981379 220.242331 \n",
       "L 151.260711 265.028678 \n",
       "L 154.540053 272.978508 \n",
       "L 157.819395 273.894254 \n",
       "L 161.098728 274.017918 \n",
       "L 164.37807 274.032064 \n",
       "L 167.657412 274.014735 \n",
       "L 170.936745 273.978662 \n",
       "L 174.216087 273.931035 \n",
       "L 177.495429 273.883291 \n",
       "L 180.774762 273.850401 \n",
       "L 184.054104 273.845921 \n",
       "L 187.333446 273.874803 \n",
       "L 190.612778 273.930328 \n",
       "L 193.892121 273.995755 \n",
       "L 197.171463 274.05293 \n",
       "L 200.450795 274.090654 \n",
       "L 203.730137 274.108809 \n",
       "L 207.00948 274.114703 \n",
       "L 210.288812 274.115882 \n",
       "L 213.568154 274.116 \n",
       "L 216.847496 274.116 \n",
       "L 220.126829 274.116 \n",
       "L 223.406181 274.116 \n",
       "L 226.685504 274.116 \n",
       "L 229.964846 274.116 \n",
       "L 233.244188 274.116 \n",
       "L 236.523511 274.116 \n",
       "L 239.802872 274.116 \n",
       "L 243.082195 274.116 \n",
       "L 246.361537 274.116 \n",
       "L 249.640879 274.116 \n",
       "L 252.920222 274.116 \n",
       "L 256.199564 274.116 \n",
       "L 259.478887 274.116 \n",
       "L 262.758248 274.116 \n",
       "L 266.037571 274.116 \n",
       "L 269.316913 274.116 \n",
       "L 272.596255 274.116 \n",
       "L 275.875578 274.116 \n",
       "L 279.15494 274.116 \n",
       "L 282.434262 274.116 \n",
       "L 285.713605 274.116 \n",
       "L 288.992947 274.116 \n",
       "L 292.272289 274.116 \n",
       "L 295.551631 274.116 \n",
       "L 298.830954 274.116 \n",
       "L 302.110315 274.116 \n",
       "L 305.389638 274.116 \n",
       "L 308.66898 274.116 \n",
       "L 311.948322 274.116 \n",
       "L 315.227645 274.116 \n",
       "L 318.507007 274.116 \n",
       "L 321.78633 274.116 \n",
       "L 325.065672 274.116 \n",
       "L 328.345014 274.116 \n",
       "L 331.624356 274.116 \n",
       "L 334.903698 274.116 \n",
       "L 338.183021 274.116 \n",
       "L 341.462363 274.116 \n",
       "L 344.741705 274.116 \n",
       "L 348.021048 274.116 \n",
       "L 351.30039 274.116 \n",
       "L 354.579713 274.116 \n",
       "L 357.859055 274.116 \n",
       "L 361.138397 274.116 \n",
       "L 364.417739 274.116 \n",
       "L 367.697081 274.116 \n",
       "L 370.976423 274.116 \n",
       "L 374.255766 274.116 \n",
       "L 377.535088 274.116 \n",
       "L 380.814431 274.116 \n",
       "L 384.093773 274.116 \n",
       "\" clip-path=\"url(#p21289cda7f)\" style=\"fill: none; stroke: #ff7f0e; stroke-width: 1.2; stroke-linecap: round\"/>\n",
       "   </g>\n",
       "   <g id=\"line2d_28\">\n",
       "    <path d=\"M 141.422694 274.116 \n",
       "L 141.422694 271.672364 \n",
       "L 141.422694 269.228727 \n",
       "L 141.422694 266.78509 \n",
       "L 141.422694 264.341454 \n",
       "L 141.422694 261.897818 \n",
       "L 141.422694 259.454181 \n",
       "L 141.422694 257.010545 \n",
       "L 141.422694 254.566908 \n",
       "L 141.422694 252.123272 \n",
       "L 141.422694 249.679636 \n",
       "L 141.422694 247.236 \n",
       "L 141.422694 244.792362 \n",
       "L 141.422694 242.348726 \n",
       "L 141.422694 239.905089 \n",
       "L 141.422694 237.461453 \n",
       "L 141.422694 235.017817 \n",
       "L 141.422694 232.574181 \n",
       "L 141.422694 230.130544 \n",
       "L 141.422694 227.686908 \n",
       "L 141.422694 225.243272 \n",
       "L 141.422694 222.799636 \n",
       "L 141.422694 220.356 \n",
       "L 141.422694 217.912363 \n",
       "L 141.422694 215.468723 \n",
       "L 141.422694 213.025087 \n",
       "L 141.422694 210.581451 \n",
       "L 141.422694 208.137815 \n",
       "L 141.422694 205.694179 \n",
       "L 141.422694 203.250542 \n",
       "L 141.422694 200.806906 \n",
       "L 141.422694 198.36327 \n",
       "L 141.422694 195.919634 \n",
       "L 141.422694 193.475998 \n",
       "L 141.422694 191.032361 \n",
       "L 141.422694 188.588725 \n",
       "L 141.422694 186.145089 \n",
       "L 141.422694 183.701453 \n",
       "L 141.422694 181.257816 \n",
       "L 141.422694 178.81418 \n",
       "L 141.422694 176.370544 \n",
       "L 141.422694 173.926908 \n",
       "L 141.422694 171.483272 \n",
       "L 141.422694 169.039635 \n",
       "L 141.422694 166.595999 \n",
       "L 141.422694 164.152363 \n",
       "L 141.422694 161.708727 \n",
       "L 141.422694 159.265091 \n",
       "L 141.422694 156.821447 \n",
       "L 141.422694 154.377811 \n",
       "L 141.422694 151.934189 \n",
       "L 141.422694 149.490553 \n",
       "L 141.422694 147.046917 \n",
       "L 141.422694 144.603266 \n",
       "L 141.422694 142.159644 \n",
       "L 141.422694 139.715993 \n",
       "L 141.422694 137.272372 \n",
       "L 141.422694 134.828721 \n",
       "L 141.422694 132.3851 \n",
       "L 141.422694 129.941449 \n",
       "L 141.422694 127.497827 \n",
       "L 141.422694 125.054176 \n",
       "L 141.422694 122.610555 \n",
       "L 141.422694 120.166904 \n",
       "L 141.422694 117.723282 \n",
       "L 141.422694 115.279631 \n",
       "L 141.422694 112.83601 \n",
       "L 141.422694 110.392359 \n",
       "L 141.422694 107.948737 \n",
       "L 141.422694 105.505086 \n",
       "L 141.422694 103.061465 \n",
       "L 141.422694 100.617814 \n",
       "L 141.422694 98.174193 \n",
       "L 141.422694 95.730542 \n",
       "L 141.422694 93.28692 \n",
       "L 141.422694 90.843269 \n",
       "L 141.422694 88.399633 \n",
       "L 141.422694 85.955997 \n",
       "L 141.422694 83.512361 \n",
       "L 141.422694 81.068724 \n",
       "L 141.422694 78.625088 \n",
       "L 141.422694 76.181452 \n",
       "L 141.422694 73.737816 \n",
       "L 141.422694 71.294179 \n",
       "L 141.422694 68.850543 \n",
       "L 141.422694 66.406907 \n",
       "L 141.422694 63.963271 \n",
       "L 141.422694 61.519635 \n",
       "L 141.422694 59.075998 \n",
       "L 141.422694 56.632362 \n",
       "L 141.422694 54.188726 \n",
       "L 141.422694 51.74509 \n",
       "L 141.422694 49.301454 \n",
       "L 141.422694 46.857817 \n",
       "L 141.422694 44.414181 \n",
       "L 141.422694 41.970545 \n",
       "L 141.422694 39.526909 \n",
       "L 141.422694 37.083272 \n",
       "L 141.422694 34.639636 \n",
       "L 141.422694 32.196 \n",
       "\" clip-path=\"url(#p21289cda7f)\" style=\"fill: none; stroke: #ff7f0e; stroke-linecap: round\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_7\">\n",
       "    <path d=\"M 43.2065 286.212 \n",
       "L 43.2065 20.1 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_8\">\n",
       "    <path d=\"M 400.3265 286.212 \n",
       "L 400.3265 20.1 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_9\">\n",
       "    <path d=\"M 43.2065 286.212 \n",
       "L 400.3265 286.212 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_10\">\n",
       "    <path d=\"M 43.2065 20.1 \n",
       "L 400.3265 20.1 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "  </g>\n",
       " </g>\n",
       " <defs>\n",
       "  <clipPath id=\"p21289cda7f\">\n",
       "   <rect x=\"43.2065\" y=\"20.1\" width=\"357.12\" height=\"266.112\"/>\n",
       "  </clipPath>\n",
       " </defs>\n",
       "</svg>\n"
      ],
      "text/plain": [
       "<Figure size 640x480 with 2 Axes>"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "image/svg+xml": [
       "<?xml version=\"1.0\" encoding=\"utf-8\" standalone=\"no\"?>\n",
       "<!DOCTYPE svg PUBLIC \"-//W3C//DTD SVG 1.1//EN\"\n",
       "  \"http://www.w3.org/Graphics/SVG/1.1/DTD/svg11.dtd\">\n",
       "<svg xmlns:xlink=\"http://www.w3.org/1999/xlink\" width=\"450.74225pt\" height=\"322.539375pt\" viewBox=\"0 0 450.74225 322.539375\" xmlns=\"http://www.w3.org/2000/svg\" version=\"1.1\">\n",
       " <metadata>\n",
       "  <rdf:RDF xmlns:dc=\"http://purl.org/dc/elements/1.1/\" xmlns:cc=\"http://creativecommons.org/ns#\" xmlns:rdf=\"http://www.w3.org/1999/02/22-rdf-syntax-ns#\">\n",
       "   <cc:Work>\n",
       "    <dc:type rdf:resource=\"http://purl.org/dc/dcmitype/StillImage\"/>\n",
       "    <dc:date>2023-10-23T15:18:34.484680</dc:date>\n",
       "    <dc:format>image/svg+xml</dc:format>\n",
       "    <dc:creator>\n",
       "     <cc:Agent>\n",
       "      <dc:title>Matplotlib v3.8.0, https://matplotlib.org/</dc:title>\n",
       "     </cc:Agent>\n",
       "    </dc:creator>\n",
       "   </cc:Work>\n",
       "  </rdf:RDF>\n",
       " </metadata>\n",
       " <defs>\n",
       "  <style type=\"text/css\">*{stroke-linejoin: round; stroke-linecap: butt}</style>\n",
       " </defs>\n",
       " <g id=\"figure_1\">\n",
       "  <g id=\"patch_1\">\n",
       "   <path d=\"M 0 322.539375 \n",
       "L 450.74225 322.539375 \n",
       "L 450.74225 0 \n",
       "L 0 0 \n",
       "z\n",
       "\" style=\"fill: #ffffff\"/>\n",
       "  </g>\n",
       "  <g id=\"axes_1\">\n",
       "   <g id=\"patch_2\">\n",
       "    <path d=\"M 43.2065 286.212 \n",
       "L 400.3265 286.212 \n",
       "L 400.3265 20.1 \n",
       "L 43.2065 20.1 \n",
       "z\n",
       "\" style=\"fill: #ffffff\"/>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_1\">\n",
       "    <g id=\"xtick_1\">\n",
       "     <g id=\"line2d_1\">\n",
       "      <defs>\n",
       "       <path id=\"m9b1a6528eb\" d=\"M 0 0 \n",
       "L 0 4.8 \n",
       "\" style=\"stroke: #262626\"/>\n",
       "      </defs>\n",
       "      <g>\n",
       "       <use xlink:href=\"#m9b1a6528eb\" x=\"59.439227\" y=\"286.212\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_1\">\n",
       "      <!-- 0.0 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(53.323227 300.810875) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-30\" d=\"M 266 2259 \n",
       "Q 266 3072 433 3567 \n",
       "Q 600 4063 929 4331 \n",
       "Q 1259 4600 1759 4600 \n",
       "Q 2128 4600 2406 4451 \n",
       "Q 2684 4303 2865 4023 \n",
       "Q 3047 3744 3150 3342 \n",
       "Q 3253 2941 3253 2259 \n",
       "Q 3253 1453 3087 958 \n",
       "Q 2922 463 2592 192 \n",
       "Q 2263 -78 1759 -78 \n",
       "Q 1097 -78 719 397 \n",
       "Q 266 969 266 2259 \n",
       "z\n",
       "M 844 2259 \n",
       "Q 844 1131 1108 757 \n",
       "Q 1372 384 1759 384 \n",
       "Q 2147 384 2411 759 \n",
       "Q 2675 1134 2675 2259 \n",
       "Q 2675 3391 2411 3762 \n",
       "Q 2147 4134 1753 4134 \n",
       "Q 1366 4134 1134 3806 \n",
       "Q 844 3388 844 2259 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "        <path id=\"ArialMT-2e\" d=\"M 581 0 \n",
       "L 581 641 \n",
       "L 1222 641 \n",
       "L 1222 0 \n",
       "L 581 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_2\">\n",
       "     <g id=\"line2d_2\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m9b1a6528eb\" x=\"124.370136\" y=\"286.212\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_2\">\n",
       "      <!-- 0.2 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(118.254136 300.810875) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-32\" d=\"M 3222 541 \n",
       "L 3222 0 \n",
       "L 194 0 \n",
       "Q 188 203 259 391 \n",
       "Q 375 700 629 1000 \n",
       "Q 884 1300 1366 1694 \n",
       "Q 2113 2306 2375 2664 \n",
       "Q 2638 3022 2638 3341 \n",
       "Q 2638 3675 2398 3904 \n",
       "Q 2159 4134 1775 4134 \n",
       "Q 1369 4134 1125 3890 \n",
       "Q 881 3647 878 3216 \n",
       "L 300 3275 \n",
       "Q 359 3922 746 4261 \n",
       "Q 1134 4600 1788 4600 \n",
       "Q 2447 4600 2831 4234 \n",
       "Q 3216 3869 3216 3328 \n",
       "Q 3216 3053 3103 2787 \n",
       "Q 2991 2522 2730 2228 \n",
       "Q 2469 1934 1863 1422 \n",
       "Q 1356 997 1212 845 \n",
       "Q 1069 694 975 541 \n",
       "L 3222 541 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-32\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_3\">\n",
       "     <g id=\"line2d_3\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m9b1a6528eb\" x=\"189.301045\" y=\"286.212\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_3\">\n",
       "      <!-- 0.4 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(183.185045 300.810875) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-34\" d=\"M 2069 0 \n",
       "L 2069 1097 \n",
       "L 81 1097 \n",
       "L 81 1613 \n",
       "L 2172 4581 \n",
       "L 2631 4581 \n",
       "L 2631 1613 \n",
       "L 3250 1613 \n",
       "L 3250 1097 \n",
       "L 2631 1097 \n",
       "L 2631 0 \n",
       "L 2069 0 \n",
       "z\n",
       "M 2069 1613 \n",
       "L 2069 3678 \n",
       "L 634 1613 \n",
       "L 2069 1613 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-34\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_4\">\n",
       "     <g id=\"line2d_4\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m9b1a6528eb\" x=\"254.231955\" y=\"286.212\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_4\">\n",
       "      <!-- 0.6 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(248.115955 300.810875) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-36\" d=\"M 3184 3459 \n",
       "L 2625 3416 \n",
       "Q 2550 3747 2413 3897 \n",
       "Q 2184 4138 1850 4138 \n",
       "Q 1581 4138 1378 3988 \n",
       "Q 1113 3794 959 3422 \n",
       "Q 806 3050 800 2363 \n",
       "Q 1003 2672 1297 2822 \n",
       "Q 1591 2972 1913 2972 \n",
       "Q 2475 2972 2870 2558 \n",
       "Q 3266 2144 3266 1488 \n",
       "Q 3266 1056 3080 686 \n",
       "Q 2894 316 2569 119 \n",
       "Q 2244 -78 1831 -78 \n",
       "Q 1128 -78 684 439 \n",
       "Q 241 956 241 2144 \n",
       "Q 241 3472 731 4075 \n",
       "Q 1159 4600 1884 4600 \n",
       "Q 2425 4600 2770 4297 \n",
       "Q 3116 3994 3184 3459 \n",
       "z\n",
       "M 888 1484 \n",
       "Q 888 1194 1011 928 \n",
       "Q 1134 663 1356 523 \n",
       "Q 1578 384 1822 384 \n",
       "Q 2178 384 2434 671 \n",
       "Q 2691 959 2691 1453 \n",
       "Q 2691 1928 2437 2201 \n",
       "Q 2184 2475 1800 2475 \n",
       "Q 1419 2475 1153 2201 \n",
       "Q 888 1928 888 1484 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-36\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_5\">\n",
       "     <g id=\"line2d_5\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m9b1a6528eb\" x=\"319.162864\" y=\"286.212\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_5\">\n",
       "      <!-- 0.8 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(313.046864 300.810875) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-38\" d=\"M 1131 2484 \n",
       "Q 781 2613 612 2850 \n",
       "Q 444 3088 444 3419 \n",
       "Q 444 3919 803 4259 \n",
       "Q 1163 4600 1759 4600 \n",
       "Q 2359 4600 2725 4251 \n",
       "Q 3091 3903 3091 3403 \n",
       "Q 3091 3084 2923 2848 \n",
       "Q 2756 2613 2416 2484 \n",
       "Q 2838 2347 3058 2040 \n",
       "Q 3278 1734 3278 1309 \n",
       "Q 3278 722 2862 322 \n",
       "Q 2447 -78 1769 -78 \n",
       "Q 1091 -78 675 323 \n",
       "Q 259 725 259 1325 \n",
       "Q 259 1772 486 2073 \n",
       "Q 713 2375 1131 2484 \n",
       "z\n",
       "M 1019 3438 \n",
       "Q 1019 3113 1228 2906 \n",
       "Q 1438 2700 1772 2700 \n",
       "Q 2097 2700 2305 2904 \n",
       "Q 2513 3109 2513 3406 \n",
       "Q 2513 3716 2298 3927 \n",
       "Q 2084 4138 1766 4138 \n",
       "Q 1444 4138 1231 3931 \n",
       "Q 1019 3725 1019 3438 \n",
       "z\n",
       "M 838 1322 \n",
       "Q 838 1081 952 856 \n",
       "Q 1066 631 1291 507 \n",
       "Q 1516 384 1775 384 \n",
       "Q 2178 384 2440 643 \n",
       "Q 2703 903 2703 1303 \n",
       "Q 2703 1709 2433 1975 \n",
       "Q 2163 2241 1756 2241 \n",
       "Q 1359 2241 1098 1978 \n",
       "Q 838 1716 838 1322 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-38\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_6\">\n",
       "     <g id=\"line2d_6\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m9b1a6528eb\" x=\"384.093773\" y=\"286.212\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_6\">\n",
       "      <!-- 1.0 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(377.977773 300.810875) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-31\" d=\"M 2384 0 \n",
       "L 1822 0 \n",
       "L 1822 3584 \n",
       "Q 1619 3391 1289 3197 \n",
       "Q 959 3003 697 2906 \n",
       "L 697 3450 \n",
       "Q 1169 3672 1522 3987 \n",
       "Q 1875 4303 2022 4600 \n",
       "L 2384 4600 \n",
       "L 2384 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-31\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"text_7\">\n",
       "     <!-- $x$ -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(218.8865 313.431375) scale(0.096 -0.096)\">\n",
       "      <defs>\n",
       "       <path id=\"DejaVuSans-Oblique-78\" d=\"M 3841 3500 \n",
       "L 2234 1784 \n",
       "L 3219 0 \n",
       "L 2559 0 \n",
       "L 1819 1388 \n",
       "L 531 0 \n",
       "L -166 0 \n",
       "L 1556 1844 \n",
       "L 641 3500 \n",
       "L 1300 3500 \n",
       "L 1972 2234 \n",
       "L 3144 3500 \n",
       "L 3841 3500 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-78\" transform=\"translate(0 0.3125)\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_2\">\n",
       "    <g id=\"ytick_1\">\n",
       "     <g id=\"line2d_7\">\n",
       "      <defs>\n",
       "       <path id=\"mbdc3dd1816\" d=\"M 0 0 \n",
       "L -4.8 0 \n",
       "\" style=\"stroke: #262626\"/>\n",
       "      </defs>\n",
       "      <g>\n",
       "       <use xlink:href=\"#mbdc3dd1816\" x=\"43.2065\" y=\"285.92916\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_8\">\n",
       "      <!-- −12 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(19.9795 289.078598) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-2212\" d=\"M 3381 1997 \n",
       "L 356 1997 \n",
       "L 356 2522 \n",
       "L 3381 2522 \n",
       "L 3381 1997 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-31\" x=\"58.398438\"/>\n",
       "       <use xlink:href=\"#ArialMT-32\" x=\"114.013672\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_2\">\n",
       "     <g id=\"line2d_8\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mbdc3dd1816\" x=\"43.2065\" y=\"244.436967\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_9\">\n",
       "      <!-- −10 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(19.9795 247.586404) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-31\" x=\"58.398438\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"114.013672\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_3\">\n",
       "     <g id=\"line2d_9\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mbdc3dd1816\" x=\"43.2065\" y=\"202.944773\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_10\">\n",
       "      <!-- −8 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(24.873125 206.09421) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-38\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_4\">\n",
       "     <g id=\"line2d_10\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mbdc3dd1816\" x=\"43.2065\" y=\"161.452579\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_11\">\n",
       "      <!-- −6 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(24.873125 164.602016) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-36\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_5\">\n",
       "     <g id=\"line2d_11\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mbdc3dd1816\" x=\"43.2065\" y=\"119.960385\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_12\">\n",
       "      <!-- −4 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(24.873125 123.109822) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-34\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_6\">\n",
       "     <g id=\"line2d_12\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mbdc3dd1816\" x=\"43.2065\" y=\"78.468191\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_13\">\n",
       "      <!-- −2 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(24.873125 81.617629) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-32\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_7\">\n",
       "     <g id=\"line2d_13\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mbdc3dd1816\" x=\"43.2065\" y=\"36.975997\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_14\">\n",
       "      <!-- 0 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(30.012875 40.125435) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"text_15\">\n",
       "     <!-- $y$ -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(13.9635 156.036) rotate(-90) scale(0.096 -0.096)\">\n",
       "      <defs>\n",
       "       <path id=\"DejaVuSans-Oblique-79\" d=\"M 1588 -325 \n",
       "Q 1188 -997 936 -1164 \n",
       "Q 684 -1331 294 -1331 \n",
       "L -159 -1331 \n",
       "L -63 -850 \n",
       "L 269 -850 \n",
       "Q 509 -850 678 -719 \n",
       "Q 847 -588 1056 -206 \n",
       "L 1234 128 \n",
       "L 459 3500 \n",
       "L 1069 3500 \n",
       "L 1650 819 \n",
       "L 3256 3500 \n",
       "L 3859 3500 \n",
       "L 1588 -325 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-79\" transform=\"translate(0 0.3125)\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"PolyCollection_1\">\n",
       "    <defs>\n",
       "     <path id=\"m169727574a\" d=\"M 59.439227 -207.624937 \n",
       "L 59.439227 -199.347216 \n",
       "L 62.718566 -201.362231 \n",
       "L 65.997905 -202.951834 \n",
       "L 69.277244 -204.904432 \n",
       "L 72.556583 -207.456364 \n",
       "L 75.835921 -210.642464 \n",
       "L 79.115261 -214.427521 \n",
       "L 82.394598 -218.742026 \n",
       "L 85.673938 -223.49781 \n",
       "L 88.953278 -228.595539 \n",
       "L 92.232615 -233.926593 \n",
       "L 95.511955 -239.380116 \n",
       "L 98.791295 -244.844442 \n",
       "L 102.070632 -250.211695 \n",
       "L 105.349969 -255.3811 \n",
       "L 108.629311 -260.260212 \n",
       "L 111.908649 -264.768424 \n",
       "L 115.187986 -268.840053 \n",
       "L 118.467328 -272.424162 \n",
       "L 121.746666 -275.492149 \n",
       "L 125.026003 -278.034107 \n",
       "L 128.305345 -280.061437 \n",
       "L 131.584682 -281.601295 \n",
       "L 134.86402 -282.687733 \n",
       "L 138.143362 -283.350224 \n",
       "L 141.422694 -283.612263 \n",
       "L 144.702037 -283.480573 \n",
       "L 147.981379 -282.950238 \n",
       "L 151.260711 -282.003719 \n",
       "L 154.540053 -280.622227 \n",
       "L 157.819395 -278.795855 \n",
       "L 161.098728 -276.530052 \n",
       "L 164.37807 -273.837806 \n",
       "L 167.657412 -270.73914 \n",
       "L 170.936745 -267.256859 \n",
       "L 174.216087 -263.41895 \n",
       "L 177.495429 -259.257136 \n",
       "L 180.774762 -254.808712 \n",
       "L 184.054104 -250.115146 \n",
       "L 187.333446 -245.220699 \n",
       "L 190.612778 -240.172872 \n",
       "L 193.892121 -235.019488 \n",
       "L 197.171463 -229.807609 \n",
       "L 200.450795 -224.582094 \n",
       "L 203.730137 -219.38354 \n",
       "L 207.00948 -214.24682 \n",
       "L 210.288812 -209.200017 \n",
       "L 213.568154 -204.263343 \n",
       "L 216.847496 -199.447961 \n",
       "L 220.126829 -194.755766 \n",
       "L 223.406181 -190.178729 \n",
       "L 226.685504 -185.698055 \n",
       "L 229.964846 -181.281307 \n",
       "L 233.244188 -176.873353 \n",
       "L 236.523511 -172.362793 \n",
       "L 239.802872 -167.436314 \n",
       "L 243.082195 -161.021703 \n",
       "L 246.361537 -151.803695 \n",
       "L 249.640879 -140.983435 \n",
       "L 252.920222 -129.707587 \n",
       "L 256.199564 -118.412151 \n",
       "L 259.478887 -107.346191 \n",
       "L 262.758248 -96.712653 \n",
       "L 266.037571 -86.702561 \n",
       "L 269.316913 -77.500983 \n",
       "L 272.596255 -69.28834 \n",
       "L 275.875578 -62.237751 \n",
       "L 279.15494 -56.512441 \n",
       "L 282.434262 -52.260363 \n",
       "L 285.713605 -49.610991 \n",
       "L 288.992947 -48.671637 \n",
       "L 292.272289 -49.521859 \n",
       "L 295.551631 -52.209793 \n",
       "L 298.830954 -56.75089 \n",
       "L 302.110315 -63.122181 \n",
       "L 305.389638 -71.262173 \n",
       "L 308.66898 -81.069528 \n",
       "L 311.948322 -92.40405 \n",
       "L 315.227645 -105.085218 \n",
       "L 318.507007 -118.899396 \n",
       "L 321.78633 -133.598924 \n",
       "L 325.065672 -148.90876 \n",
       "L 328.345014 -164.532951 \n",
       "L 331.624356 -180.156558 \n",
       "L 334.903698 -195.455522 \n",
       "L 338.183021 -210.096244 \n",
       "L 341.462363 -223.739603 \n",
       "L 344.741705 -236.040365 \n",
       "L 348.021048 -246.666098 \n",
       "L 351.30039 -255.390886 \n",
       "L 354.579713 -262.163974 \n",
       "L 357.859055 -267.018748 \n",
       "L 361.138397 -269.978378 \n",
       "L 364.417739 -271.062699 \n",
       "L 367.697081 -270.287473 \n",
       "L 370.976423 -267.701652 \n",
       "L 374.255766 -263.357186 \n",
       "L 377.535088 -257.297591 \n",
       "L 380.814431 -249.530539 \n",
       "L 384.093773 -240.048128 \n",
       "L 384.093773 -248.193798 \n",
       "L 384.093773 -248.193798 \n",
       "L 380.814431 -256.783341 \n",
       "L 377.535088 -264.473929 \n",
       "L 374.255766 -270.831729 \n",
       "L 370.976423 -275.500368 \n",
       "L 367.697081 -278.251438 \n",
       "L 364.417739 -278.956764 \n",
       "L 361.138397 -277.574131 \n",
       "L 357.859055 -274.142408 \n",
       "L 354.579713 -268.792227 \n",
       "L 351.30039 -261.768667 \n",
       "L 348.021048 -253.413126 \n",
       "L 344.741705 -244.05219 \n",
       "L 341.462363 -233.910726 \n",
       "L 338.183021 -223.169443 \n",
       "L 334.903698 -212.021262 \n",
       "L 331.624356 -200.691489 \n",
       "L 328.345014 -189.417916 \n",
       "L 325.065672 -178.429514 \n",
       "L 321.78633 -167.948231 \n",
       "L 318.507007 -158.165617 \n",
       "L 315.227645 -149.248865 \n",
       "L 311.948322 -141.331147 \n",
       "L 308.66898 -134.508382 \n",
       "L 305.389638 -128.844168 \n",
       "L 302.110315 -124.36482 \n",
       "L 298.830954 -121.065975 \n",
       "L 295.551631 -118.911188 \n",
       "L 292.272289 -117.841392 \n",
       "L 288.992947 -117.772639 \n",
       "L 285.713605 -118.608161 \n",
       "L 282.434262 -120.239317 \n",
       "L 279.15494 -122.550949 \n",
       "L 275.875578 -125.427938 \n",
       "L 272.596255 -128.759261 \n",
       "L 269.316913 -132.440422 \n",
       "L 266.037571 -136.379174 \n",
       "L 262.758248 -140.497406 \n",
       "L 259.478887 -144.734932 \n",
       "L 256.199564 -149.053715 \n",
       "L 252.920222 -153.449314 \n",
       "L 249.640879 -157.984782 \n",
       "L 246.361537 -162.934173 \n",
       "L 243.082195 -169.30585 \n",
       "L 239.802872 -178.185911 \n",
       "L 236.523511 -188.166256 \n",
       "L 233.244188 -198.101848 \n",
       "L 229.964846 -207.62552 \n",
       "L 226.685504 -216.587971 \n",
       "L 223.406181 -224.910426 \n",
       "L 220.126829 -232.548829 \n",
       "L 216.847496 -239.482192 \n",
       "L 213.568154 -245.708419 \n",
       "L 210.288812 -251.241065 \n",
       "L 207.00948 -256.107369 \n",
       "L 203.730137 -260.346574 \n",
       "L 200.450795 -264.007416 \n",
       "L 197.171463 -267.145938 \n",
       "L 193.892121 -269.823546 \n",
       "L 190.612778 -272.104528 \n",
       "L 187.333446 -274.053305 \n",
       "L 184.054104 -275.732292 \n",
       "L 180.774762 -277.200061 \n",
       "L 177.495429 -278.507995 \n",
       "L 174.216087 -279.700029 \n",
       "L 170.936745 -280.811114 \n",
       "L 167.657412 -281.865127 \n",
       "L 164.37807 -282.87676 \n",
       "L 161.098728 -283.850465 \n",
       "L 157.819395 -284.781882 \n",
       "L 154.540053 -285.655305 \n",
       "L 151.260711 -286.44319 \n",
       "L 147.981379 -287.09908 \n",
       "L 144.702037 -287.565574 \n",
       "L 141.422694 -287.785696 \n",
       "L 138.143362 -287.715707 \n",
       "L 134.86402 -287.326264 \n",
       "L 131.584682 -286.608644 \n",
       "L 128.305345 -285.566854 \n",
       "L 125.026003 -284.217098 \n",
       "L 121.746666 -282.578829 \n",
       "L 118.467328 -280.667247 \n",
       "L 115.187986 -278.489162 \n",
       "L 111.908649 -276.046365 \n",
       "L 108.629311 -273.33311 \n",
       "L 105.349969 -270.343922 \n",
       "L 102.070632 -267.072642 \n",
       "L 98.791295 -263.515674 \n",
       "L 95.511955 -259.67372 \n",
       "L 92.232615 -255.551551 \n",
       "L 88.953278 -251.15984 \n",
       "L 85.673938 -246.516296 \n",
       "L 82.394598 -241.645768 \n",
       "L 79.115261 -236.583251 \n",
       "L 75.835921 -231.37396 \n",
       "L 72.556583 -226.076857 \n",
       "L 69.277244 -220.777973 \n",
       "L 65.997905 -215.623536 \n",
       "L 62.718566 -210.948306 \n",
       "L 59.439227 -207.624937 \n",
       "z\n",
       "\" style=\"stroke: #1f77b4; stroke-opacity: 0.5; stroke-width: 0.8\"/>\n",
       "    </defs>\n",
       "    <g clip-path=\"url(#pa35bb67c4f)\">\n",
       "     <use xlink:href=\"#m169727574a\" x=\"0\" y=\"322.539375\" style=\"fill: #1f77b4; fill-opacity: 0.5; stroke: #1f77b4; stroke-opacity: 0.5; stroke-width: 0.8\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"PolyCollection_2\">\n",
       "    <defs>\n",
       "     <path id=\"mb8a6c1bf9c\" d=\"M 59.439227 -199.347216 \n",
       "L 59.439227 -197.625514 \n",
       "L 62.718566 -199.815765 \n",
       "L 65.997905 -201.714108 \n",
       "L 69.277244 -203.885291 \n",
       "L 72.556583 -206.573635 \n",
       "L 75.835921 -209.842872 \n",
       "L 79.115261 -213.675967 \n",
       "L 82.394598 -218.013531 \n",
       "L 85.673938 -222.772729 \n",
       "L 88.953278 -227.856757 \n",
       "L 92.232615 -233.157807 \n",
       "L 95.511955 -238.564548 \n",
       "L 98.791295 -243.96391 \n",
       "L 102.070632 -249.245951 \n",
       "L 105.349969 -254.30754 \n",
       "L 108.629311 -259.054493 \n",
       "L 111.908649 -263.406394 \n",
       "L 115.187986 -267.301248 \n",
       "L 118.467328 -270.69736 \n",
       "L 121.746666 -273.579181 \n",
       "L 125.026003 -275.951305 \n",
       "L 128.305345 -277.834846 \n",
       "L 131.584682 -279.258899 \n",
       "L 134.86402 -280.253577 \n",
       "L 138.143362 -280.844642 \n",
       "L 141.422694 -281.054584 \n",
       "L 144.702037 -280.898375 \n",
       "L 147.981379 -280.385775 \n",
       "L 151.260711 -279.517793 \n",
       "L 154.540053 -278.286035 \n",
       "L 157.819395 -276.672801 \n",
       "L 161.098728 -274.657346 \n",
       "L 164.37807 -272.222 \n",
       "L 167.657412 -269.362183 \n",
       "L 170.936745 -266.087573 \n",
       "L 174.216087 -262.42251 \n",
       "L 177.495429 -258.40092 \n",
       "L 180.774762 -254.064573 \n",
       "L 184.054104 -249.459857 \n",
       "L 187.333446 -244.635473 \n",
       "L 190.612778 -239.64253 \n",
       "L 193.892121 -234.531673 \n",
       "L 197.171463 -229.352084 \n",
       "L 200.450795 -224.150152 \n",
       "L 203.730137 -218.967486 \n",
       "L 207.00948 -213.839515 \n",
       "L 210.288812 -208.794429 \n",
       "L 213.568154 -203.852032 \n",
       "L 216.847496 -199.022445 \n",
       "L 220.126829 -194.305597 \n",
       "L 223.406181 -189.68992 \n",
       "L 226.685504 -185.150425 \n",
       "L 229.964846 -180.64325 \n",
       "L 233.244188 -176.091181 \n",
       "L 236.523511 -171.339651 \n",
       "L 239.802872 -166.021081 \n",
       "L 243.082195 -159.300941 \n",
       "L 246.361537 -150.427181 \n",
       "L 249.640879 -140.024851 \n",
       "L 252.920222 -129.003339 \n",
       "L 256.199564 -117.860247 \n",
       "L 259.478887 -106.891274 \n",
       "L 262.758248 -96.322928 \n",
       "L 266.037571 -86.3584 \n",
       "L 269.316913 -77.189389 \n",
       "L 272.596255 -69.000251 \n",
       "L 275.875578 -61.966458 \n",
       "L 279.15494 -56.252782 \n",
       "L 282.434262 -52.008045 \n",
       "L 285.713605 -49.362372 \n",
       "L 288.992947 -48.423375 \n",
       "L 292.272289 -49.270787 \n",
       "L 295.551631 -51.952666 \n",
       "L 298.830954 -56.484306 \n",
       "L 302.110315 -62.842341 \n",
       "L 305.389638 -70.964745 \n",
       "L 308.66898 -80.749288 \n",
       "L 311.948322 -92.054666 \n",
       "L 315.227645 -104.698777 \n",
       "L 318.507007 -118.465748 \n",
       "L 321.78633 -133.104823 \n",
       "L 325.065672 -148.336657 \n",
       "L 328.345014 -163.85935 \n",
       "L 331.624356 -179.349873 \n",
       "L 334.903698 -194.474383 \n",
       "L 338.183021 -208.890545 \n",
       "L 341.462363 -222.261707 \n",
       "L 344.741705 -234.278836 \n",
       "L 348.021048 -244.69203 \n",
       "L 351.30039 -253.346705 \n",
       "L 354.579713 -260.167784 \n",
       "L 357.859055 -265.112246 \n",
       "L 361.138397 -268.151319 \n",
       "L 364.417739 -269.283032 \n",
       "L 367.697081 -268.518611 \n",
       "L 370.976423 -265.907065 \n",
       "L 374.255766 -261.510264 \n",
       "L 377.535088 -255.400235 \n",
       "L 380.814431 -247.646332 \n",
       "L 384.093773 -238.306838 \n",
       "L 384.093773 -240.048128 \n",
       "L 384.093773 -240.048128 \n",
       "L 380.814431 -249.530539 \n",
       "L 377.535088 -257.297591 \n",
       "L 374.255766 -263.357186 \n",
       "L 370.976423 -267.701652 \n",
       "L 367.697081 -270.287473 \n",
       "L 364.417739 -271.062699 \n",
       "L 361.138397 -269.978378 \n",
       "L 357.859055 -267.018748 \n",
       "L 354.579713 -262.163974 \n",
       "L 351.30039 -255.390886 \n",
       "L 348.021048 -246.666098 \n",
       "L 344.741705 -236.040365 \n",
       "L 341.462363 -223.739603 \n",
       "L 338.183021 -210.096244 \n",
       "L 334.903698 -195.455522 \n",
       "L 331.624356 -180.156558 \n",
       "L 328.345014 -164.532951 \n",
       "L 325.065672 -148.90876 \n",
       "L 321.78633 -133.598924 \n",
       "L 318.507007 -118.899396 \n",
       "L 315.227645 -105.085218 \n",
       "L 311.948322 -92.40405 \n",
       "L 308.66898 -81.069528 \n",
       "L 305.389638 -71.262173 \n",
       "L 302.110315 -63.122181 \n",
       "L 298.830954 -56.75089 \n",
       "L 295.551631 -52.209793 \n",
       "L 292.272289 -49.521859 \n",
       "L 288.992947 -48.671637 \n",
       "L 285.713605 -49.610991 \n",
       "L 282.434262 -52.260363 \n",
       "L 279.15494 -56.512441 \n",
       "L 275.875578 -62.237751 \n",
       "L 272.596255 -69.28834 \n",
       "L 269.316913 -77.500983 \n",
       "L 266.037571 -86.702561 \n",
       "L 262.758248 -96.712653 \n",
       "L 259.478887 -107.346191 \n",
       "L 256.199564 -118.412151 \n",
       "L 252.920222 -129.707587 \n",
       "L 249.640879 -140.983435 \n",
       "L 246.361537 -151.803695 \n",
       "L 243.082195 -161.021703 \n",
       "L 239.802872 -167.436314 \n",
       "L 236.523511 -172.362793 \n",
       "L 233.244188 -176.873353 \n",
       "L 229.964846 -181.281307 \n",
       "L 226.685504 -185.698055 \n",
       "L 223.406181 -190.178729 \n",
       "L 220.126829 -194.755766 \n",
       "L 216.847496 -199.447961 \n",
       "L 213.568154 -204.263343 \n",
       "L 210.288812 -209.200017 \n",
       "L 207.00948 -214.24682 \n",
       "L 203.730137 -219.38354 \n",
       "L 200.450795 -224.582094 \n",
       "L 197.171463 -229.807609 \n",
       "L 193.892121 -235.019488 \n",
       "L 190.612778 -240.172872 \n",
       "L 187.333446 -245.220699 \n",
       "L 184.054104 -250.115146 \n",
       "L 180.774762 -254.808712 \n",
       "L 177.495429 -259.257136 \n",
       "L 174.216087 -263.41895 \n",
       "L 170.936745 -267.256859 \n",
       "L 167.657412 -270.73914 \n",
       "L 164.37807 -273.837806 \n",
       "L 161.098728 -276.530052 \n",
       "L 157.819395 -278.795855 \n",
       "L 154.540053 -280.622227 \n",
       "L 151.260711 -282.003719 \n",
       "L 147.981379 -282.950238 \n",
       "L 144.702037 -283.480573 \n",
       "L 141.422694 -283.612263 \n",
       "L 138.143362 -283.350224 \n",
       "L 134.86402 -282.687733 \n",
       "L 131.584682 -281.601295 \n",
       "L 128.305345 -280.061437 \n",
       "L 125.026003 -278.034107 \n",
       "L 121.746666 -275.492149 \n",
       "L 118.467328 -272.424162 \n",
       "L 115.187986 -268.840053 \n",
       "L 111.908649 -264.768424 \n",
       "L 108.629311 -260.260212 \n",
       "L 105.349969 -255.3811 \n",
       "L 102.070632 -250.211695 \n",
       "L 98.791295 -244.844442 \n",
       "L 95.511955 -239.380116 \n",
       "L 92.232615 -233.926593 \n",
       "L 88.953278 -228.595539 \n",
       "L 85.673938 -223.49781 \n",
       "L 82.394598 -218.742026 \n",
       "L 79.115261 -214.427521 \n",
       "L 75.835921 -210.642464 \n",
       "L 72.556583 -207.456364 \n",
       "L 69.277244 -204.904432 \n",
       "L 65.997905 -202.951834 \n",
       "L 62.718566 -201.362231 \n",
       "L 59.439227 -199.347216 \n",
       "z\n",
       "\" style=\"stroke: #ff7f0e; stroke-opacity: 0.5; stroke-width: 0.8\"/>\n",
       "    </defs>\n",
       "    <g clip-path=\"url(#pa35bb67c4f)\">\n",
       "     <use xlink:href=\"#mb8a6c1bf9c\" x=\"0\" y=\"322.539375\" style=\"fill: #ff7f0e; fill-opacity: 0.5; stroke: #ff7f0e; stroke-opacity: 0.5; stroke-width: 0.8\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"PolyCollection_3\">\n",
       "    <defs>\n",
       "     <path id=\"mcbb19f9864\" d=\"M 59.439227 -209.346634 \n",
       "L 59.439227 -207.624937 \n",
       "L 62.718566 -210.948306 \n",
       "L 65.997905 -215.623536 \n",
       "L 69.277244 -220.777973 \n",
       "L 72.556583 -226.076857 \n",
       "L 75.835921 -231.37396 \n",
       "L 79.115261 -236.583251 \n",
       "L 82.394598 -241.645768 \n",
       "L 85.673938 -246.516296 \n",
       "L 88.953278 -251.15984 \n",
       "L 92.232615 -255.551551 \n",
       "L 95.511955 -259.67372 \n",
       "L 98.791295 -263.515674 \n",
       "L 102.070632 -267.072642 \n",
       "L 105.349969 -270.343922 \n",
       "L 108.629311 -273.33311 \n",
       "L 111.908649 -276.046365 \n",
       "L 115.187986 -278.489162 \n",
       "L 118.467328 -280.667247 \n",
       "L 121.746666 -282.578829 \n",
       "L 125.026003 -284.217098 \n",
       "L 128.305345 -285.566854 \n",
       "L 131.584682 -286.608644 \n",
       "L 134.86402 -287.326264 \n",
       "L 138.143362 -287.715707 \n",
       "L 141.422694 -287.785696 \n",
       "L 144.702037 -287.565574 \n",
       "L 147.981379 -287.09908 \n",
       "L 151.260711 -286.44319 \n",
       "L 154.540053 -285.655305 \n",
       "L 157.819395 -284.781882 \n",
       "L 161.098728 -283.850465 \n",
       "L 164.37807 -282.87676 \n",
       "L 167.657412 -281.865127 \n",
       "L 170.936745 -280.811114 \n",
       "L 174.216087 -279.700029 \n",
       "L 177.495429 -278.507995 \n",
       "L 180.774762 -277.200061 \n",
       "L 184.054104 -275.732292 \n",
       "L 187.333446 -274.053305 \n",
       "L 190.612778 -272.104528 \n",
       "L 193.892121 -269.823546 \n",
       "L 197.171463 -267.145938 \n",
       "L 200.450795 -264.007416 \n",
       "L 203.730137 -260.346574 \n",
       "L 207.00948 -256.107369 \n",
       "L 210.288812 -251.241065 \n",
       "L 213.568154 -245.708419 \n",
       "L 216.847496 -239.482192 \n",
       "L 220.126829 -232.548829 \n",
       "L 223.406181 -224.910426 \n",
       "L 226.685504 -216.587971 \n",
       "L 229.964846 -207.62552 \n",
       "L 233.244188 -198.101848 \n",
       "L 236.523511 -188.166256 \n",
       "L 239.802872 -178.185911 \n",
       "L 243.082195 -169.30585 \n",
       "L 246.361537 -162.934173 \n",
       "L 249.640879 -157.984782 \n",
       "L 252.920222 -153.449314 \n",
       "L 256.199564 -149.053715 \n",
       "L 259.478887 -144.734932 \n",
       "L 262.758248 -140.497406 \n",
       "L 266.037571 -136.379174 \n",
       "L 269.316913 -132.440422 \n",
       "L 272.596255 -128.759261 \n",
       "L 275.875578 -125.427938 \n",
       "L 279.15494 -122.550949 \n",
       "L 282.434262 -120.239317 \n",
       "L 285.713605 -118.608161 \n",
       "L 288.992947 -117.772639 \n",
       "L 292.272289 -117.841392 \n",
       "L 295.551631 -118.911188 \n",
       "L 298.830954 -121.065975 \n",
       "L 302.110315 -124.36482 \n",
       "L 305.389638 -128.844168 \n",
       "L 308.66898 -134.508382 \n",
       "L 311.948322 -141.331147 \n",
       "L 315.227645 -149.248865 \n",
       "L 318.507007 -158.165617 \n",
       "L 321.78633 -167.948231 \n",
       "L 325.065672 -178.429514 \n",
       "L 328.345014 -189.417916 \n",
       "L 331.624356 -200.691489 \n",
       "L 334.903698 -212.021262 \n",
       "L 338.183021 -223.169443 \n",
       "L 341.462363 -233.910726 \n",
       "L 344.741705 -244.05219 \n",
       "L 348.021048 -253.413126 \n",
       "L 351.30039 -261.768667 \n",
       "L 354.579713 -268.792227 \n",
       "L 357.859055 -274.142408 \n",
       "L 361.138397 -277.574131 \n",
       "L 364.417739 -278.956764 \n",
       "L 367.697081 -278.251438 \n",
       "L 370.976423 -275.500368 \n",
       "L 374.255766 -270.831729 \n",
       "L 377.535088 -264.473929 \n",
       "L 380.814431 -256.783341 \n",
       "L 384.093773 -248.193798 \n",
       "L 384.093773 -249.935085 \n",
       "L 384.093773 -249.935085 \n",
       "L 380.814431 -258.667548 \n",
       "L 377.535088 -266.371285 \n",
       "L 374.255766 -272.678651 \n",
       "L 370.976423 -277.294956 \n",
       "L 367.697081 -280.0203 \n",
       "L 364.417739 -280.736432 \n",
       "L 361.138397 -279.401189 \n",
       "L 357.859055 -276.048911 \n",
       "L 354.579713 -270.788417 \n",
       "L 351.30039 -263.812847 \n",
       "L 348.021048 -255.387194 \n",
       "L 344.741705 -245.81372 \n",
       "L 341.462363 -235.388622 \n",
       "L 338.183021 -224.375142 \n",
       "L 334.903698 -213.002406 \n",
       "L 331.624356 -201.498174 \n",
       "L 328.345014 -190.091517 \n",
       "L 325.065672 -179.001617 \n",
       "L 321.78633 -168.442332 \n",
       "L 318.507007 -158.599265 \n",
       "L 315.227645 -149.635316 \n",
       "L 311.948322 -141.680521 \n",
       "L 308.66898 -134.828622 \n",
       "L 305.389638 -129.141616 \n",
       "L 302.110315 -124.644649 \n",
       "L 298.830954 -121.332548 \n",
       "L 295.551631 -119.168314 \n",
       "L 292.272289 -118.092464 \n",
       "L 288.992947 -118.020902 \n",
       "L 285.713605 -118.856779 \n",
       "L 282.434262 -120.491635 \n",
       "L 279.15494 -122.810628 \n",
       "L 275.875578 -125.699231 \n",
       "L 272.596255 -129.047351 \n",
       "L 269.316913 -132.752016 \n",
       "L 266.037571 -136.723355 \n",
       "L 262.758248 -140.887142 \n",
       "L 259.478887 -145.189859 \n",
       "L 256.199564 -149.605628 \n",
       "L 252.920222 -154.153561 \n",
       "L 249.640879 -158.943366 \n",
       "L 246.361537 -164.310686 \n",
       "L 243.082195 -171.026612 \n",
       "L 239.802872 -179.601143 \n",
       "L 236.523511 -189.189399 \n",
       "L 233.244188 -198.884019 \n",
       "L 229.964846 -208.263568 \n",
       "L 226.685504 -217.135601 \n",
       "L 223.406181 -225.399235 \n",
       "L 220.126829 -232.999002 \n",
       "L 216.847496 -239.907704 \n",
       "L 213.568154 -246.11973 \n",
       "L 210.288812 -251.646655 \n",
       "L 207.00948 -256.514678 \n",
       "L 203.730137 -260.76263 \n",
       "L 200.450795 -264.43936 \n",
       "L 197.171463 -267.601462 \n",
       "L 193.892121 -270.311365 \n",
       "L 190.612778 -272.634872 \n",
       "L 187.333446 -274.63853 \n",
       "L 184.054104 -276.38758 \n",
       "L 180.774762 -277.9442 \n",
       "L 177.495429 -279.364212 \n",
       "L 174.216087 -280.696469 \n",
       "L 170.936745 -281.980399 \n",
       "L 167.657412 -283.242084 \n",
       "L 164.37807 -284.492566 \n",
       "L 161.098728 -285.723172 \n",
       "L 157.819395 -286.904936 \n",
       "L 154.540053 -287.991496 \n",
       "L 151.260711 -288.929116 \n",
       "L 147.981379 -289.663543 \n",
       "L 144.702037 -290.147771 \n",
       "L 141.422694 -290.343375 \n",
       "L 138.143362 -290.22129 \n",
       "L 134.86402 -289.76042 \n",
       "L 131.584682 -288.951041 \n",
       "L 128.305345 -287.793445 \n",
       "L 125.026003 -286.299902 \n",
       "L 121.746666 -284.491796 \n",
       "L 118.467328 -282.394049 \n",
       "L 115.187986 -280.027968 \n",
       "L 111.908649 -277.408395 \n",
       "L 108.629311 -274.53883 \n",
       "L 105.349969 -271.417482 \n",
       "L 102.070632 -268.038386 \n",
       "L 98.791295 -264.396209 \n",
       "L 95.511955 -260.489291 \n",
       "L 92.232615 -256.320337 \n",
       "L 88.953278 -251.898625 \n",
       "L 85.673938 -247.241377 \n",
       "L 82.394598 -242.374262 \n",
       "L 79.115261 -237.334805 \n",
       "L 75.835921 -232.173551 \n",
       "L 72.556583 -226.959585 \n",
       "L 69.277244 -221.797115 \n",
       "L 65.997905 -216.861262 \n",
       "L 62.718566 -212.494767 \n",
       "L 59.439227 -209.346634 \n",
       "z\n",
       "\" style=\"stroke: #ff7f0e; stroke-opacity: 0.5; stroke-width: 0.8\"/>\n",
       "    </defs>\n",
       "    <g clip-path=\"url(#pa35bb67c4f)\">\n",
       "     <use xlink:href=\"#mcbb19f9864\" x=\"0\" y=\"322.539375\" style=\"fill: #ff7f0e; fill-opacity: 0.5; stroke: #ff7f0e; stroke-opacity: 0.5; stroke-width: 0.8\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"line2d_14\">\n",
       "    <defs>\n",
       "     <path id=\"m180454fb2d\" d=\"M -5 5 \n",
       "L 5 -5 \n",
       "M -5 -5 \n",
       "L 5 5 \n",
       "\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "    </defs>\n",
       "    <g clip-path=\"url(#pa35bb67c4f)\">\n",
       "     <use xlink:href=\"#m180454fb2d\" x=\"361.243318\" y=\"41.922722\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     <use xlink:href=\"#m180454fb2d\" x=\"162.151989\" y=\"42.777659\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     <use xlink:href=\"#m180454fb2d\" x=\"119.149308\" y=\"45.068182\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     <use xlink:href=\"#m180454fb2d\" x=\"243.082195\" y=\"157.51443\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     <use xlink:href=\"#m180454fb2d\" x=\"147.981379\" y=\"37.416125\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     <use xlink:href=\"#m180454fb2d\" x=\"384.093773\" y=\"81.511696\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     <use xlink:href=\"#m180454fb2d\" x=\"344.741705\" y=\"86.753465\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     <use xlink:href=\"#m180454fb2d\" x=\"59.439227\" y=\"119.355013\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     <use xlink:href=\"#m180454fb2d\" x=\"141.422694\" y=\"36.99691\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     <use xlink:href=\"#m180454fb2d\" x=\"141.422694\" y=\"36.99691\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     <use xlink:href=\"#m180454fb2d\" x=\"141.422694\" y=\"36.99691\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"line2d_15\">\n",
       "    <path d=\"M 59.439227 119.053301 \n",
       "L 62.718566 116.384109 \n",
       "L 65.997905 113.25169 \n",
       "L 69.277244 109.698172 \n",
       "L 72.556583 105.772765 \n",
       "L 75.835921 101.531163 \n",
       "L 79.115261 97.033989 \n",
       "L 82.394598 92.345478 \n",
       "L 85.673938 87.532322 \n",
       "L 88.953278 82.661685 \n",
       "L 92.232615 77.800303 \n",
       "L 95.511955 73.012457 \n",
       "L 98.791295 68.359317 \n",
       "L 102.070632 63.897206 \n",
       "L 105.349969 59.676864 \n",
       "L 108.629311 55.742714 \n",
       "L 111.908649 52.13198 \n",
       "L 115.187986 48.874767 \n",
       "L 118.467328 45.99367 \n",
       "L 121.746666 43.503886 \n",
       "L 125.026003 41.413772 \n",
       "L 128.305345 39.725229 \n",
       "L 131.584682 38.434405 \n",
       "L 134.86402 37.532377 \n",
       "L 138.143362 37.006409 \n",
       "L 141.422694 36.840396 \n",
       "L 144.702037 37.016302 \n",
       "L 147.981379 37.514716 \n",
       "L 151.260711 38.31592 \n",
       "L 154.540053 39.400609 \n",
       "L 157.819395 40.750507 \n",
       "L 161.098728 42.349116 \n",
       "L 164.37807 44.182092 \n",
       "L 167.657412 46.237241 \n",
       "L 170.936745 48.505388 \n",
       "L 174.216087 50.979886 \n",
       "L 177.495429 53.656809 \n",
       "L 180.774762 56.534988 \n",
       "L 184.054104 59.615656 \n",
       "L 187.333446 62.902374 \n",
       "L 190.612778 66.400674 \n",
       "L 193.892121 70.117857 \n",
       "L 197.171463 74.062601 \n",
       "L 200.450795 78.24462 \n",
       "L 203.730137 82.674318 \n",
       "L 207.00948 87.36228 \n",
       "L 210.288812 92.318833 \n",
       "L 213.568154 97.553494 \n",
       "L 216.847496 103.074301 \n",
       "L 220.126829 108.887075 \n",
       "L 223.406181 114.9948 \n",
       "L 226.685504 121.396362 \n",
       "L 229.964846 128.085964 \n",
       "L 233.244188 135.051775 \n",
       "L 236.523511 142.27485 \n",
       "L 239.802872 149.728263 \n",
       "L 243.082195 157.375598 \n",
       "L 246.361537 165.170441 \n",
       "L 249.640879 173.055266 \n",
       "L 252.920222 180.960925 \n",
       "L 256.199564 188.806437 \n",
       "L 259.478887 196.498813 \n",
       "L 262.758248 203.93434 \n",
       "L 266.037571 210.998502 \n",
       "L 269.316913 217.568672 \n",
       "L 272.596255 223.515574 \n",
       "L 275.875578 228.70653 \n",
       "L 279.15494 233.007675 \n",
       "L 282.434262 236.289535 \n",
       "L 285.713605 238.429799 \n",
       "L 288.992947 239.317237 \n",
       "L 292.272289 238.857749 \n",
       "L 295.551631 236.978885 \n",
       "L 298.830954 233.630943 \n",
       "L 302.110315 228.79588 \n",
       "L 305.389638 222.486199 \n",
       "L 308.66898 214.750415 \n",
       "L 311.948322 205.671782 \n",
       "L 315.227645 195.372333 \n",
       "L 318.507007 184.006868 \n",
       "L 321.78633 171.765797 \n",
       "L 325.065672 158.870238 \n",
       "L 328.345014 145.563942 \n",
       "L 331.624356 132.115351 \n",
       "L 334.903698 118.800983 \n",
       "L 338.183021 105.906531 \n",
       "L 341.462363 93.714211 \n",
       "L 344.741705 82.493097 \n",
       "L 348.021048 72.499763 \n",
       "L 351.30039 63.959599 \n",
       "L 354.579713 57.061274 \n",
       "L 357.859055 51.958797 \n",
       "L 361.138397 48.763121 \n",
       "L 364.417739 47.529643 \n",
       "L 367.697081 48.26992 \n",
       "L 370.976423 50.938365 \n",
       "L 374.255766 55.444917 \n",
       "L 377.535088 61.653615 \n",
       "L 380.814431 69.382435 \n",
       "L 384.093773 78.418412 \n",
       "\" clip-path=\"url(#pa35bb67c4f)\" style=\"fill: none; stroke: #1f77b4; stroke-width: 2; stroke-linecap: round\"/>\n",
       "   </g>\n",
       "   <g id=\"line2d_16\">\n",
       "    <path d=\"M 59.439227 119.355013 \n",
       "L 62.718566 114.292244 \n",
       "L 65.997905 109.248261 \n",
       "L 69.277244 104.24177 \n",
       "L 72.556583 99.29141 \n",
       "L 75.835921 94.415609 \n",
       "L 79.115261 89.63262 \n",
       "L 82.394598 84.960373 \n",
       "L 85.673938 80.416442 \n",
       "L 88.953278 76.018014 \n",
       "L 92.232615 71.781779 \n",
       "L 95.511955 67.723906 \n",
       "L 98.791295 63.859976 \n",
       "L 102.070632 60.204931 \n",
       "L 105.349969 56.773007 \n",
       "L 108.629311 53.577726 \n",
       "L 111.908649 50.631806 \n",
       "L 115.187986 47.947137 \n",
       "L 118.467328 45.534725 \n",
       "L 121.746666 43.404679 \n",
       "L 125.026003 41.566166 \n",
       "L 128.305345 40.027357 \n",
       "L 131.584682 38.795423 \n",
       "L 134.86402 37.876502 \n",
       "L 138.143362 37.275666 \n",
       "L 141.422694 36.99691 \n",
       "L 144.702037 37.043138 \n",
       "L 147.981379 37.416125 \n",
       "L 151.260711 38.116529 \n",
       "L 154.540053 39.143881 \n",
       "L 157.819395 40.496558 \n",
       "L 161.098728 42.171781 \n",
       "L 164.37807 44.165651 \n",
       "L 167.657412 46.473079 \n",
       "L 170.936745 49.087857 \n",
       "L 174.216087 52.002616 \n",
       "L 177.495429 55.208843 \n",
       "L 180.774762 58.696887 \n",
       "L 184.054104 62.455952 \n",
       "L 187.333446 66.474156 \n",
       "L 190.612778 70.738431 \n",
       "L 193.892121 75.234656 \n",
       "L 197.171463 79.947547 \n",
       "L 200.450795 84.86078 \n",
       "L 203.730137 89.956887 \n",
       "L 207.00948 95.217294 \n",
       "L 210.288812 100.622348 \n",
       "L 213.568154 106.151321 \n",
       "L 216.847496 111.782336 \n",
       "L 220.126829 117.492456 \n",
       "L 223.406181 123.257628 \n",
       "L 226.685504 129.05263 \n",
       "L 229.964846 134.851194 \n",
       "L 233.244188 140.625888 \n",
       "L 236.523511 146.347992 \n",
       "L 239.802872 151.98788 \n",
       "L 243.082195 157.51443 \n",
       "L 246.361537 162.895579 \n",
       "L 249.640879 168.097912 \n",
       "L 252.920222 173.086843 \n",
       "L 256.199564 177.826632 \n",
       "L 259.478887 182.280249 \n",
       "L 262.758248 186.409611 \n",
       "L 266.037571 190.175452 \n",
       "L 269.316913 193.53753 \n",
       "L 272.596255 196.454653 \n",
       "L 275.875578 198.884936 \n",
       "L 279.15494 200.785881 \n",
       "L 282.434262 202.114752 \n",
       "L 285.713605 202.828882 \n",
       "L 288.992947 202.88613 \n",
       "L 292.272289 202.245432 \n",
       "L 295.551631 200.867543 \n",
       "L 298.830954 198.715853 \n",
       "L 302.110315 195.75733 \n",
       "L 305.389638 191.964146 \n",
       "L 308.66898 187.314567 \n",
       "L 311.948322 181.795239 \n",
       "L 315.227645 175.403115 \n",
       "L 318.507007 168.147553 \n",
       "L 321.78633 160.053491 \n",
       "L 325.065672 151.164111 \n",
       "L 328.345014 141.544358 \n",
       "L 331.624356 131.284618 \n",
       "L 334.903698 120.504414 \n",
       "L 338.183021 109.356302 \n",
       "L 341.462363 98.02962 \n",
       "L 344.741705 86.753465 \n",
       "L 348.021048 75.799177 \n",
       "L 351.30039 65.481279 \n",
       "L 354.579713 56.155823 \n",
       "L 357.859055 48.216005 \n",
       "L 361.138397 42.084183 \n",
       "L 364.417739 38.197425 \n",
       "L 367.697081 36.987497 \n",
       "L 370.976423 38.852468 \n",
       "L 374.255766 44.119566 \n",
       "L 377.535088 52.998895 \n",
       "L 380.814431 65.528254 \n",
       "L 384.093773 81.511696 \n",
       "\" clip-path=\"url(#pa35bb67c4f)\" style=\"fill: none; stroke-dasharray: 7.68,1.92,1.2,1.92; stroke-dashoffset: 0; stroke: #bf00bf; stroke-width: 1.2\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_3\">\n",
       "    <path d=\"M 43.2065 285.92916 \n",
       "L 43.2065 36.975997 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_4\">\n",
       "    <path d=\"M 59.439227 286.212 \n",
       "L 384.093773 286.212 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"text_16\">\n",
       "    <!-- N=7, psi=0.10 -->\n",
       "    <g style=\"fill: #262626\" transform=\"translate(191.87975 14.1) scale(0.096 -0.096)\">\n",
       "     <defs>\n",
       "      <path id=\"ArialMT-4e\" d=\"M 488 0 \n",
       "L 488 4581 \n",
       "L 1109 4581 \n",
       "L 3516 984 \n",
       "L 3516 4581 \n",
       "L 4097 4581 \n",
       "L 4097 0 \n",
       "L 3475 0 \n",
       "L 1069 3600 \n",
       "L 1069 0 \n",
       "L 488 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-3d\" d=\"M 3381 2694 \n",
       "L 356 2694 \n",
       "L 356 3219 \n",
       "L 3381 3219 \n",
       "L 3381 2694 \n",
       "z\n",
       "M 3381 1303 \n",
       "L 356 1303 \n",
       "L 356 1828 \n",
       "L 3381 1828 \n",
       "L 3381 1303 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-37\" d=\"M 303 3981 \n",
       "L 303 4522 \n",
       "L 3269 4522 \n",
       "L 3269 4084 \n",
       "Q 2831 3619 2401 2847 \n",
       "Q 1972 2075 1738 1259 \n",
       "Q 1569 684 1522 0 \n",
       "L 944 0 \n",
       "Q 953 541 1156 1306 \n",
       "Q 1359 2072 1739 2783 \n",
       "Q 2119 3494 2547 3981 \n",
       "L 303 3981 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-2c\" d=\"M 569 0 \n",
       "L 569 641 \n",
       "L 1209 641 \n",
       "L 1209 0 \n",
       "Q 1209 -353 1084 -570 \n",
       "Q 959 -788 688 -906 \n",
       "L 531 -666 \n",
       "Q 709 -588 793 -436 \n",
       "Q 878 -284 888 0 \n",
       "L 569 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-20\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-70\" d=\"M 422 -1272 \n",
       "L 422 3319 \n",
       "L 934 3319 \n",
       "L 934 2888 \n",
       "Q 1116 3141 1344 3267 \n",
       "Q 1572 3394 1897 3394 \n",
       "Q 2322 3394 2647 3175 \n",
       "Q 2972 2956 3137 2557 \n",
       "Q 3303 2159 3303 1684 \n",
       "Q 3303 1175 3120 767 \n",
       "Q 2938 359 2589 142 \n",
       "Q 2241 -75 1856 -75 \n",
       "Q 1575 -75 1351 44 \n",
       "Q 1128 163 984 344 \n",
       "L 984 -1272 \n",
       "L 422 -1272 \n",
       "z\n",
       "M 931 1641 \n",
       "Q 931 1000 1190 694 \n",
       "Q 1450 388 1819 388 \n",
       "Q 2194 388 2461 705 \n",
       "Q 2728 1022 2728 1688 \n",
       "Q 2728 2322 2467 2637 \n",
       "Q 2206 2953 1844 2953 \n",
       "Q 1484 2953 1207 2617 \n",
       "Q 931 2281 931 1641 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-73\" d=\"M 197 991 \n",
       "L 753 1078 \n",
       "Q 800 744 1014 566 \n",
       "Q 1228 388 1613 388 \n",
       "Q 2000 388 2187 545 \n",
       "Q 2375 703 2375 916 \n",
       "Q 2375 1106 2209 1216 \n",
       "Q 2094 1291 1634 1406 \n",
       "Q 1016 1563 777 1677 \n",
       "Q 538 1791 414 1992 \n",
       "Q 291 2194 291 2438 \n",
       "Q 291 2659 392 2848 \n",
       "Q 494 3038 669 3163 \n",
       "Q 800 3259 1026 3326 \n",
       "Q 1253 3394 1513 3394 \n",
       "Q 1903 3394 2198 3281 \n",
       "Q 2494 3169 2634 2976 \n",
       "Q 2775 2784 2828 2463 \n",
       "L 2278 2388 \n",
       "Q 2241 2644 2061 2787 \n",
       "Q 1881 2931 1553 2931 \n",
       "Q 1166 2931 1000 2803 \n",
       "Q 834 2675 834 2503 \n",
       "Q 834 2394 903 2306 \n",
       "Q 972 2216 1119 2156 \n",
       "Q 1203 2125 1616 2013 \n",
       "Q 2213 1853 2448 1751 \n",
       "Q 2684 1650 2818 1456 \n",
       "Q 2953 1263 2953 975 \n",
       "Q 2953 694 2789 445 \n",
       "Q 2625 197 2315 61 \n",
       "Q 2006 -75 1616 -75 \n",
       "Q 969 -75 630 194 \n",
       "Q 291 463 197 991 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-69\" d=\"M 425 3934 \n",
       "L 425 4581 \n",
       "L 988 4581 \n",
       "L 988 3934 \n",
       "L 425 3934 \n",
       "z\n",
       "M 425 0 \n",
       "L 425 3319 \n",
       "L 988 3319 \n",
       "L 988 0 \n",
       "L 425 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "     </defs>\n",
       "     <use xlink:href=\"#ArialMT-4e\"/>\n",
       "     <use xlink:href=\"#ArialMT-3d\" x=\"72.216797\"/>\n",
       "     <use xlink:href=\"#ArialMT-37\" x=\"130.615234\"/>\n",
       "     <use xlink:href=\"#ArialMT-2c\" x=\"186.230469\"/>\n",
       "     <use xlink:href=\"#ArialMT-20\" x=\"214.013672\"/>\n",
       "     <use xlink:href=\"#ArialMT-70\" x=\"241.796875\"/>\n",
       "     <use xlink:href=\"#ArialMT-73\" x=\"297.412109\"/>\n",
       "     <use xlink:href=\"#ArialMT-69\" x=\"347.412109\"/>\n",
       "     <use xlink:href=\"#ArialMT-3d\" x=\"369.628906\"/>\n",
       "     <use xlink:href=\"#ArialMT-30\" x=\"428.027344\"/>\n",
       "     <use xlink:href=\"#ArialMT-2e\" x=\"483.642578\"/>\n",
       "     <use xlink:href=\"#ArialMT-31\" x=\"511.425781\"/>\n",
       "     <use xlink:href=\"#ArialMT-30\" x=\"567.041016\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"legend_1\">\n",
       "    <g id=\"line2d_17\">\n",
       "     <g>\n",
       "      <use xlink:href=\"#m180454fb2d\" x=\"59.9265\" y=\"220.007125\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"text_17\">\n",
       "     <!-- Observations -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(75.7665 223.087125) scale(0.088 -0.088)\">\n",
       "      <defs>\n",
       "       <path id=\"ArialMT-4f\" d=\"M 309 2231 \n",
       "Q 309 3372 921 4017 \n",
       "Q 1534 4663 2503 4663 \n",
       "Q 3138 4663 3647 4359 \n",
       "Q 4156 4056 4423 3514 \n",
       "Q 4691 2972 4691 2284 \n",
       "Q 4691 1588 4409 1038 \n",
       "Q 4128 488 3612 205 \n",
       "Q 3097 -78 2500 -78 \n",
       "Q 1853 -78 1343 234 \n",
       "Q 834 547 571 1087 \n",
       "Q 309 1628 309 2231 \n",
       "z\n",
       "M 934 2222 \n",
       "Q 934 1394 1379 917 \n",
       "Q 1825 441 2497 441 \n",
       "Q 3181 441 3623 922 \n",
       "Q 4066 1403 4066 2288 \n",
       "Q 4066 2847 3877 3264 \n",
       "Q 3688 3681 3323 3911 \n",
       "Q 2959 4141 2506 4141 \n",
       "Q 1863 4141 1398 3698 \n",
       "Q 934 3256 934 2222 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-62\" d=\"M 941 0 \n",
       "L 419 0 \n",
       "L 419 4581 \n",
       "L 981 4581 \n",
       "L 981 2947 \n",
       "Q 1338 3394 1891 3394 \n",
       "Q 2197 3394 2470 3270 \n",
       "Q 2744 3147 2920 2923 \n",
       "Q 3097 2700 3197 2384 \n",
       "Q 3297 2069 3297 1709 \n",
       "Q 3297 856 2875 390 \n",
       "Q 2453 -75 1863 -75 \n",
       "Q 1275 -75 941 416 \n",
       "L 941 0 \n",
       "z\n",
       "M 934 1684 \n",
       "Q 934 1088 1097 822 \n",
       "Q 1363 388 1816 388 \n",
       "Q 2184 388 2453 708 \n",
       "Q 2722 1028 2722 1663 \n",
       "Q 2722 2313 2464 2622 \n",
       "Q 2206 2931 1841 2931 \n",
       "Q 1472 2931 1203 2611 \n",
       "Q 934 2291 934 1684 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-65\" d=\"M 2694 1069 \n",
       "L 3275 997 \n",
       "Q 3138 488 2766 206 \n",
       "Q 2394 -75 1816 -75 \n",
       "Q 1088 -75 661 373 \n",
       "Q 234 822 234 1631 \n",
       "Q 234 2469 665 2931 \n",
       "Q 1097 3394 1784 3394 \n",
       "Q 2450 3394 2872 2941 \n",
       "Q 3294 2488 3294 1666 \n",
       "Q 3294 1616 3291 1516 \n",
       "L 816 1516 \n",
       "Q 847 969 1125 678 \n",
       "Q 1403 388 1819 388 \n",
       "Q 2128 388 2347 550 \n",
       "Q 2566 713 2694 1069 \n",
       "z\n",
       "M 847 1978 \n",
       "L 2700 1978 \n",
       "Q 2663 2397 2488 2606 \n",
       "Q 2219 2931 1791 2931 \n",
       "Q 1403 2931 1139 2672 \n",
       "Q 875 2413 847 1978 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-72\" d=\"M 416 0 \n",
       "L 416 3319 \n",
       "L 922 3319 \n",
       "L 922 2816 \n",
       "Q 1116 3169 1280 3281 \n",
       "Q 1444 3394 1641 3394 \n",
       "Q 1925 3394 2219 3213 \n",
       "L 2025 2691 \n",
       "Q 1819 2813 1613 2813 \n",
       "Q 1428 2813 1281 2702 \n",
       "Q 1134 2591 1072 2394 \n",
       "Q 978 2094 978 1738 \n",
       "L 978 0 \n",
       "L 416 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-76\" d=\"M 1344 0 \n",
       "L 81 3319 \n",
       "L 675 3319 \n",
       "L 1388 1331 \n",
       "Q 1503 1009 1600 663 \n",
       "Q 1675 925 1809 1294 \n",
       "L 2547 3319 \n",
       "L 3125 3319 \n",
       "L 1869 0 \n",
       "L 1344 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-61\" d=\"M 2588 409 \n",
       "Q 2275 144 1986 34 \n",
       "Q 1697 -75 1366 -75 \n",
       "Q 819 -75 525 192 \n",
       "Q 231 459 231 875 \n",
       "Q 231 1119 342 1320 \n",
       "Q 453 1522 633 1644 \n",
       "Q 813 1766 1038 1828 \n",
       "Q 1203 1872 1538 1913 \n",
       "Q 2219 1994 2541 2106 \n",
       "Q 2544 2222 2544 2253 \n",
       "Q 2544 2597 2384 2738 \n",
       "Q 2169 2928 1744 2928 \n",
       "Q 1347 2928 1158 2789 \n",
       "Q 969 2650 878 2297 \n",
       "L 328 2372 \n",
       "Q 403 2725 575 2942 \n",
       "Q 747 3159 1072 3276 \n",
       "Q 1397 3394 1825 3394 \n",
       "Q 2250 3394 2515 3294 \n",
       "Q 2781 3194 2906 3042 \n",
       "Q 3031 2891 3081 2659 \n",
       "Q 3109 2516 3109 2141 \n",
       "L 3109 1391 \n",
       "Q 3109 606 3145 398 \n",
       "Q 3181 191 3288 0 \n",
       "L 2700 0 \n",
       "Q 2613 175 2588 409 \n",
       "z\n",
       "M 2541 1666 \n",
       "Q 2234 1541 1622 1453 \n",
       "Q 1275 1403 1131 1340 \n",
       "Q 988 1278 909 1158 \n",
       "Q 831 1038 831 891 \n",
       "Q 831 666 1001 516 \n",
       "Q 1172 366 1500 366 \n",
       "Q 1825 366 2078 508 \n",
       "Q 2331 650 2450 897 \n",
       "Q 2541 1088 2541 1459 \n",
       "L 2541 1666 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-74\" d=\"M 1650 503 \n",
       "L 1731 6 \n",
       "Q 1494 -44 1306 -44 \n",
       "Q 1000 -44 831 53 \n",
       "Q 663 150 594 308 \n",
       "Q 525 466 525 972 \n",
       "L 525 2881 \n",
       "L 113 2881 \n",
       "L 113 3319 \n",
       "L 525 3319 \n",
       "L 525 4141 \n",
       "L 1084 4478 \n",
       "L 1084 3319 \n",
       "L 1650 3319 \n",
       "L 1650 2881 \n",
       "L 1084 2881 \n",
       "L 1084 941 \n",
       "Q 1084 700 1114 631 \n",
       "Q 1144 563 1211 522 \n",
       "Q 1278 481 1403 481 \n",
       "Q 1497 481 1650 503 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-6f\" d=\"M 213 1659 \n",
       "Q 213 2581 725 3025 \n",
       "Q 1153 3394 1769 3394 \n",
       "Q 2453 3394 2887 2945 \n",
       "Q 3322 2497 3322 1706 \n",
       "Q 3322 1066 3130 698 \n",
       "Q 2938 331 2570 128 \n",
       "Q 2203 -75 1769 -75 \n",
       "Q 1072 -75 642 372 \n",
       "Q 213 819 213 1659 \n",
       "z\n",
       "M 791 1659 \n",
       "Q 791 1022 1069 705 \n",
       "Q 1347 388 1769 388 \n",
       "Q 2188 388 2466 706 \n",
       "Q 2744 1025 2744 1678 \n",
       "Q 2744 2294 2464 2611 \n",
       "Q 2184 2928 1769 2928 \n",
       "Q 1347 2928 1069 2612 \n",
       "Q 791 2297 791 1659 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-6e\" d=\"M 422 0 \n",
       "L 422 3319 \n",
       "L 928 3319 \n",
       "L 928 2847 \n",
       "Q 1294 3394 1984 3394 \n",
       "Q 2284 3394 2536 3286 \n",
       "Q 2788 3178 2913 3003 \n",
       "Q 3038 2828 3088 2588 \n",
       "Q 3119 2431 3119 2041 \n",
       "L 3119 0 \n",
       "L 2556 0 \n",
       "L 2556 2019 \n",
       "Q 2556 2363 2490 2533 \n",
       "Q 2425 2703 2258 2804 \n",
       "Q 2091 2906 1866 2906 \n",
       "Q 1506 2906 1245 2678 \n",
       "Q 984 2450 984 1813 \n",
       "L 984 0 \n",
       "L 422 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#ArialMT-4f\"/>\n",
       "      <use xlink:href=\"#ArialMT-62\" x=\"77.783203\"/>\n",
       "      <use xlink:href=\"#ArialMT-73\" x=\"133.398438\"/>\n",
       "      <use xlink:href=\"#ArialMT-65\" x=\"183.398438\"/>\n",
       "      <use xlink:href=\"#ArialMT-72\" x=\"239.013672\"/>\n",
       "      <use xlink:href=\"#ArialMT-76\" x=\"272.314453\"/>\n",
       "      <use xlink:href=\"#ArialMT-61\" x=\"322.314453\"/>\n",
       "      <use xlink:href=\"#ArialMT-74\" x=\"377.929688\"/>\n",
       "      <use xlink:href=\"#ArialMT-69\" x=\"405.712891\"/>\n",
       "      <use xlink:href=\"#ArialMT-6f\" x=\"427.929688\"/>\n",
       "      <use xlink:href=\"#ArialMT-6e\" x=\"483.544922\"/>\n",
       "      <use xlink:href=\"#ArialMT-73\" x=\"539.160156\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"line2d_18\">\n",
       "     <path d=\"M 51.1265 232.591125 \n",
       "L 59.9265 232.591125 \n",
       "L 68.7265 232.591125 \n",
       "\" style=\"fill: none; stroke: #1f77b4; stroke-width: 2; stroke-linecap: round\"/>\n",
       "    </g>\n",
       "    <g id=\"text_18\">\n",
       "     <!-- $m_n(x)$ -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(75.7665 235.671125) scale(0.088 -0.088)\">\n",
       "      <defs>\n",
       "       <path id=\"DejaVuSans-Oblique-6d\" d=\"M 5747 2113 \n",
       "L 5338 0 \n",
       "L 4763 0 \n",
       "L 5166 2094 \n",
       "Q 5191 2228 5203 2325 \n",
       "Q 5216 2422 5216 2491 \n",
       "Q 5216 2772 5059 2928 \n",
       "Q 4903 3084 4622 3084 \n",
       "Q 4203 3084 3875 2770 \n",
       "Q 3547 2456 3450 1953 \n",
       "L 3066 0 \n",
       "L 2491 0 \n",
       "L 2900 2094 \n",
       "Q 2925 2209 2937 2307 \n",
       "Q 2950 2406 2950 2484 \n",
       "Q 2950 2769 2794 2926 \n",
       "Q 2638 3084 2363 3084 \n",
       "Q 1938 3084 1609 2770 \n",
       "Q 1281 2456 1184 1953 \n",
       "L 800 0 \n",
       "L 225 0 \n",
       "L 909 3500 \n",
       "L 1484 3500 \n",
       "L 1375 2956 \n",
       "Q 1609 3263 1923 3423 \n",
       "Q 2238 3584 2597 3584 \n",
       "Q 2978 3584 3223 3384 \n",
       "Q 3469 3184 3519 2828 \n",
       "Q 3781 3197 4126 3390 \n",
       "Q 4472 3584 4856 3584 \n",
       "Q 5306 3584 5551 3325 \n",
       "Q 5797 3066 5797 2591 \n",
       "Q 5797 2488 5784 2364 \n",
       "Q 5772 2241 5747 2113 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-Oblique-6e\" d=\"M 3566 2113 \n",
       "L 3156 0 \n",
       "L 2578 0 \n",
       "L 2988 2091 \n",
       "Q 3016 2238 3031 2350 \n",
       "Q 3047 2463 3047 2528 \n",
       "Q 3047 2791 2881 2937 \n",
       "Q 2716 3084 2419 3084 \n",
       "Q 1956 3084 1622 2776 \n",
       "Q 1288 2469 1184 1941 \n",
       "L 800 0 \n",
       "L 225 0 \n",
       "L 903 3500 \n",
       "L 1478 3500 \n",
       "L 1363 2950 \n",
       "Q 1603 3253 1940 3418 \n",
       "Q 2278 3584 2650 3584 \n",
       "Q 3113 3584 3367 3334 \n",
       "Q 3622 3084 3622 2631 \n",
       "Q 3622 2519 3608 2391 \n",
       "Q 3594 2263 3566 2113 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-28\" d=\"M 1984 4856 \n",
       "Q 1566 4138 1362 3434 \n",
       "Q 1159 2731 1159 2009 \n",
       "Q 1159 1288 1364 580 \n",
       "Q 1569 -128 1984 -844 \n",
       "L 1484 -844 \n",
       "Q 1016 -109 783 600 \n",
       "Q 550 1309 550 2009 \n",
       "Q 550 2706 781 3412 \n",
       "Q 1013 4119 1484 4856 \n",
       "L 1984 4856 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-29\" d=\"M 513 4856 \n",
       "L 1013 4856 \n",
       "Q 1481 4119 1714 3412 \n",
       "Q 1947 2706 1947 2009 \n",
       "Q 1947 1309 1714 600 \n",
       "Q 1481 -109 1013 -844 \n",
       "L 513 -844 \n",
       "Q 928 -128 1133 580 \n",
       "Q 1338 1288 1338 2009 \n",
       "Q 1338 2731 1133 3434 \n",
       "Q 928 4138 513 4856 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-6d\" transform=\"translate(0 0.125)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-6e\" transform=\"translate(97.412109 -16.28125) scale(0.7)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-28\" transform=\"translate(144.511719 0.125)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-78\" transform=\"translate(183.525391 0.125)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-29\" transform=\"translate(242.705078 0.125)\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"patch_5\">\n",
       "     <path d=\"M 51.1265 249.828125 \n",
       "L 68.7265 249.828125 \n",
       "L 68.7265 243.668125 \n",
       "L 51.1265 243.668125 \n",
       "z\n",
       "\" style=\"fill: #1f77b4; fill-opacity: 0.5; stroke: #1f77b4; stroke-opacity: 0.5; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "    </g>\n",
       "    <g id=\"text_19\">\n",
       "     <!-- $f(\\mathbf{x}^*)$ 95% pred. -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(75.7665 249.828125) scale(0.088 -0.088)\">\n",
       "      <defs>\n",
       "       <path id=\"DejaVuSans-Oblique-66\" d=\"M 3059 4863 \n",
       "L 2969 4384 \n",
       "L 2419 4384 \n",
       "Q 2106 4384 1964 4261 \n",
       "Q 1822 4138 1753 3809 \n",
       "L 1691 3500 \n",
       "L 2638 3500 \n",
       "L 2553 3053 \n",
       "L 1606 3053 \n",
       "L 1013 0 \n",
       "L 434 0 \n",
       "L 1031 3053 \n",
       "L 481 3053 \n",
       "L 563 3500 \n",
       "L 1113 3500 \n",
       "L 1159 3744 \n",
       "Q 1278 4363 1576 4613 \n",
       "Q 1875 4863 2516 4863 \n",
       "L 3059 4863 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-Bold-78\" d=\"M 1422 1791 \n",
       "L 159 3500 \n",
       "L 1344 3500 \n",
       "L 2059 2463 \n",
       "L 2784 3500 \n",
       "L 3969 3500 \n",
       "L 2706 1797 \n",
       "L 4031 0 \n",
       "L 2847 0 \n",
       "L 2059 1106 \n",
       "L 1281 0 \n",
       "L 97 0 \n",
       "L 1422 1791 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-2a\" d=\"M 3009 3897 \n",
       "L 1888 3291 \n",
       "L 3009 2681 \n",
       "L 2828 2375 \n",
       "L 1778 3009 \n",
       "L 1778 1831 \n",
       "L 1422 1831 \n",
       "L 1422 3009 \n",
       "L 372 2375 \n",
       "L 191 2681 \n",
       "L 1313 3291 \n",
       "L 191 3897 \n",
       "L 372 4206 \n",
       "L 1422 3572 \n",
       "L 1422 4750 \n",
       "L 1778 4750 \n",
       "L 1778 3572 \n",
       "L 2828 4206 \n",
       "L 3009 3897 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-39\" d=\"M 350 1059 \n",
       "L 891 1109 \n",
       "Q 959 728 1153 556 \n",
       "Q 1347 384 1650 384 \n",
       "Q 1909 384 2104 503 \n",
       "Q 2300 622 2425 820 \n",
       "Q 2550 1019 2634 1356 \n",
       "Q 2719 1694 2719 2044 \n",
       "Q 2719 2081 2716 2156 \n",
       "Q 2547 1888 2255 1720 \n",
       "Q 1963 1553 1622 1553 \n",
       "Q 1053 1553 659 1965 \n",
       "Q 266 2378 266 3053 \n",
       "Q 266 3750 677 4175 \n",
       "Q 1088 4600 1706 4600 \n",
       "Q 2153 4600 2523 4359 \n",
       "Q 2894 4119 3086 3673 \n",
       "Q 3278 3228 3278 2384 \n",
       "Q 3278 1506 3087 986 \n",
       "Q 2897 466 2520 194 \n",
       "Q 2144 -78 1638 -78 \n",
       "Q 1100 -78 759 220 \n",
       "Q 419 519 350 1059 \n",
       "z\n",
       "M 2653 3081 \n",
       "Q 2653 3566 2395 3850 \n",
       "Q 2138 4134 1775 4134 \n",
       "Q 1400 4134 1122 3828 \n",
       "Q 844 3522 844 3034 \n",
       "Q 844 2597 1108 2323 \n",
       "Q 1372 2050 1759 2050 \n",
       "Q 2150 2050 2401 2323 \n",
       "Q 2653 2597 2653 3081 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-35\" d=\"M 266 1200 \n",
       "L 856 1250 \n",
       "Q 922 819 1161 601 \n",
       "Q 1400 384 1738 384 \n",
       "Q 2144 384 2425 690 \n",
       "Q 2706 997 2706 1503 \n",
       "Q 2706 1984 2436 2262 \n",
       "Q 2166 2541 1728 2541 \n",
       "Q 1456 2541 1237 2417 \n",
       "Q 1019 2294 894 2097 \n",
       "L 366 2166 \n",
       "L 809 4519 \n",
       "L 3088 4519 \n",
       "L 3088 3981 \n",
       "L 1259 3981 \n",
       "L 1013 2750 \n",
       "Q 1425 3038 1878 3038 \n",
       "Q 2478 3038 2890 2622 \n",
       "Q 3303 2206 3303 1553 \n",
       "Q 3303 931 2941 478 \n",
       "Q 2500 -78 1738 -78 \n",
       "Q 1113 -78 717 272 \n",
       "Q 322 622 266 1200 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-25\" d=\"M 372 3481 \n",
       "Q 372 3972 619 4315 \n",
       "Q 866 4659 1334 4659 \n",
       "Q 1766 4659 2048 4351 \n",
       "Q 2331 4044 2331 3447 \n",
       "Q 2331 2866 2045 2552 \n",
       "Q 1759 2238 1341 2238 \n",
       "Q 925 2238 648 2547 \n",
       "Q 372 2856 372 3481 \n",
       "z\n",
       "M 1350 4272 \n",
       "Q 1141 4272 1002 4090 \n",
       "Q 863 3909 863 3425 \n",
       "Q 863 2984 1003 2804 \n",
       "Q 1144 2625 1350 2625 \n",
       "Q 1563 2625 1702 2806 \n",
       "Q 1841 2988 1841 3469 \n",
       "Q 1841 3913 1700 4092 \n",
       "Q 1559 4272 1350 4272 \n",
       "z\n",
       "M 1353 -169 \n",
       "L 3859 4659 \n",
       "L 4316 4659 \n",
       "L 1819 -169 \n",
       "L 1353 -169 \n",
       "z\n",
       "M 3334 1075 \n",
       "Q 3334 1569 3581 1911 \n",
       "Q 3828 2253 4300 2253 \n",
       "Q 4731 2253 5014 1945 \n",
       "Q 5297 1638 5297 1041 \n",
       "Q 5297 459 5011 145 \n",
       "Q 4725 -169 4303 -169 \n",
       "Q 3888 -169 3611 142 \n",
       "Q 3334 453 3334 1075 \n",
       "z\n",
       "M 4316 1866 \n",
       "Q 4103 1866 3964 1684 \n",
       "Q 3825 1503 3825 1019 \n",
       "Q 3825 581 3965 400 \n",
       "Q 4106 219 4313 219 \n",
       "Q 4528 219 4667 400 \n",
       "Q 4806 581 4806 1063 \n",
       "Q 4806 1506 4665 1686 \n",
       "Q 4525 1866 4316 1866 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-64\" d=\"M 2575 0 \n",
       "L 2575 419 \n",
       "Q 2259 -75 1647 -75 \n",
       "Q 1250 -75 917 144 \n",
       "Q 584 363 401 755 \n",
       "Q 219 1147 219 1656 \n",
       "Q 219 2153 384 2558 \n",
       "Q 550 2963 881 3178 \n",
       "Q 1213 3394 1622 3394 \n",
       "Q 1922 3394 2156 3267 \n",
       "Q 2391 3141 2538 2938 \n",
       "L 2538 4581 \n",
       "L 3097 4581 \n",
       "L 3097 0 \n",
       "L 2575 0 \n",
       "z\n",
       "M 797 1656 \n",
       "Q 797 1019 1065 703 \n",
       "Q 1334 388 1700 388 \n",
       "Q 2069 388 2326 689 \n",
       "Q 2584 991 2584 1609 \n",
       "Q 2584 2291 2321 2609 \n",
       "Q 2059 2928 1675 2928 \n",
       "Q 1300 2928 1048 2622 \n",
       "Q 797 2316 797 1656 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-66\" transform=\"translate(0 0.765625)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-28\" transform=\"translate(35.205078 0.765625)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-Bold-78\" transform=\"translate(74.21875 0.765625)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-2a\" transform=\"translate(153.31543 39.046875) scale(0.7)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-29\" transform=\"translate(204.6875 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" transform=\"translate(243.701172 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-39\" transform=\"translate(271.484375 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-35\" transform=\"translate(327.099609 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-25\" transform=\"translate(382.714844 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" transform=\"translate(471.630859 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-70\" transform=\"translate(499.414062 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-72\" transform=\"translate(555.029297 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-65\" transform=\"translate(588.330078 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-64\" transform=\"translate(643.945312 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-2e\" transform=\"translate(699.560547 0.765625)\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"patch_6\">\n",
       "     <path d=\"M 51.1265 263.996125 \n",
       "L 68.7265 263.996125 \n",
       "L 68.7265 257.836125 \n",
       "L 51.1265 257.836125 \n",
       "z\n",
       "\" style=\"fill: #ff7f0e; fill-opacity: 0.5; stroke: #ff7f0e; stroke-opacity: 0.5; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "    </g>\n",
       "    <g id=\"text_20\">\n",
       "     <!-- $y^*$ 95% pred. -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(75.7665 263.996125) scale(0.088 -0.088)\">\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-79\" transform=\"translate(0 0.765625)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-2a\" transform=\"translate(77.283529 39.046875) scale(0.7)\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" transform=\"translate(128.655599 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-39\" transform=\"translate(156.438802 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-35\" transform=\"translate(212.054036 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-25\" transform=\"translate(267.669271 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" transform=\"translate(356.585286 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-70\" transform=\"translate(384.36849 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-72\" transform=\"translate(439.983724 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-65\" transform=\"translate(473.284505 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-64\" transform=\"translate(528.89974 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-2e\" transform=\"translate(584.514974 0.765625)\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"line2d_19\">\n",
       "     <path d=\"M 51.1265 273.463 \n",
       "L 59.9265 273.463 \n",
       "L 68.7265 273.463 \n",
       "\" style=\"fill: none; stroke-dasharray: 7.68,1.92,1.2,1.92; stroke-dashoffset: 0; stroke: #bf00bf; stroke-width: 1.2\"/>\n",
       "    </g>\n",
       "    <g id=\"text_21\">\n",
       "     <!-- True function -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(75.7665 276.543) scale(0.088 -0.088)\">\n",
       "      <defs>\n",
       "       <path id=\"ArialMT-54\" d=\"M 1659 0 \n",
       "L 1659 4041 \n",
       "L 150 4041 \n",
       "L 150 4581 \n",
       "L 3781 4581 \n",
       "L 3781 4041 \n",
       "L 2266 4041 \n",
       "L 2266 0 \n",
       "L 1659 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-75\" d=\"M 2597 0 \n",
       "L 2597 488 \n",
       "Q 2209 -75 1544 -75 \n",
       "Q 1250 -75 995 37 \n",
       "Q 741 150 617 320 \n",
       "Q 494 491 444 738 \n",
       "Q 409 903 409 1263 \n",
       "L 409 3319 \n",
       "L 972 3319 \n",
       "L 972 1478 \n",
       "Q 972 1038 1006 884 \n",
       "Q 1059 663 1231 536 \n",
       "Q 1403 409 1656 409 \n",
       "Q 1909 409 2131 539 \n",
       "Q 2353 669 2445 892 \n",
       "Q 2538 1116 2538 1541 \n",
       "L 2538 3319 \n",
       "L 3100 3319 \n",
       "L 3100 0 \n",
       "L 2597 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-66\" d=\"M 556 0 \n",
       "L 556 2881 \n",
       "L 59 2881 \n",
       "L 59 3319 \n",
       "L 556 3319 \n",
       "L 556 3672 \n",
       "Q 556 4006 616 4169 \n",
       "Q 697 4388 901 4523 \n",
       "Q 1106 4659 1475 4659 \n",
       "Q 1713 4659 2000 4603 \n",
       "L 1916 4113 \n",
       "Q 1741 4144 1584 4144 \n",
       "Q 1328 4144 1222 4034 \n",
       "Q 1116 3925 1116 3625 \n",
       "L 1116 3319 \n",
       "L 1763 3319 \n",
       "L 1763 2881 \n",
       "L 1116 2881 \n",
       "L 1116 0 \n",
       "L 556 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-63\" d=\"M 2588 1216 \n",
       "L 3141 1144 \n",
       "Q 3050 572 2676 248 \n",
       "Q 2303 -75 1759 -75 \n",
       "Q 1078 -75 664 370 \n",
       "Q 250 816 250 1647 \n",
       "Q 250 2184 428 2587 \n",
       "Q 606 2991 970 3192 \n",
       "Q 1334 3394 1763 3394 \n",
       "Q 2303 3394 2647 3120 \n",
       "Q 2991 2847 3088 2344 \n",
       "L 2541 2259 \n",
       "Q 2463 2594 2264 2762 \n",
       "Q 2066 2931 1784 2931 \n",
       "Q 1359 2931 1093 2626 \n",
       "Q 828 2322 828 1663 \n",
       "Q 828 994 1084 691 \n",
       "Q 1341 388 1753 388 \n",
       "Q 2084 388 2306 591 \n",
       "Q 2528 794 2588 1216 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#ArialMT-54\"/>\n",
       "      <use xlink:href=\"#ArialMT-72\" x=\"57.333984\"/>\n",
       "      <use xlink:href=\"#ArialMT-75\" x=\"90.634766\"/>\n",
       "      <use xlink:href=\"#ArialMT-65\" x=\"146.25\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" x=\"201.865234\"/>\n",
       "      <use xlink:href=\"#ArialMT-66\" x=\"229.648438\"/>\n",
       "      <use xlink:href=\"#ArialMT-75\" x=\"257.431641\"/>\n",
       "      <use xlink:href=\"#ArialMT-6e\" x=\"313.046875\"/>\n",
       "      <use xlink:href=\"#ArialMT-63\" x=\"368.662109\"/>\n",
       "      <use xlink:href=\"#ArialMT-74\" x=\"418.662109\"/>\n",
       "      <use xlink:href=\"#ArialMT-69\" x=\"446.445312\"/>\n",
       "      <use xlink:href=\"#ArialMT-6f\" x=\"468.662109\"/>\n",
       "      <use xlink:href=\"#ArialMT-6e\" x=\"524.277344\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "  </g>\n",
       "  <g id=\"axes_2\">\n",
       "   <g id=\"matplotlib.axis_3\">\n",
       "    <g id=\"ytick_8\">\n",
       "     <g id=\"line2d_20\">\n",
       "      <defs>\n",
       "       <path id=\"m97f0efac56\" d=\"M 0 0 \n",
       "L 4.8 0 \n",
       "\" style=\"stroke: #262626\"/>\n",
       "      </defs>\n",
       "      <g>\n",
       "       <use xlink:href=\"#m97f0efac56\" x=\"400.3265\" y=\"274.116\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_22\">\n",
       "      <!-- 0.000 -->\n",
       "      <g style=\"fill: #ff7f0e\" transform=\"translate(408.6265 277.265437) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"83.398438\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"139.013672\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"194.628906\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_9\">\n",
       "     <g id=\"line2d_21\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m97f0efac56\" x=\"400.3265\" y=\"237.464458\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_23\">\n",
       "      <!-- 0.005 -->\n",
       "      <g style=\"fill: #ff7f0e\" transform=\"translate(408.6265 240.613896) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"83.398438\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"139.013672\"/>\n",
       "       <use xlink:href=\"#ArialMT-35\" x=\"194.628906\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_10\">\n",
       "     <g id=\"line2d_22\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m97f0efac56\" x=\"400.3265\" y=\"200.812916\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_24\">\n",
       "      <!-- 0.010 -->\n",
       "      <g style=\"fill: #ff7f0e\" transform=\"translate(408.6265 203.962354) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"83.398438\"/>\n",
       "       <use xlink:href=\"#ArialMT-31\" x=\"139.013672\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"194.628906\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_11\">\n",
       "     <g id=\"line2d_23\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m97f0efac56\" x=\"400.3265\" y=\"164.161375\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_25\">\n",
       "      <!-- 0.015 -->\n",
       "      <g style=\"fill: #ff7f0e\" transform=\"translate(408.6265 167.310812) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"83.398438\"/>\n",
       "       <use xlink:href=\"#ArialMT-31\" x=\"139.013672\"/>\n",
       "       <use xlink:href=\"#ArialMT-35\" x=\"194.628906\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_12\">\n",
       "     <g id=\"line2d_24\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m97f0efac56\" x=\"400.3265\" y=\"127.509833\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_26\">\n",
       "      <!-- 0.020 -->\n",
       "      <g style=\"fill: #ff7f0e\" transform=\"translate(408.6265 130.65927) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"83.398438\"/>\n",
       "       <use xlink:href=\"#ArialMT-32\" x=\"139.013672\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"194.628906\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_13\">\n",
       "     <g id=\"line2d_25\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m97f0efac56\" x=\"400.3265\" y=\"90.858291\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_27\">\n",
       "      <!-- 0.025 -->\n",
       "      <g style=\"fill: #ff7f0e\" transform=\"translate(408.6265 94.007728) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"83.398438\"/>\n",
       "       <use xlink:href=\"#ArialMT-32\" x=\"139.013672\"/>\n",
       "       <use xlink:href=\"#ArialMT-35\" x=\"194.628906\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_14\">\n",
       "     <g id=\"line2d_26\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m97f0efac56\" x=\"400.3265\" y=\"54.206749\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_28\">\n",
       "      <!-- 0.030 -->\n",
       "      <g style=\"fill: #ff7f0e\" transform=\"translate(408.6265 57.356187) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-33\" d=\"M 269 1209 \n",
       "L 831 1284 \n",
       "Q 928 806 1161 595 \n",
       "Q 1394 384 1728 384 \n",
       "Q 2125 384 2398 659 \n",
       "Q 2672 934 2672 1341 \n",
       "Q 2672 1728 2419 1979 \n",
       "Q 2166 2231 1775 2231 \n",
       "Q 1616 2231 1378 2169 \n",
       "L 1441 2663 \n",
       "Q 1497 2656 1531 2656 \n",
       "Q 1891 2656 2178 2843 \n",
       "Q 2466 3031 2466 3422 \n",
       "Q 2466 3731 2256 3934 \n",
       "Q 2047 4138 1716 4138 \n",
       "Q 1388 4138 1169 3931 \n",
       "Q 950 3725 888 3313 \n",
       "L 325 3413 \n",
       "Q 428 3978 793 4289 \n",
       "Q 1159 4600 1703 4600 \n",
       "Q 2078 4600 2393 4439 \n",
       "Q 2709 4278 2876 4000 \n",
       "Q 3044 3722 3044 3409 \n",
       "Q 3044 3113 2884 2869 \n",
       "Q 2725 2625 2413 2481 \n",
       "Q 2819 2388 3044 2092 \n",
       "Q 3269 1797 3269 1353 \n",
       "Q 3269 753 2831 336 \n",
       "Q 2394 -81 1725 -81 \n",
       "Q 1122 -81 723 278 \n",
       "Q 325 638 269 1209 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"83.398438\"/>\n",
       "       <use xlink:href=\"#ArialMT-33\" x=\"139.013672\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"194.628906\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"text_29\">\n",
       "     <!-- Information Acquisition Function -->\n",
       "     <g style=\"fill: #ff7f0e\" transform=\"translate(441.63425 221.18925) rotate(-90) scale(0.096 -0.096)\">\n",
       "      <defs>\n",
       "       <path id=\"ArialMT-49\" d=\"M 597 0 \n",
       "L 597 4581 \n",
       "L 1203 4581 \n",
       "L 1203 0 \n",
       "L 597 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-6d\" d=\"M 422 0 \n",
       "L 422 3319 \n",
       "L 925 3319 \n",
       "L 925 2853 \n",
       "Q 1081 3097 1340 3245 \n",
       "Q 1600 3394 1931 3394 \n",
       "Q 2300 3394 2536 3241 \n",
       "Q 2772 3088 2869 2813 \n",
       "Q 3263 3394 3894 3394 \n",
       "Q 4388 3394 4653 3120 \n",
       "Q 4919 2847 4919 2278 \n",
       "L 4919 0 \n",
       "L 4359 0 \n",
       "L 4359 2091 \n",
       "Q 4359 2428 4304 2576 \n",
       "Q 4250 2725 4106 2815 \n",
       "Q 3963 2906 3769 2906 \n",
       "Q 3419 2906 3187 2673 \n",
       "Q 2956 2441 2956 1928 \n",
       "L 2956 0 \n",
       "L 2394 0 \n",
       "L 2394 2156 \n",
       "Q 2394 2531 2256 2718 \n",
       "Q 2119 2906 1806 2906 \n",
       "Q 1569 2906 1367 2781 \n",
       "Q 1166 2656 1075 2415 \n",
       "Q 984 2175 984 1722 \n",
       "L 984 0 \n",
       "L 422 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-41\" d=\"M -9 0 \n",
       "L 1750 4581 \n",
       "L 2403 4581 \n",
       "L 4278 0 \n",
       "L 3588 0 \n",
       "L 3053 1388 \n",
       "L 1138 1388 \n",
       "L 634 0 \n",
       "L -9 0 \n",
       "z\n",
       "M 1313 1881 \n",
       "L 2866 1881 \n",
       "L 2388 3150 \n",
       "Q 2169 3728 2063 4100 \n",
       "Q 1975 3659 1816 3225 \n",
       "L 1313 1881 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-71\" d=\"M 2538 -1272 \n",
       "L 2538 353 \n",
       "Q 2406 169 2170 47 \n",
       "Q 1934 -75 1669 -75 \n",
       "Q 1078 -75 651 397 \n",
       "Q 225 869 225 1691 \n",
       "Q 225 2191 398 2587 \n",
       "Q 572 2984 901 3189 \n",
       "Q 1231 3394 1625 3394 \n",
       "Q 2241 3394 2594 2875 \n",
       "L 2594 3319 \n",
       "L 3100 3319 \n",
       "L 3100 -1272 \n",
       "L 2538 -1272 \n",
       "z\n",
       "M 803 1669 \n",
       "Q 803 1028 1072 708 \n",
       "Q 1341 388 1716 388 \n",
       "Q 2075 388 2334 692 \n",
       "Q 2594 997 2594 1619 \n",
       "Q 2594 2281 2320 2615 \n",
       "Q 2047 2950 1678 2950 \n",
       "Q 1313 2950 1058 2639 \n",
       "Q 803 2328 803 1669 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-46\" d=\"M 525 0 \n",
       "L 525 4581 \n",
       "L 3616 4581 \n",
       "L 3616 4041 \n",
       "L 1131 4041 \n",
       "L 1131 2622 \n",
       "L 3281 2622 \n",
       "L 3281 2081 \n",
       "L 1131 2081 \n",
       "L 1131 0 \n",
       "L 525 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#ArialMT-49\"/>\n",
       "      <use xlink:href=\"#ArialMT-6e\" x=\"27.783203\"/>\n",
       "      <use xlink:href=\"#ArialMT-66\" x=\"83.398438\"/>\n",
       "      <use xlink:href=\"#ArialMT-6f\" x=\"111.181641\"/>\n",
       "      <use xlink:href=\"#ArialMT-72\" x=\"166.796875\"/>\n",
       "      <use xlink:href=\"#ArialMT-6d\" x=\"200.097656\"/>\n",
       "      <use xlink:href=\"#ArialMT-61\" x=\"283.398438\"/>\n",
       "      <use xlink:href=\"#ArialMT-74\" x=\"339.013672\"/>\n",
       "      <use xlink:href=\"#ArialMT-69\" x=\"366.796875\"/>\n",
       "      <use xlink:href=\"#ArialMT-6f\" x=\"389.013672\"/>\n",
       "      <use xlink:href=\"#ArialMT-6e\" x=\"444.628906\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" x=\"500.244141\"/>\n",
       "      <use xlink:href=\"#ArialMT-41\" x=\"522.527344\"/>\n",
       "      <use xlink:href=\"#ArialMT-63\" x=\"589.226562\"/>\n",
       "      <use xlink:href=\"#ArialMT-71\" x=\"639.226562\"/>\n",
       "      <use xlink:href=\"#ArialMT-75\" x=\"694.841797\"/>\n",
       "      <use xlink:href=\"#ArialMT-69\" x=\"750.457031\"/>\n",
       "      <use xlink:href=\"#ArialMT-73\" x=\"772.673828\"/>\n",
       "      <use xlink:href=\"#ArialMT-69\" x=\"822.673828\"/>\n",
       "      <use xlink:href=\"#ArialMT-74\" x=\"844.890625\"/>\n",
       "      <use xlink:href=\"#ArialMT-69\" x=\"872.673828\"/>\n",
       "      <use xlink:href=\"#ArialMT-6f\" x=\"894.890625\"/>\n",
       "      <use xlink:href=\"#ArialMT-6e\" x=\"950.505859\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" x=\"1006.121094\"/>\n",
       "      <use xlink:href=\"#ArialMT-46\" x=\"1033.904297\"/>\n",
       "      <use xlink:href=\"#ArialMT-75\" x=\"1094.988281\"/>\n",
       "      <use xlink:href=\"#ArialMT-6e\" x=\"1150.603516\"/>\n",
       "      <use xlink:href=\"#ArialMT-63\" x=\"1206.21875\"/>\n",
       "      <use xlink:href=\"#ArialMT-74\" x=\"1256.21875\"/>\n",
       "      <use xlink:href=\"#ArialMT-69\" x=\"1284.001953\"/>\n",
       "      <use xlink:href=\"#ArialMT-6f\" x=\"1306.21875\"/>\n",
       "      <use xlink:href=\"#ArialMT-6e\" x=\"1361.833984\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"line2d_27\">\n",
       "    <path d=\"M 59.439227 274.116 \n",
       "L 62.718566 274.116 \n",
       "L 65.997905 274.116 \n",
       "L 69.277244 274.116 \n",
       "L 72.556583 274.116 \n",
       "L 75.835921 274.116 \n",
       "L 79.115261 274.116 \n",
       "L 82.394598 274.116 \n",
       "L 85.673938 274.116 \n",
       "L 88.953278 274.116 \n",
       "L 92.232615 274.116 \n",
       "L 95.511955 274.116 \n",
       "L 98.791295 274.116 \n",
       "L 102.070632 274.116 \n",
       "L 105.349969 274.116 \n",
       "L 108.629311 274.116 \n",
       "L 111.908649 274.116 \n",
       "L 115.187986 274.116 \n",
       "L 118.467328 274.115782 \n",
       "L 121.746666 274.111412 \n",
       "L 125.026003 274.017911 \n",
       "L 128.305345 272.342758 \n",
       "L 131.584682 255.705921 \n",
       "L 134.86402 184.688219 \n",
       "L 138.143362 68.202831 \n",
       "L 141.422694 32.196 \n",
       "L 144.702037 126.328103 \n",
       "L 147.981379 228.521387 \n",
       "L 151.260711 265.940127 \n",
       "L 154.540053 272.751716 \n",
       "L 157.819395 273.755322 \n",
       "L 161.098728 273.934678 \n",
       "L 164.37807 273.963078 \n",
       "L 167.657412 273.942106 \n",
       "L 170.936745 273.89186 \n",
       "L 174.216087 273.823482 \n",
       "L 177.495429 273.752482 \n",
       "L 180.774762 273.701799 \n",
       "L 184.054104 273.693061 \n",
       "L 187.333446 273.735661 \n",
       "L 190.612778 273.821297 \n",
       "L 193.892121 273.924192 \n",
       "L 197.171463 274.015071 \n",
       "L 200.450795 274.075366 \n",
       "L 203.730137 274.10464 \n",
       "L 207.00948 274.114034 \n",
       "L 210.288812 274.115782 \n",
       "L 213.568154 274.116 \n",
       "L 216.847496 274.116 \n",
       "L 220.126829 274.116 \n",
       "L 223.406181 274.116 \n",
       "L 226.685504 274.116 \n",
       "L 229.964846 274.116 \n",
       "L 233.244188 274.116 \n",
       "L 236.523511 274.116 \n",
       "L 239.802872 274.116 \n",
       "L 243.082195 274.116 \n",
       "L 246.361537 274.116 \n",
       "L 249.640879 274.116 \n",
       "L 252.920222 274.116 \n",
       "L 256.199564 274.116 \n",
       "L 259.478887 274.116 \n",
       "L 262.758248 274.116 \n",
       "L 266.037571 274.116 \n",
       "L 269.316913 274.116 \n",
       "L 272.596255 274.116 \n",
       "L 275.875578 274.116 \n",
       "L 279.15494 274.116 \n",
       "L 282.434262 274.116 \n",
       "L 285.713605 274.116 \n",
       "L 288.992947 274.116 \n",
       "L 292.272289 274.116 \n",
       "L 295.551631 274.116 \n",
       "L 298.830954 274.116 \n",
       "L 302.110315 274.116 \n",
       "L 305.389638 274.116 \n",
       "L 308.66898 274.116 \n",
       "L 311.948322 274.116 \n",
       "L 315.227645 274.116 \n",
       "L 318.507007 274.116 \n",
       "L 321.78633 274.116 \n",
       "L 325.065672 274.116 \n",
       "L 328.345014 274.116 \n",
       "L 331.624356 274.116 \n",
       "L 334.903698 274.116 \n",
       "L 338.183021 274.116 \n",
       "L 341.462363 274.116 \n",
       "L 344.741705 274.116 \n",
       "L 348.021048 274.116 \n",
       "L 351.30039 274.116 \n",
       "L 354.579713 274.116 \n",
       "L 357.859055 274.116 \n",
       "L 361.138397 274.116 \n",
       "L 364.417739 274.116 \n",
       "L 367.697081 274.116 \n",
       "L 370.976423 274.116 \n",
       "L 374.255766 274.116 \n",
       "L 377.535088 274.116 \n",
       "L 380.814431 274.116 \n",
       "L 384.093773 274.116 \n",
       "\" clip-path=\"url(#pa35bb67c4f)\" style=\"fill: none; stroke: #ff7f0e; stroke-width: 1.2; stroke-linecap: round\"/>\n",
       "   </g>\n",
       "   <g id=\"line2d_28\">\n",
       "    <path d=\"M 141.422694 274.116 \n",
       "L 141.422694 271.672364 \n",
       "L 141.422694 269.228727 \n",
       "L 141.422694 266.785091 \n",
       "L 141.422694 264.341454 \n",
       "L 141.422694 261.897818 \n",
       "L 141.422694 259.454181 \n",
       "L 141.422694 257.010545 \n",
       "L 141.422694 254.566909 \n",
       "L 141.422694 252.123272 \n",
       "L 141.422694 249.679636 \n",
       "L 141.422694 247.236 \n",
       "L 141.422694 244.792362 \n",
       "L 141.422694 242.348728 \n",
       "L 141.422694 239.90509 \n",
       "L 141.422694 237.461455 \n",
       "L 141.422694 235.017817 \n",
       "L 141.422694 232.574179 \n",
       "L 141.422694 230.130545 \n",
       "L 141.422694 227.686907 \n",
       "L 141.422694 225.243272 \n",
       "L 141.422694 222.799635 \n",
       "L 141.422694 220.356 \n",
       "L 141.422694 217.912362 \n",
       "L 141.422694 215.468724 \n",
       "L 141.422694 213.02509 \n",
       "L 141.422694 210.581455 \n",
       "L 141.422694 208.137814 \n",
       "L 141.422694 205.694179 \n",
       "L 141.422694 203.250545 \n",
       "L 141.422694 200.80691 \n",
       "L 141.422694 198.363269 \n",
       "L 141.422694 195.919635 \n",
       "L 141.422694 193.476 \n",
       "L 141.422694 191.032359 \n",
       "L 141.422694 188.588724 \n",
       "L 141.422694 186.14509 \n",
       "L 141.422694 183.701455 \n",
       "L 141.422694 181.257814 \n",
       "L 141.422694 178.814179 \n",
       "L 141.422694 176.370545 \n",
       "L 141.422694 173.926904 \n",
       "L 141.422694 171.483269 \n",
       "L 141.422694 169.039635 \n",
       "L 141.422694 166.596 \n",
       "L 141.422694 164.152359 \n",
       "L 141.422694 161.708724 \n",
       "L 141.422694 159.26509 \n",
       "L 141.422694 156.821448 \n",
       "L 141.422694 154.377821 \n",
       "L 141.422694 151.934179 \n",
       "L 141.422694 149.490552 \n",
       "L 141.422694 147.04691 \n",
       "L 141.422694 144.603283 \n",
       "L 141.422694 142.159641 \n",
       "L 141.422694 139.716 \n",
       "L 141.422694 137.272359 \n",
       "L 141.422694 134.828731 \n",
       "L 141.422694 132.385103 \n",
       "L 141.422694 129.941462 \n",
       "L 141.422694 127.497821 \n",
       "L 141.422694 125.054179 \n",
       "L 141.422694 122.610538 \n",
       "L 141.422694 120.16691 \n",
       "L 141.422694 117.723283 \n",
       "L 141.422694 115.279641 \n",
       "L 141.422694 112.836 \n",
       "L 141.422694 110.392359 \n",
       "L 141.422694 107.948731 \n",
       "L 141.422694 105.50509 \n",
       "L 141.422694 103.061462 \n",
       "L 141.422694 100.617821 \n",
       "L 141.422694 98.174179 \n",
       "L 141.422694 95.730538 \n",
       "L 141.422694 93.28691 \n",
       "L 141.422694 90.843283 \n",
       "L 141.422694 88.399641 \n",
       "L 141.422694 85.956 \n",
       "L 141.422694 83.512359 \n",
       "L 141.422694 81.068731 \n",
       "L 141.422694 78.62509 \n",
       "L 141.422694 76.181462 \n",
       "L 141.422694 73.737821 \n",
       "L 141.422694 71.294179 \n",
       "L 141.422694 68.850538 \n",
       "L 141.422694 66.40691 \n",
       "L 141.422694 63.963269 \n",
       "L 141.422694 61.519641 \n",
       "L 141.422694 59.076 \n",
       "L 141.422694 56.632359 \n",
       "L 141.422694 54.188731 \n",
       "L 141.422694 51.74509 \n",
       "L 141.422694 49.301462 \n",
       "L 141.422694 46.857821 \n",
       "L 141.422694 44.414179 \n",
       "L 141.422694 41.970538 \n",
       "L 141.422694 39.526897 \n",
       "L 141.422694 37.083283 \n",
       "L 141.422694 34.639641 \n",
       "L 141.422694 32.196 \n",
       "\" clip-path=\"url(#pa35bb67c4f)\" style=\"fill: none; stroke: #ff7f0e; stroke-linecap: round\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_7\">\n",
       "    <path d=\"M 43.2065 286.212 \n",
       "L 43.2065 20.1 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_8\">\n",
       "    <path d=\"M 400.3265 286.212 \n",
       "L 400.3265 20.1 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_9\">\n",
       "    <path d=\"M 43.2065 286.212 \n",
       "L 400.3265 286.212 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_10\">\n",
       "    <path d=\"M 43.2065 20.1 \n",
       "L 400.3265 20.1 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "  </g>\n",
       " </g>\n",
       " <defs>\n",
       "  <clipPath id=\"pa35bb67c4f\">\n",
       "   <rect x=\"43.2065\" y=\"20.1\" width=\"357.12\" height=\"266.112\"/>\n",
       "  </clipPath>\n",
       " </defs>\n",
       "</svg>\n"
      ],
      "text/plain": [
       "<Figure size 640x480 with 2 Axes>"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "image/svg+xml": [
       "<?xml version=\"1.0\" encoding=\"utf-8\" standalone=\"no\"?>\n",
       "<!DOCTYPE svg PUBLIC \"-//W3C//DTD SVG 1.1//EN\"\n",
       "  \"http://www.w3.org/Graphics/SVG/1.1/DTD/svg11.dtd\">\n",
       "<svg xmlns:xlink=\"http://www.w3.org/1999/xlink\" width=\"455.635875pt\" height=\"322.539375pt\" viewBox=\"0 0 455.635875 322.539375\" xmlns=\"http://www.w3.org/2000/svg\" version=\"1.1\">\n",
       " <metadata>\n",
       "  <rdf:RDF xmlns:dc=\"http://purl.org/dc/elements/1.1/\" xmlns:cc=\"http://creativecommons.org/ns#\" xmlns:rdf=\"http://www.w3.org/1999/02/22-rdf-syntax-ns#\">\n",
       "   <cc:Work>\n",
       "    <dc:type rdf:resource=\"http://purl.org/dc/dcmitype/StillImage\"/>\n",
       "    <dc:date>2023-10-23T15:18:34.563683</dc:date>\n",
       "    <dc:format>image/svg+xml</dc:format>\n",
       "    <dc:creator>\n",
       "     <cc:Agent>\n",
       "      <dc:title>Matplotlib v3.8.0, https://matplotlib.org/</dc:title>\n",
       "     </cc:Agent>\n",
       "    </dc:creator>\n",
       "   </cc:Work>\n",
       "  </rdf:RDF>\n",
       " </metadata>\n",
       " <defs>\n",
       "  <style type=\"text/css\">*{stroke-linejoin: round; stroke-linecap: butt}</style>\n",
       " </defs>\n",
       " <g id=\"figure_1\">\n",
       "  <g id=\"patch_1\">\n",
       "   <path d=\"M 0 322.539375 \n",
       "L 455.635875 322.539375 \n",
       "L 455.635875 0 \n",
       "L 0 0 \n",
       "z\n",
       "\" style=\"fill: #ffffff\"/>\n",
       "  </g>\n",
       "  <g id=\"axes_1\">\n",
       "   <g id=\"patch_2\">\n",
       "    <path d=\"M 43.2065 286.212 \n",
       "L 400.3265 286.212 \n",
       "L 400.3265 20.1 \n",
       "L 43.2065 20.1 \n",
       "z\n",
       "\" style=\"fill: #ffffff\"/>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_1\">\n",
       "    <g id=\"xtick_1\">\n",
       "     <g id=\"line2d_1\">\n",
       "      <defs>\n",
       "       <path id=\"mf6fb90a513\" d=\"M 0 0 \n",
       "L 0 4.8 \n",
       "\" style=\"stroke: #262626\"/>\n",
       "      </defs>\n",
       "      <g>\n",
       "       <use xlink:href=\"#mf6fb90a513\" x=\"59.439227\" y=\"286.212\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_1\">\n",
       "      <!-- 0.0 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(53.323227 300.810875) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-30\" d=\"M 266 2259 \n",
       "Q 266 3072 433 3567 \n",
       "Q 600 4063 929 4331 \n",
       "Q 1259 4600 1759 4600 \n",
       "Q 2128 4600 2406 4451 \n",
       "Q 2684 4303 2865 4023 \n",
       "Q 3047 3744 3150 3342 \n",
       "Q 3253 2941 3253 2259 \n",
       "Q 3253 1453 3087 958 \n",
       "Q 2922 463 2592 192 \n",
       "Q 2263 -78 1759 -78 \n",
       "Q 1097 -78 719 397 \n",
       "Q 266 969 266 2259 \n",
       "z\n",
       "M 844 2259 \n",
       "Q 844 1131 1108 757 \n",
       "Q 1372 384 1759 384 \n",
       "Q 2147 384 2411 759 \n",
       "Q 2675 1134 2675 2259 \n",
       "Q 2675 3391 2411 3762 \n",
       "Q 2147 4134 1753 4134 \n",
       "Q 1366 4134 1134 3806 \n",
       "Q 844 3388 844 2259 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "        <path id=\"ArialMT-2e\" d=\"M 581 0 \n",
       "L 581 641 \n",
       "L 1222 641 \n",
       "L 1222 0 \n",
       "L 581 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_2\">\n",
       "     <g id=\"line2d_2\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mf6fb90a513\" x=\"124.370136\" y=\"286.212\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_2\">\n",
       "      <!-- 0.2 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(118.254136 300.810875) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-32\" d=\"M 3222 541 \n",
       "L 3222 0 \n",
       "L 194 0 \n",
       "Q 188 203 259 391 \n",
       "Q 375 700 629 1000 \n",
       "Q 884 1300 1366 1694 \n",
       "Q 2113 2306 2375 2664 \n",
       "Q 2638 3022 2638 3341 \n",
       "Q 2638 3675 2398 3904 \n",
       "Q 2159 4134 1775 4134 \n",
       "Q 1369 4134 1125 3890 \n",
       "Q 881 3647 878 3216 \n",
       "L 300 3275 \n",
       "Q 359 3922 746 4261 \n",
       "Q 1134 4600 1788 4600 \n",
       "Q 2447 4600 2831 4234 \n",
       "Q 3216 3869 3216 3328 \n",
       "Q 3216 3053 3103 2787 \n",
       "Q 2991 2522 2730 2228 \n",
       "Q 2469 1934 1863 1422 \n",
       "Q 1356 997 1212 845 \n",
       "Q 1069 694 975 541 \n",
       "L 3222 541 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-32\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_3\">\n",
       "     <g id=\"line2d_3\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mf6fb90a513\" x=\"189.301045\" y=\"286.212\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_3\">\n",
       "      <!-- 0.4 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(183.185045 300.810875) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-34\" d=\"M 2069 0 \n",
       "L 2069 1097 \n",
       "L 81 1097 \n",
       "L 81 1613 \n",
       "L 2172 4581 \n",
       "L 2631 4581 \n",
       "L 2631 1613 \n",
       "L 3250 1613 \n",
       "L 3250 1097 \n",
       "L 2631 1097 \n",
       "L 2631 0 \n",
       "L 2069 0 \n",
       "z\n",
       "M 2069 1613 \n",
       "L 2069 3678 \n",
       "L 634 1613 \n",
       "L 2069 1613 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-34\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_4\">\n",
       "     <g id=\"line2d_4\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mf6fb90a513\" x=\"254.231955\" y=\"286.212\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_4\">\n",
       "      <!-- 0.6 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(248.115955 300.810875) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-36\" d=\"M 3184 3459 \n",
       "L 2625 3416 \n",
       "Q 2550 3747 2413 3897 \n",
       "Q 2184 4138 1850 4138 \n",
       "Q 1581 4138 1378 3988 \n",
       "Q 1113 3794 959 3422 \n",
       "Q 806 3050 800 2363 \n",
       "Q 1003 2672 1297 2822 \n",
       "Q 1591 2972 1913 2972 \n",
       "Q 2475 2972 2870 2558 \n",
       "Q 3266 2144 3266 1488 \n",
       "Q 3266 1056 3080 686 \n",
       "Q 2894 316 2569 119 \n",
       "Q 2244 -78 1831 -78 \n",
       "Q 1128 -78 684 439 \n",
       "Q 241 956 241 2144 \n",
       "Q 241 3472 731 4075 \n",
       "Q 1159 4600 1884 4600 \n",
       "Q 2425 4600 2770 4297 \n",
       "Q 3116 3994 3184 3459 \n",
       "z\n",
       "M 888 1484 \n",
       "Q 888 1194 1011 928 \n",
       "Q 1134 663 1356 523 \n",
       "Q 1578 384 1822 384 \n",
       "Q 2178 384 2434 671 \n",
       "Q 2691 959 2691 1453 \n",
       "Q 2691 1928 2437 2201 \n",
       "Q 2184 2475 1800 2475 \n",
       "Q 1419 2475 1153 2201 \n",
       "Q 888 1928 888 1484 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-36\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_5\">\n",
       "     <g id=\"line2d_5\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mf6fb90a513\" x=\"319.162864\" y=\"286.212\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_5\">\n",
       "      <!-- 0.8 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(313.046864 300.810875) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-38\" d=\"M 1131 2484 \n",
       "Q 781 2613 612 2850 \n",
       "Q 444 3088 444 3419 \n",
       "Q 444 3919 803 4259 \n",
       "Q 1163 4600 1759 4600 \n",
       "Q 2359 4600 2725 4251 \n",
       "Q 3091 3903 3091 3403 \n",
       "Q 3091 3084 2923 2848 \n",
       "Q 2756 2613 2416 2484 \n",
       "Q 2838 2347 3058 2040 \n",
       "Q 3278 1734 3278 1309 \n",
       "Q 3278 722 2862 322 \n",
       "Q 2447 -78 1769 -78 \n",
       "Q 1091 -78 675 323 \n",
       "Q 259 725 259 1325 \n",
       "Q 259 1772 486 2073 \n",
       "Q 713 2375 1131 2484 \n",
       "z\n",
       "M 1019 3438 \n",
       "Q 1019 3113 1228 2906 \n",
       "Q 1438 2700 1772 2700 \n",
       "Q 2097 2700 2305 2904 \n",
       "Q 2513 3109 2513 3406 \n",
       "Q 2513 3716 2298 3927 \n",
       "Q 2084 4138 1766 4138 \n",
       "Q 1444 4138 1231 3931 \n",
       "Q 1019 3725 1019 3438 \n",
       "z\n",
       "M 838 1322 \n",
       "Q 838 1081 952 856 \n",
       "Q 1066 631 1291 507 \n",
       "Q 1516 384 1775 384 \n",
       "Q 2178 384 2440 643 \n",
       "Q 2703 903 2703 1303 \n",
       "Q 2703 1709 2433 1975 \n",
       "Q 2163 2241 1756 2241 \n",
       "Q 1359 2241 1098 1978 \n",
       "Q 838 1716 838 1322 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-38\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_6\">\n",
       "     <g id=\"line2d_6\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mf6fb90a513\" x=\"384.093773\" y=\"286.212\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_6\">\n",
       "      <!-- 1.0 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(377.977773 300.810875) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-31\" d=\"M 2384 0 \n",
       "L 1822 0 \n",
       "L 1822 3584 \n",
       "Q 1619 3391 1289 3197 \n",
       "Q 959 3003 697 2906 \n",
       "L 697 3450 \n",
       "Q 1169 3672 1522 3987 \n",
       "Q 1875 4303 2022 4600 \n",
       "L 2384 4600 \n",
       "L 2384 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-31\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"text_7\">\n",
       "     <!-- $x$ -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(218.8865 313.431375) scale(0.096 -0.096)\">\n",
       "      <defs>\n",
       "       <path id=\"DejaVuSans-Oblique-78\" d=\"M 3841 3500 \n",
       "L 2234 1784 \n",
       "L 3219 0 \n",
       "L 2559 0 \n",
       "L 1819 1388 \n",
       "L 531 0 \n",
       "L -166 0 \n",
       "L 1556 1844 \n",
       "L 641 3500 \n",
       "L 1300 3500 \n",
       "L 1972 2234 \n",
       "L 3144 3500 \n",
       "L 3841 3500 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-78\" transform=\"translate(0 0.3125)\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_2\">\n",
       "    <g id=\"ytick_1\">\n",
       "     <g id=\"line2d_7\">\n",
       "      <defs>\n",
       "       <path id=\"m43c6786039\" d=\"M 0 0 \n",
       "L -4.8 0 \n",
       "\" style=\"stroke: #262626\"/>\n",
       "      </defs>\n",
       "      <g>\n",
       "       <use xlink:href=\"#m43c6786039\" x=\"43.2065\" y=\"285.922316\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_8\">\n",
       "      <!-- −12 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(19.9795 289.071753) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-2212\" d=\"M 3381 1997 \n",
       "L 356 1997 \n",
       "L 356 2522 \n",
       "L 3381 2522 \n",
       "L 3381 1997 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-31\" x=\"58.398438\"/>\n",
       "       <use xlink:href=\"#ArialMT-32\" x=\"114.013672\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_2\">\n",
       "     <g id=\"line2d_8\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m43c6786039\" x=\"43.2065\" y=\"244.410432\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_9\">\n",
       "      <!-- −10 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(19.9795 247.55987) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-31\" x=\"58.398438\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"114.013672\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_3\">\n",
       "     <g id=\"line2d_9\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m43c6786039\" x=\"43.2065\" y=\"202.898548\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_10\">\n",
       "      <!-- −8 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(24.873125 206.047986) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-38\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_4\">\n",
       "     <g id=\"line2d_10\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m43c6786039\" x=\"43.2065\" y=\"161.386665\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_11\">\n",
       "      <!-- −6 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(24.873125 164.536102) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-36\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_5\">\n",
       "     <g id=\"line2d_11\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m43c6786039\" x=\"43.2065\" y=\"119.874781\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_12\">\n",
       "      <!-- −4 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(24.873125 123.024219) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-34\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_6\">\n",
       "     <g id=\"line2d_12\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m43c6786039\" x=\"43.2065\" y=\"78.362898\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_13\">\n",
       "      <!-- −2 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(24.873125 81.512335) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-32\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_7\">\n",
       "     <g id=\"line2d_13\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m43c6786039\" x=\"43.2065\" y=\"36.851014\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_14\">\n",
       "      <!-- 0 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(30.012875 40.000451) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"text_15\">\n",
       "     <!-- $y$ -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(13.9635 156.036) rotate(-90) scale(0.096 -0.096)\">\n",
       "      <defs>\n",
       "       <path id=\"DejaVuSans-Oblique-79\" d=\"M 1588 -325 \n",
       "Q 1188 -997 936 -1164 \n",
       "Q 684 -1331 294 -1331 \n",
       "L -159 -1331 \n",
       "L -63 -850 \n",
       "L 269 -850 \n",
       "Q 509 -850 678 -719 \n",
       "Q 847 -588 1056 -206 \n",
       "L 1234 128 \n",
       "L 459 3500 \n",
       "L 1069 3500 \n",
       "L 1650 819 \n",
       "L 3256 3500 \n",
       "L 3859 3500 \n",
       "L 1588 -325 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-79\" transform=\"translate(0 0.3125)\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"PolyCollection_1\">\n",
       "    <defs>\n",
       "     <path id=\"m1185a9fbeb\" d=\"M 59.439227 -207.713559 \n",
       "L 59.439227 -199.432167 \n",
       "L 62.718566 -201.466715 \n",
       "L 65.997905 -203.08093 \n",
       "L 69.277244 -205.057203 \n",
       "L 72.556583 -207.630714 \n",
       "L 75.835921 -210.835716 \n",
       "L 79.115261 -214.63642 \n",
       "L 82.394598 -218.962617 \n",
       "L 85.673938 -223.725681 \n",
       "L 88.953278 -228.825928 \n",
       "L 92.232615 -234.154316 \n",
       "L 95.511955 -239.600129 \n",
       "L 98.791295 -245.051942 \n",
       "L 102.070632 -250.402556 \n",
       "L 105.349969 -255.552401 \n",
       "L 108.629311 -260.411178 \n",
       "L 111.908649 -264.900929 \n",
       "L 115.187986 -268.959634 \n",
       "L 118.467328 -272.540591 \n",
       "L 121.746666 -275.619255 \n",
       "L 125.026003 -278.186885 \n",
       "L 128.305345 -280.253024 \n",
       "L 131.584682 -281.838383 \n",
       "L 134.86402 -282.967071 \n",
       "L 138.143362 -283.658761 \n",
       "L 141.422694 -283.927158 \n",
       "L 144.702037 -283.775093 \n",
       "L 147.981379 -283.20049 \n",
       "L 151.260711 -282.199508 \n",
       "L 154.540053 -280.771875 \n",
       "L 157.819395 -278.919725 \n",
       "L 161.098728 -276.650302 \n",
       "L 164.37807 -273.971787 \n",
       "L 167.657412 -270.897172 \n",
       "L 170.936745 -267.443391 \n",
       "L 174.216087 -263.633941 \n",
       "L 177.495429 -259.49824 \n",
       "L 180.774762 -255.071656 \n",
       "L 184.054104 -250.394861 \n",
       "L 187.333446 -245.511922 \n",
       "L 190.612778 -240.470346 \n",
       "L 193.892121 -235.318173 \n",
       "L 197.171463 -230.103049 \n",
       "L 200.450795 -224.870041 \n",
       "L 203.730137 -219.660538 \n",
       "L 207.00948 -214.509964 \n",
       "L 210.288812 -209.447059 \n",
       "L 213.568154 -204.492504 \n",
       "L 216.847496 -199.65816 \n",
       "L 220.126829 -194.946259 \n",
       "L 223.406181 -190.349334 \n",
       "L 226.685504 -185.849026 \n",
       "L 229.964846 -181.413168 \n",
       "L 233.244188 -176.986842 \n",
       "L 236.523511 -172.458831 \n",
       "L 239.802872 -167.516029 \n",
       "L 243.082195 -161.087834 \n",
       "L 246.361537 -151.862422 \n",
       "L 249.640879 -141.03592 \n",
       "L 252.920222 -129.753404 \n",
       "L 256.199564 -118.451143 \n",
       "L 259.478887 -107.37827 \n",
       "L 262.758248 -96.738201 \n",
       "L 266.037571 -86.721973 \n",
       "L 269.316913 -77.515 \n",
       "L 272.596255 -69.297707 \n",
       "L 275.875578 -62.243316 \n",
       "L 279.15494 -56.515013 \n",
       "L 282.434262 -52.261075 \n",
       "L 285.713605 -49.610802 \n",
       "L 288.992947 -48.671815 \n",
       "L 292.272289 -49.523212 \n",
       "L 295.551631 -52.213193 \n",
       "L 298.830954 -56.758028 \n",
       "L 302.110315 -63.133451 \n",
       "L 305.389638 -71.278593 \n",
       "L 308.66898 -81.092166 \n",
       "L 311.948322 -92.432897 \n",
       "L 315.227645 -105.12139 \n",
       "L 318.507007 -118.943074 \n",
       "L 321.78633 -133.650359 \n",
       "L 325.065672 -148.968064 \n",
       "L 328.345014 -164.600579 \n",
       "L 331.624356 -180.232105 \n",
       "L 334.903698 -195.53829 \n",
       "L 338.183021 -210.186622 \n",
       "L 341.462363 -223.836555 \n",
       "L 344.741705 -236.142902 \n",
       "L 348.021048 -246.773511 \n",
       "L 351.30039 -255.502724 \n",
       "L 354.579713 -262.27836 \n",
       "L 357.859055 -267.135082 \n",
       "L 361.138397 -270.095645 \n",
       "L 364.417739 -271.180633 \n",
       "L 367.697081 -270.404705 \n",
       "L 370.976423 -267.817568 \n",
       "L 374.255766 -263.471048 \n",
       "L 377.535088 -257.408686 \n",
       "L 380.814431 -249.638027 \n",
       "L 384.093773 -240.151433 \n",
       "L 384.093773 -248.300969 \n",
       "L 384.093773 -248.300969 \n",
       "L 380.814431 -256.894271 \n",
       "L 377.535088 -264.58843 \n",
       "L 374.255766 -270.949357 \n",
       "L 370.976423 -275.620218 \n",
       "L 367.697081 -278.372503 \n",
       "L 364.417739 -279.078463 \n",
       "L 361.138397 -277.695011 \n",
       "L 357.859055 -274.261821 \n",
       "L 354.579713 -268.909378 \n",
       "L 351.30039 -261.882769 \n",
       "L 348.021048 -253.523231 \n",
       "L 344.741705 -244.158638 \n",
       "L 341.462363 -234.012741 \n",
       "L 338.183021 -223.266461 \n",
       "L 334.903698 -212.112386 \n",
       "L 331.624356 -200.777197 \n",
       "L 328.345014 -189.497512 \n",
       "L 325.065672 -178.502589 \n",
       "L 321.78633 -168.015036 \n",
       "L 318.507007 -158.226335 \n",
       "L 315.227645 -149.303144 \n",
       "L 311.948322 -141.379333 \n",
       "L 308.66898 -134.550688 \n",
       "L 305.389638 -128.880599 \n",
       "L 302.110315 -124.395968 \n",
       "L 298.830954 -121.092064 \n",
       "L 295.551631 -118.932464 \n",
       "L 292.272289 -117.858815 \n",
       "L 288.992947 -117.786684 \n",
       "L 285.713605 -118.619217 \n",
       "L 282.434262 -120.248347 \n",
       "L 279.15494 -122.558542 \n",
       "L 275.875578 -125.435105 \n",
       "L 272.596255 -128.766999 \n",
       "L 269.316913 -132.449551 \n",
       "L 266.037571 -136.390974 \n",
       "L 262.758248 -140.513219 \n",
       "L 259.478887 -144.756051 \n",
       "L 256.199564 -149.081605 \n",
       "L 252.920222 -153.485574 \n",
       "L 249.640879 -158.031142 \n",
       "L 246.361537 -162.992462 \n",
       "L 243.082195 -169.376089 \n",
       "L 239.802872 -178.26273 \n",
       "L 236.523511 -188.247663 \n",
       "L 233.244188 -198.18701 \n",
       "L 229.964846 -207.713583 \n",
       "L 226.685504 -216.677872 \n",
       "L 223.406181 -225.000961 \n",
       "L 220.126829 -232.638732 \n",
       "L 216.847496 -239.570269 \n",
       "L 213.568154 -245.793636 \n",
       "L 210.288812 -251.322417 \n",
       "L 207.00948 -256.184258 \n",
       "L 203.730137 -260.418671 \n",
       "L 200.450795 -264.074757 \n",
       "L 197.171463 -267.209118 \n",
       "L 193.892121 -269.883815 \n",
       "L 190.612778 -272.163395 \n",
       "L 187.333446 -274.112958 \n",
       "L 184.054104 -275.795388 \n",
       "L 180.774762 -277.269521 \n",
       "L 177.495429 -278.586908 \n",
       "L 174.216087 -279.791028 \n",
       "L 170.936745 -280.915433 \n",
       "L 167.657412 -281.982219 \n",
       "L 164.37807 -283.002088 \n",
       "L 161.098728 -283.974147 \n",
       "L 157.819395 -284.887576 \n",
       "L 154.540053 -285.722299 \n",
       "L 151.260711 -286.452969 \n",
       "L 147.981379 -287.045576 \n",
       "L 144.702037 -287.461535 \n",
       "L 141.422694 -287.657623 \n",
       "L 138.143362 -287.593207 \n",
       "L 134.86402 -287.234883 \n",
       "L 131.584682 -286.563991 \n",
       "L 128.305345 -285.574652 \n",
       "L 125.026003 -284.27259 \n",
       "L 121.746666 -282.670573 \n",
       "L 118.467328 -280.781276 \n",
       "L 115.187986 -278.612357 \n",
       "L 111.908649 -276.16901 \n",
       "L 108.629311 -273.449138 \n",
       "L 105.349969 -270.450356 \n",
       "L 102.070632 -267.168738 \n",
       "L 98.791295 -263.602356 \n",
       "L 95.511955 -259.752673 \n",
       "L 92.232615 -255.624811 \n",
       "L 88.953278 -251.229606 \n",
       "L 85.673938 -246.58465 \n",
       "L 82.394598 -241.714439 \n",
       "L 79.115261 -236.653771 \n",
       "L 75.835921 -231.447455 \n",
       "L 72.556583 -226.154054 \n",
       "L 69.277244 -220.859436 \n",
       "L 65.997905 -215.709584 \n",
       "L 62.718566 -211.038604 \n",
       "L 59.439227 -207.713559 \n",
       "z\n",
       "\" style=\"stroke: #1f77b4; stroke-opacity: 0.5; stroke-width: 0.8\"/>\n",
       "    </defs>\n",
       "    <g clip-path=\"url(#p9ace12a451)\">\n",
       "     <use xlink:href=\"#m1185a9fbeb\" x=\"0\" y=\"322.539375\" style=\"fill: #1f77b4; fill-opacity: 0.5; stroke: #1f77b4; stroke-opacity: 0.5; stroke-width: 0.8\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"PolyCollection_2\">\n",
       "    <defs>\n",
       "     <path id=\"m75b43f1b0f\" d=\"M 59.439227 -199.432167 \n",
       "L 59.439227 -197.709618 \n",
       "L 62.718566 -199.917229 \n",
       "L 65.997905 -201.838593 \n",
       "L 69.277244 -204.033075 \n",
       "L 72.556583 -206.742955 \n",
       "L 75.835921 -210.031083 \n",
       "L 79.115261 -213.879754 \n",
       "L 82.394598 -218.228873 \n",
       "L 85.673938 -222.995169 \n",
       "L 88.953278 -228.08149 \n",
       "L 92.232615 -233.379657 \n",
       "L 95.511955 -238.778527 \n",
       "L 98.791295 -244.165368 \n",
       "L 102.070632 -249.431044 \n",
       "L 105.349969 -254.473796 \n",
       "L 108.629311 -259.201673 \n",
       "L 111.908649 -263.53677 \n",
       "L 115.187986 -267.419983 \n",
       "L 118.467328 -270.812037 \n",
       "L 121.746666 -273.698571 \n",
       "L 125.026003 -276.082765 \n",
       "L 128.305345 -277.983088 \n",
       "L 131.584682 -279.42466 \n",
       "L 134.86402 -280.433438 \n",
       "L 138.143362 -281.032256 \n",
       "L 141.422694 -281.241406 \n",
       "L 144.702037 -281.076306 \n",
       "L 147.981379 -280.548261 \n",
       "L 151.260711 -279.661976 \n",
       "L 154.540053 -278.413968 \n",
       "L 157.819395 -276.791295 \n",
       "L 161.098728 -274.776698 \n",
       "L 164.37807 -272.353509 \n",
       "L 167.657412 -269.514963 \n",
       "L 170.936745 -266.266995 \n",
       "L 174.216087 -262.629795 \n",
       "L 177.495429 -258.634566 \n",
       "L 180.774762 -254.320751 \n",
       "L 184.054104 -249.733649 \n",
       "L 187.333446 -244.921596 \n",
       "L 190.612778 -239.935639 \n",
       "L 193.892121 -234.826618 \n",
       "L 197.171463 -229.644313 \n",
       "L 200.450795 -224.435311 \n",
       "L 203.730137 -219.24204 \n",
       "L 207.00948 -214.100487 \n",
       "L 210.288812 -209.039512 \n",
       "L 213.568154 -204.079399 \n",
       "L 216.847496 -199.230977 \n",
       "L 220.126829 -194.494491 \n",
       "L 223.406181 -189.858977 \n",
       "L 226.685504 -185.29984 \n",
       "L 229.964846 -180.773512 \n",
       "L 233.244188 -176.202983 \n",
       "L 236.523511 -171.433936 \n",
       "L 239.802872 -166.099293 \n",
       "L 243.082195 -159.366285 \n",
       "L 246.361537 -150.484692 \n",
       "L 249.640879 -140.076168 \n",
       "L 252.920222 -129.048238 \n",
       "L 256.199564 -117.898523 \n",
       "L 259.478887 -106.92278 \n",
       "L 262.758248 -96.348014 \n",
       "L 266.037571 -86.377431 \n",
       "L 269.316913 -77.203079 \n",
       "L 272.596255 -69.009342 \n",
       "L 275.875578 -61.971777 \n",
       "L 279.15494 -56.255112 \n",
       "L 282.434262 -52.008538 \n",
       "L 285.713605 -49.361986 \n",
       "L 288.992947 -48.423375 \n",
       "L 292.272289 -49.271981 \n",
       "L 295.551631 -51.955905 \n",
       "L 298.830954 -56.491279 \n",
       "L 302.110315 -62.853439 \n",
       "L 305.389638 -70.980964 \n",
       "L 308.66898 -80.771734 \n",
       "L 311.948322 -92.083328 \n",
       "L 315.227645 -104.734746 \n",
       "L 318.507007 -118.5092 \n",
       "L 321.78633 -133.156013 \n",
       "L 325.065672 -148.395689 \n",
       "L 328.345014 -163.926679 \n",
       "L 331.624356 -179.425048 \n",
       "L 334.903698 -194.556705 \n",
       "L 338.183021 -208.980386 \n",
       "L 341.462363 -222.357987 \n",
       "L 344.741705 -234.380556 \n",
       "L 348.021048 -244.798413 \n",
       "L 351.30039 -253.457422 \n",
       "L 354.579713 -260.281151 \n",
       "L 357.859055 -265.227623 \n",
       "L 361.138397 -268.26772 \n",
       "L 364.417739 -269.400125 \n",
       "L 367.697081 -268.635013 \n",
       "L 370.976423 -266.022166 \n",
       "L 374.255766 -261.623284 \n",
       "L 377.535088 -255.510429 \n",
       "L 380.814431 -247.752926 \n",
       "L 384.093773 -238.409317 \n",
       "L 384.093773 -240.151433 \n",
       "L 384.093773 -240.151433 \n",
       "L 380.814431 -249.638027 \n",
       "L 377.535088 -257.408686 \n",
       "L 374.255766 -263.471048 \n",
       "L 370.976423 -267.817568 \n",
       "L 367.697081 -270.404705 \n",
       "L 364.417739 -271.180633 \n",
       "L 361.138397 -270.095645 \n",
       "L 357.859055 -267.135082 \n",
       "L 354.579713 -262.27836 \n",
       "L 351.30039 -255.502724 \n",
       "L 348.021048 -246.773511 \n",
       "L 344.741705 -236.142902 \n",
       "L 341.462363 -223.836555 \n",
       "L 338.183021 -210.186622 \n",
       "L 334.903698 -195.53829 \n",
       "L 331.624356 -180.232105 \n",
       "L 328.345014 -164.600579 \n",
       "L 325.065672 -148.968064 \n",
       "L 321.78633 -133.650359 \n",
       "L 318.507007 -118.943074 \n",
       "L 315.227645 -105.12139 \n",
       "L 311.948322 -92.432897 \n",
       "L 308.66898 -81.092166 \n",
       "L 305.389638 -71.278593 \n",
       "L 302.110315 -63.133451 \n",
       "L 298.830954 -56.758028 \n",
       "L 295.551631 -52.213193 \n",
       "L 292.272289 -49.523212 \n",
       "L 288.992947 -48.671815 \n",
       "L 285.713605 -49.610802 \n",
       "L 282.434262 -52.261075 \n",
       "L 279.15494 -56.515013 \n",
       "L 275.875578 -62.243316 \n",
       "L 272.596255 -69.297707 \n",
       "L 269.316913 -77.515 \n",
       "L 266.037571 -86.721973 \n",
       "L 262.758248 -96.738201 \n",
       "L 259.478887 -107.37827 \n",
       "L 256.199564 -118.451143 \n",
       "L 252.920222 -129.753404 \n",
       "L 249.640879 -141.03592 \n",
       "L 246.361537 -151.862422 \n",
       "L 243.082195 -161.087834 \n",
       "L 239.802872 -167.516029 \n",
       "L 236.523511 -172.458831 \n",
       "L 233.244188 -176.986842 \n",
       "L 229.964846 -181.413168 \n",
       "L 226.685504 -185.849026 \n",
       "L 223.406181 -190.349334 \n",
       "L 220.126829 -194.946259 \n",
       "L 216.847496 -199.65816 \n",
       "L 213.568154 -204.492504 \n",
       "L 210.288812 -209.447059 \n",
       "L 207.00948 -214.509964 \n",
       "L 203.730137 -219.660538 \n",
       "L 200.450795 -224.870041 \n",
       "L 197.171463 -230.103049 \n",
       "L 193.892121 -235.318173 \n",
       "L 190.612778 -240.470346 \n",
       "L 187.333446 -245.511922 \n",
       "L 184.054104 -250.394861 \n",
       "L 180.774762 -255.071656 \n",
       "L 177.495429 -259.49824 \n",
       "L 174.216087 -263.633941 \n",
       "L 170.936745 -267.443391 \n",
       "L 167.657412 -270.897172 \n",
       "L 164.37807 -273.971787 \n",
       "L 161.098728 -276.650302 \n",
       "L 157.819395 -278.919725 \n",
       "L 154.540053 -280.771875 \n",
       "L 151.260711 -282.199508 \n",
       "L 147.981379 -283.20049 \n",
       "L 144.702037 -283.775093 \n",
       "L 141.422694 -283.927158 \n",
       "L 138.143362 -283.658761 \n",
       "L 134.86402 -282.967071 \n",
       "L 131.584682 -281.838383 \n",
       "L 128.305345 -280.253024 \n",
       "L 125.026003 -278.186885 \n",
       "L 121.746666 -275.619255 \n",
       "L 118.467328 -272.540591 \n",
       "L 115.187986 -268.959634 \n",
       "L 111.908649 -264.900929 \n",
       "L 108.629311 -260.411178 \n",
       "L 105.349969 -255.552401 \n",
       "L 102.070632 -250.402556 \n",
       "L 98.791295 -245.051942 \n",
       "L 95.511955 -239.600129 \n",
       "L 92.232615 -234.154316 \n",
       "L 88.953278 -228.825928 \n",
       "L 85.673938 -223.725681 \n",
       "L 82.394598 -218.962617 \n",
       "L 79.115261 -214.63642 \n",
       "L 75.835921 -210.835716 \n",
       "L 72.556583 -207.630714 \n",
       "L 69.277244 -205.057203 \n",
       "L 65.997905 -203.08093 \n",
       "L 62.718566 -201.466715 \n",
       "L 59.439227 -199.432167 \n",
       "z\n",
       "\" style=\"stroke: #ff7f0e; stroke-opacity: 0.5; stroke-width: 0.8\"/>\n",
       "    </defs>\n",
       "    <g clip-path=\"url(#p9ace12a451)\">\n",
       "     <use xlink:href=\"#m75b43f1b0f\" x=\"0\" y=\"322.539375\" style=\"fill: #ff7f0e; fill-opacity: 0.5; stroke: #ff7f0e; stroke-opacity: 0.5; stroke-width: 0.8\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"PolyCollection_3\">\n",
       "    <defs>\n",
       "     <path id=\"mc4712339c9\" d=\"M 59.439227 -209.436117 \n",
       "L 59.439227 -207.713559 \n",
       "L 62.718566 -211.038604 \n",
       "L 65.997905 -215.709584 \n",
       "L 69.277244 -220.859436 \n",
       "L 72.556583 -226.154054 \n",
       "L 75.835921 -231.447455 \n",
       "L 79.115261 -236.653771 \n",
       "L 82.394598 -241.714439 \n",
       "L 85.673938 -246.58465 \n",
       "L 88.953278 -251.229606 \n",
       "L 92.232615 -255.624811 \n",
       "L 95.511955 -259.752673 \n",
       "L 98.791295 -263.602356 \n",
       "L 102.070632 -267.168738 \n",
       "L 105.349969 -270.450356 \n",
       "L 108.629311 -273.449138 \n",
       "L 111.908649 -276.16901 \n",
       "L 115.187986 -278.612357 \n",
       "L 118.467328 -280.781276 \n",
       "L 121.746666 -282.670573 \n",
       "L 125.026003 -284.27259 \n",
       "L 128.305345 -285.574652 \n",
       "L 131.584682 -286.563991 \n",
       "L 134.86402 -287.234883 \n",
       "L 138.143362 -287.593207 \n",
       "L 141.422694 -287.657623 \n",
       "L 144.702037 -287.461535 \n",
       "L 147.981379 -287.045576 \n",
       "L 151.260711 -286.452969 \n",
       "L 154.540053 -285.722299 \n",
       "L 157.819395 -284.887576 \n",
       "L 161.098728 -283.974147 \n",
       "L 164.37807 -283.002088 \n",
       "L 167.657412 -281.982219 \n",
       "L 170.936745 -280.915433 \n",
       "L 174.216087 -279.791028 \n",
       "L 177.495429 -278.586908 \n",
       "L 180.774762 -277.269521 \n",
       "L 184.054104 -275.795388 \n",
       "L 187.333446 -274.112958 \n",
       "L 190.612778 -272.163395 \n",
       "L 193.892121 -269.883815 \n",
       "L 197.171463 -267.209118 \n",
       "L 200.450795 -264.074757 \n",
       "L 203.730137 -260.418671 \n",
       "L 207.00948 -256.184258 \n",
       "L 210.288812 -251.322417 \n",
       "L 213.568154 -245.793636 \n",
       "L 216.847496 -239.570269 \n",
       "L 220.126829 -232.638732 \n",
       "L 223.406181 -225.000961 \n",
       "L 226.685504 -216.677872 \n",
       "L 229.964846 -207.713583 \n",
       "L 233.244188 -198.18701 \n",
       "L 236.523511 -188.247663 \n",
       "L 239.802872 -178.26273 \n",
       "L 243.082195 -169.376089 \n",
       "L 246.361537 -162.992462 \n",
       "L 249.640879 -158.031142 \n",
       "L 252.920222 -153.485574 \n",
       "L 256.199564 -149.081605 \n",
       "L 259.478887 -144.756051 \n",
       "L 262.758248 -140.513219 \n",
       "L 266.037571 -136.390974 \n",
       "L 269.316913 -132.449551 \n",
       "L 272.596255 -128.766999 \n",
       "L 275.875578 -125.435105 \n",
       "L 279.15494 -122.558542 \n",
       "L 282.434262 -120.248347 \n",
       "L 285.713605 -118.619217 \n",
       "L 288.992947 -117.786684 \n",
       "L 292.272289 -117.858815 \n",
       "L 295.551631 -118.932464 \n",
       "L 298.830954 -121.092064 \n",
       "L 302.110315 -124.395968 \n",
       "L 305.389638 -128.880599 \n",
       "L 308.66898 -134.550688 \n",
       "L 311.948322 -141.379333 \n",
       "L 315.227645 -149.303144 \n",
       "L 318.507007 -158.226335 \n",
       "L 321.78633 -168.015036 \n",
       "L 325.065672 -178.502589 \n",
       "L 328.345014 -189.497512 \n",
       "L 331.624356 -200.777197 \n",
       "L 334.903698 -212.112386 \n",
       "L 338.183021 -223.266461 \n",
       "L 341.462363 -234.012741 \n",
       "L 344.741705 -244.158638 \n",
       "L 348.021048 -253.523231 \n",
       "L 351.30039 -261.882769 \n",
       "L 354.579713 -268.909378 \n",
       "L 357.859055 -274.261821 \n",
       "L 361.138397 -277.695011 \n",
       "L 364.417739 -279.078463 \n",
       "L 367.697081 -278.372503 \n",
       "L 370.976423 -275.620218 \n",
       "L 374.255766 -270.949357 \n",
       "L 377.535088 -264.58843 \n",
       "L 380.814431 -256.894271 \n",
       "L 384.093773 -248.300969 \n",
       "L 384.093773 -250.043082 \n",
       "L 384.093773 -250.043082 \n",
       "L 380.814431 -258.779372 \n",
       "L 377.535088 -266.486686 \n",
       "L 374.255766 -272.797119 \n",
       "L 370.976423 -277.41562 \n",
       "L 367.697081 -280.142196 \n",
       "L 364.417739 -280.858972 \n",
       "L 361.138397 -279.522935 \n",
       "L 357.859055 -276.16928 \n",
       "L 354.579713 -270.906587 \n",
       "L 351.30039 -263.928071 \n",
       "L 348.021048 -255.49833 \n",
       "L 344.741705 -245.920983 \n",
       "L 341.462363 -235.49131 \n",
       "L 338.183021 -224.472698 \n",
       "L 334.903698 -213.093966 \n",
       "L 331.624356 -201.584255 \n",
       "L 328.345014 -190.171412 \n",
       "L 325.065672 -179.074964 \n",
       "L 321.78633 -168.509381 \n",
       "L 318.507007 -158.660218 \n",
       "L 315.227645 -149.689788 \n",
       "L 311.948322 -141.728902 \n",
       "L 308.66898 -134.87112 \n",
       "L 305.389638 -129.178228 \n",
       "L 302.110315 -124.67597 \n",
       "L 298.830954 -121.358813 \n",
       "L 295.551631 -119.189752 \n",
       "L 292.272289 -118.110046 \n",
       "L 288.992947 -118.035124 \n",
       "L 285.713605 -118.868033 \n",
       "L 282.434262 -120.500874 \n",
       "L 279.15494 -122.818443 \n",
       "L 275.875578 -125.706645 \n",
       "L 272.596255 -129.055374 \n",
       "L 269.316913 -132.761471 \n",
       "L 266.037571 -136.735525 \n",
       "L 262.758248 -140.903406 \n",
       "L 259.478887 -145.211541 \n",
       "L 256.199564 -149.634225 \n",
       "L 252.920222 -154.19074 \n",
       "L 249.640879 -158.990894 \n",
       "L 246.361537 -164.370192 \n",
       "L 243.082195 -171.097639 \n",
       "L 239.802872 -179.679465 \n",
       "L 236.523511 -189.272558 \n",
       "L 233.244188 -198.970868 \n",
       "L 229.964846 -208.35324 \n",
       "L 226.685504 -217.227058 \n",
       "L 223.406181 -225.491323 \n",
       "L 220.126829 -233.0905 \n",
       "L 216.847496 -239.997457 \n",
       "L 213.568154 -246.20674 \n",
       "L 210.288812 -251.729967 \n",
       "L 207.00948 -256.593735 \n",
       "L 203.730137 -260.837169 \n",
       "L 200.450795 -264.509487 \n",
       "L 197.171463 -267.667854 \n",
       "L 193.892121 -270.375366 \n",
       "L 190.612778 -272.698101 \n",
       "L 187.333446 -274.703283 \n",
       "L 184.054104 -276.4566 \n",
       "L 180.774762 -278.020427 \n",
       "L 177.495429 -279.450584 \n",
       "L 174.216087 -280.795173 \n",
       "L 170.936745 -282.091829 \n",
       "L 167.657412 -283.364429 \n",
       "L 164.37807 -284.620366 \n",
       "L 161.098728 -285.84775 \n",
       "L 157.819395 -287.016006 \n",
       "L 154.540053 -288.080206 \n",
       "L 151.260711 -288.990502 \n",
       "L 147.981379 -289.697805 \n",
       "L 144.702037 -290.160321 \n",
       "L 141.422694 -290.343375 \n",
       "L 138.143362 -290.219712 \n",
       "L 134.86402 -289.768516 \n",
       "L 131.584682 -288.977715 \n",
       "L 128.305345 -287.844588 \n",
       "L 125.026003 -286.376709 \n",
       "L 121.746666 -284.591255 \n",
       "L 118.467328 -282.50983 \n",
       "L 115.187986 -280.152009 \n",
       "L 111.908649 -277.533168 \n",
       "L 108.629311 -274.658642 \n",
       "L 105.349969 -271.528959 \n",
       "L 102.070632 -268.140249 \n",
       "L 98.791295 -264.488933 \n",
       "L 95.511955 -260.574274 \n",
       "L 92.232615 -256.39947 \n",
       "L 88.953278 -251.974044 \n",
       "L 85.673938 -247.315163 \n",
       "L 82.394598 -242.448183 \n",
       "L 79.115261 -237.410437 \n",
       "L 75.835921 -232.252088 \n",
       "L 72.556583 -227.041814 \n",
       "L 69.277244 -221.883564 \n",
       "L 65.997905 -216.951916 \n",
       "L 62.718566 -212.588085 \n",
       "L 59.439227 -209.436117 \n",
       "z\n",
       "\" style=\"stroke: #ff7f0e; stroke-opacity: 0.5; stroke-width: 0.8\"/>\n",
       "    </defs>\n",
       "    <g clip-path=\"url(#p9ace12a451)\">\n",
       "     <use xlink:href=\"#mc4712339c9\" x=\"0\" y=\"322.539375\" style=\"fill: #ff7f0e; fill-opacity: 0.5; stroke: #ff7f0e; stroke-opacity: 0.5; stroke-width: 0.8\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"line2d_14\">\n",
       "    <defs>\n",
       "     <path id=\"mff8e0d9bee\" d=\"M -5 5 \n",
       "L 5 -5 \n",
       "M -5 -5 \n",
       "L 5 5 \n",
       "\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "    </defs>\n",
       "    <g clip-path=\"url(#p9ace12a451)\">\n",
       "     <use xlink:href=\"#mff8e0d9bee\" x=\"361.243318\" y=\"41.800086\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     <use xlink:href=\"#mff8e0d9bee\" x=\"162.151989\" y=\"42.655429\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     <use xlink:href=\"#mff8e0d9bee\" x=\"119.149308\" y=\"44.947038\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     <use xlink:href=\"#mff8e0d9bee\" x=\"243.082195\" y=\"157.446647\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     <use xlink:href=\"#mff8e0d9bee\" x=\"147.981379\" y=\"37.29135\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     <use xlink:href=\"#mff8e0d9bee\" x=\"384.093773\" y=\"81.407847\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     <use xlink:href=\"#mff8e0d9bee\" x=\"344.741705\" y=\"86.652103\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     <use xlink:href=\"#mff8e0d9bee\" x=\"59.439227\" y=\"119.269122\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     <use xlink:href=\"#mff8e0d9bee\" x=\"141.422694\" y=\"36.871937\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     <use xlink:href=\"#mff8e0d9bee\" x=\"141.422694\" y=\"36.871937\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     <use xlink:href=\"#mff8e0d9bee\" x=\"141.422694\" y=\"36.871937\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     <use xlink:href=\"#mff8e0d9bee\" x=\"141.422694\" y=\"36.871937\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"line2d_15\">\n",
       "    <path d=\"M 59.439227 118.96651 \n",
       "L 62.718566 116.286718 \n",
       "L 65.997905 113.144118 \n",
       "L 69.277244 109.581055 \n",
       "L 72.556583 105.646991 \n",
       "L 75.835921 101.397789 \n",
       "L 79.115261 96.894279 \n",
       "L 82.394598 92.200847 \n",
       "L 85.673938 87.384209 \n",
       "L 88.953278 82.511608 \n",
       "L 92.232615 77.649811 \n",
       "L 95.511955 72.862974 \n",
       "L 98.791295 68.212226 \n",
       "L 102.070632 63.753728 \n",
       "L 105.349969 59.537997 \n",
       "L 108.629311 55.609217 \n",
       "L 111.908649 52.004406 \n",
       "L 115.187986 48.753379 \n",
       "L 118.467328 45.878442 \n",
       "L 121.746666 43.394462 \n",
       "L 125.026003 41.309638 \n",
       "L 128.305345 39.625537 \n",
       "L 131.584682 38.338188 \n",
       "L 134.86402 37.438398 \n",
       "L 138.143362 36.913391 \n",
       "L 141.422694 36.746984 \n",
       "L 144.702037 36.921061 \n",
       "L 147.981379 37.416342 \n",
       "L 151.260711 38.213136 \n",
       "L 154.540053 39.292288 \n",
       "L 157.819395 40.635725 \n",
       "L 161.098728 42.227151 \n",
       "L 164.37807 44.052438 \n",
       "L 167.657412 46.099679 \n",
       "L 170.936745 48.359963 \n",
       "L 174.216087 50.826891 \n",
       "L 177.495429 53.4968 \n",
       "L 180.774762 56.368786 \n",
       "L 184.054104 59.444251 \n",
       "L 187.333446 62.726935 \n",
       "L 190.612778 66.222504 \n",
       "L 193.892121 69.938382 \n",
       "L 197.171463 73.883292 \n",
       "L 200.450795 78.066976 \n",
       "L 203.730137 82.499771 \n",
       "L 207.00948 87.192263 \n",
       "L 210.288812 92.154637 \n",
       "L 213.568154 97.396305 \n",
       "L 216.847496 102.925161 \n",
       "L 220.126829 108.746879 \n",
       "L 223.406181 114.864227 \n",
       "L 226.685504 121.275928 \n",
       "L 229.964846 127.975999 \n",
       "L 233.244188 134.952449 \n",
       "L 236.523511 142.186128 \n",
       "L 239.802872 149.649996 \n",
       "L 243.082195 157.307413 \n",
       "L 246.361537 165.111933 \n",
       "L 249.640879 173.005844 \n",
       "L 252.920222 180.919886 \n",
       "L 256.199564 188.773001 \n",
       "L 259.478887 196.472214 \n",
       "L 262.758248 203.913665 \n",
       "L 266.037571 210.982902 \n",
       "L 269.316913 217.5571 \n",
       "L 272.596255 223.507022 \n",
       "L 275.875578 228.700164 \n",
       "L 279.15494 233.002598 \n",
       "L 282.434262 236.284669 \n",
       "L 285.713605 238.424365 \n",
       "L 288.992947 239.310126 \n",
       "L 292.272289 238.848362 \n",
       "L 295.551631 236.966547 \n",
       "L 298.830954 233.614324 \n",
       "L 302.110315 228.77467 \n",
       "L 305.389638 222.459779 \n",
       "L 308.66898 214.717948 \n",
       "L 311.948322 205.633265 \n",
       "L 315.227645 195.327108 \n",
       "L 318.507007 183.954666 \n",
       "L 321.78633 171.706678 \n",
       "L 325.065672 158.804049 \n",
       "L 328.345014 145.490329 \n",
       "L 331.624356 132.034724 \n",
       "L 334.903698 118.714037 \n",
       "L 338.183021 105.812833 \n",
       "L 341.462363 93.614727 \n",
       "L 344.741705 82.388605 \n",
       "L 348.021048 72.391004 \n",
       "L 351.30039 63.846628 \n",
       "L 354.579713 56.945506 \n",
       "L 357.859055 51.840924 \n",
       "L 361.138397 48.644048 \n",
       "L 364.417739 47.409827 \n",
       "L 367.697081 48.150771 \n",
       "L 370.976423 50.820482 \n",
       "L 374.255766 55.329174 \n",
       "L 377.535088 61.540817 \n",
       "L 380.814431 69.273226 \n",
       "L 384.093773 78.313174 \n",
       "\" clip-path=\"url(#p9ace12a451)\" style=\"fill: none; stroke: #1f77b4; stroke-width: 2; stroke-linecap: round\"/>\n",
       "   </g>\n",
       "   <g id=\"line2d_16\">\n",
       "    <path d=\"M 59.439227 119.269122 \n",
       "L 62.718566 114.20395 \n",
       "L 65.997905 109.157574 \n",
       "L 69.277244 104.148707 \n",
       "L 72.556583 99.195998 \n",
       "L 75.835921 94.317884 \n",
       "L 79.115261 89.532625 \n",
       "L 82.394598 84.858161 \n",
       "L 85.673938 80.312073 \n",
       "L 88.953278 75.911558 \n",
       "L 92.232615 71.673313 \n",
       "L 95.511955 67.613514 \n",
       "L 98.791295 63.74775 \n",
       "L 102.070632 60.090971 \n",
       "L 105.349969 56.657418 \n",
       "L 108.629311 53.460621 \n",
       "L 111.908649 50.513303 \n",
       "L 115.187986 47.82736 \n",
       "L 118.467328 45.413803 \n",
       "L 121.746666 43.282747 \n",
       "L 125.026003 41.443361 \n",
       "L 128.305345 39.903821 \n",
       "L 131.584682 38.671303 \n",
       "L 134.86402 37.751947 \n",
       "L 138.143362 37.150825 \n",
       "L 141.422694 36.871937 \n",
       "L 144.702037 36.918186 \n",
       "L 147.981379 37.29135 \n",
       "L 151.260711 37.992087 \n",
       "L 154.540053 39.019927 \n",
       "L 157.819395 40.373246 \n",
       "L 161.098728 42.049263 \n",
       "L 164.37807 44.044079 \n",
       "L 167.657412 46.352602 \n",
       "L 170.936745 48.968621 \n",
       "L 174.216087 51.884763 \n",
       "L 177.495429 55.092512 \n",
       "L 180.774762 58.582211 \n",
       "L 184.054104 62.34306 \n",
       "L 187.333446 66.363171 \n",
       "L 190.612778 70.62947 \n",
       "L 193.892121 75.127828 \n",
       "L 197.171463 79.842955 \n",
       "L 200.450795 84.75852 \n",
       "L 203.730137 89.857045 \n",
       "L 207.00948 95.119948 \n",
       "L 210.288812 100.527568 \n",
       "L 213.568154 106.059165 \n",
       "L 216.847496 111.692851 \n",
       "L 220.126829 117.405681 \n",
       "L 223.406181 123.173589 \n",
       "L 226.685504 128.971341 \n",
       "L 229.964846 134.772657 \n",
       "L 233.244188 140.55009 \n",
       "L 236.523511 146.274911 \n",
       "L 239.802872 151.917475 \n",
       "L 243.082195 157.446647 \n",
       "L 246.361537 162.83035 \n",
       "L 249.640879 168.035151 \n",
       "L 252.920222 173.02645 \n",
       "L 256.199564 177.768488 \n",
       "L 259.478887 182.224219 \n",
       "L 262.758248 186.35554 \n",
       "L 266.037571 190.123168 \n",
       "L 269.316913 193.486842 \n",
       "L 272.596255 196.405349 \n",
       "L 275.875578 198.836785 \n",
       "L 279.15494 200.738632 \n",
       "L 282.434262 202.068133 \n",
       "L 285.713605 202.782603 \n",
       "L 288.992947 202.839878 \n",
       "L 292.272289 202.198875 \n",
       "L 295.551631 200.820333 \n",
       "L 298.830954 198.667622 \n",
       "L 302.110315 195.707695 \n",
       "L 305.389638 191.912711 \n",
       "L 308.66898 187.260926 \n",
       "L 311.948322 181.738979 \n",
       "L 315.227645 175.343821 \n",
       "L 318.507007 168.084816 \n",
       "L 321.78633 159.986913 \n",
       "L 325.065672 151.093315 \n",
       "L 328.345014 141.468996 \n",
       "L 331.624356 131.204388 \n",
       "L 334.903698 120.419068 \n",
       "L 338.183021 109.265666 \n",
       "L 341.462363 97.93361 \n",
       "L 344.741705 86.652103 \n",
       "L 348.021048 75.692617 \n",
       "L 351.30039 65.369823 \n",
       "L 354.579713 56.039941 \n",
       "L 357.859055 48.096356 \n",
       "L 361.138397 41.961623 \n",
       "L 364.417739 38.073022 \n",
       "L 367.697081 36.862519 \n",
       "L 370.976423 38.728375 \n",
       "L 374.255766 43.997973 \n",
       "L 377.535088 52.881516 \n",
       "L 380.814431 65.41682 \n",
       "L 384.093773 81.407847 \n",
       "\" clip-path=\"url(#p9ace12a451)\" style=\"fill: none; stroke-dasharray: 7.68,1.92,1.2,1.92; stroke-dashoffset: 0; stroke: #bf00bf; stroke-width: 1.2\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_3\">\n",
       "    <path d=\"M 43.2065 285.922316 \n",
       "L 43.2065 36.851014 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_4\">\n",
       "    <path d=\"M 59.439227 286.212 \n",
       "L 384.093773 286.212 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"text_16\">\n",
       "    <!-- N=8, psi=0.10 -->\n",
       "    <g style=\"fill: #262626\" transform=\"translate(191.87975 14.1) scale(0.096 -0.096)\">\n",
       "     <defs>\n",
       "      <path id=\"ArialMT-4e\" d=\"M 488 0 \n",
       "L 488 4581 \n",
       "L 1109 4581 \n",
       "L 3516 984 \n",
       "L 3516 4581 \n",
       "L 4097 4581 \n",
       "L 4097 0 \n",
       "L 3475 0 \n",
       "L 1069 3600 \n",
       "L 1069 0 \n",
       "L 488 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-3d\" d=\"M 3381 2694 \n",
       "L 356 2694 \n",
       "L 356 3219 \n",
       "L 3381 3219 \n",
       "L 3381 2694 \n",
       "z\n",
       "M 3381 1303 \n",
       "L 356 1303 \n",
       "L 356 1828 \n",
       "L 3381 1828 \n",
       "L 3381 1303 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-2c\" d=\"M 569 0 \n",
       "L 569 641 \n",
       "L 1209 641 \n",
       "L 1209 0 \n",
       "Q 1209 -353 1084 -570 \n",
       "Q 959 -788 688 -906 \n",
       "L 531 -666 \n",
       "Q 709 -588 793 -436 \n",
       "Q 878 -284 888 0 \n",
       "L 569 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-20\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-70\" d=\"M 422 -1272 \n",
       "L 422 3319 \n",
       "L 934 3319 \n",
       "L 934 2888 \n",
       "Q 1116 3141 1344 3267 \n",
       "Q 1572 3394 1897 3394 \n",
       "Q 2322 3394 2647 3175 \n",
       "Q 2972 2956 3137 2557 \n",
       "Q 3303 2159 3303 1684 \n",
       "Q 3303 1175 3120 767 \n",
       "Q 2938 359 2589 142 \n",
       "Q 2241 -75 1856 -75 \n",
       "Q 1575 -75 1351 44 \n",
       "Q 1128 163 984 344 \n",
       "L 984 -1272 \n",
       "L 422 -1272 \n",
       "z\n",
       "M 931 1641 \n",
       "Q 931 1000 1190 694 \n",
       "Q 1450 388 1819 388 \n",
       "Q 2194 388 2461 705 \n",
       "Q 2728 1022 2728 1688 \n",
       "Q 2728 2322 2467 2637 \n",
       "Q 2206 2953 1844 2953 \n",
       "Q 1484 2953 1207 2617 \n",
       "Q 931 2281 931 1641 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-73\" d=\"M 197 991 \n",
       "L 753 1078 \n",
       "Q 800 744 1014 566 \n",
       "Q 1228 388 1613 388 \n",
       "Q 2000 388 2187 545 \n",
       "Q 2375 703 2375 916 \n",
       "Q 2375 1106 2209 1216 \n",
       "Q 2094 1291 1634 1406 \n",
       "Q 1016 1563 777 1677 \n",
       "Q 538 1791 414 1992 \n",
       "Q 291 2194 291 2438 \n",
       "Q 291 2659 392 2848 \n",
       "Q 494 3038 669 3163 \n",
       "Q 800 3259 1026 3326 \n",
       "Q 1253 3394 1513 3394 \n",
       "Q 1903 3394 2198 3281 \n",
       "Q 2494 3169 2634 2976 \n",
       "Q 2775 2784 2828 2463 \n",
       "L 2278 2388 \n",
       "Q 2241 2644 2061 2787 \n",
       "Q 1881 2931 1553 2931 \n",
       "Q 1166 2931 1000 2803 \n",
       "Q 834 2675 834 2503 \n",
       "Q 834 2394 903 2306 \n",
       "Q 972 2216 1119 2156 \n",
       "Q 1203 2125 1616 2013 \n",
       "Q 2213 1853 2448 1751 \n",
       "Q 2684 1650 2818 1456 \n",
       "Q 2953 1263 2953 975 \n",
       "Q 2953 694 2789 445 \n",
       "Q 2625 197 2315 61 \n",
       "Q 2006 -75 1616 -75 \n",
       "Q 969 -75 630 194 \n",
       "Q 291 463 197 991 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-69\" d=\"M 425 3934 \n",
       "L 425 4581 \n",
       "L 988 4581 \n",
       "L 988 3934 \n",
       "L 425 3934 \n",
       "z\n",
       "M 425 0 \n",
       "L 425 3319 \n",
       "L 988 3319 \n",
       "L 988 0 \n",
       "L 425 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "     </defs>\n",
       "     <use xlink:href=\"#ArialMT-4e\"/>\n",
       "     <use xlink:href=\"#ArialMT-3d\" x=\"72.216797\"/>\n",
       "     <use xlink:href=\"#ArialMT-38\" x=\"130.615234\"/>\n",
       "     <use xlink:href=\"#ArialMT-2c\" x=\"186.230469\"/>\n",
       "     <use xlink:href=\"#ArialMT-20\" x=\"214.013672\"/>\n",
       "     <use xlink:href=\"#ArialMT-70\" x=\"241.796875\"/>\n",
       "     <use xlink:href=\"#ArialMT-73\" x=\"297.412109\"/>\n",
       "     <use xlink:href=\"#ArialMT-69\" x=\"347.412109\"/>\n",
       "     <use xlink:href=\"#ArialMT-3d\" x=\"369.628906\"/>\n",
       "     <use xlink:href=\"#ArialMT-30\" x=\"428.027344\"/>\n",
       "     <use xlink:href=\"#ArialMT-2e\" x=\"483.642578\"/>\n",
       "     <use xlink:href=\"#ArialMT-31\" x=\"511.425781\"/>\n",
       "     <use xlink:href=\"#ArialMT-30\" x=\"567.041016\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"legend_1\">\n",
       "    <g id=\"line2d_17\">\n",
       "     <g>\n",
       "      <use xlink:href=\"#mff8e0d9bee\" x=\"59.9265\" y=\"220.007125\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"text_17\">\n",
       "     <!-- Observations -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(75.7665 223.087125) scale(0.088 -0.088)\">\n",
       "      <defs>\n",
       "       <path id=\"ArialMT-4f\" d=\"M 309 2231 \n",
       "Q 309 3372 921 4017 \n",
       "Q 1534 4663 2503 4663 \n",
       "Q 3138 4663 3647 4359 \n",
       "Q 4156 4056 4423 3514 \n",
       "Q 4691 2972 4691 2284 \n",
       "Q 4691 1588 4409 1038 \n",
       "Q 4128 488 3612 205 \n",
       "Q 3097 -78 2500 -78 \n",
       "Q 1853 -78 1343 234 \n",
       "Q 834 547 571 1087 \n",
       "Q 309 1628 309 2231 \n",
       "z\n",
       "M 934 2222 \n",
       "Q 934 1394 1379 917 \n",
       "Q 1825 441 2497 441 \n",
       "Q 3181 441 3623 922 \n",
       "Q 4066 1403 4066 2288 \n",
       "Q 4066 2847 3877 3264 \n",
       "Q 3688 3681 3323 3911 \n",
       "Q 2959 4141 2506 4141 \n",
       "Q 1863 4141 1398 3698 \n",
       "Q 934 3256 934 2222 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-62\" d=\"M 941 0 \n",
       "L 419 0 \n",
       "L 419 4581 \n",
       "L 981 4581 \n",
       "L 981 2947 \n",
       "Q 1338 3394 1891 3394 \n",
       "Q 2197 3394 2470 3270 \n",
       "Q 2744 3147 2920 2923 \n",
       "Q 3097 2700 3197 2384 \n",
       "Q 3297 2069 3297 1709 \n",
       "Q 3297 856 2875 390 \n",
       "Q 2453 -75 1863 -75 \n",
       "Q 1275 -75 941 416 \n",
       "L 941 0 \n",
       "z\n",
       "M 934 1684 \n",
       "Q 934 1088 1097 822 \n",
       "Q 1363 388 1816 388 \n",
       "Q 2184 388 2453 708 \n",
       "Q 2722 1028 2722 1663 \n",
       "Q 2722 2313 2464 2622 \n",
       "Q 2206 2931 1841 2931 \n",
       "Q 1472 2931 1203 2611 \n",
       "Q 934 2291 934 1684 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-65\" d=\"M 2694 1069 \n",
       "L 3275 997 \n",
       "Q 3138 488 2766 206 \n",
       "Q 2394 -75 1816 -75 \n",
       "Q 1088 -75 661 373 \n",
       "Q 234 822 234 1631 \n",
       "Q 234 2469 665 2931 \n",
       "Q 1097 3394 1784 3394 \n",
       "Q 2450 3394 2872 2941 \n",
       "Q 3294 2488 3294 1666 \n",
       "Q 3294 1616 3291 1516 \n",
       "L 816 1516 \n",
       "Q 847 969 1125 678 \n",
       "Q 1403 388 1819 388 \n",
       "Q 2128 388 2347 550 \n",
       "Q 2566 713 2694 1069 \n",
       "z\n",
       "M 847 1978 \n",
       "L 2700 1978 \n",
       "Q 2663 2397 2488 2606 \n",
       "Q 2219 2931 1791 2931 \n",
       "Q 1403 2931 1139 2672 \n",
       "Q 875 2413 847 1978 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-72\" d=\"M 416 0 \n",
       "L 416 3319 \n",
       "L 922 3319 \n",
       "L 922 2816 \n",
       "Q 1116 3169 1280 3281 \n",
       "Q 1444 3394 1641 3394 \n",
       "Q 1925 3394 2219 3213 \n",
       "L 2025 2691 \n",
       "Q 1819 2813 1613 2813 \n",
       "Q 1428 2813 1281 2702 \n",
       "Q 1134 2591 1072 2394 \n",
       "Q 978 2094 978 1738 \n",
       "L 978 0 \n",
       "L 416 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-76\" d=\"M 1344 0 \n",
       "L 81 3319 \n",
       "L 675 3319 \n",
       "L 1388 1331 \n",
       "Q 1503 1009 1600 663 \n",
       "Q 1675 925 1809 1294 \n",
       "L 2547 3319 \n",
       "L 3125 3319 \n",
       "L 1869 0 \n",
       "L 1344 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-61\" d=\"M 2588 409 \n",
       "Q 2275 144 1986 34 \n",
       "Q 1697 -75 1366 -75 \n",
       "Q 819 -75 525 192 \n",
       "Q 231 459 231 875 \n",
       "Q 231 1119 342 1320 \n",
       "Q 453 1522 633 1644 \n",
       "Q 813 1766 1038 1828 \n",
       "Q 1203 1872 1538 1913 \n",
       "Q 2219 1994 2541 2106 \n",
       "Q 2544 2222 2544 2253 \n",
       "Q 2544 2597 2384 2738 \n",
       "Q 2169 2928 1744 2928 \n",
       "Q 1347 2928 1158 2789 \n",
       "Q 969 2650 878 2297 \n",
       "L 328 2372 \n",
       "Q 403 2725 575 2942 \n",
       "Q 747 3159 1072 3276 \n",
       "Q 1397 3394 1825 3394 \n",
       "Q 2250 3394 2515 3294 \n",
       "Q 2781 3194 2906 3042 \n",
       "Q 3031 2891 3081 2659 \n",
       "Q 3109 2516 3109 2141 \n",
       "L 3109 1391 \n",
       "Q 3109 606 3145 398 \n",
       "Q 3181 191 3288 0 \n",
       "L 2700 0 \n",
       "Q 2613 175 2588 409 \n",
       "z\n",
       "M 2541 1666 \n",
       "Q 2234 1541 1622 1453 \n",
       "Q 1275 1403 1131 1340 \n",
       "Q 988 1278 909 1158 \n",
       "Q 831 1038 831 891 \n",
       "Q 831 666 1001 516 \n",
       "Q 1172 366 1500 366 \n",
       "Q 1825 366 2078 508 \n",
       "Q 2331 650 2450 897 \n",
       "Q 2541 1088 2541 1459 \n",
       "L 2541 1666 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-74\" d=\"M 1650 503 \n",
       "L 1731 6 \n",
       "Q 1494 -44 1306 -44 \n",
       "Q 1000 -44 831 53 \n",
       "Q 663 150 594 308 \n",
       "Q 525 466 525 972 \n",
       "L 525 2881 \n",
       "L 113 2881 \n",
       "L 113 3319 \n",
       "L 525 3319 \n",
       "L 525 4141 \n",
       "L 1084 4478 \n",
       "L 1084 3319 \n",
       "L 1650 3319 \n",
       "L 1650 2881 \n",
       "L 1084 2881 \n",
       "L 1084 941 \n",
       "Q 1084 700 1114 631 \n",
       "Q 1144 563 1211 522 \n",
       "Q 1278 481 1403 481 \n",
       "Q 1497 481 1650 503 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-6f\" d=\"M 213 1659 \n",
       "Q 213 2581 725 3025 \n",
       "Q 1153 3394 1769 3394 \n",
       "Q 2453 3394 2887 2945 \n",
       "Q 3322 2497 3322 1706 \n",
       "Q 3322 1066 3130 698 \n",
       "Q 2938 331 2570 128 \n",
       "Q 2203 -75 1769 -75 \n",
       "Q 1072 -75 642 372 \n",
       "Q 213 819 213 1659 \n",
       "z\n",
       "M 791 1659 \n",
       "Q 791 1022 1069 705 \n",
       "Q 1347 388 1769 388 \n",
       "Q 2188 388 2466 706 \n",
       "Q 2744 1025 2744 1678 \n",
       "Q 2744 2294 2464 2611 \n",
       "Q 2184 2928 1769 2928 \n",
       "Q 1347 2928 1069 2612 \n",
       "Q 791 2297 791 1659 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-6e\" d=\"M 422 0 \n",
       "L 422 3319 \n",
       "L 928 3319 \n",
       "L 928 2847 \n",
       "Q 1294 3394 1984 3394 \n",
       "Q 2284 3394 2536 3286 \n",
       "Q 2788 3178 2913 3003 \n",
       "Q 3038 2828 3088 2588 \n",
       "Q 3119 2431 3119 2041 \n",
       "L 3119 0 \n",
       "L 2556 0 \n",
       "L 2556 2019 \n",
       "Q 2556 2363 2490 2533 \n",
       "Q 2425 2703 2258 2804 \n",
       "Q 2091 2906 1866 2906 \n",
       "Q 1506 2906 1245 2678 \n",
       "Q 984 2450 984 1813 \n",
       "L 984 0 \n",
       "L 422 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#ArialMT-4f\"/>\n",
       "      <use xlink:href=\"#ArialMT-62\" x=\"77.783203\"/>\n",
       "      <use xlink:href=\"#ArialMT-73\" x=\"133.398438\"/>\n",
       "      <use xlink:href=\"#ArialMT-65\" x=\"183.398438\"/>\n",
       "      <use xlink:href=\"#ArialMT-72\" x=\"239.013672\"/>\n",
       "      <use xlink:href=\"#ArialMT-76\" x=\"272.314453\"/>\n",
       "      <use xlink:href=\"#ArialMT-61\" x=\"322.314453\"/>\n",
       "      <use xlink:href=\"#ArialMT-74\" x=\"377.929688\"/>\n",
       "      <use xlink:href=\"#ArialMT-69\" x=\"405.712891\"/>\n",
       "      <use xlink:href=\"#ArialMT-6f\" x=\"427.929688\"/>\n",
       "      <use xlink:href=\"#ArialMT-6e\" x=\"483.544922\"/>\n",
       "      <use xlink:href=\"#ArialMT-73\" x=\"539.160156\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"line2d_18\">\n",
       "     <path d=\"M 51.1265 232.591125 \n",
       "L 59.9265 232.591125 \n",
       "L 68.7265 232.591125 \n",
       "\" style=\"fill: none; stroke: #1f77b4; stroke-width: 2; stroke-linecap: round\"/>\n",
       "    </g>\n",
       "    <g id=\"text_18\">\n",
       "     <!-- $m_n(x)$ -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(75.7665 235.671125) scale(0.088 -0.088)\">\n",
       "      <defs>\n",
       "       <path id=\"DejaVuSans-Oblique-6d\" d=\"M 5747 2113 \n",
       "L 5338 0 \n",
       "L 4763 0 \n",
       "L 5166 2094 \n",
       "Q 5191 2228 5203 2325 \n",
       "Q 5216 2422 5216 2491 \n",
       "Q 5216 2772 5059 2928 \n",
       "Q 4903 3084 4622 3084 \n",
       "Q 4203 3084 3875 2770 \n",
       "Q 3547 2456 3450 1953 \n",
       "L 3066 0 \n",
       "L 2491 0 \n",
       "L 2900 2094 \n",
       "Q 2925 2209 2937 2307 \n",
       "Q 2950 2406 2950 2484 \n",
       "Q 2950 2769 2794 2926 \n",
       "Q 2638 3084 2363 3084 \n",
       "Q 1938 3084 1609 2770 \n",
       "Q 1281 2456 1184 1953 \n",
       "L 800 0 \n",
       "L 225 0 \n",
       "L 909 3500 \n",
       "L 1484 3500 \n",
       "L 1375 2956 \n",
       "Q 1609 3263 1923 3423 \n",
       "Q 2238 3584 2597 3584 \n",
       "Q 2978 3584 3223 3384 \n",
       "Q 3469 3184 3519 2828 \n",
       "Q 3781 3197 4126 3390 \n",
       "Q 4472 3584 4856 3584 \n",
       "Q 5306 3584 5551 3325 \n",
       "Q 5797 3066 5797 2591 \n",
       "Q 5797 2488 5784 2364 \n",
       "Q 5772 2241 5747 2113 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-Oblique-6e\" d=\"M 3566 2113 \n",
       "L 3156 0 \n",
       "L 2578 0 \n",
       "L 2988 2091 \n",
       "Q 3016 2238 3031 2350 \n",
       "Q 3047 2463 3047 2528 \n",
       "Q 3047 2791 2881 2937 \n",
       "Q 2716 3084 2419 3084 \n",
       "Q 1956 3084 1622 2776 \n",
       "Q 1288 2469 1184 1941 \n",
       "L 800 0 \n",
       "L 225 0 \n",
       "L 903 3500 \n",
       "L 1478 3500 \n",
       "L 1363 2950 \n",
       "Q 1603 3253 1940 3418 \n",
       "Q 2278 3584 2650 3584 \n",
       "Q 3113 3584 3367 3334 \n",
       "Q 3622 3084 3622 2631 \n",
       "Q 3622 2519 3608 2391 \n",
       "Q 3594 2263 3566 2113 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-28\" d=\"M 1984 4856 \n",
       "Q 1566 4138 1362 3434 \n",
       "Q 1159 2731 1159 2009 \n",
       "Q 1159 1288 1364 580 \n",
       "Q 1569 -128 1984 -844 \n",
       "L 1484 -844 \n",
       "Q 1016 -109 783 600 \n",
       "Q 550 1309 550 2009 \n",
       "Q 550 2706 781 3412 \n",
       "Q 1013 4119 1484 4856 \n",
       "L 1984 4856 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-29\" d=\"M 513 4856 \n",
       "L 1013 4856 \n",
       "Q 1481 4119 1714 3412 \n",
       "Q 1947 2706 1947 2009 \n",
       "Q 1947 1309 1714 600 \n",
       "Q 1481 -109 1013 -844 \n",
       "L 513 -844 \n",
       "Q 928 -128 1133 580 \n",
       "Q 1338 1288 1338 2009 \n",
       "Q 1338 2731 1133 3434 \n",
       "Q 928 4138 513 4856 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-6d\" transform=\"translate(0 0.125)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-6e\" transform=\"translate(97.412109 -16.28125) scale(0.7)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-28\" transform=\"translate(144.511719 0.125)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-78\" transform=\"translate(183.525391 0.125)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-29\" transform=\"translate(242.705078 0.125)\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"patch_5\">\n",
       "     <path d=\"M 51.1265 249.828125 \n",
       "L 68.7265 249.828125 \n",
       "L 68.7265 243.668125 \n",
       "L 51.1265 243.668125 \n",
       "z\n",
       "\" style=\"fill: #1f77b4; fill-opacity: 0.5; stroke: #1f77b4; stroke-opacity: 0.5; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "    </g>\n",
       "    <g id=\"text_19\">\n",
       "     <!-- $f(\\mathbf{x}^*)$ 95% pred. -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(75.7665 249.828125) scale(0.088 -0.088)\">\n",
       "      <defs>\n",
       "       <path id=\"DejaVuSans-Oblique-66\" d=\"M 3059 4863 \n",
       "L 2969 4384 \n",
       "L 2419 4384 \n",
       "Q 2106 4384 1964 4261 \n",
       "Q 1822 4138 1753 3809 \n",
       "L 1691 3500 \n",
       "L 2638 3500 \n",
       "L 2553 3053 \n",
       "L 1606 3053 \n",
       "L 1013 0 \n",
       "L 434 0 \n",
       "L 1031 3053 \n",
       "L 481 3053 \n",
       "L 563 3500 \n",
       "L 1113 3500 \n",
       "L 1159 3744 \n",
       "Q 1278 4363 1576 4613 \n",
       "Q 1875 4863 2516 4863 \n",
       "L 3059 4863 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-Bold-78\" d=\"M 1422 1791 \n",
       "L 159 3500 \n",
       "L 1344 3500 \n",
       "L 2059 2463 \n",
       "L 2784 3500 \n",
       "L 3969 3500 \n",
       "L 2706 1797 \n",
       "L 4031 0 \n",
       "L 2847 0 \n",
       "L 2059 1106 \n",
       "L 1281 0 \n",
       "L 97 0 \n",
       "L 1422 1791 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-2a\" d=\"M 3009 3897 \n",
       "L 1888 3291 \n",
       "L 3009 2681 \n",
       "L 2828 2375 \n",
       "L 1778 3009 \n",
       "L 1778 1831 \n",
       "L 1422 1831 \n",
       "L 1422 3009 \n",
       "L 372 2375 \n",
       "L 191 2681 \n",
       "L 1313 3291 \n",
       "L 191 3897 \n",
       "L 372 4206 \n",
       "L 1422 3572 \n",
       "L 1422 4750 \n",
       "L 1778 4750 \n",
       "L 1778 3572 \n",
       "L 2828 4206 \n",
       "L 3009 3897 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-39\" d=\"M 350 1059 \n",
       "L 891 1109 \n",
       "Q 959 728 1153 556 \n",
       "Q 1347 384 1650 384 \n",
       "Q 1909 384 2104 503 \n",
       "Q 2300 622 2425 820 \n",
       "Q 2550 1019 2634 1356 \n",
       "Q 2719 1694 2719 2044 \n",
       "Q 2719 2081 2716 2156 \n",
       "Q 2547 1888 2255 1720 \n",
       "Q 1963 1553 1622 1553 \n",
       "Q 1053 1553 659 1965 \n",
       "Q 266 2378 266 3053 \n",
       "Q 266 3750 677 4175 \n",
       "Q 1088 4600 1706 4600 \n",
       "Q 2153 4600 2523 4359 \n",
       "Q 2894 4119 3086 3673 \n",
       "Q 3278 3228 3278 2384 \n",
       "Q 3278 1506 3087 986 \n",
       "Q 2897 466 2520 194 \n",
       "Q 2144 -78 1638 -78 \n",
       "Q 1100 -78 759 220 \n",
       "Q 419 519 350 1059 \n",
       "z\n",
       "M 2653 3081 \n",
       "Q 2653 3566 2395 3850 \n",
       "Q 2138 4134 1775 4134 \n",
       "Q 1400 4134 1122 3828 \n",
       "Q 844 3522 844 3034 \n",
       "Q 844 2597 1108 2323 \n",
       "Q 1372 2050 1759 2050 \n",
       "Q 2150 2050 2401 2323 \n",
       "Q 2653 2597 2653 3081 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-35\" d=\"M 266 1200 \n",
       "L 856 1250 \n",
       "Q 922 819 1161 601 \n",
       "Q 1400 384 1738 384 \n",
       "Q 2144 384 2425 690 \n",
       "Q 2706 997 2706 1503 \n",
       "Q 2706 1984 2436 2262 \n",
       "Q 2166 2541 1728 2541 \n",
       "Q 1456 2541 1237 2417 \n",
       "Q 1019 2294 894 2097 \n",
       "L 366 2166 \n",
       "L 809 4519 \n",
       "L 3088 4519 \n",
       "L 3088 3981 \n",
       "L 1259 3981 \n",
       "L 1013 2750 \n",
       "Q 1425 3038 1878 3038 \n",
       "Q 2478 3038 2890 2622 \n",
       "Q 3303 2206 3303 1553 \n",
       "Q 3303 931 2941 478 \n",
       "Q 2500 -78 1738 -78 \n",
       "Q 1113 -78 717 272 \n",
       "Q 322 622 266 1200 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-25\" d=\"M 372 3481 \n",
       "Q 372 3972 619 4315 \n",
       "Q 866 4659 1334 4659 \n",
       "Q 1766 4659 2048 4351 \n",
       "Q 2331 4044 2331 3447 \n",
       "Q 2331 2866 2045 2552 \n",
       "Q 1759 2238 1341 2238 \n",
       "Q 925 2238 648 2547 \n",
       "Q 372 2856 372 3481 \n",
       "z\n",
       "M 1350 4272 \n",
       "Q 1141 4272 1002 4090 \n",
       "Q 863 3909 863 3425 \n",
       "Q 863 2984 1003 2804 \n",
       "Q 1144 2625 1350 2625 \n",
       "Q 1563 2625 1702 2806 \n",
       "Q 1841 2988 1841 3469 \n",
       "Q 1841 3913 1700 4092 \n",
       "Q 1559 4272 1350 4272 \n",
       "z\n",
       "M 1353 -169 \n",
       "L 3859 4659 \n",
       "L 4316 4659 \n",
       "L 1819 -169 \n",
       "L 1353 -169 \n",
       "z\n",
       "M 3334 1075 \n",
       "Q 3334 1569 3581 1911 \n",
       "Q 3828 2253 4300 2253 \n",
       "Q 4731 2253 5014 1945 \n",
       "Q 5297 1638 5297 1041 \n",
       "Q 5297 459 5011 145 \n",
       "Q 4725 -169 4303 -169 \n",
       "Q 3888 -169 3611 142 \n",
       "Q 3334 453 3334 1075 \n",
       "z\n",
       "M 4316 1866 \n",
       "Q 4103 1866 3964 1684 \n",
       "Q 3825 1503 3825 1019 \n",
       "Q 3825 581 3965 400 \n",
       "Q 4106 219 4313 219 \n",
       "Q 4528 219 4667 400 \n",
       "Q 4806 581 4806 1063 \n",
       "Q 4806 1506 4665 1686 \n",
       "Q 4525 1866 4316 1866 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-64\" d=\"M 2575 0 \n",
       "L 2575 419 \n",
       "Q 2259 -75 1647 -75 \n",
       "Q 1250 -75 917 144 \n",
       "Q 584 363 401 755 \n",
       "Q 219 1147 219 1656 \n",
       "Q 219 2153 384 2558 \n",
       "Q 550 2963 881 3178 \n",
       "Q 1213 3394 1622 3394 \n",
       "Q 1922 3394 2156 3267 \n",
       "Q 2391 3141 2538 2938 \n",
       "L 2538 4581 \n",
       "L 3097 4581 \n",
       "L 3097 0 \n",
       "L 2575 0 \n",
       "z\n",
       "M 797 1656 \n",
       "Q 797 1019 1065 703 \n",
       "Q 1334 388 1700 388 \n",
       "Q 2069 388 2326 689 \n",
       "Q 2584 991 2584 1609 \n",
       "Q 2584 2291 2321 2609 \n",
       "Q 2059 2928 1675 2928 \n",
       "Q 1300 2928 1048 2622 \n",
       "Q 797 2316 797 1656 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-66\" transform=\"translate(0 0.765625)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-28\" transform=\"translate(35.205078 0.765625)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-Bold-78\" transform=\"translate(74.21875 0.765625)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-2a\" transform=\"translate(153.31543 39.046875) scale(0.7)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-29\" transform=\"translate(204.6875 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" transform=\"translate(243.701172 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-39\" transform=\"translate(271.484375 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-35\" transform=\"translate(327.099609 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-25\" transform=\"translate(382.714844 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" transform=\"translate(471.630859 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-70\" transform=\"translate(499.414062 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-72\" transform=\"translate(555.029297 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-65\" transform=\"translate(588.330078 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-64\" transform=\"translate(643.945312 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-2e\" transform=\"translate(699.560547 0.765625)\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"patch_6\">\n",
       "     <path d=\"M 51.1265 263.996125 \n",
       "L 68.7265 263.996125 \n",
       "L 68.7265 257.836125 \n",
       "L 51.1265 257.836125 \n",
       "z\n",
       "\" style=\"fill: #ff7f0e; fill-opacity: 0.5; stroke: #ff7f0e; stroke-opacity: 0.5; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "    </g>\n",
       "    <g id=\"text_20\">\n",
       "     <!-- $y^*$ 95% pred. -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(75.7665 263.996125) scale(0.088 -0.088)\">\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-79\" transform=\"translate(0 0.765625)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-2a\" transform=\"translate(77.283529 39.046875) scale(0.7)\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" transform=\"translate(128.655599 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-39\" transform=\"translate(156.438802 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-35\" transform=\"translate(212.054036 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-25\" transform=\"translate(267.669271 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" transform=\"translate(356.585286 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-70\" transform=\"translate(384.36849 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-72\" transform=\"translate(439.983724 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-65\" transform=\"translate(473.284505 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-64\" transform=\"translate(528.89974 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-2e\" transform=\"translate(584.514974 0.765625)\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"line2d_19\">\n",
       "     <path d=\"M 51.1265 273.463 \n",
       "L 59.9265 273.463 \n",
       "L 68.7265 273.463 \n",
       "\" style=\"fill: none; stroke-dasharray: 7.68,1.92,1.2,1.92; stroke-dashoffset: 0; stroke: #bf00bf; stroke-width: 1.2\"/>\n",
       "    </g>\n",
       "    <g id=\"text_21\">\n",
       "     <!-- True function -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(75.7665 276.543) scale(0.088 -0.088)\">\n",
       "      <defs>\n",
       "       <path id=\"ArialMT-54\" d=\"M 1659 0 \n",
       "L 1659 4041 \n",
       "L 150 4041 \n",
       "L 150 4581 \n",
       "L 3781 4581 \n",
       "L 3781 4041 \n",
       "L 2266 4041 \n",
       "L 2266 0 \n",
       "L 1659 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-75\" d=\"M 2597 0 \n",
       "L 2597 488 \n",
       "Q 2209 -75 1544 -75 \n",
       "Q 1250 -75 995 37 \n",
       "Q 741 150 617 320 \n",
       "Q 494 491 444 738 \n",
       "Q 409 903 409 1263 \n",
       "L 409 3319 \n",
       "L 972 3319 \n",
       "L 972 1478 \n",
       "Q 972 1038 1006 884 \n",
       "Q 1059 663 1231 536 \n",
       "Q 1403 409 1656 409 \n",
       "Q 1909 409 2131 539 \n",
       "Q 2353 669 2445 892 \n",
       "Q 2538 1116 2538 1541 \n",
       "L 2538 3319 \n",
       "L 3100 3319 \n",
       "L 3100 0 \n",
       "L 2597 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-66\" d=\"M 556 0 \n",
       "L 556 2881 \n",
       "L 59 2881 \n",
       "L 59 3319 \n",
       "L 556 3319 \n",
       "L 556 3672 \n",
       "Q 556 4006 616 4169 \n",
       "Q 697 4388 901 4523 \n",
       "Q 1106 4659 1475 4659 \n",
       "Q 1713 4659 2000 4603 \n",
       "L 1916 4113 \n",
       "Q 1741 4144 1584 4144 \n",
       "Q 1328 4144 1222 4034 \n",
       "Q 1116 3925 1116 3625 \n",
       "L 1116 3319 \n",
       "L 1763 3319 \n",
       "L 1763 2881 \n",
       "L 1116 2881 \n",
       "L 1116 0 \n",
       "L 556 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-63\" d=\"M 2588 1216 \n",
       "L 3141 1144 \n",
       "Q 3050 572 2676 248 \n",
       "Q 2303 -75 1759 -75 \n",
       "Q 1078 -75 664 370 \n",
       "Q 250 816 250 1647 \n",
       "Q 250 2184 428 2587 \n",
       "Q 606 2991 970 3192 \n",
       "Q 1334 3394 1763 3394 \n",
       "Q 2303 3394 2647 3120 \n",
       "Q 2991 2847 3088 2344 \n",
       "L 2541 2259 \n",
       "Q 2463 2594 2264 2762 \n",
       "Q 2066 2931 1784 2931 \n",
       "Q 1359 2931 1093 2626 \n",
       "Q 828 2322 828 1663 \n",
       "Q 828 994 1084 691 \n",
       "Q 1341 388 1753 388 \n",
       "Q 2084 388 2306 591 \n",
       "Q 2528 794 2588 1216 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#ArialMT-54\"/>\n",
       "      <use xlink:href=\"#ArialMT-72\" x=\"57.333984\"/>\n",
       "      <use xlink:href=\"#ArialMT-75\" x=\"90.634766\"/>\n",
       "      <use xlink:href=\"#ArialMT-65\" x=\"146.25\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" x=\"201.865234\"/>\n",
       "      <use xlink:href=\"#ArialMT-66\" x=\"229.648438\"/>\n",
       "      <use xlink:href=\"#ArialMT-75\" x=\"257.431641\"/>\n",
       "      <use xlink:href=\"#ArialMT-6e\" x=\"313.046875\"/>\n",
       "      <use xlink:href=\"#ArialMT-63\" x=\"368.662109\"/>\n",
       "      <use xlink:href=\"#ArialMT-74\" x=\"418.662109\"/>\n",
       "      <use xlink:href=\"#ArialMT-69\" x=\"446.445312\"/>\n",
       "      <use xlink:href=\"#ArialMT-6f\" x=\"468.662109\"/>\n",
       "      <use xlink:href=\"#ArialMT-6e\" x=\"524.277344\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "  </g>\n",
       "  <g id=\"axes_2\">\n",
       "   <g id=\"matplotlib.axis_3\">\n",
       "    <g id=\"ytick_8\">\n",
       "     <g id=\"line2d_20\">\n",
       "      <defs>\n",
       "       <path id=\"md3bb5b3a47\" d=\"M 0 0 \n",
       "L 4.8 0 \n",
       "\" style=\"stroke: #262626\"/>\n",
       "      </defs>\n",
       "      <g>\n",
       "       <use xlink:href=\"#md3bb5b3a47\" x=\"400.3265\" y=\"274.116\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_22\">\n",
       "      <!-- 0.0000 -->\n",
       "      <g style=\"fill: #ff7f0e\" transform=\"translate(408.6265 277.265437) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"83.398438\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"139.013672\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"194.628906\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"250.244141\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_9\">\n",
       "     <g id=\"line2d_21\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#md3bb5b3a47\" x=\"400.3265\" y=\"240.954375\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_23\">\n",
       "      <!-- 0.0025 -->\n",
       "      <g style=\"fill: #ff7f0e\" transform=\"translate(408.6265 244.103813) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"83.398438\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"139.013672\"/>\n",
       "       <use xlink:href=\"#ArialMT-32\" x=\"194.628906\"/>\n",
       "       <use xlink:href=\"#ArialMT-35\" x=\"250.244141\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_10\">\n",
       "     <g id=\"line2d_22\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#md3bb5b3a47\" x=\"400.3265\" y=\"207.792751\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_24\">\n",
       "      <!-- 0.0050 -->\n",
       "      <g style=\"fill: #ff7f0e\" transform=\"translate(408.6265 210.942188) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"83.398438\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"139.013672\"/>\n",
       "       <use xlink:href=\"#ArialMT-35\" x=\"194.628906\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"250.244141\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_11\">\n",
       "     <g id=\"line2d_23\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#md3bb5b3a47\" x=\"400.3265\" y=\"174.631126\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_25\">\n",
       "      <!-- 0.0075 -->\n",
       "      <g style=\"fill: #ff7f0e\" transform=\"translate(408.6265 177.780564) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-37\" d=\"M 303 3981 \n",
       "L 303 4522 \n",
       "L 3269 4522 \n",
       "L 3269 4084 \n",
       "Q 2831 3619 2401 2847 \n",
       "Q 1972 2075 1738 1259 \n",
       "Q 1569 684 1522 0 \n",
       "L 944 0 \n",
       "Q 953 541 1156 1306 \n",
       "Q 1359 2072 1739 2783 \n",
       "Q 2119 3494 2547 3981 \n",
       "L 303 3981 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"83.398438\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"139.013672\"/>\n",
       "       <use xlink:href=\"#ArialMT-37\" x=\"194.628906\"/>\n",
       "       <use xlink:href=\"#ArialMT-35\" x=\"250.244141\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_12\">\n",
       "     <g id=\"line2d_24\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#md3bb5b3a47\" x=\"400.3265\" y=\"141.469501\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_26\">\n",
       "      <!-- 0.0100 -->\n",
       "      <g style=\"fill: #ff7f0e\" transform=\"translate(408.6265 144.618939) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"83.398438\"/>\n",
       "       <use xlink:href=\"#ArialMT-31\" x=\"139.013672\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"194.628906\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"250.244141\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_13\">\n",
       "     <g id=\"line2d_25\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#md3bb5b3a47\" x=\"400.3265\" y=\"108.307877\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_27\">\n",
       "      <!-- 0.0125 -->\n",
       "      <g style=\"fill: #ff7f0e\" transform=\"translate(408.6265 111.457314) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"83.398438\"/>\n",
       "       <use xlink:href=\"#ArialMT-31\" x=\"139.013672\"/>\n",
       "       <use xlink:href=\"#ArialMT-32\" x=\"194.628906\"/>\n",
       "       <use xlink:href=\"#ArialMT-35\" x=\"250.244141\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_14\">\n",
       "     <g id=\"line2d_26\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#md3bb5b3a47\" x=\"400.3265\" y=\"75.146252\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_28\">\n",
       "      <!-- 0.0150 -->\n",
       "      <g style=\"fill: #ff7f0e\" transform=\"translate(408.6265 78.29569) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"83.398438\"/>\n",
       "       <use xlink:href=\"#ArialMT-31\" x=\"139.013672\"/>\n",
       "       <use xlink:href=\"#ArialMT-35\" x=\"194.628906\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"250.244141\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_15\">\n",
       "     <g id=\"line2d_27\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#md3bb5b3a47\" x=\"400.3265\" y=\"41.984627\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_29\">\n",
       "      <!-- 0.0175 -->\n",
       "      <g style=\"fill: #ff7f0e\" transform=\"translate(408.6265 45.134065) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"83.398438\"/>\n",
       "       <use xlink:href=\"#ArialMT-31\" x=\"139.013672\"/>\n",
       "       <use xlink:href=\"#ArialMT-37\" x=\"194.628906\"/>\n",
       "       <use xlink:href=\"#ArialMT-35\" x=\"250.244141\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"text_30\">\n",
       "     <!-- Information Acquisition Function -->\n",
       "     <g style=\"fill: #ff7f0e\" transform=\"translate(446.527875 221.18925) rotate(-90) scale(0.096 -0.096)\">\n",
       "      <defs>\n",
       "       <path id=\"ArialMT-49\" d=\"M 597 0 \n",
       "L 597 4581 \n",
       "L 1203 4581 \n",
       "L 1203 0 \n",
       "L 597 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-6d\" d=\"M 422 0 \n",
       "L 422 3319 \n",
       "L 925 3319 \n",
       "L 925 2853 \n",
       "Q 1081 3097 1340 3245 \n",
       "Q 1600 3394 1931 3394 \n",
       "Q 2300 3394 2536 3241 \n",
       "Q 2772 3088 2869 2813 \n",
       "Q 3263 3394 3894 3394 \n",
       "Q 4388 3394 4653 3120 \n",
       "Q 4919 2847 4919 2278 \n",
       "L 4919 0 \n",
       "L 4359 0 \n",
       "L 4359 2091 \n",
       "Q 4359 2428 4304 2576 \n",
       "Q 4250 2725 4106 2815 \n",
       "Q 3963 2906 3769 2906 \n",
       "Q 3419 2906 3187 2673 \n",
       "Q 2956 2441 2956 1928 \n",
       "L 2956 0 \n",
       "L 2394 0 \n",
       "L 2394 2156 \n",
       "Q 2394 2531 2256 2718 \n",
       "Q 2119 2906 1806 2906 \n",
       "Q 1569 2906 1367 2781 \n",
       "Q 1166 2656 1075 2415 \n",
       "Q 984 2175 984 1722 \n",
       "L 984 0 \n",
       "L 422 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-41\" d=\"M -9 0 \n",
       "L 1750 4581 \n",
       "L 2403 4581 \n",
       "L 4278 0 \n",
       "L 3588 0 \n",
       "L 3053 1388 \n",
       "L 1138 1388 \n",
       "L 634 0 \n",
       "L -9 0 \n",
       "z\n",
       "M 1313 1881 \n",
       "L 2866 1881 \n",
       "L 2388 3150 \n",
       "Q 2169 3728 2063 4100 \n",
       "Q 1975 3659 1816 3225 \n",
       "L 1313 1881 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-71\" d=\"M 2538 -1272 \n",
       "L 2538 353 \n",
       "Q 2406 169 2170 47 \n",
       "Q 1934 -75 1669 -75 \n",
       "Q 1078 -75 651 397 \n",
       "Q 225 869 225 1691 \n",
       "Q 225 2191 398 2587 \n",
       "Q 572 2984 901 3189 \n",
       "Q 1231 3394 1625 3394 \n",
       "Q 2241 3394 2594 2875 \n",
       "L 2594 3319 \n",
       "L 3100 3319 \n",
       "L 3100 -1272 \n",
       "L 2538 -1272 \n",
       "z\n",
       "M 803 1669 \n",
       "Q 803 1028 1072 708 \n",
       "Q 1341 388 1716 388 \n",
       "Q 2075 388 2334 692 \n",
       "Q 2594 997 2594 1619 \n",
       "Q 2594 2281 2320 2615 \n",
       "Q 2047 2950 1678 2950 \n",
       "Q 1313 2950 1058 2639 \n",
       "Q 803 2328 803 1669 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-46\" d=\"M 525 0 \n",
       "L 525 4581 \n",
       "L 3616 4581 \n",
       "L 3616 4041 \n",
       "L 1131 4041 \n",
       "L 1131 2622 \n",
       "L 3281 2622 \n",
       "L 3281 2081 \n",
       "L 1131 2081 \n",
       "L 1131 0 \n",
       "L 525 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#ArialMT-49\"/>\n",
       "      <use xlink:href=\"#ArialMT-6e\" x=\"27.783203\"/>\n",
       "      <use xlink:href=\"#ArialMT-66\" x=\"83.398438\"/>\n",
       "      <use xlink:href=\"#ArialMT-6f\" x=\"111.181641\"/>\n",
       "      <use xlink:href=\"#ArialMT-72\" x=\"166.796875\"/>\n",
       "      <use xlink:href=\"#ArialMT-6d\" x=\"200.097656\"/>\n",
       "      <use xlink:href=\"#ArialMT-61\" x=\"283.398438\"/>\n",
       "      <use xlink:href=\"#ArialMT-74\" x=\"339.013672\"/>\n",
       "      <use xlink:href=\"#ArialMT-69\" x=\"366.796875\"/>\n",
       "      <use xlink:href=\"#ArialMT-6f\" x=\"389.013672\"/>\n",
       "      <use xlink:href=\"#ArialMT-6e\" x=\"444.628906\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" x=\"500.244141\"/>\n",
       "      <use xlink:href=\"#ArialMT-41\" x=\"522.527344\"/>\n",
       "      <use xlink:href=\"#ArialMT-63\" x=\"589.226562\"/>\n",
       "      <use xlink:href=\"#ArialMT-71\" x=\"639.226562\"/>\n",
       "      <use xlink:href=\"#ArialMT-75\" x=\"694.841797\"/>\n",
       "      <use xlink:href=\"#ArialMT-69\" x=\"750.457031\"/>\n",
       "      <use xlink:href=\"#ArialMT-73\" x=\"772.673828\"/>\n",
       "      <use xlink:href=\"#ArialMT-69\" x=\"822.673828\"/>\n",
       "      <use xlink:href=\"#ArialMT-74\" x=\"844.890625\"/>\n",
       "      <use xlink:href=\"#ArialMT-69\" x=\"872.673828\"/>\n",
       "      <use xlink:href=\"#ArialMT-6f\" x=\"894.890625\"/>\n",
       "      <use xlink:href=\"#ArialMT-6e\" x=\"950.505859\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" x=\"1006.121094\"/>\n",
       "      <use xlink:href=\"#ArialMT-46\" x=\"1033.904297\"/>\n",
       "      <use xlink:href=\"#ArialMT-75\" x=\"1094.988281\"/>\n",
       "      <use xlink:href=\"#ArialMT-6e\" x=\"1150.603516\"/>\n",
       "      <use xlink:href=\"#ArialMT-63\" x=\"1206.21875\"/>\n",
       "      <use xlink:href=\"#ArialMT-74\" x=\"1256.21875\"/>\n",
       "      <use xlink:href=\"#ArialMT-69\" x=\"1284.001953\"/>\n",
       "      <use xlink:href=\"#ArialMT-6f\" x=\"1306.21875\"/>\n",
       "      <use xlink:href=\"#ArialMT-6e\" x=\"1361.833984\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"line2d_28\">\n",
       "    <path d=\"M 59.439227 274.116 \n",
       "L 62.718566 274.116 \n",
       "L 65.997905 274.116 \n",
       "L 69.277244 274.116 \n",
       "L 72.556583 274.116 \n",
       "L 75.835921 274.116 \n",
       "L 79.115261 274.116 \n",
       "L 82.394598 274.116 \n",
       "L 85.673938 274.116 \n",
       "L 88.953278 274.116 \n",
       "L 92.232615 274.116 \n",
       "L 95.511955 274.116 \n",
       "L 98.791295 274.116 \n",
       "L 102.070632 274.116 \n",
       "L 105.349969 274.116 \n",
       "L 108.629311 274.116 \n",
       "L 111.908649 274.116 \n",
       "L 115.187986 274.116 \n",
       "L 118.467328 274.115605 \n",
       "L 121.746666 274.108884 \n",
       "L 125.026003 273.992661 \n",
       "L 128.305345 272.234685 \n",
       "L 131.584682 256.091504 \n",
       "L 134.86402 186.061032 \n",
       "L 138.143362 66.047027 \n",
       "L 141.422694 32.196 \n",
       "L 144.702037 133.896533 \n",
       "L 147.981379 231.540319 \n",
       "L 151.260711 265.40874 \n",
       "L 154.540053 272.256032 \n",
       "L 157.819395 273.513536 \n",
       "L 161.098728 273.788282 \n",
       "L 164.37807 273.842045 \n",
       "L 167.657412 273.815559 \n",
       "L 170.936745 273.741634 \n",
       "L 174.216087 273.63648 \n",
       "L 177.495429 273.525001 \n",
       "L 180.774762 273.443565 \n",
       "L 184.054104 273.426962 \n",
       "L 187.333446 273.494166 \n",
       "L 190.612778 273.631736 \n",
       "L 193.892121 273.799746 \n",
       "L 197.171463 273.949176 \n",
       "L 200.450795 274.048796 \n",
       "L 203.730137 274.097025 \n",
       "L 207.00948 274.112837 \n",
       "L 210.288812 274.115605 \n",
       "L 213.568154 274.116 \n",
       "L 216.847496 274.116 \n",
       "L 220.126829 274.116 \n",
       "L 223.406181 274.116 \n",
       "L 226.685504 274.116 \n",
       "L 229.964846 274.116 \n",
       "L 233.244188 274.116 \n",
       "L 236.523511 274.116 \n",
       "L 239.802872 274.116 \n",
       "L 243.082195 274.116 \n",
       "L 246.361537 274.116 \n",
       "L 249.640879 274.116 \n",
       "L 252.920222 274.116 \n",
       "L 256.199564 274.116 \n",
       "L 259.478887 274.116 \n",
       "L 262.758248 274.116 \n",
       "L 266.037571 274.116 \n",
       "L 269.316913 274.116 \n",
       "L 272.596255 274.116 \n",
       "L 275.875578 274.116 \n",
       "L 279.15494 274.116 \n",
       "L 282.434262 274.116 \n",
       "L 285.713605 274.116 \n",
       "L 288.992947 274.116 \n",
       "L 292.272289 274.116 \n",
       "L 295.551631 274.116 \n",
       "L 298.830954 274.116 \n",
       "L 302.110315 274.116 \n",
       "L 305.389638 274.116 \n",
       "L 308.66898 274.116 \n",
       "L 311.948322 274.116 \n",
       "L 315.227645 274.116 \n",
       "L 318.507007 274.116 \n",
       "L 321.78633 274.116 \n",
       "L 325.065672 274.116 \n",
       "L 328.345014 274.116 \n",
       "L 331.624356 274.116 \n",
       "L 334.903698 274.116 \n",
       "L 338.183021 274.116 \n",
       "L 341.462363 274.116 \n",
       "L 344.741705 274.116 \n",
       "L 348.021048 274.116 \n",
       "L 351.30039 274.116 \n",
       "L 354.579713 274.116 \n",
       "L 357.859055 274.116 \n",
       "L 361.138397 274.116 \n",
       "L 364.417739 274.116 \n",
       "L 367.697081 274.116 \n",
       "L 370.976423 274.116 \n",
       "L 374.255766 274.116 \n",
       "L 377.535088 274.116 \n",
       "L 380.814431 274.116 \n",
       "L 384.093773 274.116 \n",
       "\" clip-path=\"url(#p9ace12a451)\" style=\"fill: none; stroke: #ff7f0e; stroke-width: 1.2; stroke-linecap: round\"/>\n",
       "   </g>\n",
       "   <g id=\"line2d_29\">\n",
       "    <path d=\"M 141.422694 274.116 \n",
       "L 141.422694 271.672364 \n",
       "L 141.422694 269.228727 \n",
       "L 141.422694 266.785091 \n",
       "L 141.422694 264.341454 \n",
       "L 141.422694 261.897818 \n",
       "L 141.422694 259.454182 \n",
       "L 141.422694 257.010545 \n",
       "L 141.422694 254.566909 \n",
       "L 141.422694 252.123273 \n",
       "L 141.422694 249.679636 \n",
       "L 141.422694 247.236 \n",
       "L 141.422694 244.792364 \n",
       "L 141.422694 242.348728 \n",
       "L 141.422694 239.90509 \n",
       "L 141.422694 237.461454 \n",
       "L 141.422694 235.017818 \n",
       "L 141.422694 232.574182 \n",
       "L 141.422694 230.130546 \n",
       "L 141.422694 227.686907 \n",
       "L 141.422694 225.243272 \n",
       "L 141.422694 222.799636 \n",
       "L 141.422694 220.356 \n",
       "L 141.422694 217.912364 \n",
       "L 141.422694 215.468728 \n",
       "L 141.422694 213.025093 \n",
       "L 141.422694 210.581457 \n",
       "L 141.422694 208.137815 \n",
       "L 141.422694 205.694179 \n",
       "L 141.422694 203.250543 \n",
       "L 141.422694 200.806907 \n",
       "L 141.422694 198.363272 \n",
       "L 141.422694 195.919636 \n",
       "L 141.422694 193.476 \n",
       "L 141.422694 191.032364 \n",
       "L 141.422694 188.588728 \n",
       "L 141.422694 186.145093 \n",
       "L 141.422694 183.701457 \n",
       "L 141.422694 181.257815 \n",
       "L 141.422694 178.814179 \n",
       "L 141.422694 176.370543 \n",
       "L 141.422694 173.926907 \n",
       "L 141.422694 171.483272 \n",
       "L 141.422694 169.03963 \n",
       "L 141.422694 166.596 \n",
       "L 141.422694 164.152358 \n",
       "L 141.422694 161.708728 \n",
       "L 141.422694 159.265086 \n",
       "L 141.422694 156.821457 \n",
       "L 141.422694 154.377815 \n",
       "L 141.422694 151.934185 \n",
       "L 141.422694 149.490543 \n",
       "L 141.422694 147.046914 \n",
       "L 141.422694 144.603272 \n",
       "L 141.422694 142.159642 \n",
       "L 141.422694 139.716 \n",
       "L 141.422694 137.27237 \n",
       "L 141.422694 134.828728 \n",
       "L 141.422694 132.385086 \n",
       "L 141.422694 129.941457 \n",
       "L 141.422694 127.497827 \n",
       "L 141.422694 125.054185 \n",
       "L 141.422694 122.610543 \n",
       "L 141.422694 120.166914 \n",
       "L 141.422694 117.723272 \n",
       "L 141.422694 115.27963 \n",
       "L 141.422694 112.836 \n",
       "L 141.422694 110.39237 \n",
       "L 141.422694 107.948728 \n",
       "L 141.422694 105.505086 \n",
       "L 141.422694 103.061457 \n",
       "L 141.422694 100.617827 \n",
       "L 141.422694 98.174185 \n",
       "L 141.422694 95.730543 \n",
       "L 141.422694 93.286914 \n",
       "L 141.422694 90.843272 \n",
       "L 141.422694 88.39963 \n",
       "L 141.422694 85.956 \n",
       "L 141.422694 83.51237 \n",
       "L 141.422694 81.068728 \n",
       "L 141.422694 78.625086 \n",
       "L 141.422694 76.181457 \n",
       "L 141.422694 73.737815 \n",
       "L 141.422694 71.294185 \n",
       "L 141.422694 68.850543 \n",
       "L 141.422694 66.406914 \n",
       "L 141.422694 63.963259 \n",
       "L 141.422694 61.51963 \n",
       "L 141.422694 59.076 \n",
       "L 141.422694 56.63237 \n",
       "L 141.422694 54.188716 \n",
       "L 141.422694 51.745086 \n",
       "L 141.422694 49.301457 \n",
       "L 141.422694 46.857827 \n",
       "L 141.422694 44.414173 \n",
       "L 141.422694 41.970543 \n",
       "L 141.422694 39.526914 \n",
       "L 141.422694 37.083284 \n",
       "L 141.422694 34.63963 \n",
       "L 141.422694 32.196 \n",
       "\" clip-path=\"url(#p9ace12a451)\" style=\"fill: none; stroke: #ff7f0e; stroke-linecap: round\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_7\">\n",
       "    <path d=\"M 43.2065 286.212 \n",
       "L 43.2065 20.1 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_8\">\n",
       "    <path d=\"M 400.3265 286.212 \n",
       "L 400.3265 20.1 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_9\">\n",
       "    <path d=\"M 43.2065 286.212 \n",
       "L 400.3265 286.212 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_10\">\n",
       "    <path d=\"M 43.2065 20.1 \n",
       "L 400.3265 20.1 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "  </g>\n",
       " </g>\n",
       " <defs>\n",
       "  <clipPath id=\"p9ace12a451\">\n",
       "   <rect x=\"43.2065\" y=\"20.1\" width=\"357.12\" height=\"266.112\"/>\n",
       "  </clipPath>\n",
       " </defs>\n",
       "</svg>\n"
      ],
      "text/plain": [
       "<Figure size 640x480 with 2 Axes>"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "image/svg+xml": [
       "<?xml version=\"1.0\" encoding=\"utf-8\" standalone=\"no\"?>\n",
       "<!DOCTYPE svg PUBLIC \"-//W3C//DTD SVG 1.1//EN\"\n",
       "  \"http://www.w3.org/Graphics/SVG/1.1/DTD/svg11.dtd\">\n",
       "<svg xmlns:xlink=\"http://www.w3.org/1999/xlink\" width=\"450.74225pt\" height=\"322.539375pt\" viewBox=\"0 0 450.74225 322.539375\" xmlns=\"http://www.w3.org/2000/svg\" version=\"1.1\">\n",
       " <metadata>\n",
       "  <rdf:RDF xmlns:dc=\"http://purl.org/dc/elements/1.1/\" xmlns:cc=\"http://creativecommons.org/ns#\" xmlns:rdf=\"http://www.w3.org/1999/02/22-rdf-syntax-ns#\">\n",
       "   <cc:Work>\n",
       "    <dc:type rdf:resource=\"http://purl.org/dc/dcmitype/StillImage\"/>\n",
       "    <dc:date>2023-10-23T15:18:34.640933</dc:date>\n",
       "    <dc:format>image/svg+xml</dc:format>\n",
       "    <dc:creator>\n",
       "     <cc:Agent>\n",
       "      <dc:title>Matplotlib v3.8.0, https://matplotlib.org/</dc:title>\n",
       "     </cc:Agent>\n",
       "    </dc:creator>\n",
       "   </cc:Work>\n",
       "  </rdf:RDF>\n",
       " </metadata>\n",
       " <defs>\n",
       "  <style type=\"text/css\">*{stroke-linejoin: round; stroke-linecap: butt}</style>\n",
       " </defs>\n",
       " <g id=\"figure_1\">\n",
       "  <g id=\"patch_1\">\n",
       "   <path d=\"M 0 322.539375 \n",
       "L 450.74225 322.539375 \n",
       "L 450.74225 0 \n",
       "L 0 0 \n",
       "z\n",
       "\" style=\"fill: #ffffff\"/>\n",
       "  </g>\n",
       "  <g id=\"axes_1\">\n",
       "   <g id=\"patch_2\">\n",
       "    <path d=\"M 43.2065 286.212 \n",
       "L 400.3265 286.212 \n",
       "L 400.3265 20.1 \n",
       "L 43.2065 20.1 \n",
       "z\n",
       "\" style=\"fill: #ffffff\"/>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_1\">\n",
       "    <g id=\"xtick_1\">\n",
       "     <g id=\"line2d_1\">\n",
       "      <defs>\n",
       "       <path id=\"mab556199d0\" d=\"M 0 0 \n",
       "L 0 4.8 \n",
       "\" style=\"stroke: #262626\"/>\n",
       "      </defs>\n",
       "      <g>\n",
       "       <use xlink:href=\"#mab556199d0\" x=\"59.439227\" y=\"286.212\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_1\">\n",
       "      <!-- 0.0 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(53.323227 300.810875) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-30\" d=\"M 266 2259 \n",
       "Q 266 3072 433 3567 \n",
       "Q 600 4063 929 4331 \n",
       "Q 1259 4600 1759 4600 \n",
       "Q 2128 4600 2406 4451 \n",
       "Q 2684 4303 2865 4023 \n",
       "Q 3047 3744 3150 3342 \n",
       "Q 3253 2941 3253 2259 \n",
       "Q 3253 1453 3087 958 \n",
       "Q 2922 463 2592 192 \n",
       "Q 2263 -78 1759 -78 \n",
       "Q 1097 -78 719 397 \n",
       "Q 266 969 266 2259 \n",
       "z\n",
       "M 844 2259 \n",
       "Q 844 1131 1108 757 \n",
       "Q 1372 384 1759 384 \n",
       "Q 2147 384 2411 759 \n",
       "Q 2675 1134 2675 2259 \n",
       "Q 2675 3391 2411 3762 \n",
       "Q 2147 4134 1753 4134 \n",
       "Q 1366 4134 1134 3806 \n",
       "Q 844 3388 844 2259 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "        <path id=\"ArialMT-2e\" d=\"M 581 0 \n",
       "L 581 641 \n",
       "L 1222 641 \n",
       "L 1222 0 \n",
       "L 581 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_2\">\n",
       "     <g id=\"line2d_2\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mab556199d0\" x=\"124.370136\" y=\"286.212\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_2\">\n",
       "      <!-- 0.2 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(118.254136 300.810875) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-32\" d=\"M 3222 541 \n",
       "L 3222 0 \n",
       "L 194 0 \n",
       "Q 188 203 259 391 \n",
       "Q 375 700 629 1000 \n",
       "Q 884 1300 1366 1694 \n",
       "Q 2113 2306 2375 2664 \n",
       "Q 2638 3022 2638 3341 \n",
       "Q 2638 3675 2398 3904 \n",
       "Q 2159 4134 1775 4134 \n",
       "Q 1369 4134 1125 3890 \n",
       "Q 881 3647 878 3216 \n",
       "L 300 3275 \n",
       "Q 359 3922 746 4261 \n",
       "Q 1134 4600 1788 4600 \n",
       "Q 2447 4600 2831 4234 \n",
       "Q 3216 3869 3216 3328 \n",
       "Q 3216 3053 3103 2787 \n",
       "Q 2991 2522 2730 2228 \n",
       "Q 2469 1934 1863 1422 \n",
       "Q 1356 997 1212 845 \n",
       "Q 1069 694 975 541 \n",
       "L 3222 541 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-32\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_3\">\n",
       "     <g id=\"line2d_3\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mab556199d0\" x=\"189.301045\" y=\"286.212\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_3\">\n",
       "      <!-- 0.4 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(183.185045 300.810875) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-34\" d=\"M 2069 0 \n",
       "L 2069 1097 \n",
       "L 81 1097 \n",
       "L 81 1613 \n",
       "L 2172 4581 \n",
       "L 2631 4581 \n",
       "L 2631 1613 \n",
       "L 3250 1613 \n",
       "L 3250 1097 \n",
       "L 2631 1097 \n",
       "L 2631 0 \n",
       "L 2069 0 \n",
       "z\n",
       "M 2069 1613 \n",
       "L 2069 3678 \n",
       "L 634 1613 \n",
       "L 2069 1613 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-34\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_4\">\n",
       "     <g id=\"line2d_4\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mab556199d0\" x=\"254.231955\" y=\"286.212\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_4\">\n",
       "      <!-- 0.6 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(248.115955 300.810875) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-36\" d=\"M 3184 3459 \n",
       "L 2625 3416 \n",
       "Q 2550 3747 2413 3897 \n",
       "Q 2184 4138 1850 4138 \n",
       "Q 1581 4138 1378 3988 \n",
       "Q 1113 3794 959 3422 \n",
       "Q 806 3050 800 2363 \n",
       "Q 1003 2672 1297 2822 \n",
       "Q 1591 2972 1913 2972 \n",
       "Q 2475 2972 2870 2558 \n",
       "Q 3266 2144 3266 1488 \n",
       "Q 3266 1056 3080 686 \n",
       "Q 2894 316 2569 119 \n",
       "Q 2244 -78 1831 -78 \n",
       "Q 1128 -78 684 439 \n",
       "Q 241 956 241 2144 \n",
       "Q 241 3472 731 4075 \n",
       "Q 1159 4600 1884 4600 \n",
       "Q 2425 4600 2770 4297 \n",
       "Q 3116 3994 3184 3459 \n",
       "z\n",
       "M 888 1484 \n",
       "Q 888 1194 1011 928 \n",
       "Q 1134 663 1356 523 \n",
       "Q 1578 384 1822 384 \n",
       "Q 2178 384 2434 671 \n",
       "Q 2691 959 2691 1453 \n",
       "Q 2691 1928 2437 2201 \n",
       "Q 2184 2475 1800 2475 \n",
       "Q 1419 2475 1153 2201 \n",
       "Q 888 1928 888 1484 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-36\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_5\">\n",
       "     <g id=\"line2d_5\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mab556199d0\" x=\"319.162864\" y=\"286.212\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_5\">\n",
       "      <!-- 0.8 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(313.046864 300.810875) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-38\" d=\"M 1131 2484 \n",
       "Q 781 2613 612 2850 \n",
       "Q 444 3088 444 3419 \n",
       "Q 444 3919 803 4259 \n",
       "Q 1163 4600 1759 4600 \n",
       "Q 2359 4600 2725 4251 \n",
       "Q 3091 3903 3091 3403 \n",
       "Q 3091 3084 2923 2848 \n",
       "Q 2756 2613 2416 2484 \n",
       "Q 2838 2347 3058 2040 \n",
       "Q 3278 1734 3278 1309 \n",
       "Q 3278 722 2862 322 \n",
       "Q 2447 -78 1769 -78 \n",
       "Q 1091 -78 675 323 \n",
       "Q 259 725 259 1325 \n",
       "Q 259 1772 486 2073 \n",
       "Q 713 2375 1131 2484 \n",
       "z\n",
       "M 1019 3438 \n",
       "Q 1019 3113 1228 2906 \n",
       "Q 1438 2700 1772 2700 \n",
       "Q 2097 2700 2305 2904 \n",
       "Q 2513 3109 2513 3406 \n",
       "Q 2513 3716 2298 3927 \n",
       "Q 2084 4138 1766 4138 \n",
       "Q 1444 4138 1231 3931 \n",
       "Q 1019 3725 1019 3438 \n",
       "z\n",
       "M 838 1322 \n",
       "Q 838 1081 952 856 \n",
       "Q 1066 631 1291 507 \n",
       "Q 1516 384 1775 384 \n",
       "Q 2178 384 2440 643 \n",
       "Q 2703 903 2703 1303 \n",
       "Q 2703 1709 2433 1975 \n",
       "Q 2163 2241 1756 2241 \n",
       "Q 1359 2241 1098 1978 \n",
       "Q 838 1716 838 1322 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-38\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_6\">\n",
       "     <g id=\"line2d_6\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mab556199d0\" x=\"384.093773\" y=\"286.212\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_6\">\n",
       "      <!-- 1.0 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(377.977773 300.810875) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-31\" d=\"M 2384 0 \n",
       "L 1822 0 \n",
       "L 1822 3584 \n",
       "Q 1619 3391 1289 3197 \n",
       "Q 959 3003 697 2906 \n",
       "L 697 3450 \n",
       "Q 1169 3672 1522 3987 \n",
       "Q 1875 4303 2022 4600 \n",
       "L 2384 4600 \n",
       "L 2384 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-31\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"text_7\">\n",
       "     <!-- $x$ -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(218.8865 313.431375) scale(0.096 -0.096)\">\n",
       "      <defs>\n",
       "       <path id=\"DejaVuSans-Oblique-78\" d=\"M 3841 3500 \n",
       "L 2234 1784 \n",
       "L 3219 0 \n",
       "L 2559 0 \n",
       "L 1819 1388 \n",
       "L 531 0 \n",
       "L -166 0 \n",
       "L 1556 1844 \n",
       "L 641 3500 \n",
       "L 1300 3500 \n",
       "L 1972 2234 \n",
       "L 3144 3500 \n",
       "L 3841 3500 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-78\" transform=\"translate(0 0.3125)\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_2\">\n",
       "    <g id=\"ytick_1\">\n",
       "     <g id=\"line2d_7\">\n",
       "      <defs>\n",
       "       <path id=\"mde981a9670\" d=\"M 0 0 \n",
       "L -4.8 0 \n",
       "\" style=\"stroke: #262626\"/>\n",
       "      </defs>\n",
       "      <g>\n",
       "       <use xlink:href=\"#mde981a9670\" x=\"43.2065\" y=\"285.913638\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_8\">\n",
       "      <!-- −12 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(19.9795 289.063076) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-2212\" d=\"M 3381 1997 \n",
       "L 356 1997 \n",
       "L 356 2522 \n",
       "L 3381 2522 \n",
       "L 3381 1997 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-31\" x=\"58.398438\"/>\n",
       "       <use xlink:href=\"#ArialMT-32\" x=\"114.013672\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_2\">\n",
       "     <g id=\"line2d_8\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mde981a9670\" x=\"43.2065\" y=\"244.38917\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_9\">\n",
       "      <!-- −10 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(19.9795 247.538607) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-31\" x=\"58.398438\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"114.013672\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_3\">\n",
       "     <g id=\"line2d_9\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mde981a9670\" x=\"43.2065\" y=\"202.864701\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_10\">\n",
       "      <!-- −8 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(24.873125 206.014139) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-38\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_4\">\n",
       "     <g id=\"line2d_10\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mde981a9670\" x=\"43.2065\" y=\"161.340232\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_11\">\n",
       "      <!-- −6 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(24.873125 164.48967) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-36\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_5\">\n",
       "     <g id=\"line2d_11\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mde981a9670\" x=\"43.2065\" y=\"119.815764\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_12\">\n",
       "      <!-- −4 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(24.873125 122.965201) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-34\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_6\">\n",
       "     <g id=\"line2d_12\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mde981a9670\" x=\"43.2065\" y=\"78.291295\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_13\">\n",
       "      <!-- −2 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(24.873125 81.440733) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-32\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_7\">\n",
       "     <g id=\"line2d_13\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mde981a9670\" x=\"43.2065\" y=\"36.766826\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_14\">\n",
       "      <!-- 0 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(30.012875 39.916264) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"text_15\">\n",
       "     <!-- $y$ -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(13.9635 156.036) rotate(-90) scale(0.096 -0.096)\">\n",
       "      <defs>\n",
       "       <path id=\"DejaVuSans-Oblique-79\" d=\"M 1588 -325 \n",
       "Q 1188 -997 936 -1164 \n",
       "Q 684 -1331 294 -1331 \n",
       "L -159 -1331 \n",
       "L -63 -850 \n",
       "L 269 -850 \n",
       "Q 509 -850 678 -719 \n",
       "Q 847 -588 1056 -206 \n",
       "L 1234 128 \n",
       "L 459 3500 \n",
       "L 1069 3500 \n",
       "L 1650 819 \n",
       "L 3256 3500 \n",
       "L 3859 3500 \n",
       "L 1588 -325 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-79\" transform=\"translate(0 0.3125)\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"PolyCollection_1\">\n",
       "    <defs>\n",
       "     <path id=\"mc41a932119\" d=\"M 59.439227 -207.774725 \n",
       "L 59.439227 -199.4906 \n",
       "L 62.718566 -201.53824 \n",
       "L 65.997905 -203.168912 \n",
       "L 69.277244 -205.160844 \n",
       "L 72.556583 -207.748757 \n",
       "L 75.835921 -210.966324 \n",
       "L 79.115261 -214.777403 \n",
       "L 82.394598 -219.111395 \n",
       "L 85.673938 -223.879339 \n",
       "L 88.953278 -228.981123 \n",
       "L 92.232615 -234.307764 \n",
       "L 95.511955 -239.748382 \n",
       "L 98.791295 -245.191592 \n",
       "L 102.070632 -250.530987 \n",
       "L 105.349969 -255.667877 \n",
       "L 108.629311 -260.512938 \n",
       "L 111.908649 -264.990358 \n",
       "L 115.187986 -269.040407 \n",
       "L 118.467328 -272.619284 \n",
       "L 121.746666 -275.704923 \n",
       "L 125.026003 -278.290254 \n",
       "L 128.305345 -280.383584 \n",
       "L 131.584682 -282.002054 \n",
       "L 134.86402 -283.16356 \n",
       "L 138.143362 -283.879055 \n",
       "L 141.422694 -284.153566 \n",
       "L 144.702037 -283.985032 \n",
       "L 147.981379 -283.375312 \n",
       "L 151.260711 -282.333458 \n",
       "L 154.540053 -280.872966 \n",
       "L 157.819395 -279.003217 \n",
       "L 161.098728 -276.731481 \n",
       "L 164.37807 -274.062198 \n",
       "L 167.657412 -271.00339 \n",
       "L 170.936745 -267.568728 \n",
       "L 174.216087 -263.778491 \n",
       "L 177.495429 -259.660328 \n",
       "L 180.774762 -255.24842 \n",
       "L 184.054104 -250.582998 \n",
       "L 187.333446 -245.70787 \n",
       "L 190.612778 -240.670542 \n",
       "L 193.892121 -235.519292 \n",
       "L 197.171463 -230.301899 \n",
       "L 200.450795 -225.064017 \n",
       "L 203.730137 -219.847342 \n",
       "L 207.00948 -214.687652 \n",
       "L 210.288812 -209.614035 \n",
       "L 213.568154 -204.647681 \n",
       "L 216.847496 -199.800714 \n",
       "L 220.126829 -195.075792 \n",
       "L 223.406181 -190.465673 \n",
       "L 226.685504 -185.952288 \n",
       "L 229.964846 -181.503661 \n",
       "L 233.244188 -177.065092 \n",
       "L 236.523511 -172.525412 \n",
       "L 239.802872 -167.571588 \n",
       "L 243.082195 -161.134356 \n",
       "L 246.361537 -151.90387 \n",
       "L 249.640879 -141.073194 \n",
       "L 252.920222 -129.785991 \n",
       "L 256.199564 -118.479046 \n",
       "L 259.478887 -107.401489 \n",
       "L 262.758248 -96.756888 \n",
       "L 266.037571 -86.736455 \n",
       "L 269.316913 -77.525542 \n",
       "L 272.596255 -69.305045 \n",
       "L 275.875578 -62.247843 \n",
       "L 279.15494 -56.517485 \n",
       "L 282.434262 -52.261962 \n",
       "L 285.713605 -49.610984 \n",
       "L 288.992947 -48.67193 \n",
       "L 292.272289 -49.524199 \n",
       "L 295.551631 -52.215708 \n",
       "L 298.830954 -56.762555 \n",
       "L 302.110315 -63.140742 \n",
       "L 305.389638 -71.289165 \n",
       "L 308.66898 -81.106604 \n",
       "L 311.948322 -92.451843 \n",
       "L 315.227645 -105.145193 \n",
       "L 318.507007 -118.971878 \n",
       "L 321.78633 -133.684315 \n",
       "L 325.065672 -149.007951 \n",
       "L 328.345014 -164.645483 \n",
       "L 331.624356 -180.282322 \n",
       "L 334.903698 -195.594018 \n",
       "L 338.183021 -210.246613 \n",
       "L 341.462363 -223.901313 \n",
       "L 344.741705 -236.211945 \n",
       "L 348.021048 -246.84599 \n",
       "L 351.30039 -255.577562 \n",
       "L 354.579713 -262.355582 \n",
       "L 357.859055 -267.21358 \n",
       "L 361.138397 -270.174927 \n",
       "L 364.417739 -271.26028 \n",
       "L 367.697081 -270.483936 \n",
       "L 370.976423 -267.896173 \n",
       "L 374.255766 -263.547866 \n",
       "L 377.535088 -257.484084 \n",
       "L 380.814431 -249.711342 \n",
       "L 384.093773 -240.221894 \n",
       "L 384.093773 -248.373901 \n",
       "L 384.093773 -248.373901 \n",
       "L 380.814431 -256.969672 \n",
       "L 377.535088 -264.666119 \n",
       "L 374.255766 -271.028442 \n",
       "L 370.976423 -275.7012 \n",
       "L 367.697081 -278.454162 \n",
       "L 364.417739 -279.160473 \n",
       "L 361.138397 -277.776636 \n",
       "L 357.859055 -274.342292 \n",
       "L 354.579713 -268.988348 \n",
       "L 351.30039 -261.959621 \n",
       "L 348.021048 -253.597895 \n",
       "L 344.741705 -244.230042 \n",
       "L 341.462363 -234.080357 \n",
       "L 338.183021 -223.33018 \n",
       "L 334.903698 -212.17255 \n",
       "L 331.624356 -200.833207 \n",
       "L 328.345014 -189.549092 \n",
       "L 325.065672 -178.550162 \n",
       "L 321.78633 -168.057866 \n",
       "L 318.507007 -158.264672 \n",
       "L 315.227645 -149.337371 \n",
       "L 311.948322 -141.409148 \n",
       "L 308.66898 -134.576502 \n",
       "L 305.389638 -128.902576 \n",
       "L 302.110315 -124.414377 \n",
       "L 298.830954 -121.107313 \n",
       "L 295.551631 -118.944831 \n",
       "L 292.272289 -117.868718 \n",
       "L 288.992947 -117.794328 \n",
       "L 285.713605 -118.625272 \n",
       "L 282.434262 -120.253242 \n",
       "L 279.15494 -122.562979 \n",
       "L 275.875578 -125.439474 \n",
       "L 272.596255 -128.772012 \n",
       "L 269.316913 -132.455848 \n",
       "L 266.037571 -136.399446 \n",
       "L 262.758248 -140.524614 \n",
       "L 259.478887 -144.771248 \n",
       "L 256.199564 -149.101647 \n",
       "L 252.920222 -153.511396 \n",
       "L 249.640879 -158.063886 \n",
       "L 246.361537 -163.033423 \n",
       "L 243.082195 -169.425025 \n",
       "L 239.802872 -178.31626 \n",
       "L 236.523511 -188.30422 \n",
       "L 233.244188 -198.246125 \n",
       "L 229.964846 -207.774626 \n",
       "L 226.685504 -216.740108 \n",
       "L 223.406181 -225.063557 \n",
       "L 220.126829 -232.700862 \n",
       "L 216.847496 -239.631109 \n",
       "L 213.568154 -245.852413 \n",
       "L 210.288812 -251.378532 \n",
       "L 207.00948 -256.237225 \n",
       "L 203.730137 -260.468318 \n",
       "L 200.450795 -264.121204 \n",
       "L 197.171463 -267.252672 \n",
       "L 193.892121 -269.925122 \n",
       "L 190.612778 -272.203674 \n",
       "L 187.333446 -274.153683 \n",
       "L 184.054104 -275.83839 \n",
       "L 180.774762 -277.316782 \n",
       "L 177.495429 -278.640425 \n",
       "L 174.216087 -279.852647 \n",
       "L 170.936745 -280.986083 \n",
       "L 167.657412 -282.061416 \n",
       "L 164.37807 -283.086516 \n",
       "L 161.098728 -284.057518 \n",
       "L 157.819395 -284.959022 \n",
       "L 154.540053 -285.7675 \n",
       "L 151.260711 -286.457957 \n",
       "L 147.981379 -287.003779 \n",
       "L 144.702037 -287.380441 \n",
       "L 141.422694 -287.557697 \n",
       "L 138.143362 -287.498813 \n",
       "L 134.86402 -287.165614 \n",
       "L 131.584682 -286.530619 \n",
       "L 128.305345 -285.578942 \n",
       "L 125.026003 -284.310082 \n",
       "L 121.746666 -282.732832 \n",
       "L 118.467328 -280.858343 \n",
       "L 115.187986 -278.695594 \n",
       "L 111.908649 -276.251848 \n",
       "L 108.629311 -273.527589 \n",
       "L 105.349969 -270.522332 \n",
       "L 102.070632 -267.234009 \n",
       "L 98.791295 -263.661265 \n",
       "L 95.511955 -259.806276 \n",
       "L 92.232615 -255.674703 \n",
       "L 88.953278 -251.277248 \n",
       "L 85.673938 -246.631366 \n",
       "L 82.394598 -241.761559 \n",
       "L 79.115261 -236.702188 \n",
       "L 75.835921 -231.497923 \n",
       "L 72.556583 -226.207115 \n",
       "L 69.277244 -220.915445 \n",
       "L 65.997905 -215.768685 \n",
       "L 62.718566 -211.100684 \n",
       "L 59.439227 -207.774725 \n",
       "z\n",
       "\" style=\"stroke: #1f77b4; stroke-opacity: 0.5; stroke-width: 0.8\"/>\n",
       "    </defs>\n",
       "    <g clip-path=\"url(#pb9361a8952)\">\n",
       "     <use xlink:href=\"#mc41a932119\" x=\"0\" y=\"322.539375\" style=\"fill: #1f77b4; fill-opacity: 0.5; stroke: #1f77b4; stroke-opacity: 0.5; stroke-width: 0.8\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"PolyCollection_2\">\n",
       "    <defs>\n",
       "     <path id=\"m59b22bcbb7\" d=\"M 59.439227 -199.4906 \n",
       "L 59.439227 -197.767559 \n",
       "L 62.718566 -199.986769 \n",
       "L 65.997905 -201.923506 \n",
       "L 69.277244 -204.13339 \n",
       "L 72.556583 -206.857635 \n",
       "L 75.835921 -210.158309 \n",
       "L 79.115261 -214.0173 \n",
       "L 82.394598 -218.374127 \n",
       "L 85.673938 -223.14517 \n",
       "L 88.953278 -228.232875 \n",
       "L 92.232615 -233.529153 \n",
       "L 95.511955 -238.92272 \n",
       "L 98.791295 -244.300964 \n",
       "L 102.070632 -249.555624 \n",
       "L 105.349969 -254.585903 \n",
       "L 108.629311 -259.30093 \n",
       "L 111.908649 -263.62481 \n",
       "L 115.187986 -267.500232 \n",
       "L 118.467328 -270.889597 \n",
       "L 121.746666 -273.779143 \n",
       "L 125.026003 -276.171582 \n",
       "L 128.305345 -278.083226 \n",
       "L 131.584682 -279.536664 \n",
       "L 134.86402 -280.555148 \n",
       "L 138.143362 -281.159201 \n",
       "L 141.422694 -281.367887 \n",
       "L 144.702037 -281.196645 \n",
       "L 147.981379 -280.658071 \n",
       "L 151.260711 -279.759363 \n",
       "L 154.540053 -278.500281 \n",
       "L 157.819395 -276.871253 \n",
       "L 161.098728 -274.857305 \n",
       "L 164.37807 -272.442278 \n",
       "L 167.657412 -269.617722 \n",
       "L 170.936745 -266.387591 \n",
       "L 174.216087 -262.769165 \n",
       "L 177.495429 -258.791619 \n",
       "L 180.774762 -254.492948 \n",
       "L 184.054104 -249.917784 \n",
       "L 187.333446 -245.1141 \n",
       "L 190.612778 -240.132891 \n",
       "L 193.892121 -235.025227 \n",
       "L 197.171463 -229.841005 \n",
       "L 200.450795 -224.627423 \n",
       "L 203.730137 -219.427207 \n",
       "L 207.00948 -214.276724 \n",
       "L 210.288812 -209.205181 \n",
       "L 213.568154 -204.233383 \n",
       "L 216.847496 -199.372412 \n",
       "L 220.126829 -194.622957 \n",
       "L 223.406181 -189.974276 \n",
       "L 226.685504 -185.402064 \n",
       "L 229.964846 -180.862939 \n",
       "L 233.244188 -176.280115 \n",
       "L 236.523511 -171.499355 \n",
       "L 239.802872 -166.153868 \n",
       "L 243.082195 -159.412274 \n",
       "L 246.361537 -150.525336 \n",
       "L 249.640879 -140.112657 \n",
       "L 252.920222 -129.080215 \n",
       "L 256.199564 -117.925961 \n",
       "L 259.478887 -106.945624 \n",
       "L 262.758248 -96.366424 \n",
       "L 266.037571 -86.39165 \n",
       "L 269.316913 -77.213408 \n",
       "L 272.596255 -69.016494 \n",
       "L 275.875578 -61.976142 \n",
       "L 279.15494 -56.257447 \n",
       "L 282.434262 -52.009308 \n",
       "L 285.713605 -49.362033 \n",
       "L 288.992947 -48.423375 \n",
       "L 292.272289 -49.272832 \n",
       "L 295.551631 -51.958303 \n",
       "L 298.830954 -56.495685 \n",
       "L 302.110315 -62.860626 \n",
       "L 305.389638 -70.991426 \n",
       "L 308.66898 -80.786056 \n",
       "L 311.948322 -92.102148 \n",
       "L 315.227645 -104.758392 \n",
       "L 318.507007 -118.537853 \n",
       "L 321.78633 -133.1898 \n",
       "L 325.065672 -148.435383 \n",
       "L 328.345014 -163.971348 \n",
       "L 331.624356 -179.47501 \n",
       "L 334.903698 -194.612106 \n",
       "L 338.183021 -209.039996 \n",
       "L 341.462363 -222.422267 \n",
       "L 344.741705 -234.449055 \n",
       "L 348.021048 -244.870318 \n",
       "L 351.30039 -253.531655 \n",
       "L 354.579713 -260.357718 \n",
       "L 357.859055 -265.30551 \n",
       "L 361.138397 -268.346455 \n",
       "L 364.417739 -269.479227 \n",
       "L 367.697081 -268.713709 \n",
       "L 370.976423 -266.100228 \n",
       "L 374.255766 -261.699542 \n",
       "L 377.535088 -255.585272 \n",
       "L 380.814431 -247.825648 \n",
       "L 384.093773 -238.47925 \n",
       "L 384.093773 -240.221894 \n",
       "L 384.093773 -240.221894 \n",
       "L 380.814431 -249.711342 \n",
       "L 377.535088 -257.484084 \n",
       "L 374.255766 -263.547866 \n",
       "L 370.976423 -267.896173 \n",
       "L 367.697081 -270.483936 \n",
       "L 364.417739 -271.26028 \n",
       "L 361.138397 -270.174927 \n",
       "L 357.859055 -267.21358 \n",
       "L 354.579713 -262.355582 \n",
       "L 351.30039 -255.577562 \n",
       "L 348.021048 -246.84599 \n",
       "L 344.741705 -236.211945 \n",
       "L 341.462363 -223.901313 \n",
       "L 338.183021 -210.246613 \n",
       "L 334.903698 -195.594018 \n",
       "L 331.624356 -180.282322 \n",
       "L 328.345014 -164.645483 \n",
       "L 325.065672 -149.007951 \n",
       "L 321.78633 -133.684315 \n",
       "L 318.507007 -118.971878 \n",
       "L 315.227645 -105.145193 \n",
       "L 311.948322 -92.451843 \n",
       "L 308.66898 -81.106604 \n",
       "L 305.389638 -71.289165 \n",
       "L 302.110315 -63.140742 \n",
       "L 298.830954 -56.762555 \n",
       "L 295.551631 -52.215708 \n",
       "L 292.272289 -49.524199 \n",
       "L 288.992947 -48.67193 \n",
       "L 285.713605 -49.610984 \n",
       "L 282.434262 -52.261962 \n",
       "L 279.15494 -56.517485 \n",
       "L 275.875578 -62.247843 \n",
       "L 272.596255 -69.305045 \n",
       "L 269.316913 -77.525542 \n",
       "L 266.037571 -86.736455 \n",
       "L 262.758248 -96.756888 \n",
       "L 259.478887 -107.401489 \n",
       "L 256.199564 -118.479046 \n",
       "L 252.920222 -129.785991 \n",
       "L 249.640879 -141.073194 \n",
       "L 246.361537 -151.90387 \n",
       "L 243.082195 -161.134356 \n",
       "L 239.802872 -167.571588 \n",
       "L 236.523511 -172.525412 \n",
       "L 233.244188 -177.065092 \n",
       "L 229.964846 -181.503661 \n",
       "L 226.685504 -185.952288 \n",
       "L 223.406181 -190.465673 \n",
       "L 220.126829 -195.075792 \n",
       "L 216.847496 -199.800714 \n",
       "L 213.568154 -204.647681 \n",
       "L 210.288812 -209.614035 \n",
       "L 207.00948 -214.687652 \n",
       "L 203.730137 -219.847342 \n",
       "L 200.450795 -225.064017 \n",
       "L 197.171463 -230.301899 \n",
       "L 193.892121 -235.519292 \n",
       "L 190.612778 -240.670542 \n",
       "L 187.333446 -245.70787 \n",
       "L 184.054104 -250.582998 \n",
       "L 180.774762 -255.24842 \n",
       "L 177.495429 -259.660328 \n",
       "L 174.216087 -263.778491 \n",
       "L 170.936745 -267.568728 \n",
       "L 167.657412 -271.00339 \n",
       "L 164.37807 -274.062198 \n",
       "L 161.098728 -276.731481 \n",
       "L 157.819395 -279.003217 \n",
       "L 154.540053 -280.872966 \n",
       "L 151.260711 -282.333458 \n",
       "L 147.981379 -283.375312 \n",
       "L 144.702037 -283.985032 \n",
       "L 141.422694 -284.153566 \n",
       "L 138.143362 -283.879055 \n",
       "L 134.86402 -283.16356 \n",
       "L 131.584682 -282.002054 \n",
       "L 128.305345 -280.383584 \n",
       "L 125.026003 -278.290254 \n",
       "L 121.746666 -275.704923 \n",
       "L 118.467328 -272.619284 \n",
       "L 115.187986 -269.040407 \n",
       "L 111.908649 -264.990358 \n",
       "L 108.629311 -260.512938 \n",
       "L 105.349969 -255.667877 \n",
       "L 102.070632 -250.530987 \n",
       "L 98.791295 -245.191592 \n",
       "L 95.511955 -239.748382 \n",
       "L 92.232615 -234.307764 \n",
       "L 88.953278 -228.981123 \n",
       "L 85.673938 -223.879339 \n",
       "L 82.394598 -219.111395 \n",
       "L 79.115261 -214.777403 \n",
       "L 75.835921 -210.966324 \n",
       "L 72.556583 -207.748757 \n",
       "L 69.277244 -205.160844 \n",
       "L 65.997905 -203.168912 \n",
       "L 62.718566 -201.53824 \n",
       "L 59.439227 -199.4906 \n",
       "z\n",
       "\" style=\"stroke: #ff7f0e; stroke-opacity: 0.5; stroke-width: 0.8\"/>\n",
       "    </defs>\n",
       "    <g clip-path=\"url(#pb9361a8952)\">\n",
       "     <use xlink:href=\"#m59b22bcbb7\" x=\"0\" y=\"322.539375\" style=\"fill: #ff7f0e; fill-opacity: 0.5; stroke: #ff7f0e; stroke-opacity: 0.5; stroke-width: 0.8\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"PolyCollection_3\">\n",
       "    <defs>\n",
       "     <path id=\"mfad0cac2df\" d=\"M 59.439227 -209.497772 \n",
       "L 59.439227 -207.774725 \n",
       "L 62.718566 -211.100684 \n",
       "L 65.997905 -215.768685 \n",
       "L 69.277244 -220.915445 \n",
       "L 72.556583 -226.207115 \n",
       "L 75.835921 -231.497923 \n",
       "L 79.115261 -236.702188 \n",
       "L 82.394598 -241.761559 \n",
       "L 85.673938 -246.631366 \n",
       "L 88.953278 -251.277248 \n",
       "L 92.232615 -255.674703 \n",
       "L 95.511955 -259.806276 \n",
       "L 98.791295 -263.661265 \n",
       "L 102.070632 -267.234009 \n",
       "L 105.349969 -270.522332 \n",
       "L 108.629311 -273.527589 \n",
       "L 111.908649 -276.251848 \n",
       "L 115.187986 -278.695594 \n",
       "L 118.467328 -280.858343 \n",
       "L 121.746666 -282.732832 \n",
       "L 125.026003 -284.310082 \n",
       "L 128.305345 -285.578942 \n",
       "L 131.584682 -286.530619 \n",
       "L 134.86402 -287.165614 \n",
       "L 138.143362 -287.498813 \n",
       "L 141.422694 -287.557697 \n",
       "L 144.702037 -287.380441 \n",
       "L 147.981379 -287.003779 \n",
       "L 151.260711 -286.457957 \n",
       "L 154.540053 -285.7675 \n",
       "L 157.819395 -284.959022 \n",
       "L 161.098728 -284.057518 \n",
       "L 164.37807 -283.086516 \n",
       "L 167.657412 -282.061416 \n",
       "L 170.936745 -280.986083 \n",
       "L 174.216087 -279.852647 \n",
       "L 177.495429 -278.640425 \n",
       "L 180.774762 -277.316782 \n",
       "L 184.054104 -275.83839 \n",
       "L 187.333446 -274.153683 \n",
       "L 190.612778 -272.203674 \n",
       "L 193.892121 -269.925122 \n",
       "L 197.171463 -267.252672 \n",
       "L 200.450795 -264.121204 \n",
       "L 203.730137 -260.468318 \n",
       "L 207.00948 -256.237225 \n",
       "L 210.288812 -251.378532 \n",
       "L 213.568154 -245.852413 \n",
       "L 216.847496 -239.631109 \n",
       "L 220.126829 -232.700862 \n",
       "L 223.406181 -225.063557 \n",
       "L 226.685504 -216.740108 \n",
       "L 229.964846 -207.774626 \n",
       "L 233.244188 -198.246125 \n",
       "L 236.523511 -188.30422 \n",
       "L 239.802872 -178.31626 \n",
       "L 243.082195 -169.425025 \n",
       "L 246.361537 -163.033423 \n",
       "L 249.640879 -158.063886 \n",
       "L 252.920222 -153.511396 \n",
       "L 256.199564 -149.101647 \n",
       "L 259.478887 -144.771248 \n",
       "L 262.758248 -140.524614 \n",
       "L 266.037571 -136.399446 \n",
       "L 269.316913 -132.455848 \n",
       "L 272.596255 -128.772012 \n",
       "L 275.875578 -125.439474 \n",
       "L 279.15494 -122.562979 \n",
       "L 282.434262 -120.253242 \n",
       "L 285.713605 -118.625272 \n",
       "L 288.992947 -117.794328 \n",
       "L 292.272289 -117.868718 \n",
       "L 295.551631 -118.944831 \n",
       "L 298.830954 -121.107313 \n",
       "L 302.110315 -124.414377 \n",
       "L 305.389638 -128.902576 \n",
       "L 308.66898 -134.576502 \n",
       "L 311.948322 -141.409148 \n",
       "L 315.227645 -149.337371 \n",
       "L 318.507007 -158.264672 \n",
       "L 321.78633 -168.057866 \n",
       "L 325.065672 -178.550162 \n",
       "L 328.345014 -189.549092 \n",
       "L 331.624356 -200.833207 \n",
       "L 334.903698 -212.17255 \n",
       "L 338.183021 -223.33018 \n",
       "L 341.462363 -234.080357 \n",
       "L 344.741705 -244.230042 \n",
       "L 348.021048 -253.597895 \n",
       "L 351.30039 -261.959621 \n",
       "L 354.579713 -268.988348 \n",
       "L 357.859055 -274.342292 \n",
       "L 361.138397 -277.776636 \n",
       "L 364.417739 -279.160473 \n",
       "L 367.697081 -278.454162 \n",
       "L 370.976423 -275.7012 \n",
       "L 374.255766 -271.028442 \n",
       "L 377.535088 -264.666119 \n",
       "L 380.814431 -256.969672 \n",
       "L 384.093773 -248.373901 \n",
       "L 384.093773 -250.116543 \n",
       "L 384.093773 -250.116543 \n",
       "L 380.814431 -258.855367 \n",
       "L 377.535088 -266.564931 \n",
       "L 374.255766 -272.876764 \n",
       "L 370.976423 -277.497146 \n",
       "L 367.697081 -280.22439 \n",
       "L 364.417739 -280.941526 \n",
       "L 361.138397 -279.605108 \n",
       "L 357.859055 -276.250362 \n",
       "L 354.579713 -270.98621 \n",
       "L 351.30039 -264.005528 \n",
       "L 348.021048 -255.573568 \n",
       "L 344.741705 -245.992934 \n",
       "L 341.462363 -235.559403 \n",
       "L 338.183021 -224.536797 \n",
       "L 334.903698 -213.154462 \n",
       "L 331.624356 -201.640519 \n",
       "L 328.345014 -190.223226 \n",
       "L 325.065672 -179.122731 \n",
       "L 321.78633 -168.552381 \n",
       "L 318.507007 -158.698707 \n",
       "L 315.227645 -149.724162 \n",
       "L 311.948322 -141.758843 \n",
       "L 308.66898 -134.897051 \n",
       "L 305.389638 -129.200324 \n",
       "L 302.110315 -124.694503 \n",
       "L 298.830954 -121.374183 \n",
       "L 295.551631 -119.202236 \n",
       "L 292.272289 -118.120084 \n",
       "L 288.992947 -118.042882 \n",
       "L 285.713605 -118.874222 \n",
       "L 282.434262 -120.505905 \n",
       "L 279.15494 -122.823028 \n",
       "L 275.875578 -125.711165 \n",
       "L 272.596255 -129.060573 \n",
       "L 269.316913 -132.767972 \n",
       "L 266.037571 -136.744251 \n",
       "L 262.758248 -140.915088 \n",
       "L 259.478887 -145.227093 \n",
       "L 256.199564 -149.654731 \n",
       "L 252.920222 -154.217172 \n",
       "L 249.640879 -159.024424 \n",
       "L 246.361537 -164.411957 \n",
       "L 243.082195 -171.147106 \n",
       "L 239.802872 -179.733979 \n",
       "L 236.523511 -189.330278 \n",
       "L 233.244188 -199.031102 \n",
       "L 229.964846 -208.415348 \n",
       "L 226.685504 -217.290327 \n",
       "L 223.406181 -225.554954 \n",
       "L 220.126829 -233.153693 \n",
       "L 216.847496 -240.059407 \n",
       "L 213.568154 -246.266714 \n",
       "L 210.288812 -251.787388 \n",
       "L 207.00948 -256.648156 \n",
       "L 203.730137 -260.888453 \n",
       "L 200.450795 -264.557801 \n",
       "L 197.171463 -267.713568 \n",
       "L 193.892121 -270.419187 \n",
       "L 190.612778 -272.741323 \n",
       "L 187.333446 -274.747453 \n",
       "L 184.054104 -276.503607 \n",
       "L 180.774762 -278.072256 \n",
       "L 177.495429 -279.509133 \n",
       "L 174.216087 -280.861974 \n",
       "L 170.936745 -282.16722 \n",
       "L 167.657412 -283.447083 \n",
       "L 164.37807 -284.706436 \n",
       "L 161.098728 -285.931694 \n",
       "L 157.819395 -287.090984 \n",
       "L 154.540053 -288.140185 \n",
       "L 151.260711 -289.032052 \n",
       "L 147.981379 -289.72102 \n",
       "L 144.702037 -290.168828 \n",
       "L 141.422694 -290.343375 \n",
       "L 138.143362 -290.218667 \n",
       "L 134.86402 -289.774026 \n",
       "L 131.584682 -288.996008 \n",
       "L 128.305345 -287.879298 \n",
       "L 125.026003 -286.428755 \n",
       "L 121.746666 -284.65861 \n",
       "L 118.467328 -282.58803 \n",
       "L 115.187986 -280.235769 \n",
       "L 111.908649 -277.617395 \n",
       "L 108.629311 -274.739597 \n",
       "L 105.349969 -271.604306 \n",
       "L 102.070632 -268.209371 \n",
       "L 98.791295 -264.551893 \n",
       "L 95.511955 -260.631941 \n",
       "L 92.232615 -256.453315 \n",
       "L 88.953278 -252.025493 \n",
       "L 85.673938 -247.365536 \n",
       "L 82.394598 -242.498828 \n",
       "L 79.115261 -237.462291 \n",
       "L 75.835921 -232.305938 \n",
       "L 72.556583 -227.098237 \n",
       "L 69.277244 -221.942899 \n",
       "L 65.997905 -217.014087 \n",
       "L 62.718566 -212.652145 \n",
       "L 59.439227 -209.497772 \n",
       "z\n",
       "\" style=\"stroke: #ff7f0e; stroke-opacity: 0.5; stroke-width: 0.8\"/>\n",
       "    </defs>\n",
       "    <g clip-path=\"url(#pb9361a8952)\">\n",
       "     <use xlink:href=\"#mfad0cac2df\" x=\"0\" y=\"322.539375\" style=\"fill: #ff7f0e; fill-opacity: 0.5; stroke: #ff7f0e; stroke-opacity: 0.5; stroke-width: 0.8\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"line2d_14\">\n",
       "    <defs>\n",
       "     <path id=\"md413cddbcb\" d=\"M -5 5 \n",
       "L 5 -5 \n",
       "M -5 -5 \n",
       "L 5 5 \n",
       "\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "    </defs>\n",
       "    <g clip-path=\"url(#pb9361a8952)\">\n",
       "     <use xlink:href=\"#md413cddbcb\" x=\"361.243318\" y=\"41.717399\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     <use xlink:href=\"#md413cddbcb\" x=\"162.151989\" y=\"42.573001\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     <use xlink:href=\"#md413cddbcb\" x=\"119.149308\" y=\"44.865305\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     <use xlink:href=\"#md413cddbcb\" x=\"243.082195\" y=\"157.39902\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     <use xlink:href=\"#md413cddbcb\" x=\"147.981379\" y=\"37.207297\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     <use xlink:href=\"#md413cddbcb\" x=\"384.093773\" y=\"81.337167\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     <use xlink:href=\"#md413cddbcb\" x=\"344.741705\" y=\"86.583014\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     <use xlink:href=\"#md413cddbcb\" x=\"59.439227\" y=\"119.209921\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     <use xlink:href=\"#md413cddbcb\" x=\"141.422694\" y=\"36.787756\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     <use xlink:href=\"#md413cddbcb\" x=\"141.422694\" y=\"36.787756\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     <use xlink:href=\"#md413cddbcb\" x=\"141.422694\" y=\"36.787756\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     <use xlink:href=\"#md413cddbcb\" x=\"141.422694\" y=\"36.787756\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     <use xlink:href=\"#md413cddbcb\" x=\"141.422694\" y=\"36.787756\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"line2d_15\">\n",
       "    <path d=\"M 59.439227 118.906712 \n",
       "L 62.718566 116.219915 \n",
       "L 65.997905 113.070576 \n",
       "L 69.277244 109.50123 \n",
       "L 72.556583 105.561439 \n",
       "L 75.835921 101.307252 \n",
       "L 79.115261 96.79958 \n",
       "L 82.394598 92.102898 \n",
       "L 85.673938 87.284022 \n",
       "L 88.953278 82.410191 \n",
       "L 92.232615 77.548141 \n",
       "L 95.511955 72.762046 \n",
       "L 98.791295 68.112947 \n",
       "L 102.070632 63.656877 \n",
       "L 105.349969 59.44427 \n",
       "L 108.629311 55.519111 \n",
       "L 111.908649 51.918272 \n",
       "L 115.187986 48.671375 \n",
       "L 118.467328 45.800562 \n",
       "L 121.746666 43.320498 \n",
       "L 125.026003 41.239207 \n",
       "L 128.305345 39.558113 \n",
       "L 131.584682 38.273039 \n",
       "L 134.86402 37.374788 \n",
       "L 138.143362 36.850441 \n",
       "L 141.422694 36.683744 \n",
       "L 144.702037 36.856639 \n",
       "L 147.981379 37.34983 \n",
       "L 151.260711 38.143668 \n",
       "L 154.540053 39.219142 \n",
       "L 157.819395 40.558256 \n",
       "L 161.098728 42.144875 \n",
       "L 164.37807 43.965018 \n",
       "L 167.657412 46.006972 \n",
       "L 170.936745 48.261969 \n",
       "L 174.216087 50.723806 \n",
       "L 177.495429 53.388998 \n",
       "L 180.774762 56.256773 \n",
       "L 184.054104 59.32868 \n",
       "L 187.333446 62.608599 \n",
       "L 190.612778 66.102267 \n",
       "L 193.892121 69.817168 \n",
       "L 197.171463 73.76209 \n",
       "L 200.450795 77.946763 \n",
       "L 203.730137 82.381545 \n",
       "L 207.00948 87.076935 \n",
       "L 210.288812 92.043091 \n",
       "L 213.568154 97.289328 \n",
       "L 216.847496 102.823463 \n",
       "L 220.126829 108.65105 \n",
       "L 223.406181 114.774758 \n",
       "L 226.685504 121.193179 \n",
       "L 229.964846 127.900231 \n",
       "L 233.244188 134.883767 \n",
       "L 236.523511 142.124559 \n",
       "L 239.802872 149.595451 \n",
       "L 243.082195 157.259685 \n",
       "L 246.361537 165.070729 \n",
       "L 249.640879 172.970835 \n",
       "L 252.920222 180.890682 \n",
       "L 256.199564 188.749029 \n",
       "L 259.478887 196.453012 \n",
       "L 262.758248 203.898619 \n",
       "L 266.037571 210.971424 \n",
       "L 269.316913 217.548685 \n",
       "L 272.596255 223.500846 \n",
       "L 275.875578 228.695722 \n",
       "L 279.15494 232.999143 \n",
       "L 282.434262 236.281773 \n",
       "L 285.713605 238.421247 \n",
       "L 288.992947 239.306246 \n",
       "L 292.272289 238.842917 \n",
       "L 295.551631 236.959106 \n",
       "L 298.830954 233.604441 \n",
       "L 302.110315 228.761815 \n",
       "L 305.389638 222.443505 \n",
       "L 308.66898 214.697822 \n",
       "L 311.948322 205.60888 \n",
       "L 315.227645 195.298093 \n",
       "L 318.507007 183.921095 \n",
       "L 321.78633 171.668285 \n",
       "L 325.065672 158.760318 \n",
       "L 328.345014 145.442088 \n",
       "L 331.624356 131.981611 \n",
       "L 334.903698 118.656093 \n",
       "L 338.183021 105.750978 \n",
       "L 341.462363 93.54854 \n",
       "L 344.741705 82.318382 \n",
       "L 348.021048 72.317432 \n",
       "L 351.30039 63.770784 \n",
       "L 354.579713 56.86741 \n",
       "L 357.859055 51.761439 \n",
       "L 361.138397 48.563594 \n",
       "L 364.417739 47.328999 \n",
       "L 367.697081 48.070326 \n",
       "L 370.976423 50.740688 \n",
       "L 374.255766 55.251222 \n",
       "L 377.535088 61.464273 \n",
       "L 380.814431 69.198868 \n",
       "L 384.093773 78.241477 \n",
       "\" clip-path=\"url(#pb9361a8952)\" style=\"fill: none; stroke: #1f77b4; stroke-width: 2; stroke-linecap: round\"/>\n",
       "   </g>\n",
       "   <g id=\"line2d_16\">\n",
       "    <path d=\"M 59.439227 119.209921 \n",
       "L 62.718566 114.143214 \n",
       "L 65.997905 109.095307 \n",
       "L 69.277244 104.084922 \n",
       "L 72.556583 99.130711 \n",
       "L 75.835921 94.251118 \n",
       "L 79.115261 89.464409 \n",
       "L 82.394598 84.788527 \n",
       "L 85.673938 80.241061 \n",
       "L 88.953278 75.839212 \n",
       "L 92.232615 71.599682 \n",
       "L 95.511955 67.538653 \n",
       "L 98.791295 63.671717 \n",
       "L 102.070632 60.013829 \n",
       "L 105.349969 56.579235 \n",
       "L 108.629311 53.381469 \n",
       "L 111.908649 50.433257 \n",
       "L 115.187986 47.7465 \n",
       "L 118.467328 45.332211 \n",
       "L 121.746666 43.200509 \n",
       "L 125.026003 41.360566 \n",
       "L 128.305345 39.82056 \n",
       "L 131.584682 38.587667 \n",
       "L 134.86402 37.668032 \n",
       "L 138.143362 37.066728 \n",
       "L 141.422694 36.787756 \n",
       "L 144.702037 36.834019 \n",
       "L 147.981379 37.207297 \n",
       "L 151.260711 37.908246 \n",
       "L 154.540053 38.936397 \n",
       "L 157.819395 40.290126 \n",
       "L 161.098728 41.966652 \n",
       "L 164.37807 43.962073 \n",
       "L 167.657412 46.271295 \n",
       "L 170.936745 48.888108 \n",
       "L 174.216087 51.805134 \n",
       "L 177.495429 55.013854 \n",
       "L 180.774762 58.504612 \n",
       "L 184.054104 62.266601 \n",
       "L 187.333446 66.28793 \n",
       "L 190.612778 70.555523 \n",
       "L 193.892121 75.055245 \n",
       "L 197.171463 79.771801 \n",
       "L 200.450795 84.688857 \n",
       "L 203.730137 89.788928 \n",
       "L 207.00948 95.053426 \n",
       "L 210.288812 100.462685 \n",
       "L 213.568154 105.995959 \n",
       "L 216.847496 111.631354 \n",
       "L 220.126829 117.345915 \n",
       "L 223.406181 123.115571 \n",
       "L 226.685504 128.915082 \n",
       "L 229.964846 134.718156 \n",
       "L 233.244188 140.497341 \n",
       "L 236.523511 146.223897 \n",
       "L 239.802872 151.868172 \n",
       "L 243.082195 157.39902 \n",
       "L 246.361537 162.784356 \n",
       "L 249.640879 167.990735 \n",
       "L 252.920222 172.983547 \n",
       "L 256.199564 177.727022 \n",
       "L 259.478887 182.184104 \n",
       "L 262.758248 186.316677 \n",
       "L 266.037571 190.085447 \n",
       "L 269.316913 193.450141 \n",
       "L 272.596255 196.369533 \n",
       "L 275.875578 198.801707 \n",
       "L 279.15494 200.70413 \n",
       "L 282.434262 202.034034 \n",
       "L 285.713605 202.74872 \n",
       "L 288.992947 202.806013 \n",
       "L 292.272289 202.164816 \n",
       "L 295.551631 200.785856 \n",
       "L 298.830954 198.632492 \n",
       "L 302.110315 195.671668 \n",
       "L 305.389638 191.875533 \n",
       "L 308.66898 187.222338 \n",
       "L 311.948322 181.698717 \n",
       "L 315.227645 175.30162 \n",
       "L 318.507007 168.040414 \n",
       "L 321.78633 159.940056 \n",
       "L 325.065672 151.043762 \n",
       "L 328.345014 141.416526 \n",
       "L 331.624356 131.148805 \n",
       "L 334.903698 120.360216 \n",
       "L 338.183021 109.203432 \n",
       "L 341.462363 97.86794 \n",
       "L 344.741705 86.583014 \n",
       "L 348.021048 75.620205 \n",
       "L 351.30039 65.294282 \n",
       "L 354.579713 55.961571 \n",
       "L 357.859055 48.015578 \n",
       "L 361.138397 41.878985 \n",
       "L 364.417739 37.989205 \n",
       "L 367.697081 36.778335 \n",
       "L 370.976423 38.644757 \n",
       "L 374.255766 43.915952 \n",
       "L 377.535088 52.802188 \n",
       "L 380.814431 65.341293 \n",
       "L 384.093773 81.337167 \n",
       "\" clip-path=\"url(#pb9361a8952)\" style=\"fill: none; stroke-dasharray: 7.68,1.92,1.2,1.92; stroke-dashoffset: 0; stroke: #bf00bf; stroke-width: 1.2\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_3\">\n",
       "    <path d=\"M 43.2065 285.913638 \n",
       "L 43.2065 36.766826 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_4\">\n",
       "    <path d=\"M 59.439227 286.212 \n",
       "L 384.093773 286.212 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"text_16\">\n",
       "    <!-- N=9, psi=0.10 -->\n",
       "    <g style=\"fill: #262626\" transform=\"translate(191.87975 14.1) scale(0.096 -0.096)\">\n",
       "     <defs>\n",
       "      <path id=\"ArialMT-4e\" d=\"M 488 0 \n",
       "L 488 4581 \n",
       "L 1109 4581 \n",
       "L 3516 984 \n",
       "L 3516 4581 \n",
       "L 4097 4581 \n",
       "L 4097 0 \n",
       "L 3475 0 \n",
       "L 1069 3600 \n",
       "L 1069 0 \n",
       "L 488 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-3d\" d=\"M 3381 2694 \n",
       "L 356 2694 \n",
       "L 356 3219 \n",
       "L 3381 3219 \n",
       "L 3381 2694 \n",
       "z\n",
       "M 3381 1303 \n",
       "L 356 1303 \n",
       "L 356 1828 \n",
       "L 3381 1828 \n",
       "L 3381 1303 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-39\" d=\"M 350 1059 \n",
       "L 891 1109 \n",
       "Q 959 728 1153 556 \n",
       "Q 1347 384 1650 384 \n",
       "Q 1909 384 2104 503 \n",
       "Q 2300 622 2425 820 \n",
       "Q 2550 1019 2634 1356 \n",
       "Q 2719 1694 2719 2044 \n",
       "Q 2719 2081 2716 2156 \n",
       "Q 2547 1888 2255 1720 \n",
       "Q 1963 1553 1622 1553 \n",
       "Q 1053 1553 659 1965 \n",
       "Q 266 2378 266 3053 \n",
       "Q 266 3750 677 4175 \n",
       "Q 1088 4600 1706 4600 \n",
       "Q 2153 4600 2523 4359 \n",
       "Q 2894 4119 3086 3673 \n",
       "Q 3278 3228 3278 2384 \n",
       "Q 3278 1506 3087 986 \n",
       "Q 2897 466 2520 194 \n",
       "Q 2144 -78 1638 -78 \n",
       "Q 1100 -78 759 220 \n",
       "Q 419 519 350 1059 \n",
       "z\n",
       "M 2653 3081 \n",
       "Q 2653 3566 2395 3850 \n",
       "Q 2138 4134 1775 4134 \n",
       "Q 1400 4134 1122 3828 \n",
       "Q 844 3522 844 3034 \n",
       "Q 844 2597 1108 2323 \n",
       "Q 1372 2050 1759 2050 \n",
       "Q 2150 2050 2401 2323 \n",
       "Q 2653 2597 2653 3081 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-2c\" d=\"M 569 0 \n",
       "L 569 641 \n",
       "L 1209 641 \n",
       "L 1209 0 \n",
       "Q 1209 -353 1084 -570 \n",
       "Q 959 -788 688 -906 \n",
       "L 531 -666 \n",
       "Q 709 -588 793 -436 \n",
       "Q 878 -284 888 0 \n",
       "L 569 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-20\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-70\" d=\"M 422 -1272 \n",
       "L 422 3319 \n",
       "L 934 3319 \n",
       "L 934 2888 \n",
       "Q 1116 3141 1344 3267 \n",
       "Q 1572 3394 1897 3394 \n",
       "Q 2322 3394 2647 3175 \n",
       "Q 2972 2956 3137 2557 \n",
       "Q 3303 2159 3303 1684 \n",
       "Q 3303 1175 3120 767 \n",
       "Q 2938 359 2589 142 \n",
       "Q 2241 -75 1856 -75 \n",
       "Q 1575 -75 1351 44 \n",
       "Q 1128 163 984 344 \n",
       "L 984 -1272 \n",
       "L 422 -1272 \n",
       "z\n",
       "M 931 1641 \n",
       "Q 931 1000 1190 694 \n",
       "Q 1450 388 1819 388 \n",
       "Q 2194 388 2461 705 \n",
       "Q 2728 1022 2728 1688 \n",
       "Q 2728 2322 2467 2637 \n",
       "Q 2206 2953 1844 2953 \n",
       "Q 1484 2953 1207 2617 \n",
       "Q 931 2281 931 1641 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-73\" d=\"M 197 991 \n",
       "L 753 1078 \n",
       "Q 800 744 1014 566 \n",
       "Q 1228 388 1613 388 \n",
       "Q 2000 388 2187 545 \n",
       "Q 2375 703 2375 916 \n",
       "Q 2375 1106 2209 1216 \n",
       "Q 2094 1291 1634 1406 \n",
       "Q 1016 1563 777 1677 \n",
       "Q 538 1791 414 1992 \n",
       "Q 291 2194 291 2438 \n",
       "Q 291 2659 392 2848 \n",
       "Q 494 3038 669 3163 \n",
       "Q 800 3259 1026 3326 \n",
       "Q 1253 3394 1513 3394 \n",
       "Q 1903 3394 2198 3281 \n",
       "Q 2494 3169 2634 2976 \n",
       "Q 2775 2784 2828 2463 \n",
       "L 2278 2388 \n",
       "Q 2241 2644 2061 2787 \n",
       "Q 1881 2931 1553 2931 \n",
       "Q 1166 2931 1000 2803 \n",
       "Q 834 2675 834 2503 \n",
       "Q 834 2394 903 2306 \n",
       "Q 972 2216 1119 2156 \n",
       "Q 1203 2125 1616 2013 \n",
       "Q 2213 1853 2448 1751 \n",
       "Q 2684 1650 2818 1456 \n",
       "Q 2953 1263 2953 975 \n",
       "Q 2953 694 2789 445 \n",
       "Q 2625 197 2315 61 \n",
       "Q 2006 -75 1616 -75 \n",
       "Q 969 -75 630 194 \n",
       "Q 291 463 197 991 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-69\" d=\"M 425 3934 \n",
       "L 425 4581 \n",
       "L 988 4581 \n",
       "L 988 3934 \n",
       "L 425 3934 \n",
       "z\n",
       "M 425 0 \n",
       "L 425 3319 \n",
       "L 988 3319 \n",
       "L 988 0 \n",
       "L 425 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "     </defs>\n",
       "     <use xlink:href=\"#ArialMT-4e\"/>\n",
       "     <use xlink:href=\"#ArialMT-3d\" x=\"72.216797\"/>\n",
       "     <use xlink:href=\"#ArialMT-39\" x=\"130.615234\"/>\n",
       "     <use xlink:href=\"#ArialMT-2c\" x=\"186.230469\"/>\n",
       "     <use xlink:href=\"#ArialMT-20\" x=\"214.013672\"/>\n",
       "     <use xlink:href=\"#ArialMT-70\" x=\"241.796875\"/>\n",
       "     <use xlink:href=\"#ArialMT-73\" x=\"297.412109\"/>\n",
       "     <use xlink:href=\"#ArialMT-69\" x=\"347.412109\"/>\n",
       "     <use xlink:href=\"#ArialMT-3d\" x=\"369.628906\"/>\n",
       "     <use xlink:href=\"#ArialMT-30\" x=\"428.027344\"/>\n",
       "     <use xlink:href=\"#ArialMT-2e\" x=\"483.642578\"/>\n",
       "     <use xlink:href=\"#ArialMT-31\" x=\"511.425781\"/>\n",
       "     <use xlink:href=\"#ArialMT-30\" x=\"567.041016\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"legend_1\">\n",
       "    <g id=\"line2d_17\">\n",
       "     <g>\n",
       "      <use xlink:href=\"#md413cddbcb\" x=\"59.9265\" y=\"220.007125\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"text_17\">\n",
       "     <!-- Observations -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(75.7665 223.087125) scale(0.088 -0.088)\">\n",
       "      <defs>\n",
       "       <path id=\"ArialMT-4f\" d=\"M 309 2231 \n",
       "Q 309 3372 921 4017 \n",
       "Q 1534 4663 2503 4663 \n",
       "Q 3138 4663 3647 4359 \n",
       "Q 4156 4056 4423 3514 \n",
       "Q 4691 2972 4691 2284 \n",
       "Q 4691 1588 4409 1038 \n",
       "Q 4128 488 3612 205 \n",
       "Q 3097 -78 2500 -78 \n",
       "Q 1853 -78 1343 234 \n",
       "Q 834 547 571 1087 \n",
       "Q 309 1628 309 2231 \n",
       "z\n",
       "M 934 2222 \n",
       "Q 934 1394 1379 917 \n",
       "Q 1825 441 2497 441 \n",
       "Q 3181 441 3623 922 \n",
       "Q 4066 1403 4066 2288 \n",
       "Q 4066 2847 3877 3264 \n",
       "Q 3688 3681 3323 3911 \n",
       "Q 2959 4141 2506 4141 \n",
       "Q 1863 4141 1398 3698 \n",
       "Q 934 3256 934 2222 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-62\" d=\"M 941 0 \n",
       "L 419 0 \n",
       "L 419 4581 \n",
       "L 981 4581 \n",
       "L 981 2947 \n",
       "Q 1338 3394 1891 3394 \n",
       "Q 2197 3394 2470 3270 \n",
       "Q 2744 3147 2920 2923 \n",
       "Q 3097 2700 3197 2384 \n",
       "Q 3297 2069 3297 1709 \n",
       "Q 3297 856 2875 390 \n",
       "Q 2453 -75 1863 -75 \n",
       "Q 1275 -75 941 416 \n",
       "L 941 0 \n",
       "z\n",
       "M 934 1684 \n",
       "Q 934 1088 1097 822 \n",
       "Q 1363 388 1816 388 \n",
       "Q 2184 388 2453 708 \n",
       "Q 2722 1028 2722 1663 \n",
       "Q 2722 2313 2464 2622 \n",
       "Q 2206 2931 1841 2931 \n",
       "Q 1472 2931 1203 2611 \n",
       "Q 934 2291 934 1684 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-65\" d=\"M 2694 1069 \n",
       "L 3275 997 \n",
       "Q 3138 488 2766 206 \n",
       "Q 2394 -75 1816 -75 \n",
       "Q 1088 -75 661 373 \n",
       "Q 234 822 234 1631 \n",
       "Q 234 2469 665 2931 \n",
       "Q 1097 3394 1784 3394 \n",
       "Q 2450 3394 2872 2941 \n",
       "Q 3294 2488 3294 1666 \n",
       "Q 3294 1616 3291 1516 \n",
       "L 816 1516 \n",
       "Q 847 969 1125 678 \n",
       "Q 1403 388 1819 388 \n",
       "Q 2128 388 2347 550 \n",
       "Q 2566 713 2694 1069 \n",
       "z\n",
       "M 847 1978 \n",
       "L 2700 1978 \n",
       "Q 2663 2397 2488 2606 \n",
       "Q 2219 2931 1791 2931 \n",
       "Q 1403 2931 1139 2672 \n",
       "Q 875 2413 847 1978 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-72\" d=\"M 416 0 \n",
       "L 416 3319 \n",
       "L 922 3319 \n",
       "L 922 2816 \n",
       "Q 1116 3169 1280 3281 \n",
       "Q 1444 3394 1641 3394 \n",
       "Q 1925 3394 2219 3213 \n",
       "L 2025 2691 \n",
       "Q 1819 2813 1613 2813 \n",
       "Q 1428 2813 1281 2702 \n",
       "Q 1134 2591 1072 2394 \n",
       "Q 978 2094 978 1738 \n",
       "L 978 0 \n",
       "L 416 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-76\" d=\"M 1344 0 \n",
       "L 81 3319 \n",
       "L 675 3319 \n",
       "L 1388 1331 \n",
       "Q 1503 1009 1600 663 \n",
       "Q 1675 925 1809 1294 \n",
       "L 2547 3319 \n",
       "L 3125 3319 \n",
       "L 1869 0 \n",
       "L 1344 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-61\" d=\"M 2588 409 \n",
       "Q 2275 144 1986 34 \n",
       "Q 1697 -75 1366 -75 \n",
       "Q 819 -75 525 192 \n",
       "Q 231 459 231 875 \n",
       "Q 231 1119 342 1320 \n",
       "Q 453 1522 633 1644 \n",
       "Q 813 1766 1038 1828 \n",
       "Q 1203 1872 1538 1913 \n",
       "Q 2219 1994 2541 2106 \n",
       "Q 2544 2222 2544 2253 \n",
       "Q 2544 2597 2384 2738 \n",
       "Q 2169 2928 1744 2928 \n",
       "Q 1347 2928 1158 2789 \n",
       "Q 969 2650 878 2297 \n",
       "L 328 2372 \n",
       "Q 403 2725 575 2942 \n",
       "Q 747 3159 1072 3276 \n",
       "Q 1397 3394 1825 3394 \n",
       "Q 2250 3394 2515 3294 \n",
       "Q 2781 3194 2906 3042 \n",
       "Q 3031 2891 3081 2659 \n",
       "Q 3109 2516 3109 2141 \n",
       "L 3109 1391 \n",
       "Q 3109 606 3145 398 \n",
       "Q 3181 191 3288 0 \n",
       "L 2700 0 \n",
       "Q 2613 175 2588 409 \n",
       "z\n",
       "M 2541 1666 \n",
       "Q 2234 1541 1622 1453 \n",
       "Q 1275 1403 1131 1340 \n",
       "Q 988 1278 909 1158 \n",
       "Q 831 1038 831 891 \n",
       "Q 831 666 1001 516 \n",
       "Q 1172 366 1500 366 \n",
       "Q 1825 366 2078 508 \n",
       "Q 2331 650 2450 897 \n",
       "Q 2541 1088 2541 1459 \n",
       "L 2541 1666 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-74\" d=\"M 1650 503 \n",
       "L 1731 6 \n",
       "Q 1494 -44 1306 -44 \n",
       "Q 1000 -44 831 53 \n",
       "Q 663 150 594 308 \n",
       "Q 525 466 525 972 \n",
       "L 525 2881 \n",
       "L 113 2881 \n",
       "L 113 3319 \n",
       "L 525 3319 \n",
       "L 525 4141 \n",
       "L 1084 4478 \n",
       "L 1084 3319 \n",
       "L 1650 3319 \n",
       "L 1650 2881 \n",
       "L 1084 2881 \n",
       "L 1084 941 \n",
       "Q 1084 700 1114 631 \n",
       "Q 1144 563 1211 522 \n",
       "Q 1278 481 1403 481 \n",
       "Q 1497 481 1650 503 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-6f\" d=\"M 213 1659 \n",
       "Q 213 2581 725 3025 \n",
       "Q 1153 3394 1769 3394 \n",
       "Q 2453 3394 2887 2945 \n",
       "Q 3322 2497 3322 1706 \n",
       "Q 3322 1066 3130 698 \n",
       "Q 2938 331 2570 128 \n",
       "Q 2203 -75 1769 -75 \n",
       "Q 1072 -75 642 372 \n",
       "Q 213 819 213 1659 \n",
       "z\n",
       "M 791 1659 \n",
       "Q 791 1022 1069 705 \n",
       "Q 1347 388 1769 388 \n",
       "Q 2188 388 2466 706 \n",
       "Q 2744 1025 2744 1678 \n",
       "Q 2744 2294 2464 2611 \n",
       "Q 2184 2928 1769 2928 \n",
       "Q 1347 2928 1069 2612 \n",
       "Q 791 2297 791 1659 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-6e\" d=\"M 422 0 \n",
       "L 422 3319 \n",
       "L 928 3319 \n",
       "L 928 2847 \n",
       "Q 1294 3394 1984 3394 \n",
       "Q 2284 3394 2536 3286 \n",
       "Q 2788 3178 2913 3003 \n",
       "Q 3038 2828 3088 2588 \n",
       "Q 3119 2431 3119 2041 \n",
       "L 3119 0 \n",
       "L 2556 0 \n",
       "L 2556 2019 \n",
       "Q 2556 2363 2490 2533 \n",
       "Q 2425 2703 2258 2804 \n",
       "Q 2091 2906 1866 2906 \n",
       "Q 1506 2906 1245 2678 \n",
       "Q 984 2450 984 1813 \n",
       "L 984 0 \n",
       "L 422 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#ArialMT-4f\"/>\n",
       "      <use xlink:href=\"#ArialMT-62\" x=\"77.783203\"/>\n",
       "      <use xlink:href=\"#ArialMT-73\" x=\"133.398438\"/>\n",
       "      <use xlink:href=\"#ArialMT-65\" x=\"183.398438\"/>\n",
       "      <use xlink:href=\"#ArialMT-72\" x=\"239.013672\"/>\n",
       "      <use xlink:href=\"#ArialMT-76\" x=\"272.314453\"/>\n",
       "      <use xlink:href=\"#ArialMT-61\" x=\"322.314453\"/>\n",
       "      <use xlink:href=\"#ArialMT-74\" x=\"377.929688\"/>\n",
       "      <use xlink:href=\"#ArialMT-69\" x=\"405.712891\"/>\n",
       "      <use xlink:href=\"#ArialMT-6f\" x=\"427.929688\"/>\n",
       "      <use xlink:href=\"#ArialMT-6e\" x=\"483.544922\"/>\n",
       "      <use xlink:href=\"#ArialMT-73\" x=\"539.160156\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"line2d_18\">\n",
       "     <path d=\"M 51.1265 232.591125 \n",
       "L 59.9265 232.591125 \n",
       "L 68.7265 232.591125 \n",
       "\" style=\"fill: none; stroke: #1f77b4; stroke-width: 2; stroke-linecap: round\"/>\n",
       "    </g>\n",
       "    <g id=\"text_18\">\n",
       "     <!-- $m_n(x)$ -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(75.7665 235.671125) scale(0.088 -0.088)\">\n",
       "      <defs>\n",
       "       <path id=\"DejaVuSans-Oblique-6d\" d=\"M 5747 2113 \n",
       "L 5338 0 \n",
       "L 4763 0 \n",
       "L 5166 2094 \n",
       "Q 5191 2228 5203 2325 \n",
       "Q 5216 2422 5216 2491 \n",
       "Q 5216 2772 5059 2928 \n",
       "Q 4903 3084 4622 3084 \n",
       "Q 4203 3084 3875 2770 \n",
       "Q 3547 2456 3450 1953 \n",
       "L 3066 0 \n",
       "L 2491 0 \n",
       "L 2900 2094 \n",
       "Q 2925 2209 2937 2307 \n",
       "Q 2950 2406 2950 2484 \n",
       "Q 2950 2769 2794 2926 \n",
       "Q 2638 3084 2363 3084 \n",
       "Q 1938 3084 1609 2770 \n",
       "Q 1281 2456 1184 1953 \n",
       "L 800 0 \n",
       "L 225 0 \n",
       "L 909 3500 \n",
       "L 1484 3500 \n",
       "L 1375 2956 \n",
       "Q 1609 3263 1923 3423 \n",
       "Q 2238 3584 2597 3584 \n",
       "Q 2978 3584 3223 3384 \n",
       "Q 3469 3184 3519 2828 \n",
       "Q 3781 3197 4126 3390 \n",
       "Q 4472 3584 4856 3584 \n",
       "Q 5306 3584 5551 3325 \n",
       "Q 5797 3066 5797 2591 \n",
       "Q 5797 2488 5784 2364 \n",
       "Q 5772 2241 5747 2113 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-Oblique-6e\" d=\"M 3566 2113 \n",
       "L 3156 0 \n",
       "L 2578 0 \n",
       "L 2988 2091 \n",
       "Q 3016 2238 3031 2350 \n",
       "Q 3047 2463 3047 2528 \n",
       "Q 3047 2791 2881 2937 \n",
       "Q 2716 3084 2419 3084 \n",
       "Q 1956 3084 1622 2776 \n",
       "Q 1288 2469 1184 1941 \n",
       "L 800 0 \n",
       "L 225 0 \n",
       "L 903 3500 \n",
       "L 1478 3500 \n",
       "L 1363 2950 \n",
       "Q 1603 3253 1940 3418 \n",
       "Q 2278 3584 2650 3584 \n",
       "Q 3113 3584 3367 3334 \n",
       "Q 3622 3084 3622 2631 \n",
       "Q 3622 2519 3608 2391 \n",
       "Q 3594 2263 3566 2113 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-28\" d=\"M 1984 4856 \n",
       "Q 1566 4138 1362 3434 \n",
       "Q 1159 2731 1159 2009 \n",
       "Q 1159 1288 1364 580 \n",
       "Q 1569 -128 1984 -844 \n",
       "L 1484 -844 \n",
       "Q 1016 -109 783 600 \n",
       "Q 550 1309 550 2009 \n",
       "Q 550 2706 781 3412 \n",
       "Q 1013 4119 1484 4856 \n",
       "L 1984 4856 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-29\" d=\"M 513 4856 \n",
       "L 1013 4856 \n",
       "Q 1481 4119 1714 3412 \n",
       "Q 1947 2706 1947 2009 \n",
       "Q 1947 1309 1714 600 \n",
       "Q 1481 -109 1013 -844 \n",
       "L 513 -844 \n",
       "Q 928 -128 1133 580 \n",
       "Q 1338 1288 1338 2009 \n",
       "Q 1338 2731 1133 3434 \n",
       "Q 928 4138 513 4856 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-6d\" transform=\"translate(0 0.125)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-6e\" transform=\"translate(97.412109 -16.28125) scale(0.7)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-28\" transform=\"translate(144.511719 0.125)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-78\" transform=\"translate(183.525391 0.125)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-29\" transform=\"translate(242.705078 0.125)\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"patch_5\">\n",
       "     <path d=\"M 51.1265 249.828125 \n",
       "L 68.7265 249.828125 \n",
       "L 68.7265 243.668125 \n",
       "L 51.1265 243.668125 \n",
       "z\n",
       "\" style=\"fill: #1f77b4; fill-opacity: 0.5; stroke: #1f77b4; stroke-opacity: 0.5; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "    </g>\n",
       "    <g id=\"text_19\">\n",
       "     <!-- $f(\\mathbf{x}^*)$ 95% pred. -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(75.7665 249.828125) scale(0.088 -0.088)\">\n",
       "      <defs>\n",
       "       <path id=\"DejaVuSans-Oblique-66\" d=\"M 3059 4863 \n",
       "L 2969 4384 \n",
       "L 2419 4384 \n",
       "Q 2106 4384 1964 4261 \n",
       "Q 1822 4138 1753 3809 \n",
       "L 1691 3500 \n",
       "L 2638 3500 \n",
       "L 2553 3053 \n",
       "L 1606 3053 \n",
       "L 1013 0 \n",
       "L 434 0 \n",
       "L 1031 3053 \n",
       "L 481 3053 \n",
       "L 563 3500 \n",
       "L 1113 3500 \n",
       "L 1159 3744 \n",
       "Q 1278 4363 1576 4613 \n",
       "Q 1875 4863 2516 4863 \n",
       "L 3059 4863 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-Bold-78\" d=\"M 1422 1791 \n",
       "L 159 3500 \n",
       "L 1344 3500 \n",
       "L 2059 2463 \n",
       "L 2784 3500 \n",
       "L 3969 3500 \n",
       "L 2706 1797 \n",
       "L 4031 0 \n",
       "L 2847 0 \n",
       "L 2059 1106 \n",
       "L 1281 0 \n",
       "L 97 0 \n",
       "L 1422 1791 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-2a\" d=\"M 3009 3897 \n",
       "L 1888 3291 \n",
       "L 3009 2681 \n",
       "L 2828 2375 \n",
       "L 1778 3009 \n",
       "L 1778 1831 \n",
       "L 1422 1831 \n",
       "L 1422 3009 \n",
       "L 372 2375 \n",
       "L 191 2681 \n",
       "L 1313 3291 \n",
       "L 191 3897 \n",
       "L 372 4206 \n",
       "L 1422 3572 \n",
       "L 1422 4750 \n",
       "L 1778 4750 \n",
       "L 1778 3572 \n",
       "L 2828 4206 \n",
       "L 3009 3897 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-35\" d=\"M 266 1200 \n",
       "L 856 1250 \n",
       "Q 922 819 1161 601 \n",
       "Q 1400 384 1738 384 \n",
       "Q 2144 384 2425 690 \n",
       "Q 2706 997 2706 1503 \n",
       "Q 2706 1984 2436 2262 \n",
       "Q 2166 2541 1728 2541 \n",
       "Q 1456 2541 1237 2417 \n",
       "Q 1019 2294 894 2097 \n",
       "L 366 2166 \n",
       "L 809 4519 \n",
       "L 3088 4519 \n",
       "L 3088 3981 \n",
       "L 1259 3981 \n",
       "L 1013 2750 \n",
       "Q 1425 3038 1878 3038 \n",
       "Q 2478 3038 2890 2622 \n",
       "Q 3303 2206 3303 1553 \n",
       "Q 3303 931 2941 478 \n",
       "Q 2500 -78 1738 -78 \n",
       "Q 1113 -78 717 272 \n",
       "Q 322 622 266 1200 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-25\" d=\"M 372 3481 \n",
       "Q 372 3972 619 4315 \n",
       "Q 866 4659 1334 4659 \n",
       "Q 1766 4659 2048 4351 \n",
       "Q 2331 4044 2331 3447 \n",
       "Q 2331 2866 2045 2552 \n",
       "Q 1759 2238 1341 2238 \n",
       "Q 925 2238 648 2547 \n",
       "Q 372 2856 372 3481 \n",
       "z\n",
       "M 1350 4272 \n",
       "Q 1141 4272 1002 4090 \n",
       "Q 863 3909 863 3425 \n",
       "Q 863 2984 1003 2804 \n",
       "Q 1144 2625 1350 2625 \n",
       "Q 1563 2625 1702 2806 \n",
       "Q 1841 2988 1841 3469 \n",
       "Q 1841 3913 1700 4092 \n",
       "Q 1559 4272 1350 4272 \n",
       "z\n",
       "M 1353 -169 \n",
       "L 3859 4659 \n",
       "L 4316 4659 \n",
       "L 1819 -169 \n",
       "L 1353 -169 \n",
       "z\n",
       "M 3334 1075 \n",
       "Q 3334 1569 3581 1911 \n",
       "Q 3828 2253 4300 2253 \n",
       "Q 4731 2253 5014 1945 \n",
       "Q 5297 1638 5297 1041 \n",
       "Q 5297 459 5011 145 \n",
       "Q 4725 -169 4303 -169 \n",
       "Q 3888 -169 3611 142 \n",
       "Q 3334 453 3334 1075 \n",
       "z\n",
       "M 4316 1866 \n",
       "Q 4103 1866 3964 1684 \n",
       "Q 3825 1503 3825 1019 \n",
       "Q 3825 581 3965 400 \n",
       "Q 4106 219 4313 219 \n",
       "Q 4528 219 4667 400 \n",
       "Q 4806 581 4806 1063 \n",
       "Q 4806 1506 4665 1686 \n",
       "Q 4525 1866 4316 1866 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-64\" d=\"M 2575 0 \n",
       "L 2575 419 \n",
       "Q 2259 -75 1647 -75 \n",
       "Q 1250 -75 917 144 \n",
       "Q 584 363 401 755 \n",
       "Q 219 1147 219 1656 \n",
       "Q 219 2153 384 2558 \n",
       "Q 550 2963 881 3178 \n",
       "Q 1213 3394 1622 3394 \n",
       "Q 1922 3394 2156 3267 \n",
       "Q 2391 3141 2538 2938 \n",
       "L 2538 4581 \n",
       "L 3097 4581 \n",
       "L 3097 0 \n",
       "L 2575 0 \n",
       "z\n",
       "M 797 1656 \n",
       "Q 797 1019 1065 703 \n",
       "Q 1334 388 1700 388 \n",
       "Q 2069 388 2326 689 \n",
       "Q 2584 991 2584 1609 \n",
       "Q 2584 2291 2321 2609 \n",
       "Q 2059 2928 1675 2928 \n",
       "Q 1300 2928 1048 2622 \n",
       "Q 797 2316 797 1656 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-66\" transform=\"translate(0 0.765625)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-28\" transform=\"translate(35.205078 0.765625)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-Bold-78\" transform=\"translate(74.21875 0.765625)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-2a\" transform=\"translate(153.31543 39.046875) scale(0.7)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-29\" transform=\"translate(204.6875 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" transform=\"translate(243.701172 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-39\" transform=\"translate(271.484375 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-35\" transform=\"translate(327.099609 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-25\" transform=\"translate(382.714844 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" transform=\"translate(471.630859 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-70\" transform=\"translate(499.414062 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-72\" transform=\"translate(555.029297 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-65\" transform=\"translate(588.330078 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-64\" transform=\"translate(643.945312 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-2e\" transform=\"translate(699.560547 0.765625)\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"patch_6\">\n",
       "     <path d=\"M 51.1265 263.996125 \n",
       "L 68.7265 263.996125 \n",
       "L 68.7265 257.836125 \n",
       "L 51.1265 257.836125 \n",
       "z\n",
       "\" style=\"fill: #ff7f0e; fill-opacity: 0.5; stroke: #ff7f0e; stroke-opacity: 0.5; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "    </g>\n",
       "    <g id=\"text_20\">\n",
       "     <!-- $y^*$ 95% pred. -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(75.7665 263.996125) scale(0.088 -0.088)\">\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-79\" transform=\"translate(0 0.765625)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-2a\" transform=\"translate(77.283529 39.046875) scale(0.7)\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" transform=\"translate(128.655599 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-39\" transform=\"translate(156.438802 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-35\" transform=\"translate(212.054036 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-25\" transform=\"translate(267.669271 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" transform=\"translate(356.585286 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-70\" transform=\"translate(384.36849 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-72\" transform=\"translate(439.983724 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-65\" transform=\"translate(473.284505 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-64\" transform=\"translate(528.89974 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-2e\" transform=\"translate(584.514974 0.765625)\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"line2d_19\">\n",
       "     <path d=\"M 51.1265 273.463 \n",
       "L 59.9265 273.463 \n",
       "L 68.7265 273.463 \n",
       "\" style=\"fill: none; stroke-dasharray: 7.68,1.92,1.2,1.92; stroke-dashoffset: 0; stroke: #bf00bf; stroke-width: 1.2\"/>\n",
       "    </g>\n",
       "    <g id=\"text_21\">\n",
       "     <!-- True function -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(75.7665 276.543) scale(0.088 -0.088)\">\n",
       "      <defs>\n",
       "       <path id=\"ArialMT-54\" d=\"M 1659 0 \n",
       "L 1659 4041 \n",
       "L 150 4041 \n",
       "L 150 4581 \n",
       "L 3781 4581 \n",
       "L 3781 4041 \n",
       "L 2266 4041 \n",
       "L 2266 0 \n",
       "L 1659 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-75\" d=\"M 2597 0 \n",
       "L 2597 488 \n",
       "Q 2209 -75 1544 -75 \n",
       "Q 1250 -75 995 37 \n",
       "Q 741 150 617 320 \n",
       "Q 494 491 444 738 \n",
       "Q 409 903 409 1263 \n",
       "L 409 3319 \n",
       "L 972 3319 \n",
       "L 972 1478 \n",
       "Q 972 1038 1006 884 \n",
       "Q 1059 663 1231 536 \n",
       "Q 1403 409 1656 409 \n",
       "Q 1909 409 2131 539 \n",
       "Q 2353 669 2445 892 \n",
       "Q 2538 1116 2538 1541 \n",
       "L 2538 3319 \n",
       "L 3100 3319 \n",
       "L 3100 0 \n",
       "L 2597 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-66\" d=\"M 556 0 \n",
       "L 556 2881 \n",
       "L 59 2881 \n",
       "L 59 3319 \n",
       "L 556 3319 \n",
       "L 556 3672 \n",
       "Q 556 4006 616 4169 \n",
       "Q 697 4388 901 4523 \n",
       "Q 1106 4659 1475 4659 \n",
       "Q 1713 4659 2000 4603 \n",
       "L 1916 4113 \n",
       "Q 1741 4144 1584 4144 \n",
       "Q 1328 4144 1222 4034 \n",
       "Q 1116 3925 1116 3625 \n",
       "L 1116 3319 \n",
       "L 1763 3319 \n",
       "L 1763 2881 \n",
       "L 1116 2881 \n",
       "L 1116 0 \n",
       "L 556 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-63\" d=\"M 2588 1216 \n",
       "L 3141 1144 \n",
       "Q 3050 572 2676 248 \n",
       "Q 2303 -75 1759 -75 \n",
       "Q 1078 -75 664 370 \n",
       "Q 250 816 250 1647 \n",
       "Q 250 2184 428 2587 \n",
       "Q 606 2991 970 3192 \n",
       "Q 1334 3394 1763 3394 \n",
       "Q 2303 3394 2647 3120 \n",
       "Q 2991 2847 3088 2344 \n",
       "L 2541 2259 \n",
       "Q 2463 2594 2264 2762 \n",
       "Q 2066 2931 1784 2931 \n",
       "Q 1359 2931 1093 2626 \n",
       "Q 828 2322 828 1663 \n",
       "Q 828 994 1084 691 \n",
       "Q 1341 388 1753 388 \n",
       "Q 2084 388 2306 591 \n",
       "Q 2528 794 2588 1216 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#ArialMT-54\"/>\n",
       "      <use xlink:href=\"#ArialMT-72\" x=\"57.333984\"/>\n",
       "      <use xlink:href=\"#ArialMT-75\" x=\"90.634766\"/>\n",
       "      <use xlink:href=\"#ArialMT-65\" x=\"146.25\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" x=\"201.865234\"/>\n",
       "      <use xlink:href=\"#ArialMT-66\" x=\"229.648438\"/>\n",
       "      <use xlink:href=\"#ArialMT-75\" x=\"257.431641\"/>\n",
       "      <use xlink:href=\"#ArialMT-6e\" x=\"313.046875\"/>\n",
       "      <use xlink:href=\"#ArialMT-63\" x=\"368.662109\"/>\n",
       "      <use xlink:href=\"#ArialMT-74\" x=\"418.662109\"/>\n",
       "      <use xlink:href=\"#ArialMT-69\" x=\"446.445312\"/>\n",
       "      <use xlink:href=\"#ArialMT-6f\" x=\"468.662109\"/>\n",
       "      <use xlink:href=\"#ArialMT-6e\" x=\"524.277344\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "  </g>\n",
       "  <g id=\"axes_2\">\n",
       "   <g id=\"matplotlib.axis_3\">\n",
       "    <g id=\"ytick_8\">\n",
       "     <g id=\"line2d_20\">\n",
       "      <defs>\n",
       "       <path id=\"mc9f030b71c\" d=\"M 0 0 \n",
       "L 4.8 0 \n",
       "\" style=\"stroke: #262626\"/>\n",
       "      </defs>\n",
       "      <g>\n",
       "       <use xlink:href=\"#mc9f030b71c\" x=\"400.3265\" y=\"274.116\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_22\">\n",
       "      <!-- 0.000 -->\n",
       "      <g style=\"fill: #ff7f0e\" transform=\"translate(408.6265 277.265437) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"83.398438\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"139.013672\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"194.628906\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_9\">\n",
       "     <g id=\"line2d_21\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mc9f030b71c\" x=\"400.3265\" y=\"226.866222\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_23\">\n",
       "      <!-- 0.002 -->\n",
       "      <g style=\"fill: #ff7f0e\" transform=\"translate(408.6265 230.01566) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"83.398438\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"139.013672\"/>\n",
       "       <use xlink:href=\"#ArialMT-32\" x=\"194.628906\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_10\">\n",
       "     <g id=\"line2d_22\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mc9f030b71c\" x=\"400.3265\" y=\"179.616445\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_24\">\n",
       "      <!-- 0.004 -->\n",
       "      <g style=\"fill: #ff7f0e\" transform=\"translate(408.6265 182.765882) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"83.398438\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"139.013672\"/>\n",
       "       <use xlink:href=\"#ArialMT-34\" x=\"194.628906\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_11\">\n",
       "     <g id=\"line2d_23\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mc9f030b71c\" x=\"400.3265\" y=\"132.366667\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_25\">\n",
       "      <!-- 0.006 -->\n",
       "      <g style=\"fill: #ff7f0e\" transform=\"translate(408.6265 135.516104) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"83.398438\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"139.013672\"/>\n",
       "       <use xlink:href=\"#ArialMT-36\" x=\"194.628906\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_12\">\n",
       "     <g id=\"line2d_24\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mc9f030b71c\" x=\"400.3265\" y=\"85.116889\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_26\">\n",
       "      <!-- 0.008 -->\n",
       "      <g style=\"fill: #ff7f0e\" transform=\"translate(408.6265 88.266327) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"83.398438\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"139.013672\"/>\n",
       "       <use xlink:href=\"#ArialMT-38\" x=\"194.628906\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_13\">\n",
       "     <g id=\"line2d_25\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mc9f030b71c\" x=\"400.3265\" y=\"37.867111\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_27\">\n",
       "      <!-- 0.010 -->\n",
       "      <g style=\"fill: #ff7f0e\" transform=\"translate(408.6265 41.016549) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"83.398438\"/>\n",
       "       <use xlink:href=\"#ArialMT-31\" x=\"139.013672\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"194.628906\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"text_28\">\n",
       "     <!-- Information Acquisition Function -->\n",
       "     <g style=\"fill: #ff7f0e\" transform=\"translate(441.63425 221.18925) rotate(-90) scale(0.096 -0.096)\">\n",
       "      <defs>\n",
       "       <path id=\"ArialMT-49\" d=\"M 597 0 \n",
       "L 597 4581 \n",
       "L 1203 4581 \n",
       "L 1203 0 \n",
       "L 597 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-6d\" d=\"M 422 0 \n",
       "L 422 3319 \n",
       "L 925 3319 \n",
       "L 925 2853 \n",
       "Q 1081 3097 1340 3245 \n",
       "Q 1600 3394 1931 3394 \n",
       "Q 2300 3394 2536 3241 \n",
       "Q 2772 3088 2869 2813 \n",
       "Q 3263 3394 3894 3394 \n",
       "Q 4388 3394 4653 3120 \n",
       "Q 4919 2847 4919 2278 \n",
       "L 4919 0 \n",
       "L 4359 0 \n",
       "L 4359 2091 \n",
       "Q 4359 2428 4304 2576 \n",
       "Q 4250 2725 4106 2815 \n",
       "Q 3963 2906 3769 2906 \n",
       "Q 3419 2906 3187 2673 \n",
       "Q 2956 2441 2956 1928 \n",
       "L 2956 0 \n",
       "L 2394 0 \n",
       "L 2394 2156 \n",
       "Q 2394 2531 2256 2718 \n",
       "Q 2119 2906 1806 2906 \n",
       "Q 1569 2906 1367 2781 \n",
       "Q 1166 2656 1075 2415 \n",
       "Q 984 2175 984 1722 \n",
       "L 984 0 \n",
       "L 422 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-41\" d=\"M -9 0 \n",
       "L 1750 4581 \n",
       "L 2403 4581 \n",
       "L 4278 0 \n",
       "L 3588 0 \n",
       "L 3053 1388 \n",
       "L 1138 1388 \n",
       "L 634 0 \n",
       "L -9 0 \n",
       "z\n",
       "M 1313 1881 \n",
       "L 2866 1881 \n",
       "L 2388 3150 \n",
       "Q 2169 3728 2063 4100 \n",
       "Q 1975 3659 1816 3225 \n",
       "L 1313 1881 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-71\" d=\"M 2538 -1272 \n",
       "L 2538 353 \n",
       "Q 2406 169 2170 47 \n",
       "Q 1934 -75 1669 -75 \n",
       "Q 1078 -75 651 397 \n",
       "Q 225 869 225 1691 \n",
       "Q 225 2191 398 2587 \n",
       "Q 572 2984 901 3189 \n",
       "Q 1231 3394 1625 3394 \n",
       "Q 2241 3394 2594 2875 \n",
       "L 2594 3319 \n",
       "L 3100 3319 \n",
       "L 3100 -1272 \n",
       "L 2538 -1272 \n",
       "z\n",
       "M 803 1669 \n",
       "Q 803 1028 1072 708 \n",
       "Q 1341 388 1716 388 \n",
       "Q 2075 388 2334 692 \n",
       "Q 2594 997 2594 1619 \n",
       "Q 2594 2281 2320 2615 \n",
       "Q 2047 2950 1678 2950 \n",
       "Q 1313 2950 1058 2639 \n",
       "Q 803 2328 803 1669 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-46\" d=\"M 525 0 \n",
       "L 525 4581 \n",
       "L 3616 4581 \n",
       "L 3616 4041 \n",
       "L 1131 4041 \n",
       "L 1131 2622 \n",
       "L 3281 2622 \n",
       "L 3281 2081 \n",
       "L 1131 2081 \n",
       "L 1131 0 \n",
       "L 525 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#ArialMT-49\"/>\n",
       "      <use xlink:href=\"#ArialMT-6e\" x=\"27.783203\"/>\n",
       "      <use xlink:href=\"#ArialMT-66\" x=\"83.398438\"/>\n",
       "      <use xlink:href=\"#ArialMT-6f\" x=\"111.181641\"/>\n",
       "      <use xlink:href=\"#ArialMT-72\" x=\"166.796875\"/>\n",
       "      <use xlink:href=\"#ArialMT-6d\" x=\"200.097656\"/>\n",
       "      <use xlink:href=\"#ArialMT-61\" x=\"283.398438\"/>\n",
       "      <use xlink:href=\"#ArialMT-74\" x=\"339.013672\"/>\n",
       "      <use xlink:href=\"#ArialMT-69\" x=\"366.796875\"/>\n",
       "      <use xlink:href=\"#ArialMT-6f\" x=\"389.013672\"/>\n",
       "      <use xlink:href=\"#ArialMT-6e\" x=\"444.628906\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" x=\"500.244141\"/>\n",
       "      <use xlink:href=\"#ArialMT-41\" x=\"522.527344\"/>\n",
       "      <use xlink:href=\"#ArialMT-63\" x=\"589.226562\"/>\n",
       "      <use xlink:href=\"#ArialMT-71\" x=\"639.226562\"/>\n",
       "      <use xlink:href=\"#ArialMT-75\" x=\"694.841797\"/>\n",
       "      <use xlink:href=\"#ArialMT-69\" x=\"750.457031\"/>\n",
       "      <use xlink:href=\"#ArialMT-73\" x=\"772.673828\"/>\n",
       "      <use xlink:href=\"#ArialMT-69\" x=\"822.673828\"/>\n",
       "      <use xlink:href=\"#ArialMT-74\" x=\"844.890625\"/>\n",
       "      <use xlink:href=\"#ArialMT-69\" x=\"872.673828\"/>\n",
       "      <use xlink:href=\"#ArialMT-6f\" x=\"894.890625\"/>\n",
       "      <use xlink:href=\"#ArialMT-6e\" x=\"950.505859\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" x=\"1006.121094\"/>\n",
       "      <use xlink:href=\"#ArialMT-46\" x=\"1033.904297\"/>\n",
       "      <use xlink:href=\"#ArialMT-75\" x=\"1094.988281\"/>\n",
       "      <use xlink:href=\"#ArialMT-6e\" x=\"1150.603516\"/>\n",
       "      <use xlink:href=\"#ArialMT-63\" x=\"1206.21875\"/>\n",
       "      <use xlink:href=\"#ArialMT-74\" x=\"1256.21875\"/>\n",
       "      <use xlink:href=\"#ArialMT-69\" x=\"1284.001953\"/>\n",
       "      <use xlink:href=\"#ArialMT-6f\" x=\"1306.21875\"/>\n",
       "      <use xlink:href=\"#ArialMT-6e\" x=\"1361.833984\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"line2d_26\">\n",
       "    <path d=\"M 59.439227 274.116 \n",
       "L 62.718566 274.116 \n",
       "L 65.997905 274.116 \n",
       "L 69.277244 274.116 \n",
       "L 72.556583 274.116 \n",
       "L 75.835921 274.116 \n",
       "L 79.115261 274.116 \n",
       "L 82.394598 274.116 \n",
       "L 85.673938 274.116 \n",
       "L 88.953278 274.116 \n",
       "L 92.232615 274.116 \n",
       "L 95.511955 274.116 \n",
       "L 98.791295 274.116 \n",
       "L 102.070632 274.116 \n",
       "L 105.349969 274.116 \n",
       "L 108.629311 274.116 \n",
       "L 111.908649 274.116 \n",
       "L 115.187986 274.116 \n",
       "L 118.467328 274.115296 \n",
       "L 121.746666 274.104735 \n",
       "L 125.026003 273.945613 \n",
       "L 128.305345 271.866475 \n",
       "L 131.584682 254.549713 \n",
       "L 134.86402 182.328356 \n",
       "L 138.143362 60.326675 \n",
       "L 141.422694 32.196 \n",
       "L 144.702037 138.249643 \n",
       "L 147.981379 231.207463 \n",
       "L 151.260711 263.801983 \n",
       "L 154.540053 271.401081 \n",
       "L 157.819395 273.098609 \n",
       "L 161.098728 273.532321 \n",
       "L 164.37807 273.630891 \n",
       "L 167.657412 273.597096 \n",
       "L 170.936745 273.483739 \n",
       "L 174.216087 273.316873 \n",
       "L 177.495429 273.138038 \n",
       "L 180.774762 273.003559 \n",
       "L 184.054104 272.973988 \n",
       "L 187.333446 273.081712 \n",
       "L 190.612778 273.308424 \n",
       "L 193.892121 273.586534 \n",
       "L 197.171463 273.836482 \n",
       "L 200.450795 274.003348 \n",
       "L 203.730137 274.084317 \n",
       "L 207.00948 274.110367 \n",
       "L 210.288812 274.115296 \n",
       "L 213.568154 274.116 \n",
       "L 216.847496 274.116 \n",
       "L 220.126829 274.116 \n",
       "L 223.406181 274.116 \n",
       "L 226.685504 274.116 \n",
       "L 229.964846 274.116 \n",
       "L 233.244188 274.116 \n",
       "L 236.523511 274.116 \n",
       "L 239.802872 274.116 \n",
       "L 243.082195 274.116 \n",
       "L 246.361537 274.116 \n",
       "L 249.640879 274.116 \n",
       "L 252.920222 274.116 \n",
       "L 256.199564 274.116 \n",
       "L 259.478887 274.116 \n",
       "L 262.758248 274.116 \n",
       "L 266.037571 274.116 \n",
       "L 269.316913 274.116 \n",
       "L 272.596255 274.116 \n",
       "L 275.875578 274.116 \n",
       "L 279.15494 274.116 \n",
       "L 282.434262 274.116 \n",
       "L 285.713605 274.116 \n",
       "L 288.992947 274.116 \n",
       "L 292.272289 274.116 \n",
       "L 295.551631 274.116 \n",
       "L 298.830954 274.116 \n",
       "L 302.110315 274.116 \n",
       "L 305.389638 274.116 \n",
       "L 308.66898 274.116 \n",
       "L 311.948322 274.116 \n",
       "L 315.227645 274.116 \n",
       "L 318.507007 274.116 \n",
       "L 321.78633 274.116 \n",
       "L 325.065672 274.116 \n",
       "L 328.345014 274.116 \n",
       "L 331.624356 274.116 \n",
       "L 334.903698 274.116 \n",
       "L 338.183021 274.116 \n",
       "L 341.462363 274.116 \n",
       "L 344.741705 274.116 \n",
       "L 348.021048 274.116 \n",
       "L 351.30039 274.116 \n",
       "L 354.579713 274.116 \n",
       "L 357.859055 274.116 \n",
       "L 361.138397 274.116 \n",
       "L 364.417739 274.116 \n",
       "L 367.697081 274.116 \n",
       "L 370.976423 274.116 \n",
       "L 374.255766 274.116 \n",
       "L 377.535088 274.116 \n",
       "L 380.814431 274.116 \n",
       "L 384.093773 274.116 \n",
       "\" clip-path=\"url(#pb9361a8952)\" style=\"fill: none; stroke: #ff7f0e; stroke-width: 1.2; stroke-linecap: round\"/>\n",
       "   </g>\n",
       "   <g id=\"line2d_27\">\n",
       "    <path d=\"M 141.422694 274.116 \n",
       "L 141.422694 271.672364 \n",
       "L 141.422694 269.228727 \n",
       "L 141.422694 266.785091 \n",
       "L 141.422694 264.341454 \n",
       "L 141.422694 261.897819 \n",
       "L 141.422694 259.454182 \n",
       "L 141.422694 257.010545 \n",
       "L 141.422694 254.566909 \n",
       "L 141.422694 252.123272 \n",
       "L 141.422694 249.679637 \n",
       "L 141.422694 247.235999 \n",
       "L 141.422694 244.792364 \n",
       "L 141.422694 242.348726 \n",
       "L 141.422694 239.905091 \n",
       "L 141.422694 237.461453 \n",
       "L 141.422694 235.017818 \n",
       "L 141.422694 232.574182 \n",
       "L 141.422694 230.130544 \n",
       "L 141.422694 227.686909 \n",
       "L 141.422694 225.243274 \n",
       "L 141.422694 222.799633 \n",
       "L 141.422694 220.355998 \n",
       "L 141.422694 217.912363 \n",
       "L 141.422694 215.468728 \n",
       "L 141.422694 213.025093 \n",
       "L 141.422694 210.581452 \n",
       "L 141.422694 208.137817 \n",
       "L 141.422694 205.694181 \n",
       "L 141.422694 203.250546 \n",
       "L 141.422694 200.806906 \n",
       "L 141.422694 198.36327 \n",
       "L 141.422694 195.919635 \n",
       "L 141.422694 193.476 \n",
       "L 141.422694 191.032365 \n",
       "L 141.422694 188.588724 \n",
       "L 141.422694 186.145089 \n",
       "L 141.422694 183.701454 \n",
       "L 141.422694 181.257819 \n",
       "L 141.422694 178.814178 \n",
       "L 141.422694 176.370548 \n",
       "L 141.422694 173.926907 \n",
       "L 141.422694 171.483267 \n",
       "L 141.422694 169.039637 \n",
       "L 141.422694 166.595996 \n",
       "L 141.422694 164.152367 \n",
       "L 141.422694 161.708726 \n",
       "L 141.422694 159.265085 \n",
       "L 141.422694 156.821456 \n",
       "L 141.422694 154.377815 \n",
       "L 141.422694 151.934185 \n",
       "L 141.422694 149.490544 \n",
       "L 141.422694 147.046915 \n",
       "L 141.422694 144.603274 \n",
       "L 141.422694 142.159633 \n",
       "L 141.422694 139.716004 \n",
       "L 141.422694 137.272363 \n",
       "L 141.422694 134.828733 \n",
       "L 141.422694 132.385093 \n",
       "L 141.422694 129.941452 \n",
       "L 141.422694 127.497822 \n",
       "L 141.422694 125.054181 \n",
       "L 141.422694 122.610541 \n",
       "L 141.422694 120.166911 \n",
       "L 141.422694 117.723281 \n",
       "L 141.422694 115.27963 \n",
       "L 141.422694 112.836 \n",
       "L 141.422694 110.39237 \n",
       "L 141.422694 107.94873 \n",
       "L 141.422694 105.505089 \n",
       "L 141.422694 103.061459 \n",
       "L 141.422694 100.617819 \n",
       "L 141.422694 98.174178 \n",
       "L 141.422694 95.730548 \n",
       "L 141.422694 93.286907 \n",
       "L 141.422694 90.843267 \n",
       "L 141.422694 88.399637 \n",
       "L 141.422694 85.956007 \n",
       "L 141.422694 83.512356 \n",
       "L 141.422694 81.068726 \n",
       "L 141.422694 78.625096 \n",
       "L 141.422694 76.181467 \n",
       "L 141.422694 73.737815 \n",
       "L 141.422694 71.294185 \n",
       "L 141.422694 68.850555 \n",
       "L 141.422694 66.406904 \n",
       "L 141.422694 63.963274 \n",
       "L 141.422694 61.519644 \n",
       "L 141.422694 59.075993 \n",
       "L 141.422694 56.632363 \n",
       "L 141.422694 54.188733 \n",
       "L 141.422694 51.745082 \n",
       "L 141.422694 49.301452 \n",
       "L 141.422694 46.857822 \n",
       "L 141.422694 44.414192 \n",
       "L 141.422694 41.970541 \n",
       "L 141.422694 39.526911 \n",
       "L 141.422694 37.083281 \n",
       "L 141.422694 34.63963 \n",
       "L 141.422694 32.196 \n",
       "\" clip-path=\"url(#pb9361a8952)\" style=\"fill: none; stroke: #ff7f0e; stroke-linecap: round\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_7\">\n",
       "    <path d=\"M 43.2065 286.212 \n",
       "L 43.2065 20.1 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_8\">\n",
       "    <path d=\"M 400.3265 286.212 \n",
       "L 400.3265 20.1 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_9\">\n",
       "    <path d=\"M 43.2065 286.212 \n",
       "L 400.3265 286.212 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_10\">\n",
       "    <path d=\"M 43.2065 20.1 \n",
       "L 400.3265 20.1 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "  </g>\n",
       " </g>\n",
       " <defs>\n",
       "  <clipPath id=\"pb9361a8952\">\n",
       "   <rect x=\"43.2065\" y=\"20.1\" width=\"357.12\" height=\"266.112\"/>\n",
       "  </clipPath>\n",
       " </defs>\n",
       "</svg>\n"
      ],
      "text/plain": [
       "<Figure size 640x480 with 2 Axes>"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    }
   ],
   "source": [
    "train_x = torch.from_numpy(X).float()\n",
    "train_y = torch.from_numpy(Y).float()\n",
    "covar_module = ScaleKernel(RBFKernel())\n",
    "model = ExactGP(train_x, train_y)\n",
    "\n",
    "# It is not a good idea to train the model when we don't have enough data\n",
    "# So we fix the hyperparameters to something reasonable\n",
    "model.covar_module.base_kernel.lengthscale = 0.15\n",
    "model.covar_module.outputscale = 4.0\n",
    "model.likelihood.noise = 1e-2\n",
    "model.eval()\n",
    "\n",
    "# Run the algorithm\n",
    "X_design = torch.linspace(0, 1, 100)\n",
    "af_all = maximize(\n",
    "    f,\n",
    "    model,\n",
    "    X_design,\n",
    "    poi,\n",
    "    alpha_params=dict(psi=0.1),\n",
    "    max_it=10,\n",
    "    plot=1\n",
    ")"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "### Questions\n",
    "\n",
    "+ Repeat the main algorithm using POI for a $\\psi$ that exploits. Does the method converge?\n",
    "+ Repeat the main algorithm using POI for a $\\psi$ that explores. Does the method converge?"
   ]
  }
 ],
 "metadata": {
  "celltoolbar": "Tags",
  "kernelspec": {
   "display_name": "Python 3 (ipykernel)",
   "language": "python",
   "name": "python3"
  },
  "language_info": {
   "codemirror_mode": {
    "name": "ipython",
    "version": 3
   },
   "file_extension": ".py",
   "mimetype": "text/x-python",
   "name": "python",
   "nbconvert_exporter": "python",
   "pygments_lexer": "ipython3",
   "version": "3.11.6"
  }
 },
 "nbformat": 4,
 "nbformat_minor": 4
}
